 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---CHAPTER 10: Mixed Model Diagnostics              ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 10.2 Cultivar-Inoculation Trial         ---*/
data cultspd;
   input block cult$ inoc$ drywt;
   datalines;
1 a con 27.4
1 a dea 29.7
1 a liv 34.5
1 b con 29.4
1 b dea 32.5
1 b liv 34.4
2 a con 28.9
2 a dea 28.7
2 a liv 33.4
2 b con 28.7
2 b dea 32.4
2 b liv 36.4
3 a con 28.6
3 a dea 29.7
3 a liv 32.9
3 b con 27.2
3 b dea 29.1
3 b liv 32.6
4 a con 26.7
4 a dea 28.9
4 a liv 31.8
4 b con 26.8
4 b dea 28.6
4 b liv 30.7
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 10.1                                      ---*/
 /*---Figure 10.1                                      ---*/
 /*---Figure 10.2                                      ---*/
ods html;
ods graphics on;
proc glimmix data=cultspd
      plots=(studentpanel(type=noblup)
             studentpanel(type=blup));
   class block cult inoc;
   model drywt = cult inoc cult*inoc / ddfm=satterth;
   random block block*cult;
   ods select FitStatistics CovParms Tests3 StudentPanel;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 10.2                                      ---*/
proc glimmix data=cultspd;
   class block cult inoc;
   model drywt = cult inoc cult*inoc / ddfm=satterth;
   random block block*cult;
   output out=gmxout student(blup)  = resid_cond
                     student(noblup)= resid_marg;
run;
proc means data=gmxout min max mean;
   var resid_cond resid_marg;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 10.3                                      ---*/
ods html;
ods graphics on;
proc glimmix data=cultspd plots=studentpanel(type=noblup);
   class block cult inoc;
   model drywt = block cult block*cult 
                 inoc cult*inoc / ddfm=satterth;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 5.4, Heart Rates                        ---*/
 /*---These data are revisited in Section 10.4         ---*/
data hr;
   input patient drug$ basehr hr1 hr5 hr15 hr30 hr1h;
   array hra{5} hr1 hr5 hr15 hr30 hr1h;
   do i = 1 to 5;
      if (i = 1) then hours = 1/60;
      else if (i = 2) then hours = 5/60;
      else if (i = 3) then hours = 15/60;
      else if (i = 4) then hours = 30/60;
      else hours = 1;
      hours1 = hours;
      hr = hra{i};
      output;
   end;
   drop i hr1 hr5 hr15 hr30 hr1h;
   datalines;
201  p    92   76   84   88   96   84 
202  b    54   58   60   60   60   64 
203  p    84   86   82   84   86   82 
204  a    72   72   68   68   78   72 
205  b    80   84   84   96   92   72 
206  p    68   72   68   68   64   62 
207  a   100  104  100   92   92   68 
208  a    60   60   58   56   50   56 
209  a    88  104   88   88   78   84 
210  b    92   82   82   76   82   80 
211  b    88   80   84   80   80   78 
212  p   102   86   86   96   86   88 
214  a    84   92  100   88   88   80 
215  b   104  100   96   88   92   84 
216  a    92   80   72   64   68   64 
217  p    92   88   84   76   88   84 
218  a    72   84   78   80   80   76 
219  b    72  100   92   84   88   80 
220  p    80   80   80   78   80   78 
221  p    72   68   76   72   72   68 
222  b    88   88   98   98   96   88 
223  b    88   88   96   88   88   80 
224  p    88   78   84   64   68   64 
232  a    78   72   72   78   80   68 
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 10.3                                      ---*/
 /*---Figure 10.4                                      ---*/
 /*---Figure 10.5                                      ---*/
 /*---Figure 10.6                                      ---*/
 /*---Figure 10.7                                      ---*/
 /*---Figure 10.8                                      ---*/
ods html;
ods graphics on;
proc mixed data=hr order=data;
   class drug hours patient;
   model hr = drug basehr / noint s residual
              influence(iter=5 effect=patient est);
   repeated hours / type=sp(exp)(hours1) sub=patient;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 10.9                                      ---*/
 /*---Figure 10.10                                     ---*/
 /*---Figure 10.11                                     ---*/
ods html file="test.html";
ods graphics on;
proc mixed data=hr order=data;
   class drug hours patient;
   model hr = drug hours drug*hours basehr / s
              residual
              influence(iter=5 effect=patient);
   repeated hours / type=sp(exp)(hours) sub=patient;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/


