 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---CHAPTER 12: Power Calculations for Mixed Models  ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 4.7 Mouse Condition--Diet Experiment    ---*/
data mice;
  input cage condition diet $ gain;
  datalines;
1   1   normal    58
1   1   restrict    58
1   1   suppleme    58
1   2   normal      54
1   2   restrict    46
1   2   suppleme    57
2   1   normal      49
2   1   restrict    50
2   1   suppleme    57
2   3   normal      57
2   3   restrict    53
2   3   suppleme    62
3   1   normal      59
3   1   restrict    58
3   1   suppleme    57
3   4   normal      63
3   4   restrict    61
3   4   suppleme    65
4   2   normal      57
4   2   restrict    64
4   2   suppleme    52
4   3   normal      63
4   3   restrict    67
4   3   suppleme    51
5   2   normal      53
5   2   restrict    46
5   2   suppleme    51
5   4   normal      58
5   4   restrict    52
5   4   suppleme    61
6   3   normal      65
6   3   restrict    64
6   3   suppleme    54
6   4   normal      59
6   4   restrict    47
6   4   suppleme    73
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 12.1                                      ---*/
proc mixed data=mice nobound cl;
   class cage condition diet;
   model gain= condition|diet / solution ddfm=satterth;
   random cage cage*condition;
   ods output tests3=t3;
run;

data f_power; 
   set t3; 
   Noncen = NumDF*FValue; 
   Alpha  = 0.05; 
   FCrit  = finv(1-Alpha,NumDF,DenDF,0); 
   Power  = 1 - probf(FCrit,NumDF,DenDF,Noncen); 
run; 

proc print data=f_power; 
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 12.2                                      ---*/
data mice1;
   set mice;
   cage = cage + 6;
data mice2;
   set mice mice1;
run;

proc mixed data=mice2 nobound cl;
   class cage condition diet;
   model gain=condition|diet / ddfm=satterth;
   random cage cage*condition;
   ods select Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 12.3                                      ---*/
proc mixed data=mice nobound cl;
   class cage condition diet;
   model gain = condition|diet / ddf=11.9,40,40;
   random cage cage*condition;
   ods output tests3=t3;
run;

data f_power2; 
   set t3; 
   Alpha  = 0.05; 
   Noncen = NumDF*FValue; 
   FCrit  = finv(1-Alpha,NumDF,DenDF,0); 
   Power  = 1 - probf(FCrit,NumDF,DenDF,Noncen); 
run; 

proc print data=f_power2; 
run;  
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 12.1                                      ---*/
%macro MixedTPower;

  * run proc mixed;
  proc mixed data=&InData &ProcMixedOptions;
    &ProcMixedStatements
    ods output estimates=ests;
  run;

  libname OutLib "&OutPath";

  * compute power curves for each difference
    using a noncentral t-distribution;
  data OutLib.MixedPower;
    set ests;
    do alpha = &AlphaValues;
       do effectsize = &EffectSizes;
          tcrit  = tinv(1-alpha/2,df);
          noncen = effectsize/stderr;
          power  = sum(1, -cdf("t", tcrit,df,noncen),
		                       cdf("t",-tcrit,df,noncen));
          output;
		    end;	
      end;
  run;

  * create JMP scripting code;
  filename jslfile "&OutPath.mixedtpower.jsl";

  data _null_;
     file jslfile;
     put "%str(data=open(%".\MixedPower.sas7bdat%");)";
     put " ";
     put "Overlay Plot(X( :effectsize), Y( :power), 
          Grouping(  :Label,  :alpha),";
     put "Connect Thru Missing(1));";
   run;

%mend MixedTPower;

%let InData = mice; 
%let ProcMixedStatements= 
%str(
   class cage condition diet;
   model gain = condition|diet / ddfm=satterth;
   random cage cage*condition;
   estimate "est1: condition 2-1" condition -1 1 0 0;
   estimate "est2: diet restrict-normal" diet -1 1 0;
   estimate "est3: condition*diet 1 restr-nor"
                   diet -1 1 0  
                   condition*diet -1 1 0 0 0 0 0 0 0 0 0 0; 
); 
%let ProcMixedOptions = nobound; 
%let AlphaValues = 0.05; 
%let EffectSizes = 0 to 10 by 0.5;
%let OutPath = C:\temp\; 

%MixedTPower;

data power; set outlib.mixedpower;
  symbol = substr(label,4,1)+0;
run;
goptions reset=all hsize=9in vsize=8in;
symbol1 color=black value=none i=join l=1  r=1 w=2;
symbol2 color=black value=none i=join l=2  r=1 w=2;
symbol3 color=black value=none i=join l=21 r=1 w=2;
axis1 minor =none
      order =(0 to 1 by 0.1)
      label =(font='Arial Black' Height=1.5 angle=90 'Power')
      offset=(0.3in,0.3in)
      value =(font='Arial Black' Height=1.3);
axis2 minor =none
      order =(-2 to 12 by 2)
      label =(font='Arial Black' Height=1.5 'Effect Size')    
      offset=(0.3in,0.3in)
      value =(font='Arial Black' Height=1.3);
legend1 across  =1
        cborder =black
        mode    =protect
        position=(top left inside)
        label   = none
        value   =(font='Arial Black' Height=2
                       'Condition 2-1'
                       'Diet restrict-normal'
                       'Condition*diet 1 restr-nor');

proc gplot data=power;
   plot power*effectsize=symbol / 
               noframe 
               vaxis=axis1 haxis=axis2
               legend=legend1;
run;
quit;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 12.4                                      ---*/
 /*---Output 12.5                                      ---*/
data layout;
  do row=1 to 8;
      do col=1 to 8;
         output;
      end;
  end;
run;

/*---design option 1, 16 trts, 4 blocks, no randomization---*/
data td;
   input trt @@;
   datalines;
 1  2  3  4  5  6  7  8
 9 10 11 12 13 14 15 16
 1  2  3  4  5  6  7  8
 9 10 11 12 13 14 15 16
 1  2  3  4  5  6  7  8
 9 10 11 12 13 14 15 16
 1  2  3  4  5  6  7  8
 9 10 11 12 13 14 15 16
;

/*---specify treatment effects as the data---*/
data design1;
   merge layout td;
   mu=-6*(trt=1)-2*(trt>1 and trt<5)+3*(trt>12);
run;

proc mixed noprofile;
   class trt;
   model mu=trt/ddf=48;
   parms (16) (3) /noiter;
   repeated / subject=intercept type=sp(sph)(row col);
   lsmeans trt/diff;
   contrast '1 vs 2' trt 1 -1 0;
   contrast '1 vs 4' trt 1 0 0 -1 0;
   contrast '1 vs 5' trt 1 0 0 0 -1 0;
   contrast '1 vs 10' trt 1 0 0 0 0 0 0 0 0 -1 0;
   contrast '1 vs 13' trt 1 0 0 0 0 0 0 0 0 0 0 0 -1 0;
   contrast '1 vs 16' trt 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 -1;
   ods output diffs=trtdiff contrasts=b;
run;

proc means data=trtdiff;
   var estimate;
run;

data power1;
   set b;
   alpha=0.05;
   ncparm=fvalue;
   fcrit=finv(1-alpha,numdf,dendf,0);
   power=1-probf(fcrit,numdf,dendf,ncparm);
run;

 /*---Output 12.4---*/
proc print;
   var label numdf dendf alpha ncparm fcrit power;
run;


/*---design option 2; layout from Cochran & Cox, Experimental Designs, plan 10.2
 4x4 lattice incomplete block design---*/

data td;
  input trt @@;
  datalines;
 1  2  3  4  1  5  9 13
 5  6  7  8  2  6 10 14
 9 10 11 12  3  7 11 15
13 14 15 16  4  8 12 16
 1  6 11 16  1  8 11 14
 2  7 12 13  2  5 12 15
 3  8  9 14  3  6  9 16
 4  5 10 15  4  7 10 13
;

data design2;
   merge layout td;
   mu=-6*(trt=1)-2*(trt>1 and trt<5)+3*(trt>12);
run;

proc mixed noprofile;
   class trt;
   model mu=trt/ddf=48;
   parms (16) (3) /noiter;
   repeated / subject=intercept type=sp(sph)(row col);
   lsmeans trt/diff;
   contrast '1 vs 2' trt 1 -1 0;
   contrast '1 vs 4' trt 1 0 0 -1 0;
   contrast '1 vs 5' trt 1 0 0 0 -1 0;
   contrast '1 vs 10' trt 1 0 0 0 0 0 0 0 0 -1 0;
   contrast '1 vs 13' trt 1 0 0 0 0 0 0 0 0 0 0 0 -1 0;
   contrast '1 vs 16' trt 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 -1;
   ods output diffs=trtdiff contrasts=b;
run;
 
proc means data=trtdiff;
   var estimate;
run;

data power2;
   set b;
   alpha=0.05;
   ncparm=fvalue;
   fcrit=finv(1-alpha,numdf,dendf,0);
   power=1-probf(fcrit,numdf,dendf,ncparm);
run;
 /*---Output 12.5---*/
proc print;
   var label numdf dendf alpha ncparm fcrit power;
run;
 /*-------------------------------------------------------*/ 


 /*-------------------------------------------------------*/
 /*---Output 12.6                                      ---*/
/*---simulate noise structure from the mice data, IML is used 
     in order to accommodate the negative variance component---*/

%let seed      = 71853048;
%let var_cage  = 5.03;
%let var_cc    = -6.24;
%let var_resid = 31.56; 
%let nsim      = 1000;

proc iml;
   cov = &var_cc * j(3,3) + &var_resid * i(3);
   covh = half(cov)`;
   print cov covh;
run;
				
data noise;
   retain i j;
   do sim = 1 to &nsim;
      i = 1;
      j = 2;
      do cage = 1 to 6;
         u_cage = sqrt(&var_cage) * rannor(&seed);
         do condition = i,j;
            e1 = rannor(&seed);
            e2 = rannor(&seed);
            e3 = rannor(&seed);
            diet = "normal  ";
            noise = u_cage + 5.0318983*e1;
            output;
            diet = "restrict";
            noise = u_cage - 1.240089*e1 + 4.8766977*e2;
            output;
            diet = "suppleme";
            noise = u_cage - 1.240089*e1 - 1.594895*e2 + 4.6085237*e3;
            output;	
         end;
         j = j + 1;
         if (j = 5) then do;
            i = i + 1;
            j = i + 1;
         end;
      end;
   end;
run;

ods exclude all;
ods noresults;

proc mixed data=noise nobound;
   by sim;
   class cage condition diet;
   model noise=condition|diet;
   random cage cage*condition;
   parms &var_cage &var_cc &var_resid;
   ods output covparms=cpsim tests3=t3sim;
run;

ods exclude none;
ods results;

proc sort data=cpsim;
   by covparm;
run;

proc means data=cpsim;
   by covparm;
   var estimate;
run;

data t3sim;
   set t3sim;
   if probf < 0.05 then sig = 1;
   else sig = 0;
proc sort data=t3sim;
   by effect;
proc means data=t3sim mean;
   by effect;
   var sig;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 12.7                                      ---*/
 /*---simulate power under alternative as estimated 
     from the pilot data---*/
proc mixed data=mice nobound;
   class cage condition diet;
   model gain=condition|diet / outpm=opm;
   random cage cage*condition;
run;

data opm1;
   set opm;
   drop gain stderrpred df alpha lower upper resid;
run;

proc sort data=noise;
   by cage condition diet;
run;

data mice_sim;
   merge noise opm1;
   by cage condition diet;
   y = pred + noise;
run;

proc sort data=mice_sim;
   by sim;
run;

ods exclude all;
ods noresults;

proc mixed data=mice_sim nobound;
   by sim;
   class cage condition diet;
   model y = condition|diet / ddf=11.9,40,40;
   random cage cage*condition;
   parms &var_cage &var_cc &var_resid;
   ods output covparms=cpsim tests3=t3sim;
run;

ods exclude none;
ods results;

proc sort data=cpsim;
   by covparm;
run;

proc means data=cpsim;
   by covparm;
   var estimate;
run;

data t3sim;
   set t3sim;
   if probf < 0.05 then sig = 1;
   else sig = 0;
proc sort data=t3sim;
   by effect;
proc means data=t3sim mean;
   by effect;
   var sig;
run;
 /*-------------------------------------------------------*/



