 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---CHAPTER 13: Some Bayesian Approaches to Mixed    ---*/
 /*---            Models                               ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 13.1                                      ---*/
 /*---Figure 13.1                                      ---*/
data p;
   do p=0.2,0.1,0.05,0.01,0.005,1e-3,1e-4,1e-5,1e-6;
      log10_p = log10(p);
      bayes_factor = -exp(1)*p*log(p);
      do prior_prob_h0 = 0.9,0.5,0.1;
         prior_odds_h0 = prior_prob_h0 /(1-prior_prob_h0);
         post_odds_h0  = prior_odds_h0 * bayes_factor;
         post_prob_h0  = post_odds_h0  /(1+post_odds_h0);
         log10_pph     = log10(post_prob_h0);
         output;
      end;
   end;
run;

proc print data=p;
run;

goptions reset=all
   hsize   = 5.25 in
   vsize   = 5.25 in
   htext   = 3.0 pct
   htitle  = 3.5 pct
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss 
   lfactor = 1;

axis1 order=(-6 to 0) 
      value=(font=swissl height=1)  
      label=(font=swissl h=1) 
      major=(h=0.5) 
      minor=none;

axis2 order=(-6 to 0) 
      value=(font=swissl height=1)
      label=(font=swissl h=1) 
      major=(h=1) 
      minor=none;
symbol1 i=join r=1 color=black line=1;
symbol2 i=join r=1 color=black line=2;
symbol3 i=join r=1 color=black line=25;
proc gplot;
  plot log10_pph * log10_p = prior_prob_h0 /
                   haxis=axis1 vaxis=axis2;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.7, Teaching Methods I                 ---*/
 /*---Revisited in Chapter 13                          ---*/
data Ex_7_7sp;
    input met teacher gen $ student score y_ex @@;
    datalines;
1  1  f  1  15  11 1  1  f  2  17  11 1  1  f  3  16  11
1  1  f  4  16  11 1  1  m  1  17  11 1  1  m  2  16  11
1  1  m  3  17  11 1  1  m  4  17  11 1  2  f  1  18   8
1  2  f  2  17   8 1  2  f  3  17   8 1  2  f  4  16   8
1  2  m  1  16   8 1  2  m  2  17   8 1  2  m  3  18   8
1  2  m  4  17   8 1  3  f  1  15   9 1  3  f  2  15   9
1  3  f  3  15   9 1  3  f  4  16   9 1  3  m  1  15   9
1  3  m  2  15   9 1  3  m  3  15   9 1  3  m  4  16   9
1  4  f  1  16  17 1  4  f  2  17  17 1  4  f  3  16  17
1  4  f  4  15  17 1  4  m  1  14  17 1  4  m  2  17  17
1  4  m  3  17  17 1  4  m  4  16  17 2  1  f  1  21   6
2  1  f  2  22   6 2  1  f  3  22   6 2  1  f  4  21   6
2  1  m  1  20   6 2  1  m  2  20   6 2  1  m  3  21   6
2  1  m  4  22   6 2  2  f  1  21  11 2  2  f  2  20  11
2  2  f  3  20  11 2  2  f  4  21  11 2  2  m  1  18  11
2  2  m  2  19  11 2  2  m  3  20  11 2  2  m  4  19  11
2  3  f  1  23  13 2  3  f  2  23  13 2  3  f  3  24  13
2  3  f  4  23  13 2  3  m  1  21  13 2  3  m  2  20  13
2  3  m  3  21  13 2  3  m  4  22  13 2  4  f  1  23  18
2  4  f  2  22  18 2  4  f  3  22  18 2  4  f  4  22  18
2  4  m  1  19  18 2  4  m  2  19  18 2  4  m  3  19  18
2  4  m  4  20  18 3  1  f  1  33   8 3  1  f  2  31   8
3  1  f  3  31   8 3  1  f  4  32   8 3  1  m  1  27   8
3  1  m  2  28   8 3  1  m  3  27   8 3  1  m  4  27   8
3  2  f  1  28  18 3  2  f  2  27  18 3  2  f  3  27  18
3  2  f  4  29  18 3  2  m  1  23  18 3  2  m  2  23  18
3  2  m  3  24  18 3  2  m  4  23  18 3  3  f  1  30  12
3  3  f  2  29  12 3  3  f  3  29  12 3  3  f  4  30  12
3  3  m  1  25  12 3  3  m  2  25  12 3  3  m  3  26  12
3  3  m  4  24  12 3  4  f  1  28   6 3  4  f  2  27   6
3  4  f  3  28   6 3  4  f  4  30   6 3  4  m  1  25   6
3  4  m  2  25   6 3  4  m  3  22   6 3  4  m  4  25   6
;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 13.2                                      ---*/
proc mixed data=Ex_7_7sp covtest cl; 
   class teacher met gen;
   model score = met gen gen*met y_ex y_ex*gen / ddfm=kr;
   random teacher(met);
   ods output tests3=t3;
run;

data t3_bayes;
  set t3;
  if (probf < 1/exp(1)) then bf_sbb=-exp(1)*probf*log(probf);
  else bf_sbb = 1;
  if fvalue > 1 then bf_j = ((dendf/numdf + 1)/
                 (dendf/numdf +	fvalue))**((numdf+dendf)/2) * 
                 fvalue**(numdf/2);
  else bf_j = 1;
  do prior_prob_h0 = 0.9,0.5,0.1;
    prior_odds_h0    = prior_prob_h0/(1-prior_prob_h0);
    post_odds_h0_sbb = prior_odds_h0 * bf_sbb;
    post_odds_h0_j   = prior_odds_h0 * bf_j;
    post_prob_h0_sbb = post_odds_h0_sbb/(1+post_odds_h0_sbb);
    post_prob_h0_j   = post_odds_h0_j/(1+post_odds_h0_j);
    output;
  end;
run;

proc print data=t3_bayes;
   id effect;
   format _numeric_ best6.;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data 13.6, Beetle Fecundity                      ---*/
data beetle;
   input sire dam progeny value trait$ @@;
   datalines;
 1 1 1  58.0  fec  1 1 1   4.6  mass  1 1 2  64.0  fec  1 1 2   4.0  mass
 1 1 3  50.0  fec  1 1 3   4.1  mass  1 1 4  53.0  fec  1 1 4   4.2  mass
 1 1 5  50.0  fec  1 1 5   4.0  mass  1 2 1  54.0  fec  1 2 1   4.7  mass
 1 2 2  85.0  fec  1 2 2   5.7  mass  1 2 3  48.0  fec  1 2 3   3.6  mass
 1 2 4  55.0  fec  1 2 4   4.9  mass  1 2 5  48.0  fec  1 2 5   3.3  mass
 1 3 1  51.0  fec  1 3 1   5.1  mass  1 3 2  76.0  fec  1 3 2   5.2  mass
 1 3 3  58.0  fec  1 3 3   5.6  mass  1 3 4  48.0  fec  1 3 4   3.6  mass
 1 3 5  55.0  fec  1 3 5   3.5  mass  1 4 1  28.0  fec  1 4 1   5.1  mass
 1 4 2  44.0  fec  1 4 2   5.6  mass  1 4 3  21.0  fec  1 4 3   4.3  mass
 1 4 4  31.0  fec  1 4 4   4.4  mass  1 4 5  17.0  fec  1 4 5   4.2  mass
 1 5 1  44.0  fec  1 5 1   4.1  mass  1 5 2  51.0  fec  1 5 2   4.4  mass
 1 5 3  27.0  fec  1 5 3   4.1  mass  1 5 4  42.0  fec  1 5 4   3.5  mass
 1 5 5  40.0  fec  1 5 5   3.7  mass  2 1 1  62.0  fec  2 1 1   4.7  mass
 2 1 2  52.0  fec  2 1 2   4.3  mass  2 1 3  66.0  fec  2 1 3   5.2  mass
 2 1 4  56.0  fec  2 1 4   4.6  mass  2 1 5  37.0  fec  2 1 5   3.0  mass
 2 2 1  59.0  fec  2 2 1   4.5  mass  2 2 2  52.0  fec  2 2 2   4.7  mass
 2 2 3  62.0  fec  2 2 3   4.9  mass  2 2 4  56.0  fec  2 2 4   4.2  mass
 2 2 5  58.0  fec  2 2 5   5.5  mass  2 3 1  48.0  fec  2 3 1   5.3  mass
 2 3 2  63.0  fec  2 3 2   5.7  mass  2 3 3  21.0  fec  2 3 3   4.2  mass
 2 3 4  60.0  fec  2 3 4   4.4  mass  2 3 5  50.0  fec  2 3 5   3.9  mass
 2 4 1  38.0  fec  2 4 1   4.4  mass  2 4 2  56.0  fec  2 4 2   4.3  mass
 2 4 3  33.0  fec  2 4 3   4.8  mass  2 4 4  22.0  fec  2 4 4   4.5  mass
 2 4 5  68.0  fec  2 4 5   4.9  mass  3 1 1  70.0  fec  3 1 1   5.5  mass
 3 1 2  36.0  fec  3 1 2   4.1  mass  3 1 3  64.0  fec  3 1 3   4.9  mass
 3 1 4  46.0  fec  3 1 4   4.8  mass  3 1 5  31.0  fec  3 1 5   4.2  mass
 3 2 1  43.0  fec  3 2 1   5.7  mass  3 2 2  17.0  fec  3 2 2   5.2  mass
 3 2 3  23.0  fec  3 2 3   4.9  mass  3 2 4  76.0  fec  3 2 4   5.6  mass
 3 2 5  12.0  fec  3 2 5   4.7  mass  3 3 1  18.0  fec  3 3 1   4.1  mass
 3 3 2   9.0  fec  3 3 2   4.9  mass  3 3 3  18.0  fec  3 3 3   3.8  mass
 3 3 4  53.0  fec  3 3 4   4.2  mass  3 3 5  43.0  fec  3 3 5   4.5  mass
 3 4 1  53.0  fec  3 4 1   4.0  mass  3 4 2  57.0  fec  3 4 2   5.1  mass
 3 4 3  60.0  fec  3 4 3   4.2  mass  3 4 4  50.0  fec  3 4 4   5.1  mass
 3 4 5  62.0  fec  3 4 5   5.0  mass  3 5 1  83.0  fec  3 5 1   6.4  mass
 3 5 2  22.0  fec  3 5 2   4.8  mass  3 5 3  22.0  fec  3 5 3   5.3  mass
 3 5 4  71.0  fec  3 5 4   4.6  mass  3 5 5  71.0  fec  3 5 5   5.3  mass
 4 1 1  70.0  fec  4 1 1   4.8  mass  4 1 2  66.0  fec  4 1 2   5.5  mass
 4 1 3  64.0  fec  4 1 3   5.1  mass  4 1 4  43.0  fec  4 1 4   3.9  mass
 4 1 5  46.0  fec  4 1 5   3.5  mass  4 2 1  34.0  fec  4 2 1   4.3  mass
 4 2 2  16.0  fec  4 2 2   4.6  mass  4 2 3  14.0  fec  4 2 3   4.3  mass
 4 2 4  19.0  fec  4 2 4   4.1  mass  4 2 5  17.0  fec  4 2 5   4.5  mass
 4 3 1  46.0  fec  4 3 1   5.3  mass  4 3 2  62.0  fec  4 3 2   5.4  mass
 4 3 3  72.0  fec  4 3 3   5.4  mass  4 3 4  54.0  fec  4 3 4   5.1  mass
 4 3 5  55.0  fec  4 3 5   4.9  mass  4 4 1  52.0  fec  4 4 1   4.3  mass
 4 4 2  61.0  fec  4 4 2   4.6  mass  4 4 3  57.0  fec  4 4 3   4.2  mass
 4 4 4  71.0  fec  4 4 4   4.9  mass  4 4 5  52.0  fec  4 4 5   4.6  mass
 4 5 1  51.0  fec  4 5 1   4.0  mass  4 5 2  45.0  fec  4 5 2   4.1  mass
 4 5 3  51.0  fec  4 5 3   4.5  mass  4 5 4  44.0  fec  4 5 4   4.6  mass
 4 5 5  44.0  fec  4 5 5   4.0  mass  5 1 1  75.0  fec  5 1 1   5.1  mass
 5 1 2  62.0  fec  5 1 2   5.4  mass  5 1 3  60.0  fec  5 1 3   5.2  mass
 5 1 4  64.0  fec  5 1 4   4.8  mass  5 1 5  64.0  fec  5 1 5   5.1  mass
 5 2 1  92.0  fec  5 2 1   5.6  mass  5 2 2  88.0  fec  5 2 2   5.5  mass
 5 2 3  67.0  fec  5 2 3   5.5  mass  5 2 4  72.0  fec  5 2 4   5.5  mass
 5 2 5  77.0  fec  5 2 5   5.4  mass  5 3 1  85.0  fec  5 3 1   5.7  mass
 5 3 2  64.0  fec  5 3 2   4.9  mass  5 3 3  48.0  fec  5 3 3   4.5  mass
 5 3 4  50.0  fec  5 3 4   4.1  mass  5 3 5  59.0  fec  5 3 5   5.1  mass
 5 4 1  93.0  fec  5 4 1   5.1  mass  5 4 2  47.0  fec  5 4 2   4.7  mass
 5 4 3  58.0  fec  5 4 3   4.0  mass  5 4 4  48.0  fec  5 4 4   3.8  mass
 5 4 5  39.0  fec  5 4 5   3.6  mass  6 1 1  73.0  fec  6 1 1   4.1  mass
 6 1 2  33.0  fec  6 1 2   3.3  mass  6 1 3  25.0  fec  6 1 3   4.0  mass
 6 1 4  53.0  fec  6 1 4   4.0  mass  6 1 5  29.0  fec  6 1 5   3.9  mass
 6 2 1  72.0  fec  6 2 1   5.0  mass  6 2 2  75.0  fec  6 2 2   5.0  mass
 6 2 3  75.0  fec  6 2 3   4.6  mass  6 2 4  77.0  fec  6 2 4   5.5  mass
 6 2 5  63.0  fec  6 2 5   4.8  mass  6 3 1  54.0  fec  6 3 1   3.9  mass
 6 3 2  40.0  fec  6 3 2   3.1  mass  6 3 3  58.0  fec  6 3 3   4.2  mass
 6 3 4  52.0  fec  6 3 4   4.4  mass  6 3 5  53.0  fec  6 3 5   4.1  mass
 6 4 1  63.0  fec  6 4 1   5.0  mass  6 4 2  57.0  fec  6 4 2   3.8  mass
 6 4 3  36.0  fec  6 4 3   3.2  mass  6 4 4  20.0  fec  6 4 4   4.3  mass
 6 4 5  49.0  fec  6 4 5   4.9  mass  6 5 1  67.0  fec  6 5 1   4.4  mass
 6 5 2  85.0  fec  6 5 2   5.8  mass  6 5 3  46.0  fec  6 5 3   4.7  mass
 6 5 4  68.0  fec  6 5 4   4.8  mass  6 5 5  44.0  fec  6 5 5   5.0  mass
 7 1 1  32.0  fec  7 1 1   5.3  mass  7 1 2  64.0  fec  7 1 2   4.7  mass
 7 1 3  72.0  fec  7 1 3   5.7  mass  7 1 4  40.0  fec  7 1 4   3.9  mass
 7 1 5  40.0  fec  7 1 5   5.4  mass  7 2 1  70.0  fec  7 2 1   5.0  mass
 7 2 2  19.0  fec  7 2 2   4.9  mass  7 2 3  31.0  fec  7 2 3   4.1  mass
 7 2 4  66.0  fec  7 2 4   5.0  mass  7 2 5  53.0  fec  7 2 5   5.3  mass
 7 3 1  63.0  fec  7 3 1   4.7  mass  7 3 2  50.0  fec  7 3 2   4.8  mass
 7 3 3  78.0  fec  7 3 3   5.2  mass  7 3 4  77.0  fec  7 3 4   6.3  mass
 7 3 5  48.0  fec  7 3 5   4.3  mass  7 4 1  73.0  fec  7 4 1   5.4  mass
 7 4 2  67.0  fec  7 4 2   4.9  mass  7 4 3  57.0  fec  7 4 3   4.2  mass
 7 4 4  33.0  fec  7 4 4   5.1  mass  7 4 5  53.0  fec  7 4 5   4.0  mass
 7 5 1  79.0  fec  7 5 1   5.3  mass  7 5 2  68.0  fec  7 5 2   4.8  mass
 7 5 3  39.0  fec  7 5 3   4.6  mass  7 5 4  48.0  fec  7 5 4   4.8  mass
 7 5 5  58.0  fec  7 5 5   5.1  mass  8 1 1  56.0  fec  8 1 1   4.6  mass
 8 1 2  36.0  fec  8 1 2   3.3  mass  8 1 3  40.0  fec  8 1 3   4.1  mass
 8 1 4  60.0  fec  8 1 4   4.6  mass  8 1 5  51.0  fec  8 1 5   3.8  mass
 8 2 1  63.0  fec  8 2 1   4.3  mass  8 2 2  73.0  fec  8 2 2   4.7  mass
 8 2 3  51.0  fec  8 2 3   3.8  mass  8 2 4  74.0  fec  8 2 4   4.8  mass
 8 2 5  64.0  fec  8 2 5   4.5  mass  8 3 1  48.0  fec  8 3 1   4.2  mass
 8 3 2  28.0  fec  8 3 2   4.0  mass  8 3 3  32.0  fec  8 3 3   3.6  mass
 8 3 4  50.0  fec  8 3 4   4.1  mass  8 3 5  44.0  fec  8 3 5   3.4  mass
 8 4 1  79.0  fec  8 4 1   4.6  mass  8 4 2  27.0  fec  8 4 2   2.4  mass
 8 4 3  17.0  fec  8 4 3   4.4  mass  8 4 4  41.0  fec  8 4 4   4.0  mass
 8 4 5  30.0  fec  8 4 5   5.7  mass  9 1 1  51.0  fec  9 1 1   3.3  mass
 9 1 2  48.0  fec  9 1 2   4.0  mass  9 1 3  78.0  fec  9 1 3   5.2  mass
 9 1 4  31.0  fec  9 1 4   3.9  mass  9 1 5  53.0  fec  9 1 5   3.7  mass
 9 2 1  65.0  fec  9 2 1   3.8  mass  9 2 2  40.0  fec  9 2 2   3.5  mass
 9 2 3  46.0  fec  9 2 3   4.1  mass  9 2 4  39.0  fec  9 2 4   4.7  mass
 9 2 5  58.0  fec  9 2 5   3.9  mass  9 3 1  72.0  fec  9 3 1   4.4  mass
 9 3 2  52.0  fec  9 3 2   3.7  mass  9 3 3  56.0  fec  9 3 3   3.7  mass
 9 3 4  61.0  fec  9 3 4   3.9  mass  9 3 5  46.0  fec  9 3 5   3.3  mass
 9 4 1  28.0  fec  9 4 1   4.3  mass  9 4 2  25.0  fec  9 4 2   4.4  mass
 9 4 3  63.0  fec  9 4 3   4.2  mass  9 4 4  20.0  fec  9 4 4   4.9  mass
 9 4 5  26.0  fec  9 4 5   4.2  mass 10 1 1  35.0  fec 10 1 1   4.1  mass
10 1 2  60.0  fec 10 1 2   4.6  mass 10 1 3  17.0  fec 10 1 3   4.4  mass
10 1 4  65.0  fec 10 1 4   4.5  mass 10 1 5  31.0  fec 10 1 5   4.6  mass
10 2 1  78.0  fec 10 2 1   4.7  mass 10 2 2  74.0  fec 10 2 2   4.9  mass
10 2 3  72.0  fec 10 2 3   5.3  mass 10 2 4  72.0  fec 10 2 4   5.1  mass
10 2 5  71.0  fec 10 2 5   6.4  mass 10 3 1  69.0  fec 10 3 1   4.5  mass
10 3 2  76.0  fec 10 3 2   5.0  mass 10 3 3  54.0  fec 10 3 3   4.5  mass
10 3 4  69.0  fec 10 3 4   5.2  mass 10 3 5  51.0  fec 10 3 5   4.8  mass
10 4 1  79.0  fec 10 4 1   5.5  mass 10 4 2  84.0  fec 10 4 2   5.3  mass
10 4 3  85.0  fec 10 4 3   5.2  mass 10 4 4  51.0  fec 10 4 4   6.2  mass
10 4 5  73.0  fec 10 4 5   6.8  mass 11 1 1  76.0  fec 11 1 1   4.3  mass
11 1 2  56.0  fec 11 1 2   4.4  mass 11 1 3  80.0  fec 11 1 3   4.6  mass
11 1 4  74.0  fec 11 1 4   5.2  mass 11 1 5  54.0  fec 11 1 5   4.0  mass
11 2 1  69.0  fec 11 2 1   4.0  mass 11 2 2  72.0  fec 11 2 2   4.6  mass
11 2 3  68.0  fec 11 2 3   4.4  mass 11 2 4  81.0  fec 11 2 4   4.7  mass
11 2 5  45.0  fec 11 2 5   3.6  mass 11 3 1  43.0  fec 11 3 1   3.8  mass
11 3 2  40.0  fec 11 3 2   3.6  mass 11 3 3  48.0  fec 11 3 3   4.4  mass
11 3 4  45.0  fec 11 3 4   3.4  mass 11 3 5  74.0  fec 11 3 5   5.3  mass
11 4 1  58.0  fec 11 4 1   4.1  mass 11 4 2  47.0  fec 11 4 2   3.8  mass
11 4 3  63.0  fec 11 4 3   4.0  mass 11 4 4  45.0  fec 11 4 4   3.2  mass
11 4 5  45.0  fec 11 4 5   5.0  mass 11 5 1  62.0  fec 11 5 1   4.8  mass
11 5 2  72.0  fec 11 5 2   4.1  mass 11 5 3  63.0  fec 11 5 3   5.1  mass
11 5 4  47.0  fec 11 5 4   3.8  mass 11 5 5  64.0  fec 11 5 5   6.1  mass
12 1 1  72.0  fec 12 1 1   6.3  mass 12 1 2  47.0  fec 12 1 2   4.0  mass
12 1 3  56.0  fec 12 1 3   4.9  mass 12 1 4  37.0  fec 12 1 4   4.5  mass
12 1 5  65.0  fec 12 1 5   4.8  mass 12 2 1  47.0  fec 12 2 1   5.0  mass
12 2 2  52.0  fec 12 2 2   4.9  mass 12 2 3  59.0  fec 12 2 3   5.4  mass
12 2 4  51.0  fec 12 2 4   4.6  mass 12 2 5  25.0  fec 12 2 5   3.8  mass
12 3 1  49.0  fec 12 3 1   5.2  mass 12 3 2  48.0  fec 12 3 2   4.7  mass
12 3 3  70.0  fec 12 3 3   4.8  mass 12 3 4  52.0  fec 12 3 4   4.4  mass
12 3 5  67.0  fec 12 3 5   5.4  mass 12 4 1  54.0  fec 12 4 1   5.6  mass
12 4 2  58.0  fec 12 4 2   4.6  mass 12 4 3  54.0  fec 12 4 3   4.7  mass
12 4 4  64.0  fec 12 4 4   5.3  mass 12 4 5  56.0  fec 12 4 5   5.0  mass
12 5 1  44.0  fec 12 5 1   4.9  mass 12 5 2  70.0  fec 12 5 2   5.6  mass
12 5 3  47.0  fec 12 5 3   4.4  mass 12 5 4  41.0  fec 12 5 4   3.9  mass
12 5 5  45.0  fec 12 5 5   5.3  mass 13 1 1  48.0  fec 13 1 1   3.7  mass
13 1 2  55.0  fec 13 1 2   3.5  mass 13 1 3  22.0  fec 13 1 3   4.0  mass
13 1 4  61.0  fec 13 1 4   3.8  mass 13 1 5  57.0  fec 13 1 5   4.1  mass
13 2 1  43.0  fec 13 2 1   4.7  mass 13 2 2  44.0  fec 13 2 2   3.7  mass
13 2 3  30.0  fec 13 2 3   3.9  mass 13 2 4  42.0  fec 13 2 4   2.8  mass
13 2 5  25.0  fec 13 2 5   4.1  mass 13 3 1  58.0  fec 13 3 1   4.1  mass
13 3 2  55.0  fec 13 3 2   4.3  mass 13 3 3  55.0  fec 13 3 3   4.6  mass
13 3 4  46.0  fec 13 3 4   4.6  mass 13 3 5  50.0  fec 13 3 5   4.6  mass
13 4 1  82.0  fec 13 4 1   5.3  mass 13 4 2  94.0  fec 13 4 2   4.8  mass
13 4 3  43.0  fec 13 4 3   5.0  mass 13 4 4  38.0  fec 13 4 4   5.0  mass
13 4 5  19.0  fec 13 4 5   4.2  mass 13 5 1  81.0  fec 13 5 1   4.4  mass
13 5 2  84.0  fec 13 5 2   4.7  mass 13 5 3  46.0  fec 13 5 3   3.7  mass
13 5 4  81.0  fec 13 5 4   4.5  mass 13 5 5  48.0  fec 13 5 5   4.2  mass
14 1 1  28.0  fec 14 1 1   5.7  mass 14 1 2  55.0  fec 14 1 2   5.8  mass
14 1 3  27.0  fec 14 1 3   5.3  mass 14 1 4  48.0  fec 14 1 4   4.3  mass
14 1 5  52.0  fec 14 1 5   5.2  mass 14 2 1  39.0  fec 14 2 1   3.9  mass
14 2 2  48.0  fec 14 2 2   4.7  mass 14 2 3  30.0  fec 14 2 3   5.5  mass
14 2 4  51.0  fec 14 2 4   4.8  mass 14 2 5  43.0  fec 14 2 5   4.0  mass
14 3 1  24.0  fec 14 3 1   4.4  mass 14 3 2  20.0  fec 14 3 2   4.8  mass
14 3 3  14.0  fec 14 3 3   4.0  mass 14 3 4  18.0  fec 14 3 4   3.8  mass
14 3 5  48.0  fec 14 3 5   3.9  mass 14 4 1  60.0  fec 14 4 1   4.5  mass
14 4 2  45.0  fec 14 4 2   4.0  mass 14 4 3  57.0  fec 14 4 3   5.5  mass
14 4 4  38.0  fec 14 4 4   4.9  mass 14 4 5  62.0  fec 14 4 5   5.1  mass
14 5 1  52.0  fec 14 5 1   4.5  mass 14 5 2  58.0  fec 14 5 2   4.5  mass
14 5 3  54.0  fec 14 5 3   5.6  mass 14 5 4  64.0  fec 14 5 4   5.1  mass
14 5 5  49.0  fec 14 5 5   4.5  mass 15 1 1  88.0  fec 15 1 1   5.2  mass
15 1 2  48.0  fec 15 1 2   4.4  mass 15 1 3  48.0  fec 15 1 3   3.6  mass
15 1 4  61.0  fec 15 1 4   4.7  mass 15 1 5  41.0  fec 15 1 5   3.9  mass
15 2 1  64.0  fec 15 2 1   4.3  mass 15 2 2  78.0  fec 15 2 2   5.5  mass
15 2 3  67.0  fec 15 2 3   4.5  mass 15 2 4  71.0  fec 15 2 4   5.1  mass
15 2 5  59.0  fec 15 2 5   4.5  mass 15 3 1  64.0  fec 15 3 1   5.0  mass
15 3 2  59.0  fec 15 3 2   4.9  mass 15 3 3  51.0  fec 15 3 3   5.3  mass
15 3 4  67.0  fec 15 3 4   4.8  mass 15 3 5  72.0  fec 15 3 5   6.0  mass
15 4 1  86.0  fec 15 4 1   4.9  mass 15 4 2  81.0  fec 15 4 2   5.9  mass
15 4 3  71.0  fec 15 4 3   6.1  mass 15 4 4  86.0  fec 15 4 4   5.6  mass
15 4 5  73.0  fec 15 4 5   4.8  mass 15 5 1  75.0  fec 15 5 1   6.3  mass
15 5 2  61.0  fec 15 5 2   5.6  mass 15 5 3  42.0  fec 15 5 3   5.1  mass
15 5 4  65.0  fec 15 5 4   5.3  mass 15 5 5  58.0  fec 15 5 5   4.9  mass
16 1 1  50.0  fec 16 1 1   4.0  mass 16 1 2  23.0  fec 16 1 2   4.5  mass
16 1 3  74.0  fec 16 1 3   5.0  mass 16 1 4  64.0  fec 16 1 4   4.3  mass
16 1 5  51.0  fec 16 1 5   4.3  mass 16 2 1  74.0  fec 16 2 1   5.3  mass
16 2 2  68.0  fec 16 2 2   4.7  mass 16 2 3  61.0  fec 16 2 3   3.8  mass
16 2 4  60.0  fec 16 2 4   4.0  mass 16 2 5  60.0  fec 16 2 5   4.3  mass
16 3 1  72.0  fec 16 3 1   4.8  mass 16 3 2  62.0  fec 16 3 2   4.5  mass
16 3 3  68.0  fec 16 3 3   4.4  mass 16 3 4  78.0  fec 16 3 4   5.2  mass
16 3 5  63.0  fec 16 3 5   4.7  mass 16 4 1  68.0  fec 16 4 1   3.9  mass
16 4 2  72.0  fec 16 4 2   4.0  mass 16 4 3  61.0  fec 16 4 3   3.5  mass
16 4 4  56.0  fec 16 4 4   4.1  mass 16 4 5  73.0  fec 16 4 5   4.8  mass
17 1 1  14.0  fec 17 1 1   3.7  mass 17 1 2  26.0  fec 17 1 2   4.9  mass
17 1 3  44.0  fec 17 1 3   3.4  mass 17 1 4  34.0  fec 17 1 4   3.9  mass
17 1 5  51.0  fec 17 1 5   4.4  mass 17 2 1  57.0  fec 17 2 1   4.3  mass
17 2 2  75.0  fec 17 2 2   6.6  mass 17 2 3  45.0  fec 17 2 3   3.3  mass
17 2 4  68.0  fec 17 2 4   5.6  mass 17 2 5  77.0  fec 17 2 5   5.2  mass
17 3 1  51.0  fec 17 3 1   5.1  mass 17 3 2  35.0  fec 17 3 2   5.4  mass
17 3 3  61.0  fec 17 3 3   5.3  mass 17 3 4  34.0  fec 17 3 4   5.4  mass
17 3 5  57.0  fec 17 3 5   4.7  mass 17 4 1  62.0  fec 17 4 1   5.2  mass
17 4 2  49.0  fec 17 4 2   3.8  mass 17 4 3  40.0  fec 17 4 3   4.9  mass
17 4 4  45.0  fec 17 4 4   4.9  mass 17 4 5  55.0  fec 17 4 5   4.6  mass
17 5 1  65.0  fec 17 5 1   4.7  mass 17 5 2  24.0  fec 17 5 2   3.4  mass
17 5 3  19.0  fec 17 5 3   4.8  mass 17 5 4  28.0  fec 17 5 4   3.6  mass
17 5 5  68.0  fec 17 5 5   4.7  mass 18 1 1  28.0  fec 18 1 1   3.8  mass
18 1 2  42.0  fec 18 1 2   3.3  mass 18 1 3  19.0  fec 18 1 3   3.4  mass
18 1 4  24.0  fec 18 1 4   5.0  mass 18 1 5  15.0  fec 18 1 5   2.7  mass
18 2 1  80.0  fec 18 2 1   5.7  mass 18 2 2  57.0  fec 18 2 2   3.8  mass
18 2 3  76.0  fec 18 2 3   4.7  mass 18 2 4  30.0  fec 18 2 4   4.7  mass
18 2 5  72.0  fec 18 2 5   5.6  mass 18 3 1  61.0  fec 18 3 1   4.1  mass
18 3 2  46.0  fec 18 3 2   3.6  mass 18 3 3  50.0  fec 18 3 3   4.1  mass
18 3 4  64.0  fec 18 3 4   3.8  mass 18 3 5  41.0  fec 18 3 5   4.0  mass
18 4 1  71.0  fec 18 4 1   4.3  mass 18 4 2  59.0  fec 18 4 2   4.8  mass
18 4 3  58.0  fec 18 4 3   4.1  mass 18 4 4  61.0  fec 18 4 4   4.0  mass
18 4 5  70.0  fec 18 4 5   4.6  mass 19 1 1  73.0  fec 19 1 1   5.0  mass
19 1 2  63.0  fec 19 1 2   4.2  mass 19 1 3  58.0  fec 19 1 3   4.1  mass
19 1 4  64.0  fec 19 1 4   4.0  mass 19 1 5  72.0  fec 19 1 5   5.2  mass
19 2 1  66.0  fec 19 2 1   4.4  mass 19 2 2  61.0  fec 19 2 2   3.5  mass
19 2 3  85.0  fec 19 2 3   4.2  mass 19 2 4  32.0  fec 19 2 4   4.6  mass
19 2 5  48.0  fec 19 2 5   4.0  mass 19 3 1  68.0  fec 19 3 1   4.7  mass
19 3 2  62.0  fec 19 3 2   4.4  mass 19 3 3  60.0  fec 19 3 3   3.8  mass
19 3 4  62.0  fec 19 3 4   5.0  mass 19 3 5  52.0  fec 19 3 5   4.4  mass
19 4 1  70.0  fec 19 4 1   4.0  mass 19 4 2  71.0  fec 19 4 2   4.9  mass
19 4 3  44.0  fec 19 4 3   3.6  mass 19 4 4  63.0  fec 19 4 4   4.4  mass
19 5 1  64.0  fec 19 5 1   4.6  mass 19 5 2  62.0  fec 19 5 2   4.4  mass
19 5 3  53.0  fec 19 5 3   4.9  mass 19 5 4  62.0  fec 19 5 4   4.4  mass
19 5 5  55.0  fec 19 5 5   4.5  mass 20 1 1  55.0  fec 20 1 1   4.0  mass
20 1 2  86.0  fec 20 1 2   7.0  mass 20 1 3  71.0  fec 20 1 3   4.5  mass
20 1 4  62.0  fec 20 1 4   5.0  mass 20 1 5  48.0  fec 20 1 5   4.8  mass
20 2 1  57.0  fec 20 2 1   4.6  mass 20 2 2  51.0  fec 20 2 2   4.4  mass
20 2 3  66.0  fec 20 2 3   4.8  mass 20 2 4  38.0  fec 20 2 4   4.0  mass
20 2 5  68.0  fec 20 2 5   5.5  mass 20 3 1  22.0  fec 20 3 1   4.6  mass
20 3 2  18.0  fec 20 3 2   5.9  mass 20 3 3   6.0  fec 20 3 3   5.5  mass
20 3 4  20.0  fec 20 3 4   4.2  mass 20 3 5   4.0  fec 20 3 5   4.5  mass
20 4 1  56.0  fec 20 4 1   3.9  mass 20 4 2  57.0  fec 20 4 2   4.9  mass
20 4 3  64.0  fec 20 4 3   5.0  mass 20 4 4  54.0  fec 20 4 4   4.0  mass
20 4 5  58.0  fec 20 4 5   4.8  mass 21 1 1  58.0  fec 21 1 1   4.1  mass
21 1 2  81.0  fec 21 1 2   5.7  mass 21 1 3  74.0  fec 21 1 3   5.3  mass
21 1 4  62.0  fec 21 1 4   4.1  mass 21 1 5  58.0  fec 21 1 5   4.7  mass
21 2 1  69.0  fec 21 2 1   4.9  mass 21 2 2  74.0  fec 21 2 2   6.2  mass
21 2 3  58.0  fec 21 2 3   5.0  mass 21 2 4  64.0  fec 21 2 4   4.5  mass
21 2 5  59.0  fec 21 2 5   5.5  mass 21 3 1  47.0  fec 21 3 1   4.9  mass
21 3 2  65.0  fec 21 3 2   5.2  mass 21 3 3  28.0  fec 21 3 3   5.1  mass
21 3 4  58.0  fec 21 3 4   4.0  mass 21 3 5  64.0  fec 21 3 5   4.5  mass
21 4 1  80.0  fec 21 4 1   4.7  mass 21 4 2  83.0  fec 21 4 2   4.0  mass
21 4 3  69.0  fec 21 4 3   4.8  mass 21 4 4  62.0  fec 21 4 4   5.0  mass
21 4 5  59.0  fec 21 4 5   5.3  mass 22 1 1  68.0  fec 22 1 1   4.5  mass
22 1 2  39.0  fec 22 1 2   5.2  mass 22 1 3  40.0  fec 22 1 3   4.8  mass
22 1 4  60.0  fec 22 1 4   4.7  mass 22 1 5  45.0  fec 22 1 5   3.7  mass
22 2 1  80.0  fec 22 2 1   5.0  mass 22 2 2  70.0  fec 22 2 2   5.0  mass
22 2 3  81.0  fec 22 2 3   5.2  mass 22 2 4  61.0  fec 22 2 4   5.2  mass
22 2 5  67.0  fec 22 2 5   4.9  mass 22 3 1  60.0  fec 22 3 1   5.8  mass
22 3 2  64.0  fec 22 3 2   5.3  mass 22 3 3  46.0  fec 22 3 3   4.4  mass
22 3 4  60.0  fec 22 3 4   5.7  mass 22 3 5  59.0  fec 22 3 5   4.8  mass
22 4 1  71.0  fec 22 4 1   5.0  mass 22 4 2  68.0  fec 22 4 2   5.2  mass
22 4 3  78.0  fec 22 4 3   5.4  mass 22 4 4  60.0  fec 22 4 4   4.4  mass
22 4 5  58.0  fec 22 4 5   5.6  mass 22 5 1  66.0  fec 22 5 1   5.1  mass
22 5 2  53.0  fec 22 5 2   4.1  mass 22 5 3  65.0  fec 22 5 3   5.0  mass
22 5 4  25.0  fec 22 5 4   4.5  mass 22 5 5  58.0  fec 22 5 5   4.8  mass
23 1 1  73.0  fec 23 1 1   5.1  mass 23 1 2  64.0  fec 23 1 2   5.7  mass
23 1 3  64.0  fec 23 1 3   6.1  mass 23 1 4  64.0  fec 23 1 4   6.0  mass
23 1 5  87.0  fec 23 1 5   7.2  mass 23 2 1  36.0  fec 23 2 1   4.9  mass
23 2 2  73.0  fec 23 2 2   6.1  mass 23 2 3  42.0  fec 23 2 3   3.6  mass
23 2 4  68.0  fec 23 2 4   5.3  mass 23 2 5  52.0  fec 23 2 5   5.2  mass
23 3 1  65.0  fec 23 3 1   4.9  mass 23 3 2  76.0  fec 23 3 2   4.6  mass
23 3 3  59.0  fec 23 3 3   5.1  mass 23 3 4  45.0  fec 23 3 4   4.6  mass
23 3 5  67.0  fec 23 3 5   5.3  mass 23 4 1  54.0  fec 23 4 1   5.6  mass
23 4 2  50.0  fec 23 4 2   3.6  mass 23 4 3  50.0  fec 23 4 3   4.8  mass
23 4 4  60.0  fec 23 4 4   3.9  mass 23 4 5  59.0  fec 23 4 5   5.2  mass
23 5 1  101.0 fec 23 5 1   6.3  mass 23 5 2  96.0  fec 23 5 2   5.2  mass
23 5 3  104.0 fec 23 5 3   5.1  mass 23 5 4  97.0  fec 23 5 4   5.7  mass
23 5 5  79.0  fec 23 5 5   5.5  mass 24 1 1  74.0  fec 24 1 1   4.3  mass
24 1 2  93.0  fec 24 1 2   5.2  mass 24 1 3  93.0  fec 24 1 3   5.5  mass
24 1 4  101.0 fec 24 1 4   5.9  mass 24 1 5  86.0  fec 24 1 5   5.1  mass
24 2 1  77.0  fec 24 2 1   5.3  mass 24 2 2  59.0  fec 24 2 2   3.4  mass
24 2 3  82.0  fec 24 2 3   5.4  mass 24 2 4  82.0  fec 24 2 4   5.1  mass
24 2 5  68.0  fec 24 2 5   5.1  mass 24 3 1  31.0  fec 24 3 1   4.7  mass
24 3 2  57.0  fec 24 3 2   5.6  mass 24 3 3  52.0  fec 24 3 3   6.5  mass
24 3 4  39.0  fec 24 3 4   4.6  mass 24 3 5  39.0  fec 24 3 5   5.4  mass
24 4 1  81.0  fec 24 4 1   4.9  mass 24 4 2  86.0  fec 24 4 2   4.8  mass
24 4 3  77.0  fec 24 4 3   4.3  mass 24 4 4  65.0  fec 24 4 4   3.9  mass
24 4 5  80.0  fec 24 4 5   4.6  mass
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---output 13.3                                      ---*/
proc mixed data=beetle covtest cl asycov;
   where trait = 'fec';
   class sire dam;
   model value = / solution;
   random sire dam(sire);
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 13.4                                      ---*/
proc mixed data=beetle covtest cl asycov;
	 where trait = 'fec';
	 class sire dam;
	 model value = / solution;
	 random sire dam(sire);
	 prior / nsample=1e4 seed=3102834 out=post 
           psearch ptrans;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 13.5                                      ---*/
data post;
  set post;
  Var_Additive      = 4*covp1;
  Var_Maternal      = covp2 - covp1;
  Var_Environmental = covp3 - 2*covp1;
  if Var_Maternal < 0 or Var_Environmental < 0 then delete;
  Var_Total         = Var_Additive + Var_Maternal + 
                      Var_Environmental;
  Percent_Var_Additive = 100*Var_Additive/Var_Total;
  Percent_Var_Maternal = 100*Var_Maternal/Var_Total;
  Percent_Var_Environmental = 100*Var_Environmental/Var_Total;
  rename covp1 = Var_Sire 
         covp2 = Var_Dam_Sire 
         covp3 = Var_Residual
         beta1 = Intercept;
run;

proc univariate data=post noprint;
  var Var_Sire Var_Dam_Sire Var_Residual Intercept;
  output out=confInt pctlpts=2.5,50,97.5
                pctlpre = Sire_ DamSire_ Residual_ Intercept_ 
                pctlname= lower Median upper
                mean    = Sire_mean DamSire_mean 
                          Residual_Mean Intercept_Mean
                std     = Sire_Std DamSire_Std Residual_Std  
                          Intercept_Std;
run;
proc print data=confInt label noobs; var sire:     ;
proc print data=confInt label noobs; var damsire:  ;
proc print data=confInt label noobs; var residual: ;
proc print data=confInt label noobs; var intercept:;
run;
 /*-------------------------------------------------------*/ 

 /*-------------------------------------------------------*/
 /*---Output 13.6                                       ---*/
proc univariate data=post noprint;
  var Var_Additive Var_Maternal Var_Environmental;
  output out=confInt pctlpts=2.5,50,97.5
                pctlpre=Additive_ Maternal_ Environ_
                pctlname=lower Median upper
                mean=Additive_mean Maternal_mean Environ_Mean
                std=Additive_Std   Maternal_Std  Environ_Std;
run;
proc print data=confInt label noobs; var Additive:;
proc print data=confInt label noobs; var Maternal:;
proc print data=confInt label noobs; var Environ:;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 13.7                                      ---*/
 /*---Figure 13.2                                      ---*/
ods html;
ods graphics on;
proc corr data=post plots=matrix;
  var Var_Additive Var_Maternal Var_Environmental;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 13.8                                      ---*/
proc univariate data=post noprint;
  var Percent_Var_Additive 
      Percent_Var_Maternal 
      Percent_Var_Environmental;
  output out=confInt pctlpts=2.5,50,97.5
                     pctlpre=Additive_ Maternal_ Environ_
                     pctlname=lower Median upper
                     mean   =Additive_mean Maternal_mean Environ_Mean
                     std    =Additive_Std  Maternal_Std  Environ_Std;

run;
proc print data=confInt label noobs; var Additive:;
proc print data=confInt label noobs; var Maternal:;
proc print data=confInt label noobs; var Environ:;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 13.9                                      ---*/
data pv;
   input type $ Parm1 Parm2;
   datalines;
ig 11.265 16709
ig 42.967 32216  
ig 219.55 38966
run; 

proc mixed data=beetle covtest cl asycov;
   where trait = 'fec';
   class sire dam;
   model value = / solution;
   random sire dam(sire);
   prior data=pv / nsample=1e4 seed=3102834 out=post1 
                   psearch ptrans;
run;

data post1;
   set post1;
   Var_Additive      = 4*covp1;
   Var_Maternal      = covp2 - covp1;
   Var_Environmental = covp3 - 2*covp1;
   if Var_Maternal < 0 or Var_Environmental < 0 then delete;
   Var_Total = Var_Additive + Var_Maternal + Var_Environmental;
   Percent_Var_Additive      = 100*Var_Additive/Var_Total;
   Percent_Var_Maternal      = 100*Var_Maternal/Var_Total;
   Percent_Var_Environmental = 100*Var_Environmental/Var_Total;
   rename covp1 = Var_Sire 
          covp2 = Var_Dam_Sire 
          covp3 = Var_Residual
          beta1 = Intercept;
run;

proc means data= post1 mean std;
run;
 /*-------------------------------------------------------*/





