
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/

/*-------------------------------------------------------*/
 /*---CHAPTER 14: Generalized Linear Mixed Models      ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 14.5, Clinics                           ---*/
data clinics;
   input clinic trt$ fav unfav;
   nij = fav+unfav;
   if fav=0 then fav = 0.1/nij;
   datalines;
1 drug 11 25
1 cntl 10 27
2 drug 16 4
2 cntl 22 10
3 drug 14 5
3 cntl 7 12
4 drug 2 14
4 cntl 1 16
5 drug 6 11
5 cntl 0 12
6 drug 1 10
6 cntl 0 10
7 drug 1 4
7 cntl 1 8
8 drug 4 2
8 cntl 6 1
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.1                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth;
   random clinic trt*clinic;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.2                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth oddsratio;
   random clinic trt*clinic;
   lsmeans trt                     / ilink;
   estimate 'trt diff' trt 1 -1    / exp cl;
   estimate 'trt 1 clinic 1 BLUP' intercept 1 trt 1 0 
            | clinic 1 0           / ilink;
   estimate 'trt 1 clinic 6 BLUP' intercept 1 trt 1 0
            | clinic 0 0 0 0 0 1 0 / ilink;
   ods select OddsRatios LSMeans Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.3                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth;
   random clinic trt*clinic / s;
   ods select ParameterEstimates SolutionR;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.4                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth;
   random clinic trt*clinic;
   output out=gmxout pred(ilink   noblup) = mupa
                     pred(ilink     blup) = mu
                     pred(noilink noblup) = linppa
                     pred(noilink blup  ) = linp;
run;
proc print data=gmxout; 
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.5                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth
                         link=probit;
   random clinic trt*clinic / solution;
   lsmeans trt / ilink;
   estimate 'trt diff' trt 1 -1 / cl;
   estimate 'trt 1 clinic 1 BLUP' intercept 1 trt 1 0 
            | clinic 1 0 / ilink;
   estimate 'trt 1 clinic 6 BLUP' intercept 1 trt 1 0
            | clinic 0 0 0 0 0 1 0 / ilink;
   ods select FitStatistics CovParms Tests3 Estimates LSMeans;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.6                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth
                         link=probit;
   random clinic trt*clinic / solution;
   ods select ParameterEstimates SolutionR;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 14.6, Seed Mix                          ---*/
data mix;
   input trt blk mix count @@;
   y = count + 1;
   datalines;
1 1 1  24 1 1 2  12 1 1 3   8 1 1 4  13 1 2 1   9 1 2 2   9
1 2 3   9 1 2 4  18 1 3 1  12 1 3 2   8 1 3 3  44 1 3 4   0
1 4 1   8 1 4 2  12 1 4 3  25 1 4 4   0 2 1 1  11 2 1 2  32
2 1 3  12 2 1 4  22 2 2 1  41 2 2 2  15 2 2 3  39 2 2 4  38
2 3 1  30 2 3 2  11 2 3 3   5 2 3 4  50 2 4 1  11 2 4 2   0
2 4 3   7 2 4 4  10 3 1 1   0 3 1 2   0 3 1 3  19 3 1 4  25
3 2 1  33 3 2 2  14 3 2 3  20 3 2 4  30 3 3 1  46 3 3 2  31
3 3 3   5 3 3 4   7 3 4 1   8 3 4 2  25 3 4 3  19 3 4 4   3
4 1 1  19 4 1 2  50 4 1 3  20 4 1 4   7 4 2 1  13 4 2 2  42
4 2 3  37 4 2 4   6 4 3 1  10 4 3 2   9 4 3 3  10 4 3 4  24
4 4 1  24 4 4 2  34 4 4 3  35 4 4 4  45 5 1 1  19 5 1 2  48
5 1 3  50 5 1 4  34 5 2 1   0 5 2 2  36 5 2 3  24 5 2 4  24
5 3 1  40 5 3 2  40 5 3 3  14 5 3 4  18 5 4 1  99 5 4 2  39
5 4 3  21 5 4 4  25 6 1 1 115 6 1 2  38 6 1 3  16 6 1 4  34
6 2 1  52 6 2 2  55 6 2 3  17 6 2 4  18 6 3 1  37 6 3 2  19
6 3 3  44 6 3 4  10 6 4 1  10 6 4 2  11 6 4 3  14 6 4 4  13
7 1 1  46 7 1 2  45 7 1 3  37 7 1 4  13 7 2 1  30 7 2 2  96
7 2 3  41 7 2 4  37 7 3 1  59 7 3 2  34 7 3 3  28 7 3 4  20
7 4 1  84 7 4 2  56 7 4 3  26 7 4 4  27
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.7                                      ---*/
proc glimmix data=mix;
   class trt blk mix;
   model y = trt mix trt*mix / dist=poisson;
   random blk blk*trt;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.8                                      ---*/
proc glimmix data=mix;
   class trt blk mix;
   model y = trt mix trt*mix / dist=poisson s;
   random blk*trt;
   output out=gmxout pearson(blup)=res;
run;
proc means data=gmxout mean std; var res;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.9                                      ---*/
 /*---Figure 14.1                                      ---*/
 /*---Figure 14.2                                      ---*/
ods html;
ods graphics on;
proc glimmix data=mix;
   class trt blk mix;
   model y = trt mix trt*mix / dist=poisson;
   random blk blk*trt;
   random _residual_;
   lsmeans trt / plots=diffplot adjust=tukey;
   lsmeans trt / plots=anomplot adjust=nelson; 
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.10                                     ---*/
proc glimmix data=mix;
   class trt blk mix;
   model y = trt mix trt*mix / dist=poisson;
   lsmeans trt;
   random _residual_;
run;
 /*-------------------------------------------------------*/






