 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/

/*-------------------------------------------------------*/
 /*---CHAPTER 15: Nonlinear Mixed Models               ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Orange tree data (Data Set 15.3, Appendix 2      ---*/
 /*---Draper and Smith (1981, p. 524) and              ---*/
 /*---Lindstrom and Bates (1990, Biometrics, p. 673-687)--*/
data tree; 
  input tree day circum @@; 
  datalines; 
   1  118   30    1  484   58    1  664   87    1 1004  115 
   1 1231  120    1 1372  142    1 1582  145 
   2  118   33    2  484   69    2  664  111    2 1004  156 
   2 1231  172    2 1372  203    2 1582  203 
   3  118   30    3  484   51    3  664   75    3 1004  108 
   3 1231  115    3 1372  139    3 1582  140 
   4  118   32    4  484   62    4  664  112    4 1004  167 
   4 1231  179    4 1372  209    4 1582  214 
   5  118   30    5  484   49    5  664   81    5 1004  125 
   5 1231  142    5 1372  174    5 1582  177 
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*--- Figure 15.1                                     ---*/
goptions reset=all
   hsize   = 9 in
   vsize   = 8 in
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss
   lfactor = 1;

axis1 order = (0 to 1600 by 400)
      value = (font=swissl height=2)  
      label = (font=swissl h=2)
      major = (h=0.5)
      minor = none;

axis2 order = (0 to 250 by 50)
      value = (font=swissl height=2)
      label = (font=swissl h=2)
      major = (h=1)
      minor = none;

symbol1 color=black value=none i=join l=1 r=5 w=1;

proc gplot data=tree;
   plot circum*day=tree / nolegend haxis=axis1 vaxis=axis2;
run;
quit;
goptions reset=all;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*--- Output 15.1                                     ---*/
proc nlmixed data=tree method=firo; 
   parms b1=190 b2=10 b3=100 s2u1=500 c12=0 s2u2=10 s2e=50;
   bounds s2u1 >= 0, s2u2 >= 0, s2e > 0; 
   num = b1+u1; 
   ex  = exp(-day/b3); 
   den = 1 + (b2+u2)*ex; 
   model circum ~ normal(num/den,s2e); 
   random u1 u2 ~ normal([0,0],[s2u1,c12,s2u2]) subject=tree; 
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Load the NLINMIX macro. You can download the file---*/
 /*---nlmm800.sas from the SAS technical support web site-*/ 
%include 'nlmm800.sas' / nosource;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Logistic model, NLINMIX Method 1                 ---*/
 /*---Output 15.2 and 15.3                             ---*/
%nlinmix(data=tree,
   procopt=method=ml,
   model=%str(
      num   = b1+u1;
      e     = exp(-day/b3);
      den   = 1 + (b2+u2)*e;
      predv = num/den; 
   ),
   parms=%str(b1=190 b2=10 b3=100),
   stmts=%str(
      class tree;
      model pseudo_circum = d_b1 d_b2 d_b3 / noint notest solution cl;
      random d_u1 d_u2 / subject=tree type=un solution cl;
   ),
   expand=zero
)
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Logistic model, NLINMIX Method 2                 ---*/
 /*---Output not shown                                 ---*/
%nlinmix(data=tree,
   procopt=method=ml,
   model=%str(
      num   = b1+u1;
      e     = exp(-day/b3);
      den   = 1 + (b2+u2)*e;
      predv = num/den; 
   ),
   parms=%str(b1=190 b2=10 b3=100),
   stmts=%str(
      class tree;
      model pseudo_circum = d_b1 d_b2 d_b3 / noint notest solution cl;
      random d_u1 d_u2 / subject=tree type=un solution cl;
   ),
   expand=eblup
)
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Logistic model, NLINMIX Method 3                 ---*/
 /*---Without variance weighing                        ---*/
 /*---Output not shown                                 ---*/
%nlinmix(data=tree,
   procopt=method=ml,
   model=%str(
      num   = b1;
      e     = exp(-day/b3);
      den   = 1 + b2*e;
      predv = num/den; 
   ),
   parms=%str(b1=190 b2=10 b3=100),
   stmts=%str(
      class tree;
      model pseudo_circum = d_b1 d_b2 d_b3 / noint notest solution cl;
      repeated / subject=tree type=cs;
   )
)
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Logistic model, NLINMIX Method 3                 ---*/
 /*---Without variance weighing for constant CV        ---*/
 /*---Output 15.4, Output 15.5                         ---*/
%nlinmix(data=tree,
   procopt=method=ml,
   model=%str(
      num   = b1;
      e     = exp(-day/b3);
      den   = 1 + b2*e;
      predv = num/den; 
   ),
   weight = %str(
      wghtv = 1/predv**2;
   ),
   parms=%str(b1=190 b2=10 b3=100),
   stmts=%str(
      class tree;
      model pseudo_circum = d_b1 d_b2 d_b3 / noint notest solution cl;
      repeated / subject=tree type=cs;
      weight wghtv;
   )
)
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Compare power models, each m2ll value below is the--*/
 /*---result of running the previous model using a     ---*/
 /*---different power to weight the variance           ---*/
data pom;
   input power m2ll;
   datalines;
-4     275.4207
-3.5   269.8219
-3     266.9001
-2.75  266.4461
-2.5   266.6548
-2.25  267.5017
-2     268.9451
-1     279.5383
 0     295.2636
;

proc glm data=pom;
   model m2ll = power power*power / solution;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 15.6                                      ---*/
 /*---Simulate from a model with three random components--*/
 /*---B is nested within A, plus a residual variance   ---*/
%let na = 100;
%let nb = 5;
%let nr = 2;
data nested;
  do A = 1 to &na;
     err1 = 3*rannor(339205);
     do B = 1 to &nb;
        err2 = 2*rannor(0);
        do rep = 1 to &nr;
          err3  = 1*rannor(0);
          resp = 10 + err1 + err2 + err3;
          output;
        end;
     end;
  end;
run;

 /*---PROC NLMIXED requires that the data are grouped---*/
 /*---by subject. These data are already properly    ---*/
 /*---grouped. The PROC SORT step is simply added here -*/
 /*---for completeness.                              ---*/
proc sort data=nested; by A; run;


proc nlmixed data=nested method=firo;
   array aeffect { 1  };
   array beffect {&nb };
   vara     = exp(2*logsiga);
   varb_a   = exp(2*logsigb_a);
   mean     = intercept + aeffect{1} + beffect{B};
   model resp ~ normal (mean,s2);
   random aeffect1 beffect1 beffect2 beffect3 beffect4 beffect5 ~
             normal( [0,0,0,0,0,0],
                     [vara,
                     0, varb_a,
                     0, 0, varb_a,
                     0, 0, 0, varb_a,
                     0, 0, 0, 0, varb_a,
                     0, 0, 0, 0, 0, varb_a] ) subject=A;
   estimate 'Var[A]    ' vara;
   estimate 'Var[B(A)] ' varb_a;
run;

 /*---equivalent proc mixed code---*/
proc mixed data=nested method=ml;
   class a b;
   model resp = / s;
   random a b(a);
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Section 15.5 Zero-inflated Poisson (ZIP)  Model  ---*/
 /*---Siumulated data for ZIP model                    ---*/
 /*
   Z ~ Poisson(lambda)                   
   Pr(Count=0) = pi + (1-pi)*Pr(Z=0)     
   Pr(Count=j) = (1-pi)*Pr(Z=j), j > 0   
   lambda is a function of covariates and a random effect
 */

%let pi = 0.27;
data zip;
  do s = 1 to 100;
    u = rannor(556712);
    do i = 1 to 20; 
       x = int(ranuni(0)*100);
       y = int(rannor(0)*100);
       if (ranuni(0) < &pi) then do;
          count = 0;
          lambda = .;
       end; else do;
          lambda = exp(-2 + 0.01*x + 0.01*y + u);
          count = ranpoi(0,lambda);
       end;
       output;
    end;
  end;
  drop i u lambda;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*--- Figure 15.2                                     ---*/
proc gchart data=zip; 
   vbar3d count / discrete;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Poisson model with a random effect               ---*/
 /*---Output 15.7                                      ---*/
proc nlmixed data=zip;
   parameters b0=0 b1=0 b2=0;
   lambda = exp(b0 + b1*x + b2*y + u);
   model count ~ poisson(lambda);
   random u ~ normal(0,s2u) subject=s;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/ 
 /*---Negative binomial model with a random effect     ---*/
 /*---Output 15.8                                      ---*/
proc nlmixed data=zip;
   parameters b0=0 b1=0 b2=0;
   eta = b0 + b1*x + b2*y + u;
   p = exp(eta)/(1+exp(eta));
   model count ~ negbin(22,p);
   random u ~ normal(0,s2u) subject=s;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---ZIP model with a random effect                   ---*/
 /*---Output 15.9                                      ---*/
proc nlmixed data=zip;
   parameters b0=0 b1=0 b2=0
              a0=0 s2u=1;
   /* linear predictor for the inflation probability      */
   linpinfl = a0;
   /* infprob = inflation probability for zeros           */
   /*         = logistic transform of the linear predictor*/
   infprob  = 1/(1+exp(-linpinfl));
   /* Poisson mean */
   lambda   = exp(b0 + b1*x + b2*y + u);
   /* Build the ZIP log likelihood */
   if count=0 then 
        ll = log(infprob + (1-infprob)*exp(-lambda));
   else ll = log((1-infprob)) + count*log(lambda) - lgamma(count+1) - lambda;
   model count ~ general(ll);
   random u ~ normal(0,s2u) subject=s;
   estimate "inflation probability" infprob;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Section 15.5 Poisson Hurdle Model                ---*/
 /*---Simulated data for hurdle model                  ---*/
 /*
   Z0 ~ Poisson(lambda0)              
   Z1 ~ Poisson(lambda1)              
                                      
   Pr(Count=0) = Pr(Z0=0)             
                                      
                 Pr(Z0>0)*Pr(Z1=j)    
   Pr(Count=j) = -----------------      for j > 0
                   1 - Pr(Z1=0)       
   */
data hurdle;
  do s = 1 to 100;
    u = rannor(9213740);
    do i = 1 to 20; 
       x = int(ranuni(0)*100);
       y = int(rannor(0)*100);
       count = ranpoi(0,exp(-2 + 0.01*x + 0.01*y + u) );
       if (count > 0) then do;
         count1 = 0;
         do while (count1 = 0);
             count1 = ranpoi(0,exp(-1 + 0.01*x + 0.01*y + u) );
         end;
         count = count1;
       end;
       output;
    end;
  end;
  drop i u;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 15.10                                     ---*/
proc nlmixed data=hurdle;
   parameters a0=-1 a1=0 a2=0 
              b0=-1 b1=0 b2=0
              s2u=1; 
   linpzero   = a0 + a1*x + a2*y + u;
   linpnozero = b0 + b1*x + b2*y + u;
   muzero     = exp(linpzero);
   munozero   = exp(linpnozero);
   f10        = exp(-muzero);
   f20        = exp(-munozero);
   logpnozero = log(1-f10) - log(1-f20) - munozero -
                lgamma(count+1) + count*log(munozero); 
   if count = 0 then ll = -muzero; 
   else ll = logpnozero; 
   model count ~ general(ll);
   random u ~ normal(0,s2u) subject=s;
run;
 /*-------------------------------------------------------*/



 /*-------------------------------------------------------*/
 /*---Survival and longitudinal CD4 data               ---*/
 /*---Data set for Section 15.6                        ---*/
 /* Source:         
     Carlin, B.P. and Louis, T.A. (1996) "Bayes and        
        Empirical Bayes Methods for Data Analysis",        
        Boca Raton: Chapman & Hall/CRC Press, Ch. 8.1      
     See also                                              
       1. http://www.biostat.umn.edu/~brad/data.html       
          for data sets                                    
       2. Guo, X. and Carlin, B.P. (2003) "Separate and    
          Joint Modeling of Longitudinal and Event Time    
          Data Using Standard Computer Packages", The
          American Statistician, 58, 16--24.
 */
data alldata;
  input t2death death randgrp1 gender1 prevoi1 stratum1 y1-y5;
  array yy{5} y1-y5;
  array t{5} (0,2,6,12,18);
  patient = _n_;
  do i = 1 to 5;
     obstime = t{i};
     if (yy{i} ne .) then do;
         cd4 = sqrt(yy{i});
         output;
     end;
  end;
  drop i y1-y5 t1-t5; 
  datalines;
16.97 0 0  1  1 -1 114    .    71    89     . 
19.00 0 1  1 -1 -1  40    .    66    21    25 
18.53 1 1 -1  1 -1  12   13    38     .     . 
12.70 0 0  1  1  1  15   21     7     3     . 
15.13 0 1  1  1  1  53   74    74    45     . 
 1.90 1 0 -1  1  1  21    .     .     .     . 
14.33 0 0  1  1 -1  46   29    20    10     . 
 9.57 1 1 -1 -1 -1  12    1     0     .     . 
11.57 1 0  1  1  1   0   33     .     .     . 
16.43 0 1  1  1 -1 147  180   111    56     . 
 2.40 1 0  1  1 -1  47    .     .     .     . 
18.10 0 1  1 -1 -1 185  262   177    91   138 
12.23 1 0  1 -1 -1   6   16     6     .     . 
 2.60 1 1  1 -1 -1   4    8     .     .     . 
12.23 0 1  1  1  1 138   97    83    79     . 
 7.10 1 0  1  1 -1   3    1    26     .     . 
16.67 0 0  1 -1 -1  43   24    25    25     . 
13.70 0 0  1  1 -1  32   29     9     7     . 
 2.73 1 1 -1  1 -1   9    .     .     .     . 
14.40 0 0  1  1  1 363  364   270   279     . 
 8.07 1 1  1  1 -1  52   29    11     .     . 
17.40 0 1  1 -1 -1   3    3     2     4     . 
12.53 1 1 -1 -1 -1  15    .     .     .     . 
20.27 0 0  1 -1 -1 197  255     .   235   206 
 4.57 1 0 -1  1  1   5    .     .     .     . 
20.27 0 1  1 -1 -1 295  394   411   291   185 
18.13 0 0  1 -1 -1  17    .     5     2     3 
19.57 0 1  1  1  1 285    .     .     .     . 
 6.13 1 1  1  1  1  21    .     .     .     . 
18.87 0 0 -1 -1 -1  33    .    19     .     . 
16.27 1 0 -1  1 -1  83  112    31     .     . 
 7.17 1 1  1  1 -1   3    .     1     .     . 
18.57 0 1  1  1  1  60   43     .     .    12 
18.50 0 0  1  1 -1   1    .     2     .     7 
18.40 0 1  1 -1 -1 157  101    51    47    40 
 7.67 1 0  1  1 -1   0    .     1     .     . 
14.87 1 0  1  1 -1  15    9     5     .     . 
17.87 0 1 -1 -1 -1 280  233     .     .     . 
17.70 0 0  1 -1 -1 100    .    61    20     . 
17.40 0 1  1 -1 -1 263  204     .     .     . 
17.37 0 0  1  1 -1  22   11     .     2     . 
17.37 0 0 -1 -1 -1  69    .     .     .     . 
17.23 0 0  1 -1 -1 272    .     .     .     . 
 8.47 1 1  1 -1 -1  21   29    12     .     . 
 8.43 1 0  1  1  1   3    .     .     .     . 
11.07 1 1  1 -1 -1  39   24     7     .     . 
11.07 1 0 -1  1  1  16   13     .     .     . 
 5.90 1 0  1  1  1   1    2     .     .     . 
 2.00 1 1  1 -1 -1   1    .     .     .     . 
14.40 0 1 -1 -1 -1 190  207   147    16     . 
 7.57 1 1  1  1 -1   9   20     .     .     . 
 5.57 1 0  1  1 -1   2    0     .     .     . 
 4.93 1 0  1  1  1  13    .     .     .     . 
16.03 0 0  1  1  1 111  187   130    81     . 
12.27 0 0  1  1 -1   6   10    23     4     . 
15.03 0 0  1  1  1  48   53    13    20     . 
12.20 1 1  1  1 -1  11   32    10     .     . 
12.27 0 1  1 -1 -1   6    3     3     .     . 
10.57 1 0  1  1 -1 130   27    33     .     . 
15.70 1 0  1  1  1   8    .     5     1     . 
12.30 0 0  1  1 -1 154  177     .     .     . 
14.17 0 0  1 -1 -1 271  250   125   169     . 
12.70 0 0  1  1  1 194  307   142    99     . 
 7.17 1 1  1  1 -1  32   31     6     .     . 
 2.60 1 1  1  1  1  15    .     .     .     . 
15.57 1 1  1  1  1  50    .    21     .     . 
11.13 1 1  1  1  1  17    .     6     .     . 
14.17 0 1  1  1  1 192   78    33    11     . 
 0.77 1 0  1  1  1   5    .     .     .     . 
14.07 0 1  1  1 -1  46   61    79     .     . 
 6.00 1 0  1  1 -1   4    5     .     .     . 
13.93 0 0  1 -1 -1 226  187   190   187     . 
 1.30 1 1  1  1 -1   1    .     .     .     . 
13.93 0 1  1  1 -1  21   37     4     8     . 
12.67 1 1  1  1  1 110   66    58     .     . 
13.23 0 0  1 -1 -1  19   19    16    10     . 
10.33 1 0  1  1  1  14    1     2     .     . 
12.47 0 1  1 -1 -1  52  137   104   130     . 
12.47 0 0  1 -1 -1  21   31    32     8     . 
17.93 0 0  1 -1 -1 120  300   220   272     . 
 3.13 1 1  1  1 -1   5    5     .     .     . 
18.03 0 1  1  1  1  42   34    15     .     7 
 4.60 1 1  1  1  1  50   50     .     .     . 
15.97 0 0  1  1 -1  64   15     .     .     . 
14.90 0 1 -1  1 -1  15   54    45    25     . 
15.60 0 1  1  1 -1 242  390   264   332     . 
10.40 1 0  1  1  1  39    2    24     .     . 
 9.77 1 0  1  1  1   8   30     3     .     . 
18.13 0 0  1 -1  1   4   11     2    21    19 
17.93 0 1  1 -1 -1 199  203   286   255   183 
18.13 0 0  1 -1 -1  65   51    46     5    37 
18.03 0 1  1  1  1  45   48    60    61    42 
17.87 0 0  1 -1 -1 291  314   453   382   273 
15.57 0 1  1  1 -1  39   30    21    16     . 
17.43 0 0  1 -1 -1 115   90   139   141     . 
17.67 0 0  1 -1 -1 224    .   363   262     . 
15.10 0 1  1  1  1  40   16     .     .     . 
16.30 0 0  1  1  1  40   26    36     .     . 
13.03 0 0  1 -1 -1  24    .     3     .     . 
10.30 1 0  1  1  1  21   35    28     .     . 
15.03 0 1  1  1  1 176  198    98    22     . 
 5.10 1 1  1  1  1   6    2     .     .     . 
12.90 0 0  1 -1 -1  13  162     .    42     . 
11.03 1 0  1  1  1  15   20    20     .     . 
11.17 1 0  1  1 -1  11    5     .     .     . 
14.07 0 1  1 -1 -1 275  415   284   308     . 
18.40 0 1  1  1  1  50   72    36     .     . 
 1.07 1 0  1  1  1   2    .     .     .     . 
 4.67 1 0  1  1  1  61    .     .     .     . 
12.20 0 1  1  1  1 274  265     .     .     . 
17.83 0 1  1  1  1  28   42    16     .     . 
16.23 0 0  1 -1 -1  41   30     .     .     . 
12.50 0 1  1  1  1  54    .     .     .     . 
10.23 1 1  1  1 -1   4    4     2     .     . 
15.10 1 0  1  1  1  54   21     .     .     . 
12.50 0 0  1  1  1  29   21     .     .     . 
12.93 0 1  1  1  1 100    .    14    29     . 
 7.97 1 0  1  1  1  10    .     .     .     . 
14.33 0 1  1 -1 -1 156    .    39     .     . 
 3.83 1 1 -1  1 -1   0    .     .     .     . 
12.50 0 1  1 -1 -1  59   43    61    25     . 
12.20 0 0  1  1 -1   6    4     .     .     . 
12.27 0 0  1  1 -1  71    .     .     6     . 
12.77 0 1  1  1 -1  27    8    13    18     . 
16.47 0 0  1  1 -1  15    3     3     4     . 
20.23 0 0  1 -1 -1  63   30    22     4     . 
15.47 1 1  1  1 -1  25  163   113    59     . 
 3.20 1 1  1  1  1  14    .     .     .     . 
13.50 0 0  1  1 -1  21   15     5     .     . 
19.20 0 0  1 -1 -1 197  154   135   110    31 
12.23 0 1 -1 -1 -1 130  582     .     .     . 
17.80 0 0  1 -1 -1  16   37    10     8     . 
16.70 0 0  1  1  1  37   26     0     8     . 
13.87 1 1  1  1 -1  10   12     9     .     . 
16.30 0 0  1 -1 -1  50   40    20    10     . 
16.23 0 0  1 -1 -1 109   42    18     .     . 
20.40 0 1  1 -1 -1  89   19    43     9     6 
11.30 1 1  1 -1 -1  52   15    26     .     . 
18.60 0 0  1 -1 -1  42   23    30    11    15 
13.20 1 1  1  1  1   7    .     1     .     . 
10.93 1 1  1  1 -1  10    0     5     .     . 
17.17 0 1  1 -1 -1 232  221   166   141     . 
16.40 1 0  1  1  1 117   17     .    55     . 
16.23 0 1  1 -1 -1 288  268   150   298     . 
16.03 0 0  1 -1 -1 168  226   129   144     . 
16.03 0 0  1  1  1 169  149    93    45     . 
14.63 1 0  1  1 -1  12   16     0     .     . 
15.27 0 1  1 -1 -1 126  246   153   140     . 
14.83 0 1  1 -1 -1 136  112     .    86     . 
14.60 0 0  1 -1 -1   1    3     0     0     . 
10.23 1 1  1 -1 -1  91   37     .     .     . 
13.83 0 0  1 -1 -1 280    .   319     .     . 
14.13 0 0  1 -1 -1 160  115    57    69     . 
13.13 0 1  1 -1 -1  46   31     8    10     . 
13.03 0 1  1  1 -1   5    3     3     7     .  
 6.63 1 1  1  1  1   0    .     .     .     . 
18.37 0 1  1 -1 -1 246  333     .   232   177 
16.20 0 1  1 -1 -1 224    .   204   141     . 
13.47 0 1  1 -1 -1 240  360     .   310     . 
13.20 0 0 -1  1 -1 198  172     .   286     . 
18.17 0 0  1  1  1  66   89    81    18     . 
15.57 0 1  1  1  1  40   15    34     5     . 
 5.43 1 1  1  1  1  10   30     .     .     . 
10.30 1 1  1  1  1  30    .     .     .     . 
18.37 0 0  1 -1 -1 120  160   120   130    80 
17.80 1 0  1  1  1  50    .    20    10     . 
17.80 0 1  1 -1 -1  47  110    63    20     . 
16.63 1 0  1  1  1  20   10    20     .     . 
17.37 0 0  1  1 -1  30   40    95    50     . 
15.90 0 0  1 -1 -1  80   50    60    10     . 
17.33 0 0  1  1  1  30    4    40    10     . 
 9.37 1 1  1  1  1  76  110     .     .     . 
16.97 0 0  1 -1 -1 250    .   210   220     . 
17.10 0 0  1 -1 -1  30   40    40   320     . 
 9.37 1 0  1  1  1 100   40     .     .     . 
15.80 0 0  1  1  1 140  105     .    89     . 
15.50 0 0  1  1  1  20   20    10    20     . 
15.10 0 0  1 -1 -1 270  290   220   240     . 
11.93 1 1  1  1 -1  40   20    30     .     . 
14.63 0 0  1 -1 -1 190   90   130    80     . 
 3.13 1 1  1  1  1  40    .     .     .     . 
14.57 0 1  1 -1 -1  40   80    20    20     . 
14.33 0 0  1  1 -1  70   40    30     0     . 
13.93 0 1  1 -1 -1 180  260   160   180     . 
13.37 0 1  1  1  1   0    .    60    70     . 
13.23 0 0  1 -1 -1 190  280   130   200     . 
12.97 0 0  1 -1 -1 270  370   360   350     . 
14.87 0 1  1  1 -1   7    4     6   287     . 
 1.83 0 1  1  1 -1 370    .     .     .     . 
13.73 0 0  1  1 -1  24    3    11     7     . 
16.93 0 1 -1  1 -1 144  237   242   119     . 
16.17 0 1  1  1  1  13   27     .    19     . 
12.27 0 1  1 -1 -1 104  174   194     .     . 
12.53 0 0  1  1  1  25    0     9    23     . 
12.77 0 1  1 -1 -1 110  250   170    80     . 
 1.70 1 1  1  1 -1  20    .     .     .     . 
 2.17 0 0  1 -1 -1 130    .     .     .     . 
12.30 0 1  1 -1 -1 160  230   300   200     . 
12.23 0 1  1 -1 -1 190  300   150   240     . 
12.23 0 0  1  1 -1  20   10     0     4     . 
 7.03 1 1  1  1  1   5    0     .     .     . 
 3.30 1 0 -1  1  1  59    .     .     .     . 
11.60 1 1 -1  1  1   5   14     5     .     . 
12.20 0 1 -1  1 -1  28    .    46     .     . 
 4.33 1 1  1  1  1   6    5     .     .     . 
17.57 0 0  1 -1 -1 107  126    72    14     . 
 4.53 1 1  1  1  1  23    .     .     .     . 
13.73 0 0  1  1  1   4    5     4     9     . 
18.80 0 1  1  1  1  32   39    46    30    34 
18.57 0 1  1 -1 -1 143  154   264   176     . 
 2.47 1 0  1  1  1  14    8     .     .     . 
12.43 0 0  1 -1 -1 273  383   263   369     . 
12.30 1 1  1  1  1  72   20     9     .     . 
11.90 1 0  1  1 -1  77   19     .     .     . 
13.37 0 1  1 -1 -1  95  234   216    98     . 
17.67 0 0  1  1  1  94   53    29     5     . 
 9.93 1 1  1  1 -1 165    .    35     .     . 
12.27 1 1  1  1 -1   6   18     .     .     . 
18.33 0 0  1  1 -1 281  207   160    71    62
17.67 0 0  1  1 -1  17   10     .     .     . 
11.20 1 1  1  1 -1   7   15    11     .     . 
18.13 0 1  1 -1 -1 109   92    85     .    68 
18.57 0 0  1 -1 -1 222  136     .   179     . 
17.93 0 1  1 -1 -1   6   10     8     5    11 
16.23 0 0  1 -1 -1  10    8     3     .     . 
17.20 0 1 -1  1 -1  21   17     8     .     . 
11.47 1 1  1  1 -1  10    .     .     .     . 
10.70 1 0  1  1  1   0   21     .     .     . 
 2.17 1 0  1  1 -1  13    .     .     .     . 
 2.70 1 0  1  1 -1  14    .     .     .     . 
12.67 0 1  1  1 -1   9    .    10    30     . 
12.70 0 1  1  1 -1  11    7    14    16     . 
17.03 1 0  1  1  1  53   27     .     .     . 
14.70 1 0  1 -1 -1 131  129   122    66     . 
13.30 1 1  1  1  1   3    7     .     .     . 
13.87 0 1  1 -1 -1 216  249    14   139     . 
10.87 1 1  1  1  1   8    7     .     .     . 
16.73 0 1  1  1 -1  37   30    21    16     . 
13.20 0 0  1 -1 -1 200    .   203   209     . 
13.90 0 0  1 -1 -1  32   57    13     7     . 
15.37 0 0  1 -1 -1  67   40    32    54     . 
15.97 0 0  1 -1 -1 235    .   134    53     . 
 7.93 1 0  1  1 -1  43   55     .     .     . 
16.00 0 1  1  1 -1  35   19    11     .     . 
15.60 0 1  1 -1 -1 228  235    29   294     . 
14.63 0 1  1 -1 -1 109  124    88     .     . 
14.43 1 1  1  1  1  11    .     .     .     . 
14.10 0 0  1 -1 -1  82    .     .     .     . 
14.07 0 0  1  1  1 112    9     5     .     . 
12.47 0 1 -1 -1 -1 181  110     .     .     . 
12.67 0 0  1  1  1  76   18    11     7     . 
12.33 0 0  1  1  1 152  168   144    68     . 
12.20 0 0  1  1  1   7    8     5     2     . 
16.17 0 0  1 -1 -1 230  253    17   170     . 
15.53 0 0 -1  1  1   2    3     2     4     . 
14.40 0 0  1  1  1   1    2     1     1     . 
12.70 0 0  1  1 -1   9   22     8    11     . 
19.27 0 0 -1 -1 -1 281  300   368   202   130 
 4.53 1 1 -1  1 -1   5    .     .     .     . 
20.67 0 0  1  1 -1  12   35    34    14    14 
 3.37 1 0  1  1 -1 277   84     .     .     . 
12.23 0 1  1  1  1   4    3     1     1     . 
19.27 0 0 -1  1  1   2    2     2     2     . 
14.20 0 1  1 -1 -1 254  284   291   204     . 
12.23 0 0  1  1 -1  51   75    78     .     . 
 9.80 1 1  1  1  1   6    2     1     .     . 
14.20 0 1  1  1 -1  19   27    34    12     . 
12.73 0 0 -1  1 -1  16   10     3     4     . 
12.73 0 1  1 -1 -1   2    6     1     1     . 
12.63 1 1  1  1 -1   8   12     4     .     . 
10.03 1 0  1  1  1  17    4     7     .     . 
13.27 0 1  1 -1 -1  11    8     .     5     . 
19.77 0 1  1 -1 -1  41   52    30     1     . 
19.53 0 1  1  1  1  54   39    23    14    19 
18.37 0 1  1  1  1  16    .    10     2     4 
15.93 0 1  1 -1 -1  70   35    49    26     . 
 5.03 1 1  1  1  1  10    .     .     .     . 
20.27 0 0  1 -1 -1  10   10     4     .     . 
12.93 0 1  1  1  1   8    9     6     9     . 
11.00 1 0  1  1 -1  12    .     6     .     . 
19.57 0 0  1  1  1  10    8     3     7     . 
 8.13 1 1  1  1 -1  17    3     1     .     . 
21.40 0 1  1  1  1  15    5     1     1     . 
21.13 0 1  1  1  1  31   26    27    12     . 
21.13 0 1  1  1 -1  40    9     .     .     . 
 5.53 1 1  1  1 -1  44   30     .     .     . 
 3.57 1 0  1  1  1  40    6     .     .     . 
 2.57 1 1  1  1  1  12    .     .     .     . 
12.27 0 1  1  1  1  80   35    47     3     . 
19.57 0 1  1 -1 -1  99  200   152   191     . 
13.90 0 0  1  1  1   8    .     .     5     . 
 1.43 1 0 -1  1 -1   3    .     .     .     . 
12.20 0 0  1  1 -1  34   34    36    13     . 
15.97 0 1  1 -1 -1  60   33    37    14     . 
17.83 0 0  1  1 -1  38   17    12    55     . 
12.37 1 0  1  1  1  31   22    10     .     . 
 8.80 1 0  1  1  1  34   13     9     .     . 
16.20 0 1  1  1  1  11   11     3     .     . 
 9.57 1 1  1  1  1  77   51    37     .     . 
10.63 1 1  1  1 -1   9   21     .     .     . 
13.87 0 1  1 -1 -1 122  112    77    72     . 
13.43 0 0  1 -1 -1 273  129   163   154     . 
13.03 0 0  1  1  1  81   52    26     .     . 
12.33 0 1  1  1  1  10    7    14    10     . 
12.30 0 0 -1  1  1   4    .     6     .     . 
12.07 1 0  1  1  1  35    .    11     4     . 
12.33 0 0  1 -1 -1  65   58    22    15     . 
 9.60 1 0  1  1  1   7    4     6     .     . 
15.97 0 0  1 -1 -1 180  238   171    65     . 
11.30 1 0  1  1  1   4    8     3     .     . 
20.87 0 0  1 -1 -1  93  142     .    15     . 
13.90 1 0 -1 -1 -1 297  122    89    40     . 
18.97 0 0  1 -1 -1 300  330   290   270   340 
 4.97 1 0  1  1 -1  13   10     .     .     . 
18.17 0 1  1  1  1   8   15    17    12     8 
18.07 1 0  1  1  1   3    3     8     6     3 
15.93 0 1  1  1  1   7    9     2     .     . 
18.37 0 1  1  1  1 273  152    65    38    21 
15.97 0 1  1  1 -1 137  121   146   138     . 
17.70 0 0  1 -1 -1  42    .     .     .     . 
 3.63 1 1  1  1  1   8    .     .     .     . 
 3.97 1 0  1 -1 -1  62    .     .     .     . 
17.37 0 1  1  1 -1   3    4     3     4     . 
10.07 1 0  1  1  1  13    7     3     .     . 
17.00 0 0  1  1  1  37   17    20     1     . 
11.67 1 0  1  1  1   6    3     1     .     . 
17.20 0 1  1 -1 -1 128    .    24    15     . 
 6.13 1 1  1 -1 -1  64   28     .     .     . 
 2.03 1 1  1  1  1   2    .     .     .     . 
16.47 0 1  1 -1 -1 125  147   203   113     . 
16.23 0 0  1  1  1  18   30    22     .     . 
16.03 0 0  1 -1 -1  21    .     8     7     . 
15.77 0 0  1  1 -1  47   56     .     .     . 
 7.40 1 1  1  1 -1   5    5     4     .     . 
10.80 1 0  1  1  1  11   12     8     .     . 
12.57 0 0 -1 -1 -1 184  138    37     .     . 
 1.13 1 1 -1  1  1  12    .     .     .     . 
13.20 0 0  1  1  1   7   10     9     4     . 
13.47 0 1 -1 -1 -1  40   29    28    20     . 
13.90 0 0 -1  1 -1 100  145    88    45     . 
13.93 0 1 -1 -1 -1 113  116   173   126     . 
14.60 0 1  1  1 -1  74   56    29    27     . 
14.43 0 0 -1 -1 -1 161  176     .    30     . 
 1.07 1 0  1  1 -1   5    .     .     .     . 
 7.17 1 0  1  1 -1  31   24    31     .     . 
15.33 0 1  1  1  1 233  269   182    71     . 
15.57 0 1  1  1 -1  63   71    16    16     . 
12.23 0 1  1  1  1 247  289   219     .     . 
11.50 1 1  1  1  1  10   20     .     .     . 
12.23 0 0  1 -1 -1 291  367   323   267     . 
12.27 0 0 -1 -1 -1  30   41    22    16     . 
12.23 0 0  1  1 -1   5    .     .     .     . 
12.53 0 1  1  1 -1 108  475   284   151     . 
 6.30 1 1  1 -1 -1  13   15     .     .     . 
 0.47 1 1 -1 -1 -1 341    .     .     .     .  
 4.10 1 1  1  1  1   6    6     .     .     . 
12.23 0 0  1  1  1   7   12     9     0     . 
 8.17 1 1  1  1 -1  23   54     .     .     . 
20.50 0 1  1  1  1  27   33    18     5    12 
19.80 0 1  1  1 -1  52   48    84    63    20 
 6.90 1 1  1  1  1   0    .    15     .     . 
 3.43 1 0  1  1  1   0    .     .     .     . 
 7.97 1 0  1  1 -1   4   10     0     .     . 
15.33 1 1  1  1 -1  14    .     .     0     . 
 5.37 1 0  1 -1 -1  48  143     .     .     . 
13.90 0 0  1 -1 -1  49   77     .    90     . 
 3.20 1 0  1  1 -1   5    2     .     .     . 
17.83 0 1  1 -1 -1  63  110    55    26     . 
19.93 0 0  1  1  1   6    0     .     5     . 
18.63 1 0  1  1  1   8    0     .     .     . 
 8.47 1 0  1  1  1  10    .     7     .     . 
16.87 0 0  1 -1 -1 237  306   286   276     . 
11.93 1 1  1 -1 -1  66   70     .     .     . 
18.77 0 0  1  1  1 155  104     .   184     . 
 7.83 1 1  1 -1 -1 281    .     .     .     . 
 1.63 1 1  1  1  1   0    .     .     .     . 
13.50 0 0 -1 -1 -1 201  238   240   418     . 
 6.07 1 1  1  1  1   6    0     .     .     . 
 8.30 1 1  1  1 -1  20   12    12     .     . 
19.80 0 0  1  1 -1  27   20    11     .     . 
13.60 1 0  1  1 -1 110   57    41     .     . 
17.23 0 0  1  1  1  37   40     .     .     . 
16.50 0 0  1 -1 -1   3    5     1     .     . 
13.40 0 1 -1 -1 -1 176  207   383   161     . 
17.63 0 0  1  1  1 217   90    97     9     . 
 8.33 1 0  1  1  1  84   39     .     .     . 
10.70 1 0  1  1 -1  22   14     6     .     . 
12.53 0 0  1  1  1   8   29    16     7     . 
 9.67 1 1  1 -1 -1  80   51     .     .     . 
12.20 0 0  1  1  1 224  194   125     .     . 
18.17 0 1  1  1 -1  13   19     .     3     2 
 7.70 1 0  1 -1 -1  96   53     .     .     . 
 8.73 1 0  1  1  1  10   17     9     .     . 
 2.13 1 1  1  1 -1  30    .     .     .     . 
13.00 0 0  1  1 -1  57   55     .    11     . 
11.63 1 1  1  1  1   2    3    11     .     . 
 3.00 1 0  1  1 -1  19    .     .     .     . 
12.70 0 1  1  1 -1  39   14    16     .     . 
16.93 0 1  1 -1 -1 288  323   357   369     . 
 9.63 1 0  1  1  1  15   11     3     .     . 
15.07 1 1  1  1 -1  43   13     .     .     . 
 9.93 1 1  1  1  1  14   14    10     .     . 
16.50 0 1  1 -1 -1 125    .     .     .     . 
16.97 0 1  1  1  1   7    7     3    11     . 
14.40 0 1  1  1 -1  14    9    10     7     . 
 6.60 1 1  1  1  1   2    8     .     .     . 
12.53 0 0  1  1 -1  11    7     8     0     . 
 5.23 1 0  1  1 -1   5    7     .     .     . 
13.00 0 1  1  1  1  46   47    35    25     . 
 3.40 1 0 -1  1 -1   3    2     .     .     . 
16.03 0 0  1 -1 -1 132   90    60    23     . 
12.20 1 1  1  1  1  84   57    54     .     . 
 6.87 1 1  1  1  1  26    .     .     .     . 
15.03 0 1  1 -1 -1 239  200    89    51     . 
 1.03 1 0  1  1 -1   4    .     .     .     . 
14.10 0 0  1  1 -1  29   23    35     .     . 
10.60 1 1  1 -1 -1  21  113     5     .     . 
 4.20 1 1  1 -1 -1 166    .     .     .     . 
13.60 0 1  1 -1 -1 273   87   359   285     . 
13.00 0 0  1  1 -1 181    .     .     .     . 
13.50 0 1  1  1 -1   2    4     2     0     . 
13.20 0 0  1  1  1  28   43    28    28     . 
13.20 0 0  1  1 -1  70   60    66    49     . 
 9.73 1 1  1 -1 -1  76  105    40     .     . 
13.60 0 0  1 -1 -1  78    .     .     .     . 
20.63 0 1  1 -1 -1  75  132     .     .     . 
 1.43 1 0  1  1  1  36    .     .     .     . 
12.43 0 0  1  1 -1  12    6    16    13     . 
 8.00 1 0 -1  1  1  40    .    28     .     . 
12.47 0 0  1  1 -1  16   50    17     5     . 
 2.47 1 0  1  1  1   5    .     .     .     . 
 9.07 1 1  1  1  1   3   12     .     .     . 
14.13 1 1  1  1  1  56   45     9     8     . 
15.17 1 0  1  1 -1  66   78    50    32     . 
17.70 0 0  1 -1 -1  65   96    60    91     . 
16.63 1 1  1 -1 -1 272  240   234    98     . 
14.30 0 0  1  1  1  60   24    90    76     . 
12.43 0 1 -1 -1 -1 105  272   375   150     . 
 7.30 1 1  1  1 -1  36   32    42     .     . 
 5.57 1 0  1  1  1  24    4     .     .     . 
17.20 0 0  1  1  1 300  270   143   160     . 
 7.73 1 0  1 -1 -1  20   18    10     .     . 
19.80 0 0  1 -1 -1  13   14     6     7     7 
16.47 0 1  1  1 -1  42   20    30    18     . 
13.50 0 0  1  1 -1  27   42     6     6     . 
11.50 1 1  1  1  1   7    9    21     .     . 
12.47 1 1  1 -1 -1  70   63    30     .     . 
 5.07 1 1  1  1 -1 159   73     .     .     . 
12.70 1 1  1  1  1  14   16     5     .     . 
19.03 0 1  1  1  1 138  140   154   120   126 
 7.93 0 1  1  1 -1 169  144    84     .     . 
19.07 1 0  1  1  1  40   36     .    10     . 
 0.90 1 1 -1  1  1  40    .     .     .     . 
19.70 0 1  1 -1 -1  24   15     5     5     3 
13.10 1 0  1 -1 -1  21   12    24   102     . 
20.87 0 0  1 -1 -1   6   24     .     .     . 
17.27 1 0  1  1  1  10   20    14     3     . 
13.37 0 1  1  1 -1 190  136     .     .     . 
 9.33 1 1  1 -1 -1 220  400   240     .     . 
12.30 0 1  1  1  1 247  300   220   242     . 
10.23 1 1  1  1  1   9   30    10     .     . 
 3.30 1 1  1  1  1   3   21     .     .     . 
14.33 0 1  1 -1 -1   7   10     6     7     . 
 2.00 1 0  1  1 -1  24    .     .     .     . 
13.30 1 1  1  1  1  10    6    12     .     . 
15.07 0 0 -1  1 -1   9   10     .     .     . 
 3.90 1 0  1  1  1  30    5     .     .     . 
; 

proc sort data=alldata; 
   by patient obstime;
data alldata; 
   set alldata; 
   by patient;
   last = last.patient;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 15.11                                     ---*/ 
title1 'The first 20 observations of the joint data';
proc print data=alldata(obs=20);
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Fit the longitudinal part with PROC MIXED        ---*/
 /*---The FA0(2) structure will yield parameter estimates-*/
 /*---identical to the Cholesky root of an unstructured --*/
 /*---variance-covariance matrix. This is the parameteri- */
 /*---zation chosen below in NLMIXED.                  ---*/

 /*-For comparison with NLMIXED below we choose ML esti- -*/
 /*-mation. The MIXED default would be REML.           ---*/
 /*---Output 15.12                                     ---*/
title1 'Longitudinal Model - MIXED';
proc mixed data=alldata noclprint covtest method=ml;
   class patient;
   model cd4 = obstime obstime*randgrp1 gender1 prevoi1 stratum1 / s;
   random intercept obstime / subject=patient type=fa0(2);
   ods output covparms=cp;
   ods output solutionf=solf;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Fit the survival part of the model               ---*/
 /*---Output 15.13                                     ---*/
title1 'Survival Model - LIFEREG';
proc lifereg data=alldata(where=(last=1));
   model t2death*death(0)=randgrp1 gender1 prevoi1 stratum1
          / dist=exponential;
   ods output ParameterEstimates=survpe(rename=(Parameter=SurvEffect));
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Combine the estimates from the separate models   ---*/
 /*---You can use this data set for comparison with the---*/
 /*---estimates in the joint model and to provide      ---*/
 /*---starting values in the joint model               ---*/
data SeparateEstimates; set solf cp survpe;
  length Parameter $5;
  select ; 
    when ( Effect    = 'Intercept'        ) Parameter = 'bl0'  ; 
    when ( Effect    = 'obstime'          ) Parameter = 'bl1'  ; 
    when ( Effect    = 'obstime*randgrp1' ) Parameter = 'bl2'  ; 
    when ( Effect    = 'gender1'          ) Parameter = 'bl3'  ; 
    when ( Effect    = 'prevoi1'          ) Parameter = 'bl4'  ;
    when ( Effect    = 'stratum1'         ) Parameter = 'bl5'  ;
    when ( CovParm   = 'FA(1,1)'          ) Parameter = 'a11'  ;
    when ( CovParm   = 'FA(2,1)'          ) Parameter = 'a12'  ;
    when ( CovParm   = 'FA(2,2)'          ) Parameter = 'a22'  ;
    when ( CovParm   = 'Residual'         ) Parameter = 's2'   ;
    when ( SurvEffect= 'Intercept'        ) Parameter = 'bs0'  ;
    when ( SurvEffect= 'randgrp1'         ) Parameter = 'bs1'  ;
    when ( SurvEffect= 'gender1'          ) Parameter = 'bs2'  ;
    when ( SurvEffect= 'prevoi1'          ) Parameter = 'bs3'  ;
    when ( SurvEffect= 'stratum1'         ) Parameter = 'bs4'  ;
    otherwise Parameter = '';
  end;
  if Parameter ne '';
  keep Parameter Estimate StdErr;
  rename Estimate=SeparateEstimate StdErr=SeparateStdErr;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Model XI in Guo and Carlin (2003)                ---*/
 /*---Fit by maximum likelihood with NLMIXED.          ---*/
 /*---Marginal log likelihood is computed by Gaussian  ---*/
 /*---quadrature.                                      ---*/
 /*---Output 15.14                                     ---*/
 /*-------------------------------------------------------*/
title1 'Joint Model - NLMIXED';
proc nlmixed data=alldata;

    /*---All parameters not assigned starting values   ---*/
    /*---explicitly are assigned the default value (1) ---*/
    parameters r1=0.13;

    /*---Compute log likelihood contribution of the    ---*/
    /*---survival data part when the last observaion   ---*/
    /*---of a subject is reached                       ---*/

    /*---NOTE: This parameterization yields estimates  ---*/
    /*---      equivalent to those in LIFEREG          ---*/
    if (last) then do;
      linpsurv  = bs0 + bs1*randgrp1 +
                        bs2*gender1  +
                        bs3*prevoi1  +
                        bs4*stratum1 + r1*u0 + r2*u1;
      alpha  = exp(-linpsurv);
      G_t    = exp(-alpha*t2death);
      g      = alpha*G_t;
      llsurv = (death=1)*log(g) + (death=0)*log(G_t);
    end; else llsurv=0;

    /*---Cholesky parameterization of the random effects ---*/
    /*---variance matrix.                                ---*/
    /*---This ensures that the variance-covariance matrix---*/
    /*---of the random effects is non-negative definite  ---*/
    v11 = a11*a11;
    v12 = a11*a12;
    v22 = a12*a12 + a22*a22;

    /*---Compute the contribution of the longitudinal    ---*/
    /*---part. Every observation in the data set         ---*/
    /*---makes a contribution. Notice that conditional   ---*/
    /*---on the random effects we have independent       ---*/
    /*---Gaussian contributions                          ---*/
    linplong = (bl0 + u0)            +
               (bl1 + u1)*obstime    +
                bl2*obstime*randgrp1 +
                bl3*gender1          +
                bl4*prevoi1          +
                bl5*stratum1;
    
    resid = (cd4-linplong);
    if (abs(resid) > 1.3E100) or (s2 < 1e-12) then do;
       lllong = -1e20;
    end; else do;
       lllong = -0.5*(1.837876 + resid**2 / s2  + log(s2));
    end;

    /*---Any numeric variable in the data set can be used---*/
    /*---as the response in the MODEL statement. It has  ---*/
    /*---no bearing on the results                       ---*/
    model last ~ general(lllong + llsurv);
    random u0 u1 ~ normal([0, 0],[v11,v12,v22]) subject=patient;

    /*---Compute median of the patient-specific          ---*/
    /*---survival distributions                          ---*/
    predict (1/alpha)* log(2) out=median;

    /*---Compute the variances and covariance of the random-*/
    /*---effects and obtain their std. errors by the delta--*/
    /*---method                                          ---*/
    estimate 'Var[U0]'    v11;
    estimate 'Cov[U0,U1]' v12;
    estimate 'Var[U1]'    v22;

    ods output ParameterEstimates=JointEstimates;
run;


 /*---Compare estimates in joint and separate models   ---*/
proc sort data=SeparateEstimates; by Parameter;
proc sort data=JointEstimates;    by Parameter;
data Estimates; merge SeparateEstimates JointEstimates; by Parameter;
run;

title1 'Estimates and Standard Errors from Separate and Joint Analysis';
proc print data=Estimates label;
    label SeparateEstimate = 'MLE in separate models'
          SeparateStdErr   = 'Asymptotic Std. Error of MLE in separate models'
          Estimate         = 'MLE in joint model'
          StandardError    = 'Asymptotic Std. Error of MLE in joint model';
    var SeparateEstimate SeparateStdErr
        Estimate         StandardError;
    id  Parameter;
run;


 /*---Extract predicted patient-specific median        ---*/
title1 'Patient Specific Modes and Medians for Patients 450 and 454';
title2 'With Standard Errors and Confidence Intervals';
proc print data=median(where=( ((patient=450) or (patient=454)) and (last=1)));
   var patient pred stderrpred lower upper;
run;
title1;
 /*-------------------------------------------------------*/



 /*-------------------------------------------------------*/
 /*---Phenobarbital data from Grasela and Donn (1985)  ---*/
 /*---Data set 15.7 in Appendix 2                     ---*/
data pheno;
   input indiv time dose weight apgar conc;
   retain cursub .;
   if cursub ne indiv then do;
      newsub = 1;
      cursub = indiv;
   end;
   else newsub = 0;
   if (apgar < 5) then apgarlow = 1;
   else apgarlow = 0;
   tlag = lag(time);
   if (newsub=1) then tlag = 0;
   drop apgar cursub; 
   datalines;   
 1    0.    25.0    1.4      7     . 
 1    2.0    0.0    1.4      7   17.3
 1   12.5    3.5    1.4      7     . 
 1   24.5    3.5    1.4      7     . 
 1   37.0    3.5    1.4      7     . 
 1   48.0    3.5    1.4      7     . 
 1   60.5    3.5    1.4      7     . 
 1   72.5    3.5    1.4      7     . 
 1   85.3    3.5    1.4      7     . 
 1   96.5    3.5    1.4      7     . 
 1  108.5    3.5    1.4      7     . 
 1  112.5    0.0    1.4      7   31.0
 2    0.    15.0    1.5      9     . 
 2    2.0    0.0    1.5      9    9.7
 2    4.0    3.8    1.5      9     . 
 2   16.0    3.8    1.5      9     . 
 2   27.8    3.8    1.5      9     . 
 2   40.0    3.8    1.5      9     . 
 2   52.0    3.8    1.5      9     . 
 2   63.5    0.0    1.5      9   24.6
 2   64.0    3.8    1.5      9     . 
 2   76.0    3.8    1.5      9     . 
 2   88.0    3.8    1.5      9     . 
 2  100.0    3.8    1.5      9     . 
 2  112.0    3.8    1.5      9     . 
 2  124.0    3.8    1.5      9     . 
 2  135.5    0.0    1.5      9   33.0
 3    0.    30.0    1.5      6     . 
 3    1.5    0.0    1.5      6   18.0
 3   11.5    3.7    1.5      6     . 
 3   23.5    3.7    1.5      6     . 
 3   35.5    3.7    1.5      6     . 
 3   47.5    3.7    1.5      6     . 
 3   59.3    3.7    1.5      6     . 
 3   73.0    3.7    1.5      6     . 
 3   83.5    0.0    1.5      6   23.8
 3   84.0    3.7    1.5      6     . 
 3   96.5    3.7    1.5      6     . 
 3  108.5    3.7    1.5      6     . 
 3  120.0    3.7    1.5      6     . 
 3  132.0    3.7    1.5      6     . 
 3  134.3    0.0    1.5      6   24.3
 4    0.    18.6    0.9      6     . 
 4    1.8    0.0    0.9      6   20.8
 4   12.0    2.3    0.9      6     . 
 4   24.3    2.3    0.9      6     . 
 4   35.8    2.3    0.9      6     . 
 4   48.1    2.3    0.9      6     . 
 4   59.3    0.0    0.9      6   23.9
 4   59.8    2.3    0.9      6     . 
 4   71.8    2.3    0.9      6     . 
 4   83.8    2.3    0.9      6     . 
 4   95.8    2.3    0.9      6     . 
 4  107.8    2.3    0.9      6     . 
 4  119.8    2.3    0.9      6     . 
 4  130.8    0.0    0.9      6   31.7
 5    0.    27.0    1.4      7     . 
 5    2.0    0.0    1.4      7   14.2
 5   12.0    3.4    1.4      7     . 
 5   24.0    3.4    1.4      7     . 
 5   36.0    3.4    1.4      7     . 
 5   48.0    3.4    1.4      7     . 
 5   59.5    0.0    1.4      7   18.2
 5   60.0    3.4    1.4      7     . 
 5   72.0    3.4    1.4      7     . 
 5   84.0    3.4    1.4      7     . 
 5   96.0    3.4    1.4      7     . 
 5  108.0    3.4    1.4      7     . 
 5  120.0    3.4    1.4      7     . 
 5  132.0    0.0    1.4      7   20.3
 6    0.    24.0    1.2      5     . 
 6    1.8    0.0    1.2      5   19.0
 6   11.8    3.0    1.2      5     . 
 6   23.8    3.0    1.2      5     . 
 6   35.8    3.0    1.2      5     . 
 6   47.8    3.0    1.2      5     . 
 6   59.3    0.0    1.2      5   17.3
 6   59.8    3.0    1.2      5     . 
 6   71.8    3.0    1.2      5     . 
 6   83.8    3.0    1.2      5     . 
 6   95.8    3.0    1.2      5     . 
 6  107.8    3.0    1.2      5     . 
 6  120.1    3.0    1.2      5     . 
 6  131.8    3.0    1.2      5     . 
 6  142.8    0.0    1.2      5   32.5
 7    0.    19.0    1.0      5     . 
 7    2.0    0.0    1.0      5   17.9
 7   11.3    2.4    1.0      5     . 
 7   23.3    2.4    1.0      5     . 
 7   36.5    2.4    1.0      5     . 
 7   48.2    2.4    1.0      5     . 
 7   60.3    2.4    1.0      5     . 
 7   73.8    0.0    1.0      5   23.4
 7   75.8    2.4    1.0      5     . 
 7   84.3    2.4    1.0      5     . 
 7   96.3    2.4    1.0      5     . 
 7  108.3    2.4    1.0      5     . 
 7  120.3    2.4    1.0      5     . 
 7  132.3    2.4    1.0      5     . 
 7  144.5    2.4    1.0      5     . 
 7  165.3    0.0    1.0      5   25.8
 8    0.    24.0    1.2      7     . 
 8    1.7    0.0    1.2      7   25.8
 8   11.8    3.0    1.2      7     . 
 8   23.7    3.0    1.2      7     . 
 8   35.7    3.0    1.2      7     . 
 8   47.7    3.0    1.2      7     . 
 8   59.7    3.0    1.2      7     . 
 8   71.7    3.0    1.2      7     . 
 8   73.7    0.0    1.2      7   34.2
 8   83.7    3.0    1.2      7     . 
 8   95.7    3.0    1.2      7     . 
 8  107.7    3.0    1.2      7     . 
 8  119.7    3.0    1.2      7     . 
 8  131.7    3.0    1.2      7     . 
 8  143.7    3.0    1.2      7     . 
 8  146.7    0.0    1.2      7   36.1
 9    0.    27.0    1.4      8     . 
 9    1.1    0.0    1.4      8   22.1
 9   11.1    3.2    1.4      8     . 
 9   22.3    3.2    1.4      8     . 
 9   34.6    3.2    1.4      8     . 
 9   46.6    3.2    1.4      8     . 
 9   58.7    3.2    1.4      8     . 
 9   70.9    3.2    1.4      8     . 
 9   82.7    0.0    1.4      8   29.2
 9   83.2    3.2    1.4      8     . 
 9   94.6    3.2    1.4      8     . 
 9  106.6    3.2    1.4      8     . 
 9  118.6    3.2    1.4      8     . 
 9  130.6    3.2    1.4      8     . 
 9  142.1    0.0    1.4      8   34.2
 9  142.6    3.2    1.4      8     . 
 9  312.6    0.0    1.4      8   19.6
10    0.    27.0    1.4      7     . 
10    1.2    0.0    1.4      7   19.9
10   11.2    3.5    1.4      7     . 
10   23.2    3.5    1.4      7     . 
10   35.3    3.5    1.4      7     . 
10   47.2    3.5    1.4      7     . 
10   59.2    3.5    1.4      7     . 
10   70.7    0.0    1.4      7   23.4
10   71.2    3.5    1.4      7     . 
10   83.2    3.5    1.4      7     . 
10   95.2    3.5    1.4      7     . 
10  107.2    3.5    1.4      7     . 
10  119.2    3.5    1.4      7     . 
10  131.2    3.5    1.4      7     . 
10  142.2    0.0    1.4      7   30.9
11    0.    24.0    1.2      7     . 
11   11.5   24.0    1.2      7     . 
11   23.5    3.0    1.2      7     . 
11   35.5    3.0    1.2      7     . 
11   47.5    3.0    1.2      7     . 
11   57.5    0.0    1.2      7   24.3
12    0.    26.0    1.3      6     . 
12    2.0    0.0    1.3      6   17.0
12   12.0    3.3    1.3      6     . 
12   13.0    5.0    1.3      6     . 
12   24.5    3.3    1.3      6     . 
12   36.0    3.3    1.3      6     . 
12   48.5    3.3    1.3      6     . 
12   60.0    3.3    1.3      6     . 
12   72.0    3.3    1.3      6     . 
12   84.0    3.3    1.3      6     . 
12   96.0    3.3    1.3      6     . 
12  108.0    3.3    1.3      6     . 
12  120.0    3.3    1.3      6     . 
12  132.2    0.0    1.3      6   34.1
12  132.5    3.3    1.3      6     . 
12  302.5    0.0    1.3      6   16.0
13    0.    11.0    1.1      6     . 
13   12.0   11.0    1.1      6     . 
13   25.0    2.8    1.1      6     . 
13   36.5    0.0    1.1      6   24.1
13   37.0    2.8    1.1      6     . 
13   49.0    2.8    1.1      6     . 
13   61.0    2.8    1.1      6     . 
13   74.0    2.8    1.1      6     . 
13   85.0    2.8    1.1      6     . 
13   98.0    2.8    1.1      6     . 
13  110.0    2.8    1.1      6     . 
13  121.3    2.8    1.1      6     . 
13  134.0    2.8    1.1      6     . 
13  145.0    2.8    1.1      6     . 
13  157.0    2.8    1.1      6     . 
13  169.0    0.0    1.1      6   38.2
14    0.    22.0    1.1      7     . 
14    2.3    0.0    1.1      7   25.6
14   11.8    2.8    1.1      7     . 
14   23.8    2.8    1.1      7     . 
14   35.8    2.8    1.1      7     . 
14   47.8    2.8    1.1      7     . 
14   59.3    0.0    1.1      7   25.6
14   59.8    2.8    1.1      7     . 
14   71.8    2.8    1.1      7     . 
14   83.8    2.8    1.1      7     . 
14   95.8    2.8    1.1      7     . 
14  107.3    2.8    1.1      7     . 
14  119.8    2.8    1.1      7     . 
14  131.5    0.0    1.1      7   25.7
14  131.8    2.8    1.1      7     . 
14  143.8    2.8    1.1      7     . 
14  303.3    0.0    1.1      7   14.3
15    0.    26.0    1.3      7     . 
15   12.2    3.3    1.3      7     . 
15   22.2    0.0    1.3      7   19.3
15   24.2    3.3    1.3      7     . 
15   36.2    3.3    1.3      7     . 
15   47.8    3.3    1.3      7     . 
15   70.2    3.3    1.3      7     . 
15   85.6    3.3    1.3      7     . 
15   96.2    3.3    1.3      7     . 
15  108.2    3.3    1.3      7     . 
15  120.2    3.3    1.3      7     . 
15  132.2    3.3    1.3      7     . 
15  143.7    3.3    1.3      7     . 
15  145.7    0.0    1.3      7   29.7
16    0.    12.0    1.2      9     . 
16    9.0   12.0    1.2      9     . 
16   12.0    0.0    1.2      9   17.3
16   15.4    4.0    1.2      9     . 
16   21.3    3.0    1.2      9     . 
16   33.0    3.0    1.2      9     . 
16   45.0    3.0    1.2      9     . 
16   56.0    0.0    1.2      9   26.8
16   57.0    3.0    1.2      9     . 
16   69.0    3.0    1.2      9     . 
16   81.0    3.0    1.2      9     . 
16   93.0    3.0    1.2      9     . 
16  105.0    3.0    1.2      9     . 
16  117.0    3.0    1.2      9     . 
16  129.5    3.0    1.2      9     . 
16  141.5    3.0    1.2      9     . 
16  152.8    3.0    1.2      9     . 
16  153.5    0.0    1.2      9   38.4
17    0.    22.0    1.1      5     . 
17   12.0    2.8    1.1      5     . 
17   24.0    2.8    1.1      5     . 
17   32.0    0.0    1.1      5   21.3
17   35.5    2.8    1.1      5     . 
17   48.0    2.8    1.1      5     . 
17   60.0    2.8    1.1      5     . 
17   72.0    0.0    1.1      5   28.8
17   72.3    2.8    1.1      5     . 
17   84.3    2.8    1.1      5     . 
17   95.8    2.8    1.1      5     . 
17  108.0    2.8    1.1      5     . 
17  120.0    2.8    1.1      5     . 
17  132.0    2.8    1.1      5     . 
17  144.0    2.8    1.1      5     . 
17  155.0    0.0    1.1      5   34.9
18    0.    20.0    1.0      5     . 
18    2.8    0.0    1.0      5   21.9
18   11.8   20.0    1.0      5     . 
18   23.8    2.5    1.0      5     . 
18   35.8    2.5    1.0      5     . 
18   48.1    2.5    1.0      5     . 
18   59.3    2.5    1.0      5     . 
18   71.3    0.0    1.0      5   25.9
18   71.8    2.5    1.0      5     . 
18   82.8    2.5    1.0      5     . 
18   95.8    2.5    1.0      5     . 
18  107.8    2.5    1.0      5     . 
18  119.8    2.5    1.0      5     . 
18  131.8    2.5    1.0      5     . 
18  143.8    0.0    1.0      5   28.9
18  389.8    0.0    1.0      5    6.7
19    0.    10.0    1.0      1     . 
19    4.0   10.0    1.0      1     . 
19    9.5    0.0    1.0      1   18.9
19   13.0    2.5    1.0      1     . 
19   24.0    2.5    1.0      1     . 
19   35.9    3.0    1.0      1     . 
19   48.0    3.0    1.0      1     . 
19   59.9    3.0    1.0      1     . 
19   72.0    3.0    1.0      1     . 
19   83.5    0.0    1.0      1   23.2
19   84.3    3.0    1.0      1     . 
19   96.0    3.0    1.0      1     . 
19  108.3    3.0    1.0      1     . 
19  120.0    3.0    1.0      1     . 
19  132.0    3.0    1.0      1     . 
19  144.0    3.0    1.0      1     . 
19  158.0    0.0    1.0      1   32.9
20    0.    24.0    1.2      6     . 
20    2.0    0.0    1.2      6   23.1
20   12.0    3.0    1.2      6     . 
20   24.0    3.0    1.2      6     . 
20   36.0    3.0    1.2      6     . 
20   48.0    3.0    1.2      6     . 
20   60.5    3.0    1.2      6     . 
20   62.5    0.0    1.2      6   27.8
20   72.0    3.0    1.2      6     . 
20   84.0    3.0    1.2      6     . 
20   95.5    3.0    1.2      6     . 
20  108.0    3.0    1.2      6     . 
20  120.0    3.0    1.2      6     . 
20  132.0    3.0    1.2      6     . 
20  134.0    0.0    1.2      6   34.0
21    0.    17.5    1.8      7     . 
21    4.2   17.5    1.8      7     . 
21    8.3    0.0    1.8      7   21.1
21   15.8    4.5    1.8      7     . 
21   28.0    4.5    1.8      7     . 
21   39.8    4.5    1.8      7     . 
21   51.8    4.5    1.8      7     . 
21   63.8    4.5    1.8      7     . 
21   76.8    4.5    1.8      7     . 
21   88.3    4.5    1.8      7     . 
21  100.8    4.5    1.8      7     . 
21  112.3    0.0    1.8      7   29.1
21  112.8    4.5    1.8      7     . 
21  124.3    4.5    1.8      7     . 
21  136.3    4.5    1.8      7     . 
21  148.8    4.5    1.8      7     . 
21  260.6    0.0    1.8      7   21.1
22    0.    15.0    1.5      8     . 
22    4.0   15.0    1.5      8     . 
22    6.0    0.0    1.5      8   21.8
22   16.0    4.0    1.5      8     . 
22   28.0    4.0    1.5      8     . 
22   40.0    4.0    1.5      8     . 
22   51.0    0.0    1.5      8   25.0
23    0.    60.0    3.1      3     . 
23   11.0    0.0    3.1      3   22.3
23   11.5    7.5    3.1      3     . 
23   24.0    7.5    3.1      3     . 
23   35.5    7.5    3.1      3     . 
23   47.0    7.5    3.1      3     . 
23   59.5    7.5    3.1      3     . 
23   70.5    0.0    3.1      3   26.6
23   71.5    7.5    3.1      3     . 
23   84.0    7.5    3.1      3     . 
23   95.8    7.5    3.1      3     . 
23  107.5    7.5    3.1      3     . 
23  120.0    7.5    3.1      3     . 
23  132.5    7.5    3.1      3     . 
23  140.0    0.0    3.1      3   27.7
24    0.    63.0    3.2      2     . 
24    0.7   63.0    3.2      2     . 
24    2.0    0.0    3.2      2   37.3
24    6.5   32.0    3.2      2     . 
24   16.0   10.0    3.2      2     . 
24   28.0   10.0    3.2      2     . 
24   40.0   10.0    3.2      2     . 
24   52.7   10.0    3.2      2     . 
24   64.0   10.0    3.2      2     . 
24   76.0   10.0    3.2      2     . 
24   79.0    0.0    3.2      2   41.7
24   88.0   10.0    3.2      2     . 
24  100.0   10.0    3.2      2     . 
24  112.0   10.0    3.2      2     . 
24  124.0   10.0    3.2      2     . 
24  136.0   10.0    3.2      2     . 
24  147.5   10.0    3.2      2     . 
24  176.0    0.0    3.2      2   38.1
25    0.    15.0    0.7      1     . 
25    2.0    0.0    0.7      1   13.7
25   12.0    1.9    0.7      1     . 
25   18.5    7.5    0.7      1     . 
25   21.0    0.0    0.7      1   21.8
25   23.7    1.5    0.7      1     . 
25   35.8    1.5    0.7      1     . 
25   48.3    1.5    0.7      1     . 
25   60.5    1.5    0.7      1     . 
25   61.5    0.0    0.7      1   16.7
25   70.7    5.0    0.7      1     . 
25   72.0    2.0    0.7      1     . 
25   84.0    2.0    0.7      1     . 
25   90.5    0.0    0.7      1   29.8
25   95.8    2.0    0.7      1     . 
25  108.0    2.0    0.7      1     . 
25  120.0    2.0    0.7      1     . 
25  121.5    0.0    0.7      1   38.0
25  132.0    2.0    0.7      1     . 
25  138.0    0.0    0.7      1   31.3
26    0.    70.0    3.5      9     . 
26   11.5    9.0    3.5      9     . 
26   23.5    9.0    3.5      9     . 
26   35.5    9.0    3.5      9     . 
26   37.5    0.0    3.5      9   28.6
26   47.5    9.0    3.5      9     . 
26   59.5    9.0    3.5      9     . 
26   71.5    9.0    3.5      9     . 
26   83.5    9.0    3.5      9     . 
26   95.5    9.0    3.5      9     . 
26  107.5    9.0    3.5      9     . 
26  110.5    0.0    3.5      9   34.9
27    0.    35.0    1.9      5     . 
27    1.7    0.0    1.9      5   26.4
27   12.4    5.0    1.9      5     . 
27   23.7    5.0    1.9      5     . 
27   35.2    5.0    1.9      5     . 
27   48.0    5.0    1.9      5     . 
27   59.7    5.0    1.9      5     . 
27   71.7    5.0    1.9      5     . 
27   83.2    0.0    1.9      5   33.3
28    0.    60.0    3.2      9     . 
28    2.0    0.0    3.2      9   16.9
29    0.    20.0    1.0      7     . 
29   12.0    2.5    1.0      7     . 
29   23.5    2.5    1.0      7     . 
29   36.5    2.5    1.0      7     . 
29   47.5    0.0    1.0      7   22.9
30    0.    18.0    1.8      8     . 
30    2.2   18.0    1.8      8     . 
30    6.3    0.0    1.8      8   17.9
30   15.3    3.5    1.8      8     . 
30   26.3    3.5    1.8      8     . 
30   38.8    3.5    1.8      8     . 
30   50.8    3.5    1.8      8     . 
30   62.8    3.5    1.8      8     . 
30   75.3    3.5    1.8      8     . 
30   87.3    3.5    1.8      8     . 
30   98.8    3.5    1.8      8     . 
30  110.8    3.5    1.8      8     . 
30  123.3    3.5    1.8      8     . 
30  134.8    3.5    1.8      8     . 
30  226.3    0.0    1.8      8   16.5
31    0.    30.0    1.4      8     . 
31    1.0    0.0    1.4      8   25.3
32    0.    70.0    3.6      9     . 
32    6.5    0.0    3.6      9   12.7
32   12.0    7.5    3.6      9     . 
32   21.6   35.0    3.6      9     . 
32   24.0    0.0    3.6      9   22.1
32   24.3    7.5    3.6      9     . 
32   35.6    7.5    3.6      9     . 
32   48.0    7.5    3.6      9     . 
32   61.0    7.5    3.6      9     . 
32   72.0    7.5    3.6      9     . 
32   83.5    0.0    3.6      9   21.2
33    0.    17.0    1.7      8     . 
33    4.0   17.0    1.7      8     . 
33    5.5    0.0    1.7      8   21.2
33   16.0    4.3    1.7      8     . 
33   28.0    4.3    1.7      8     . 
33   40.3    4.3    1.7      8     . 
33   52.0    4.3    1.7      8     . 
33   65.0    0.0    1.7      8   27.4
34    0.    34.0    1.7      4     . 
34    1.8    0.0    1.7      4   22.1
34   11.8    4.3    1.7      4     . 
34   23.8    4.3    1.7      4     . 
34   47.8    4.3    1.7      4     . 
34   59.8    4.0    1.7      4     . 
34   71.8    4.0    1.7      4     . 
34   83.8    4.0    1.7      4     . 
34   86.8    0.0    1.7      4   28.7
35    0.    25.0    2.5      5     . 
35    3.5   25.0    2.5      5     . 
35   15.0    6.0    2.5      5     . 
35   19.0    0.0    2.5      5   25.2
35   27.0    6.0    2.5      5     . 
35   39.0    6.0    2.5      5     . 
35   51.0    6.0    2.5      5     . 
35   63.0    6.0    2.5      5     . 
35   75.0    6.0    2.5      5     . 
35   87.0    6.0    2.5      5     . 
35   99.0    0.0    2.5      5   38.0
36    0.    30.0    1.5      5     . 
36    2.0    0.0    1.5      5   23.2
36   12.0    4.0    1.5      5     . 
36   23.5    4.0    1.5      5     . 
36   36.0    4.0    1.5      5     . 
36   48.0    4.0    1.5      5     . 
36   60.0    4.0    1.5      5     . 
36   72.0    4.0    1.5      5     . 
36   85.0    4.0    1.5      5     . 
36   96.0    4.0    1.5      5     . 
36  108.0    4.0    1.5      5     . 
36  120.0    4.0    1.5      5     . 
36  132.0    4.0    1.5      5     . 
36  134.0    0.0    1.5      5   28.9
36  304.0    0.0    1.5      5   12.7
37    0.    24.0    1.2      9     . 
37    2.3    0.0    1.2      9   19.5
37   11.8    3.0    1.2      9     . 
37   24.3    3.0    1.2      9     . 
37   36.3    3.0    1.2      9     . 
37   48.3    3.0    1.2      9     . 
37   60.3    3.0    1.2      9     . 
37   72.8    3.0    1.2      9     . 
37   84.3    3.0    1.2      9     . 
37   96.3    3.0    1.2      9     . 
37  108.3    3.0    1.2      9     . 
37  119.8    3.0    1.2      9     . 
37  132.3    3.0    1.2      9     . 
37  144.3    3.0    1.2      9     . 
37  156.3    3.0    1.2      9     . 
37  159.8    0.0    1.2      9   33.4
38    0.    26.0    1.3      8     . 
38    1.8    0.0    1.3      8   17.9
38   11.6    3.0    1.3      8     . 
38   23.3    3.0    1.3      8     . 
38   35.3    3.0    1.3      8     . 
38   47.3    3.0    1.3      8     . 
38   59.3    3.0    1.3      8     . 
38   71.3    3.0    1.3      8     . 
38   83.3    3.0    1.3      8     . 
38   95.3    3.0    1.3      8     . 
38  107.3    3.0    1.3      8     . 
38  118.8    0.0    1.3      8   21.6
38  119.3    3.0    1.3      8     . 
38  131.3    3.0    1.3      8     . 
38  143.3    3.0    1.3      8     . 
38  155.3    3.0    1.3      8     . 
38  167.3    3.0    1.3      8     . 
38  183.3    0.0    1.3      8   30.5
38  310.3    0.0    1.3      8   13.0
39    0.    56.0    1.9     10     . 
39    1.4    0.0    1.9     10   30.0
39   12.7    5.0    1.9     10     . 
39   24.4    5.0    1.9     10     . 
39   36.4    5.0    1.9     10     . 
39   48.4    5.0    1.9     10     . 
39   60.4    5.0    1.9     10     . 
39   72.3    5.0    1.9     10     . 
39   84.8    5.0    1.9     10     . 
39   96.4    5.0    1.9     10     . 
39  108.4    5.0    1.9     10     . 
39  110.4    0.0    1.9     10   37.7
39  120.4    5.0    1.9     10     . 
39  132.4    5.0    1.9     10     . 
39  260.4    0.0    1.9     10   18.4
40    0.    19.0    1.1      3     . 
40    1.0    0.0    1.1      3   13.7
40    2.0    3.0    1.1      3     . 
40    3.8   12.0    1.1      3     . 
40    4.0    0.0    1.1      3   25.0
41    0.    34.0    1.7      7     . 
41    2.0    0.0    1.7      7   18.6
41    7.3    4.0    1.7      7     . 
41   12.0    4.0    1.7      7     . 
41   24.8    4.0    1.7      7     . 
41   33.9    4.0    1.7      7     . 
41   36.0    0.0    1.7      7   21.0
41   48.3    4.0    1.7      7     . 
41   58.7    4.0    1.7      7     . 
41   59.0    0.0    1.7      7   26.4
42    0.    28.0    2.8      9     . 
42   12.0   28.0    2.8      9     . 
42   14.0    0.0    2.8      9   13.3
42   23.7    7.0    2.8      9     . 
42   36.2    7.0    2.8      9     . 
42   47.8    7.0    2.8      9     . 
42   60.0    7.0    2.8      9     . 
42   72.0    7.0    2.8      9     . 
42   84.0    7.0    2.8      9     . 
42   95.5    0.0    2.8      9   13.9
43    0.    18.0    0.9      1     . 
43    2.0    0.0    0.9      1   22.3
44    0.    14.0    1.4      7     . 
44    5.0   14.0    1.4      7     . 
44   11.0    0.0    1.4      7   17.8
44   17.0    3.5    1.4      7     . 
44   29.0    3.5    1.4      7     . 
44   41.0    3.5    1.4      7     . 
44   54.5    3.5    1.4      7     . 
44   65.0    3.5    1.4      7     . 
44   77.5    3.5    1.4      7     . 
44   89.0    3.5    1.4      7     . 
44  101.0    3.5    1.4      7     . 
44  113.0    3.5    1.4      7     . 
44  125.0    0.0    1.4      7   27.6
44  125.5    3.5    1.4      7     . 
44  292.0    0.0    1.4      7   13.5
45    0.    16.0    0.8      2     . 
45    4.5    0.0    0.8      2   16.6
45   12.5    2.0    0.8      2     . 
45   24.5    2.0    0.8      2     . 
45   36.5    2.0    0.8      2     . 
45   48.3    0.0    0.8      2   20.2
45   48.5    2.0    0.8      2     . 
45   60.5    2.0    0.8      2     . 
45   72.5    2.0    0.8      2     . 
45   84.5    2.0    0.8      2     . 
45   96.5    2.0    0.8      2     . 
45  106.5    0.0    0.8      2   24.5
46    0.    11.0    1.1      8     . 
46    0.5   11.0    1.1      8     . 
46    2.0    0.0    1.1      8   20.1
47    0.    40.0    2.6      9     . 
47    9.3    6.7    2.6      9     . 
47   19.3    6.7    2.6      9     . 
47   33.3    6.7    2.6      9     . 
47   36.3    6.7    2.6      9     . 
47   38.3    0.0    2.6      9   25.1
48    0.    14.0    0.7      8     . 
48    2.8    0.0    0.7      8   12.9
48   11.3    1.7    0.7      8     . 
48   23.3    1.7    0.7      8     . 
48   28.8   10.0    0.7      8     . 
48   35.3    1.7    0.7      8     . 
48   47.5    1.7    0.7      8     . 
48   59.3    1.7    0.7      8     . 
48   65.8    0.0    0.7      8   41.1
48   71.8    1.7    0.7      8     . 
48   84.8    0.0    0.7      8   40.3
48  112.3    0.0    0.7      8   36.8
48  137.9    0.0    0.7      8   35.8
49    0.    26.0    1.3      8     . 
49    2.0    0.0    1.3      8   18.8
49   12.0    4.0    1.3      8     . 
49   24.0    4.0    1.3      8     . 
49   36.0    4.0    1.3      8     . 
49   48.0    4.0    1.3      8     . 
49   60.5    4.0    1.3      8     . 
49   72.0    4.0    1.3      8     . 
49   74.0    0.0    1.3      8   25.1
49   84.0    4.0    1.3      8     . 
49   96.0    4.0    1.3      8     . 
49  108.5    4.0    1.3      8     . 
49  120.0    4.0    1.3      8     . 
49  132.0    4.0    1.3      8     . 
49  144.0    4.0    1.3      8     . 
49  150.0    0.0    1.3      8   37.2
50    0.    20.0    1.1      6     . 
50    3.0    0.0    1.1      6   22.2
50   12.5    2.5    1.1      6     . 
50   24.5    2.5    1.1      6     . 
50   36.5    2.5    1.1      6     . 
50   48.0    2.5    1.1      6     . 
50   60.5    2.5    1.1      6     . 
50   72.5    2.5    1.1      6     . 
50   81.0    0.0    1.1      6   30.5
50   84.5    2.5    1.1      6     . 
50   88.0   30.0    1.1      6     . 
50   89.0    0.0    1.1      6   67.9
50   96.5    2.5    1.1      6     . 
50  108.5    2.5    1.1      6     . 
50  120.5    3.5    1.1      6     . 
50  132.5    3.5    1.1      6     . 
50  144.5    3.5    1.1      6     . 
50  157.0    3.5    1.1      6     . 
50  162.0    0.0    1.1      6   58.7
51    0.    18.0    0.9      9     . 
51    3.0    0.0    0.9      9   12.7
51   11.5    2.5    0.9      9     . 
51   12.5    9.0    0.9      9     . 
51   24.5    2.5    0.9      9     . 
51   36.5    2.5    0.9      9     . 
51   49.0    2.5    0.9      9     . 
51   60.0    0.0    0.9      9   31.3
51   60.5    2.5    0.9      9     . 
51   72.5    2.5    0.9      9     . 
51   84.5    2.5    0.9      9     . 
51   96.5    2.5    0.9      9     . 
51  108.5    2.5    0.9      9     . 
51  120.5    2.5    0.9      9     . 
51  132.0    0.0    0.9      9   31.1
52    0.     9.5    0.9      7     . 
52    2.0    0.0    0.9      7   14.3
52    4.0    9.5    0.9      7     . 
52   12.5    9.0    0.9      7     . 
52   35.5    2.5    0.9      7     . 
52   37.5    2.5    0.9      7     . 
52   59.5    2.5    0.9      7     . 
52   71.5    2.5    0.9      7     . 
52   83.0    0.0    0.9      7   38.1
52   83.5    2.5    0.9      7     . 
52   95.5    2.5    0.9      7     . 
52  107.5    2.5    0.9      7     . 
52  119.5    2.5    0.9      7     . 
52  131.5    2.5    0.9      7     . 
52  143.5    2.5    0.9      7     . 
52  155.0    0.0    0.9      7   31.2
53    0.    17.0    1.7      8     . 
53    4.0   17.0    1.7      8     . 
53    6.0    0.0    1.7      8   19.1
53   23.8    4.0    1.7      8     . 
53   27.0    7.5    1.7      8     . 
53   28.0    4.0    1.7      8     . 
53   39.5    4.0    1.7      8     . 
53   47.0    0.0    1.7      8   33.3
54    0.    18.0    1.8      8     . 
54    3.7   18.0    1.8      8     . 
54    9.7    0.0    1.8      8   25.5
54   15.7    4.4    1.8      8     . 
54   27.7    4.4    1.8      8     . 
54   29.7    0.0    1.8      8   29.4
54   39.7    4.4    1.8      8     . 
54   51.7    4.4    1.8      8     . 
54   63.2    0.0    1.8      8   29.5
54   63.7    4.4    1.8      8     . 
54   75.7    4.4    1.8      8     . 
54   87.7    4.4    1.8      8     . 
54   99.7    4.4    1.8      8     . 
54  111.3    0.0    1.8      8   37.9
55    0.    25.0    1.1      4     . 
55   12.0    3.0    1.1      4     . 
55   24.0    3.0    1.1      4     . 
55   36.0    3.0    1.1      4     . 
55   48.0    3.0    1.1      4     . 
55   60.0    3.0    1.1      4     . 
55   72.0    3.0    1.1      4     . 
55   74.0    0.0    1.1      4   20.8
56    0.    12.0    0.6      4     . 
56   12.7    1.5    0.6      4     . 
56   20.0    0.0    0.6      4   18.8
57    0.    20.0    2.1      6     . 
57    0.5   20.0    2.1      6     . 
57    1.7    0.0    2.1      6   20.2
57   12.2    5.0    2.1      6     . 
57   24.7    5.0    2.1      6     . 
57   37.2    5.0    2.1      6     . 
57   47.8    5.0    2.1      6     . 
57   60.2    5.0    2.1      6     . 
57   72.2    6.0    2.1      6     . 
57   84.2    6.0    2.1      6     . 
57   96.2    6.0    2.1      6     . 
57  109.0    0.0    2.1      6   27.8
58    0.    14.0    1.4      8     . 
58    0.5   14.0    1.4      8     . 
58    8.5    0.0    1.4      8   22.4
58   12.0    3.5    1.4      8     . 
58   24.3    3.5    1.4      8     . 
58   35.8    3.5    1.4      8     . 
58   47.5    0.0    1.4      8   27.9
58   48.0    3.5    1.4      8     . 
58   59.5    3.5    1.4      8     . 
58   72.0    3.5    1.4      8     . 
58   84.0    3.5    1.4      8     . 
58   96.3    3.5    1.4      8     . 
58  107.0    3.5    1.4      8     . 
58  120.3    3.5    1.4      8     . 
58  131.8    0.0    1.4      8   31.0
59    0.    22.8    1.1      6     . 
59    1.8    0.0    1.1      6   22.6
59   12.5    3.0    1.1      6     . 
59   24.3    3.0    1.1      6     . 
59   36.3    3.0    1.1      6     . 
59   48.8    3.0    1.1      6     . 
59   60.3    3.0    1.1      6     . 
59   72.3    3.0    1.1      6     . 
59   73.8    0.0    1.1      6   34.3
59   84.3    3.0    1.1      6     . 
59   96.0    3.0    1.1      6     . 
59  108.3    3.0    1.1      6     . 
59  120.5    3.0    1.1      6     . 
59  132.3    3.0    1.1      6     . 
59  144.8    3.0    1.1      6     . 
59  146.8    0.0    1.1      6   40.2
; 
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 15.3                                      ---*/
goptions reset=all
   hsize   = 6.25 in
   vsize   = 5.25 in
   htext   = 3.0 pct
   htitle  = 3.5 pct
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss
   lfactor = 1;

axis1 order = (0 to 400 by 50)
      value = (font=swissl height=1)  
      label = (font=swissl h=1)
      major = (h=0.5)
      minor = none;

axis2 order = (0 to 70 by 10)
      value = (font=swissl height=1)
      label = (font=swissl h=1)
      major = (h=1)
      minor = none;

symbol1 color=black value=none i=join l=1 r=100 w=1;

proc gplot data=pheno;
   plot conc*time=indiv / nolegend;
run;
quit;
goptions reset=all;
/*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---One-compartment model with intravenous bolus     ---*/
 /*---administration and first-order elimination,      ---*/
 /*---constant CV weighting                            ---*/
 /*---Output 15.15                                     ---*/	  
proc nlmixed data=pheno qpoints=1;
   * starting values;
   parms beta1=0.5 beta2=1 beta3=0.15 
         s2u1=0.05 s2u2=0.03 cu12=0.015 s2e=0.01;

   * bounds;
   bounds beta1>=0, beta2>=0, s2u1>=0, s2u2>=0, s2e>0;

   * compute key terms in the model;
   clear = beta1/100*weight*exp(u1);
   vol   = beta2*weight*(1+beta3*apgarlow)*exp(u2);
   eterm = exp(-(time-tlag)*clear/vol);

   * compute predicted value depending on whether this is a 
     new subject or not;
   if (newsub = 1) then pred = dose/vol;
   else pred = dose/vol + zlag(pred)*eterm;

    * variance goes up with the square of the predicted value, 
      a constant coefficient of variation model;
   var = s2e*(pred**2);

   * model specification;
   model conc ~ normal(pred,var);

   * random effects specification;
   random u1 u2 ~ normal([0,0],[s2u1,cu12,s2u2]) subject=indiv out=ebayes;

   * compute an additional estimate of the correlation;
   estimate 'corr(u1,u2)' cu12/sqrt(s2u1*s2u2);

   * output subject-specific predictions of clearance and volume;
   predict clear out=clear;
   predict vol out=vol;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Figure 15.4                                      ---*/
 /*---code to plot empirical Bayes estimates of random ---*/
 /*---effects                                          ---*/
proc transpose data=ebayes out=ebt;
   var estimate;
   by indiv;
   id effect;
run;

data ebt;
  set ebt;
  format u1 u2 4.1;
run;

goptions reset=all
   hsize   = 5 in
   vsize   = 5 in
   htext   = 3.0 pct
   htitle  = 3.5 pct
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss
   lfactor = 1;

axis1 order = (-0.3 to 0.5 by 0.1)
      value = (font=swissl height=1)  
      label = (font=swissl h=1)
      major = (h=0.5)
      minor = none;

symbol v=circle;

proc gplot data=ebt;
   plot u1*u2 / haxis=axis1 vaxis=axis1;
run;   
quit;
goptions reset=all;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Figure 15.5                                      ---*/
 /*---Code to plot subject-specific clearance versus   ---*/
 /*---volume                                           ---*/
data clear1;
   set clear;
   if time = 0;
   clearance = pred;
   format clearance 4.1;
   keep indiv clearance;
run;

data vol1;
   set vol;
   if time = 0;
   volume = pred;
   format volume 4.1;
   keep indiv volume;
run;

data cv;
   merge clear1 vol1;
   by indiv;
run;

goptions reset=all
   hsize   = 5 in
   vsize   = 5 in
   htext   = 3.0 pct
   htitle  = 3.5 pct
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss
   lfactor = 1;

axis1 order = (0 to 5 by 1)
      value = (font=swissl height=1)  
      label = (font=swissl h=1)
      major = (h=0.5)
      minor = none;

axis2 order = (0 to 0.025 by 0.005)
      value = (font=swissl height=1)  
      label = (font=swissl h=1)
      major = (h=0.5)
      minor = none;

symbol v=circle;

proc gplot data=cv;
   plot clearance*volume / haxis=axis1 vaxis=axis2;
run;
quit;
goptions reset=all;
 /*-------------------------------------------------------*/



 /*-------------------------------------------------------*/
 /*---Code to remove dependence of variance on random  ---*/
 /*---effects                                          ---*/
 /*---Output not shown                                 ---*/
proc nlmixed data=pheno qpoints=1;
   parms beta1=0.5 beta2=1 beta3=0.15 
      s2u1=0.05 s2u2=0.03 cu12=0.015 s2e=0.01;
   bounds beta1>=0, beta2>=0, s2u1>=0, s2u2>=0, s2e>0;
   /*---mean---*/
   clear = beta1/100*weight*exp(u1);
   vol   = beta2*weight*(1+beta3*apgarlow)*exp(u2);
   eterm = exp(-(time-tlag)*clear/vol);
   if (newsub = 1) then pred = dose/vol;
   else pred = dose/vol + zlag(pred)*eterm;
   /*---variance---*/
   clear0 = beta1/100*weight;
   vol0   = beta2*weight*(1+beta3*apgarlow);
   eterm0 = exp(-(time-tlag)*clear0/vol0);
   if (newsub = 1) then pred0 = dose/vol0;
   else pred0 = dose/vol0 + zlag(pred0)*eterm0;
   var = s2e*(pred0**2);
   /*---model---*/
   model conc ~ normal(pred,var);
   random u1 u2 ~ normal([0,0],[s2u1,cu12,s2u2]) subject=indiv;
   estimate 'corr(u1,u2)' cu12/sqrt(s2u1*s2u2);
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---One-compartment model with intravenous bolus     ---*/
 /*---administration and first-order elimination,      ---*/
 /*---NLINMIX Method 2                                 ---*/
 /*---Output 15.16, Output 15.17                       ---*/
%nlinmix(data=pheno,
   modinit=%str(
      array plag{11} _temporary_;
      if (newsub=1) then do call = 1 to 11;
         plag[call] = 0;
      end;
      call = 1;
   ),
   model=%str(
      clear = beta1/100*weight*exp(u1);
      vol   = beta2*weight*(1+beta3*apgarlow)*exp(u2);
      eterm = exp(-(time-tlag)*clear/vol);
      predv = dose/vol + plag[call]*eterm;
      plag[call] = predv;
      call = call + 1;
   ),
   weight=%str(
      wghtv = 1/predv**2;
   ),
   parms=%str(beta1=0.5 beta2=1 beta3=0.15),
   stmts=%str(
      class indiv;
      model pseudo_conc = d_beta1 d_beta2 d_beta3 / 
                          noint notest solution cl;
      random d_u1 d_u2 / subject=indiv type=un solution;
      weight wghtv;
   ),
   expand=eblup
)
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Figure 15.6                                      ---*/
 /*---code to plot EBLUPs                              ---*/
proc transpose data=_solnr out=eblups;
   var estimate;
   by indiv;
   id effect;
run;

data eblups;
  set eblups;
  format d_u1 d_u2 4.1;
run;

goptions reset=all
   hsize   = 8 in
   vsize   = 8 in
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss
   lfactor = 1;

axis1 order = (-0.3 to 0.5 by 0.1)
      value = (font=swissl height=2)  
      label = (font=swissl h=2)
      major = (h=0.5)
      minor = none;

symbol v=circle;

proc gplot data=eblups;
   plot d_u1*d_u2 / haxis=axis1 vaxis=axis1;
run; quit;
goptions reset=all;
run;
 /*-------------------------------------------------------*/








