 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---CHAPTER 16: Case Studies                         ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data set 16.2, Milling Corn                      ---*/
data design;
   input batch a b c d y aa;
   aa=a;
   datalines;
 1     1     1     1     1    505     1
 1     1    -1    -1    -1    493     1
 1     1    -1     1    -1    491     1
 2     1     1    -1     0    498     1
 2     1     1    -1    -1    504     1
 2     1    -1     1     0    500     1
 3    -1     0    -1    -1    494    -1
 3    -1     0     1     0    498    -1
 3    -1    -1     0     1    498    -1
 4     0    -1    -1     0    496     0
 4     0     0     1     1    503     0
 4     0    -1     0    -1    496     0
 5    -1    -1     1     1    503    -1
 5    -1     1     1    -1    495    -1
 5    -1    -1     1    -1    494    -1
 6     0     0     0     0    486     0
 6     0     1     1    -1    501     0
 6     0     1    -1     1    490     0
 7    -1     1     0     0    494    -1
 7    -1     1     1     1    497    -1
 7    -1    -1     1    -1    492    -1
 8     1    -1     1     1    503     1
 8     1     0     0    -1    499     1
 8     1     0    -1     1    493     1
 9     1     1     1    -1    505     1
 9     1     1     0     1    500     1
 9     1    -1    -1     1    490     1
10    -1    -1    -1     1    494    -1
10    -1     1    -1    -1    497    -1
10    -1    -1    -1    -1    495    -1
;
 /*-------------------------------------------------------*/

 
 /*-------------------------------------------------------*/
 /*---Output 16.1                                      ---*/
proc mixed data=design;
   class batch aa;
   model y = a|b|c|d@2 a*a b*b c*c d*d / solution;
   random batch(aa);
   ods select ClassLevels CovParms SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.2                                      ---*/
proc mixed data=design;
   class batch aa;
   model y=a|b|c|d@2 a*a b*b c*c d*d /solution ddfm=satterth;
   random batch(aa);
   ods select SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 16.3, Mayonnaise                        ---*/
data mayo;
   input y a b c p $ d u h t;
   u  = t;
   ca = a;
   cb = b;
   cc = c;
   datalines;
 95     1     1     1    X6     0    -1         1    -1     
 67     1     1     1    X6     1    -1         1    -1     
100     1     1     1    X6     0    -0.5854    2    -0.5854
 70     1     1     1    X6     1    -0.5854    2    -0.5854
100     1     1     1    X6     0     1         3     1     
 77     1     1     1    X6     1     1         3     1     
 41     1    -1    -1    X7     0    -1         1    -1     
 32     1    -1    -1    X7     1    -1         1    -1     
 42     1    -1    -1    X7     0    -0.5854    2    -0.5854
 27     1    -1    -1    X7     1    -0.5854    2    -0.5854
 60     1    -1    -1    X7     0     1         3     1     
 27     1    -1    -1    X7     1     1         3     1     
 35     0     0     0    X8     0    -1         1    -1     
 26     0     0     0    X8     1    -1         1    -1     
 39     0     0     0    X8     0    -0.5854    2    -0.5854
 24     0     0     0    X8     1    -0.5854    2    -0.5854
 57     0     0     0    X8     0     1         3     1     
 25     0     0     0    X8     1     1         3     1     
 48     0     0     0    X9     0    -1         1    -1     
 35     0     0     0    X9     1    -1         1    -1     
 55     0     0     0    X9     0    -0.5854    2    -0.5854
 35     0     0     0    X9     1    -0.5854    2    -0.5854
 72     0     0     0    X9     0     1         3     1     
 36     0     0     0    X9     1     1         3     1     
 31    -1     1    -1    X10    0    -1         1    -1     
 26    -1     1    -1    X10    1    -1         1    -1     
 37    -1     1    -1    X10    0    -0.5854    2    -0.5854
 25    -1     1    -1    X10    1    -0.5854    2    -0.5854
 55    -1     1    -1    X10    0     1         3     1     
 25    -1     1    -1    X10    1     1         3     1     
 30    -1    -1     1    X11    0    -1         1    -1     
 25    -1    -1     1    X11    1    -1         1    -1     
 36    -1    -1     1    X11    0    -0.5854    2    -0.5854
 25    -1    -1     1    X11    1    -0.5854    2    -0.5854
 50    -1    -1     1    X11    0     1         3     1     
 25    -1    -1     1    X11    1     1         3     1     
 45     0     0     1    X12    0    -1         1    -1     
 34     0     0     1    X12    1    -1         1    -1     
 54     0     0     1    X12    0    -0.5854    2    -0.5854
 33     0     0     1    X12    1    -0.5854    2    -0.5854
 75     0     0     1    X12    0     1         3     1     
 34     0     0     1    X12    1     1         3     1     
 22     0    -1     0    X13    0    -1         1    -1     
 18     0    -1     0    X13    1    -1         1    -1     
 23     0    -1     0    X13    0    -0.5854    2    -0.5854
 16     0    -1     0    X13    1    -0.5854    2    -0.5854
 28     0    -1     0    X13    0     1         3     1     
 16     0    -1     0    X13    1     1         3     1     
 56     0     1     0    X14    0    -1         1    -1     
 40     0     1     0    X14    1    -1         1    -1     
 69     0     1     0    X14    0    -0.5854    2    -0.5854
 42     0     1     0    X14    1    -0.5854    2    -0.5854
 95     0     1     0    X14    0     1         3     1     
 45     0     1     0    X14    1     1         3     1     
 50     0     0    -1    X15    0    -1         1    -1     
 37     0     0    -1    X15    1    -1         1    -1     
 57     0     0    -1    X15    0    -0.5854    2    -0.5854
 35     0     0    -1    X15    1    -0.5854    2    -0.5854
 73     0     0    -1    X15    0     1         3     1     
 35     0     0    -1    X15    1     1         3     1     
 43     0     0     0    X16    0    -1         1    -1     
 31     0     0     0    X16    1    -1         1    -1     
 48     0     0     0    X16    0    -0.5854    2    -0.5854
 32     0     0     0    X16    1    -0.5854    2    -0.5854
 64     0     0     0    X16    0     1         3     1     
 31     0     0     0    X16    1     1         3     1     
 64     1     0     0    X17    0    -1         1    -1     
 46     1     0     0    X17    1    -1         1    -1     
 69     1     0     0    X17    0    -0.5854    2    -0.5854
 45     1     0     0    X17    1    -0.5854    2    -0.5854
 85     1     0     0    X17    0     1         3     1     
 45     1     0     0    X17    1     1         3     1     
 27    -1     0     0    X18    0    -1         1    -1     
 21    -1     0     0    X18    1    -1         1    -1     
 28    -1     0     0    X18    0    -0.5854    2    -0.5854
 21    -1     0     0    X18    1    -0.5854    2    -0.5854
 37    -1     0     0    X18    0     1         3     1     
 18    -1     0     0    X18    1     1         3     1     
 45     0     0     0    X19    0    -1         1    -1     
 35     0     0     0    X19    1    -1         1    -1     
 48     0     0     0    X19    0    -0.5854    2    -0.5854
 33     0     0     0    X19    1    -0.5854    2    -0.5854
 67     0     0     0    X19    0     1         3     1     
 33     0     0     0    X19    1     1         3     1     
 81     1     1    -1    X20    0    -1         1    -1     
 56     1     1    -1    X20    1    -1         1    -1     
 90     1     1    -1    X20    0    -0.5854    2    -0.5854
 55     1     1    -1    X20    1    -0.5854    2    -0.5854
100     1     1    -1    X20    0     1         3     1     
 58     1     1    -1    X20    1     1         3     1     
 40     1    -1     1    X21    0    -1         1    -1     
 29     1    -1     1    X21    1    -1         1    -1     
 40     1    -1     1    X21    0    -0.5854    2    -0.5854
 28     1    -1     1    X21    1    -0.5854    2    -0.5854
 52     1    -1     1    X21    0     1         3     1     
 26     1    -1     1    X21    1     1         3     1     
 49    -1     1     1    X22    0    -1         1    -1     
 35    -1     1     1    X22    1    -1         1    -1     
 55    -1     1     1    X22    0    -0.5854    2    -0.5854
 35    -1     1     1    X22    1    -0.5854    2    -0.5854
 73    -1     1     1    X22    0     1         3     1     
 35    -1     1     1    X22    1     1         3     1     
 15    -1    -1    -1    X23    0    -1         1    -1     
 13    -1    -1    -1    X23    1    -1         1    -1     
 14    -1    -1    -1    X23    0    -0.5854    2    -0.5854
 12    -1    -1    -1    X23    1    -0.5854    2    -0.5854
 18    -1    -1    -1    X23    0     1         3     1     
 11    -1    -1    -1    X23    1     1         3     1     
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.3                                      ---*/
proc mixed data=mayo;
   class ca cb cc p d u;
   model y = d a(d) b(d) c(d) a*a b*b c*c a*b a*c b*c  
           t(d) t*t t*a t*b t*c /noint solution htype=1 ddfm=kr;
   random p(ca cb cc);
   repeated / type=cs subject=d*p(ca cb cc);
   ods select CovParms FitStatistics SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.4                                      ---*/
proc mixed data=mayo;
   class ca cb cc p d u;
   model y = d a(d) b(d) c(d) a*a b*b c*c a*b a*c b*c  
           t(d) t*t t*a t*b t*c /noint solution htype=1 ddfm=kr;
   random p(ca cb cc);
   repeated / type=cs subject=d*p(ca cb cc);
   ods select Tests1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.5                                      ---*/
proc mixed data=mayo;
   class ca cb cc p d u;
   model y = d a(d) b(d) c(d) a*a b*b c*c a*b a*c b*c  
            t(d) t*t t*a t*b t*c /noint solution htype=1 ddfm=kr;
   random p(ca cb cc);
   repeated / type=sp(pow)(t) subject=d*p(ca cb cc);
   ods select CovParms FitStatistics;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.6                                      ---*/
proc mixed data=mayo;
   class ca cb cc p d u;
   model y = d a(d) b(d) c(d) a*a b*b c*c a*b a*c b*c  
            t(d) t*t t*a t*b t*c /noint solution htype=1 ddfm=kr;
   random p(ca cb cc);
   repeated / type=sp(pow)(t) subject=d*p(ca cb cc);
   ods select SolutionF Tests1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 16.4, Irrigation                        ---*/
data irrigation;
   input eu bloc trt level y @@;
   datalines;
 1  1  1  1  43   2  1  2  1  45
 3  1  1  2  41   4  1  2  2  45
 5  1  1  3  46   6  1  2  3  46
 7  1  1  4  46   8  1  2  4  46
 9  1  1  5  45  10  1  2  5  45
11  1  1  6  50  12  1  2  6  51
13  1  1  7  49  14  1  2  7  47
15  1  1  8  46  16  1  2  8  49
17  2  1  1  39  18  2  2  1  44
19  2  3  1  39  20  2  1  2  43
21  2  2  2  47  22  2  3  2  42
23  2  1  3  47  24  2  2  3  49
25  2  3  3  45  26  2  1  4  40
27  2  2  4  42  28  2  3  4  40
29  2  1  5  38  30  2  2  5  39
31  2  3  5  37  32  2  1  6  43
33  2  2  6  45  34  2  3  6  42
35  2  1  7  36  36  2  2  7  36
37  2  3  7  36  38  2  1  8  39
39  2  2  8  40  40  2  3  8  39
41  3  2  1  34  42  3  3  1  31
43  3  2  2  38  44  3  3  2  34
45  3  2  3  37  46  3  3  3  36
47  3  2  4  39  48  3  3  4  37
49  3  2  5  43  50  3  3  5  42
51  3  2  6  43  52  3  3  6  41
53  3  2  7  40  54  3  3  7  39
55  3  2  8  39  56  3  3  8  37
57  4  1  1  44  58  4  3  1  39
59  4  1  2  45  60  4  3  2  41
61  4  1  3  47  62  4  3  3  47
63  4  1  4  46  64  4  3  4  43
65  4  1  5  45  66  4  3  5  40
67  4  1  6  43  68  4  3  6  41
69  4  1  7  41  70  4  3  7  40
71  4  1  8  40  72  4  3  8  38
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.7                                      ---*/
proc glimmix data=irrigation;
   class bloc trt level;
   model y = level trt trt*level / ddfm=kr; 
   random intercept / subject=bloc;
   random level     / subject=bloc type=ar(1);
   lsmeans trt / diff;
   lsmeans level trt*level;
   estimate 'lev 1 vs lev 2' level 1 -1 0;
   estimate 'lev 1 vs lev 8' level 1  0 0  0  0  0  0  -1;
   lsmestimate trt*level 
        'trt 1 v 2 given lev 1'  1  0 0 0 0 0 0  0 -1 0,
        'lev 1 v 2 given trt 1'  1 -1 0                ,
        'lev 1 v 8 given trt 1'  1  0 0 0 0 0 0 -1  0  ;
   contrast 'linear'    level -7  -5  -3  -1   1  3   5  7;
   contrast 'quadratic' level  7   1  -3  -5  -5 -3   1  7;
   contrast 'other'     level -7   5   7   3  -3 -7  -5  7,
                        level  7 -13  -3   9   9 -3 -13  7,
                        level -7  23 -17 -15  15 17 -23  7,
                        level  1  -5   9  -5  -5  9  -5  1,
                        level -1  7  -21  35 -35 21  -7  1;
   ods select CovParms Tests3 LSMeans Diffs Estimates Contrasts
              LSMEstimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.8                                      ---*/
proc glimmix data=irrigation;
   class bloc trt level;
   model y=  level trt trt*level/ ddfm=kr;
   random bloc bloc*level;
   lsmeans trt/diff;
   lsmeans level trt*level;
   estimate 'lev 1 vs lev 2' level 1 -1 0;
   estimate 'lev 1 vs lev 8' level 1  0 0  0  0  0  0  -1;
   estimate 'trt 1 vs trt 2' trt   1 -1 0;
   lsmestimate trt*level 
            'trt 1 v 2 given lev 1' 1  0 0 0 0 0 0  0 -1 0,
            'lev 1 v 2 given trt 1' 1 -1 0,
            'lev 1 v 8 given trt 1' 1  0 0 0 0 0 0 -1 0;
   contrast 'linear'    level -7  -5  -3  -1   1  3   5  7;
   contrast 'quadratic' level  7   1  -3  -5  -5 -3   1  7;
   contrast 'other'     level -7   5   7   3  -3 -7  -5  7,
                        level  7 -13  -3   9   9 -3 -13  7,
                        level -7  23 -17 -15  15 17 -23  7,
                        level  1  -5  9   -5  -5  9  -5  1,
                        level -1   7 -21  35 -35 21  -7  1;
   ods select CovParms Tests3 Diffs Estimates Contrasts
              LSMEstimates;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 16.5, Nitrogen                          ---*/
data nitrogen;
  input row col N G y;
  nclass=N;
  datalines;
1 1 1 1 20.1
1 1 1 2 20.4
2 1 2 1 16.2
2 1 2 2 14
3 1 3 1 16.2
3 1 3 2 12.6
1 2 2 1 18.1
1 2 2 2 16.7
2 2 1 1 10.3
2 2 1 2 8.1
3 2 4 1 14.9
3 2 4 2 9.9
1 3 5 1 23.1
1 3 5 2 18.1
2 3 3 1 17.8
2 3 3 2 16.1
3 3 1 1 9.8
3 3 1 2 9
1 4 4 1 21.8
1 4 4 2 17.4
2 4 5 1 18.1
2 4 5 2 12.9
3 4 2 1 14
3 4 2 2 12.1
1 5 3 1 22.7
1 5 3 2 19.5
2 5 4 1 18.7
2 5 4 2 13.7
3 5 5 1 17
3 5 5 2 10.9
;

 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.9                                      ---*/
proc mixed data=nitrogen;
   class row col n g;
   model y = n g n*g / ddfm=satterth;
   random row col row*col*n;
   lsmeans n g n*g;
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.10                                     ---*/
proc mixed data=nitrogen;
   class row col NClass G;
   model y = N|N|N|N|G / htype=1 ddfm=satterth; 
   random row col row*col*NClass;
   ods select Tests1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.11                                     ---*/
proc mixed data=nitrogen;
   class row col NClass G;
   model y = N|N|G@2 NClass NClass*G / htype=1 ddfm=satterth;
   random row col row*col*NClass;
   ods select Tests1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 16.4                                      ---*/
ods html file="test.html";
ods graphics on;
ods select MeanPlot;
proc glimmix data=nitrogen;
   class row col G N;
   model y = G|N;
   random row col row*col*nclass;
   lsmeans G*N / plot=MeanPlot(sliceby=G join);
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 16.12                                     ---*/
proc mixed data=nitrogen;
   class row col g nclass;
   model y = g n(g) n*n/ noint solution ddfm=satterth;
   random row col row*col*nclass;
   ods select SolutionF;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Figure 16.5                                      ---*/
proc mixed data=nitrogen;
   class row col g nclass;
   model y = g n(g) n*n/ noint solution ddfm=satterth 
                         outpm=now_plot(rename=(pred=yhat));
   random row col row*col*nclass;
   ods select SolutionF;
run;
goptions reset=all;
proc sort data=now_plot; by g n; run;
axis1 value=(font=swiss h=2) 
      label=(angle=90 f=swiss h=2 'Predicted Y');
axis2 value=(font=swiss h=2 )
      label=(f=swiss h=2 'N Level');
legend1 value=(font=swiss h=2  ) 
        label=(f=swiss h=2 'By Genotype'); 
symbol1 color=black interpol=join line=1 value=circle; 
symbol2 color=black interpol=join line=20 value=triangle;
proc gplot data=now_plot;
   plot yhat*n=g / vaxis  = axis1 
                          haxis  = axis2
                          legend = legend1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 16.6, Sandhills                         ---*/
data sandhills;
   input circle ec ir v y;
   datalines;
1 1 1 1 30.0
1 1 1 2 40.9
1 1 2 1 38.9
1 1 2 2 38.2
1 2 1 1 41.8
1 2 1 2 52.2
1 2 2 1 54.8
1 2 2 2 58.2
2 1 1 1 20.5
2 1 1 2 26.9
2 1 2 1 21.4
2 1 2 2 25.1
2 2 1 1 26.4
2 2 1 2 36.7
2 2 2 1 28.9
2 2 2 2 35.9
3 1 1 1 21.0
3 1 1 2 25.4
3 1 2 1 24.0
3 1 2 2 23.3
3 2 1 1 34.4
3 2 1 2 41.0
3 2 2 1 33.2
3 2 2 2 34.9
;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 16.13                                     ---*/
proc glimmix data=sandhills;
   class circle ec ir v;
   model y=ec ir ec*ir v v*ec v*ir v*ec*ir/ddfm=satterth;
   random circle circle*ec circle*ir circle*ec*ir;
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.14                                     ---*/
 /*---Output 16.15                                     ---*/
proc glimmix data=sandhills;
   class circle ec ir v;
   model y=ec ir ec*ir v v*ec v*ir v*ec*ir/ddfm=satterth;
   random circle circle*ec circle*ir circle*ec*ir;
   lsmeans ec      / diff             cl;
   lsmeans ir*v    / slicediff=(ir v) cl;
   lsmeans ec*ir*v / slicediff=ec*ir  cl;
   ods select LSMeans Diffs SliceDiffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 16.7, Breaking Strength                 ---*/
data breaking_strength;
   input soap_pH num_washes water_temp$ dry_cycle$ 
         Breaking_Strength Elongation Slope Energy;
   pH = soap_pH;
   w  = num_washes;
   datalines;
8   10  cold  air       0.11056     16.878      0.045682857 0.672025714
8   10  cold  delicate  0.1117      18.54695652 0.041152174 0.721471739
8   10  cold  normal    0.107987755 19.11102041 0.036804082 0.723695918
8   10  hot   air       0.100611538 19.53923077 0.03965     0.683511538
8   10  hot   delicate  0.102096226 20.14716981 0.038160377 0.703624528
8   10  hot   normal    0.101670833 19.74       0.036022917 0.720902083
8   20  cold  air       0.09264878  16.64       0.041070732 0.55695122
8   20  cold  delicate  0.09106     18.4896     0.04062     0.615916
8   20  cold  normal    0.088258696 16.12826087 0.032113043 0.489576087
8   20  hot   air       0.101257143 18.81632653 0.038085714 0.66635102
8   20  hot   delicate  0.099182979 19.41446809 0.037704255 0.63837234
8   20  hot   normal    0.094102083 17.71625    0.031552083 0.572995833
8   30  cold  air       0.087420513 14.7641     0.041738462 0.530387179
8   30  cold  delicate  0.092523404 16.85957447 0.033329787 0.563642553
8   30  cold  normal    0.097338776 16.86533333 0.030046667 0.526977778
8   30  hot   air       0.0965      18.42875    0.03406875  0.633804167
8   30  hot   delicate  0.092455556 17.28962963 0.032787037 0.543883333
8   30  hot   normal    0.094755556 17.896      0.032833333 0.639137778
8   40  cold  air       0.092959459 15.70378378 0.035575676 0.525878378
8   40  cold  delicate  0.086335556 17.21377778 0.030368889 0.526986667
8   40  cold  normal    0.08709375  17.6175     0.03115625  0.530825
8   40  hot   air       0.089866    17.756      0.032736    0.558094
8   40  hot   delicate  0.083214286 17.44204082 0.03034898  0.524738776
8   40  hot   normal    0.075329167 17.76208333 0.03019375  0.5520875
8   50  cold  air       0.08597     15.5376     0.035356    0.493366
8   50  cold  delicate  0.084926667 16.56089    0.030668889 0.472746667
8   50  cold  normal    0.077727907 14.7414     0.02962093  0.436155814
8   50  hot   air       0.08686383  16.10894    0.03116383  0.493459574
8   50  hot   delicate  0.079282222 15.81822    0.027962222 0.423888889
8   50  hot   normal    0.075106    15.2064     0.027636    0.391664
10  10  cold  air       0.094640385 15.383846   0.040991    0.5117736
10  10  cold  delicate  0.090370588 16.4941176  0.0344667   0.512739
10  10  cold  normal    0.093637736 17.3056604  0.0299075   0.550775
10  10  hot   air       0.101960784 18.487059   0.0346471   0.6320549
10  10  hot   delicate  0.096967308 18.030385   0.0326192   0.5952846
10  10  hot   normal    0.085365306 16.7257143  0.02970612  0.48526122
10  20  cold  air       0.096437705 15.2419672  0.039969    0.516157
10  20  cold  delicate  0.083050909 15.458182   0.033105    0.448816
10  20  cold  normal    0.085377966 16.09051    0.030073    0.475436
10  20  hot   air       0.090378182 17.23964    0.031922    0.537931
10  20  hot   delicate  0.079803704 15.91074    0.030565    0.454283
10  20  hot   normal    0.0739      14.88       0.027289    0.387181
10  30  cold  air       0.08783871  15.6171     0.038597    0.455755
10  30  cold  delicate  0.076156364 15.91455    0.032376    0.404242
10  30  cold  normal    0.071062264 14.84717    0.027789    0.35516
10  30  hot   air       0.07604     15.148      0.029545    0.404447
10  30  hot   delicate  0.057938596 12.54772    0.027037    0.244839
10  30  hot   normal    0.055872222 11.84222    0.025644    0.233622
10  40  cold  air       0.079812281 14.35544    0.034681    0.413628
10  40  cold  delicate  0.064691379 14.60483    0.027314    0.343205
10  40  cold  normal    0.068009091 14.87855    0.026175    0.351716
10  40  hot   air       0.060152632 13.28281    0.025086    0.279744
10  40  hot   delicate  0.048512727 12.18364    0.023535    0.213495
10  40  hot   normal    0.044706122 11.43592    0.020757    0.18009
10  50  cold  air       0.077755172 11.75052    0.036457    0.402684
10  50  cold  delicate  0.051081132 11.35898    0.025847    0.238051
10  50  cold  normal    0.057578431 11.35529    0.025898    0.26828
10  50  hot   air       0.050215217 11.36404    0.024804    0.233435
10  50  hot   delicate  0.040911429 11.16834    0.020217    0.173549
10  50  hot   normal    0.034036364 11.053      0.018532    0.141359
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.16                                     ---*/
proc mixed data=breaking_strength;
   class pH water_temp dry_cycle;
   model breaking_strength=pH water_temp dry_cycle 
                       w w*pH w*water_temp w*dry_cycle/solution;
   random pH*water_temp*dry_cycle;
   contrast 'air vs dryer effect on wear'  
               w*dry_cycle 2 -1 -1;
   contrast 'delicate v normal effect on wear' 
               w*dry_cycle 0 1 -1;
   ods select CovParms Tests3 Contrasts SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.17                                     ---*/
proc mixed data=breaking_strength;
   class pH water_temp dry_cycle;
   model breaking_strength = w(pH) w(water_temp) 
                             w(dry_cycle) / solution;
   random pH*water_temp*dry_cycle;
   estimate 'slope: ph 8, cold, air' 
             w(ph) 1 0 w(water_temp) 1 0 w(dry_cycle) 1 0 0;
   estimate 'slope: ph 8, cold, delicate' 
             w(ph) 1 0 w(water_temp) 1 0 w(dry_cycle) 0 1 0;
   estimate 'slope: ph 8, cold, normal' 
             w(ph) 1 0 w(water_temp) 1 0 w(dry_cycle) 0 0 1;
   estimate 'slope: ph 8, hot, air' 
             w(ph) 1 0 w(water_temp) 0 1 w(dry_cycle) 1 0 0;
   estimate 'slope: ph 8, hot, delicate' 
             w(ph) 1 0 w(water_temp) 0 1 w(dry_cycle) 0 1 0;
   estimate 'slope: ph 8, hot, normal' 
             w(ph) 1 0 w(water_temp) 0 1 w(dry_cycle) 0 0 1;
   estimate 'slope: ph 10, cold, air' 
             w(ph) 0 1 w(water_temp) 1 0 w(dry_cycle) 1 0 0;
   estimate 'slope: ph 10, cold, delicate' 
             w(ph) 0 1 w(water_temp) 1 0 w(dry_cycle) 0 1 0;
   estimate 'slope: ph 10, cold, normal' 
             w(ph) 0 1 w(water_temp) 1 0 w(dry_cycle) 0 0 1;
   estimate 'slope: ph 10, hot, air' 
             w(ph) 0 1 w(water_temp) 0 1 w(dry_cycle) 1 0 0;
   estimate 'slope: ph 10, hot, delicate' 
             w(ph) 0 1 w(water_temp) 0 1 w(dry_cycle) 0 1 0;
   estimate 'slope: ph 10, hot, normal' 
             w(ph) 0 1 w(water_temp) 0 1 w(dry_cycle) 0 0 1;
   estimate 'avg slope: ph 8' 
             w(ph) 6 0 w(water_temp) 3 3 w(dry_cycle) 2 2 2
             / divisor=6;
   estimate 'avg slope: ph 10' 
             w(ph) 0 6 w(water_temp) 3 3 w(dry_cycle) 2 2 2
             / divisor=6;
   estimate 'avg slope: cold water' 
             w(ph) 3 3 w(water_temp) 6 0 w(dry_cycle) 2 2 2
             / divisor=6;
   estimate 'avg slope: hot water' 
             w(ph) 3 3 w(water_temp) 0 6 w(dry_cycle) 2 2 2
             / divisor=6;
   estimate 'avg slope: air dry' 
             w(ph) 1 1 w(water_temp) 1 1 w(dry_cycle) 2 0 0
             / divisor=2;
   estimate 'avg slope: delicate dry' 
             w(ph) 1 1 w(water_temp) 1 1 w(dry_cycle) 0 2 0
             / divisor=2;
   estimate 'avg slope: normal dry' 
             w(ph) 1 1 w(water_temp) 1 1 w(dry_cycle) 0 0 2
             / divisor=2;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 16.8, 2^3 Factorial                     ---*/
data fac_sp;
  input rep blk a b c y;
  abc = a*b*c;
  datalines;
 1  1  -1  -1  -1  117
 1  1  -1   1   1  130
 1  1   1  -1   1  122
 1  1   1   1  -1  113
 1  2  -1  -1   1  123
 1  2  -1   1  -1  121
 1  2   1  -1  -1  122
 1  2   1   1   1  125
 2  1  -1  -1  -1  127
 2  1  -1   1   1  137
 2  1   1  -1   1  131
 2  1   1   1  -1  122
 2  2  -1  -1   1  128
 2  2  -1   1  -1  124
 2  2   1  -1  -1  124
 2  2   1   1   1  130
 3  1  -1  -1  -1  114
 3  1  -1   1   1  132
 3  1   1  -1   1  121
 3  1   1   1  -1  116
 3  2  -1  -1   1  125
 3  2  -1   1  -1  124
 3  2   1  -1  -1  122
 3  2   1   1   1  129
 4  1  -1  -1  -1  118
 4  1  -1   1   1  132
 4  1   1  -1   1  120
 4  1   1   1  -1  117
 4  2  -1  -1   1  120
 4  2  -1   1  -1  118
 4  2   1  -1  -1  113
 4  2   1   1   1  122
 5  1  -1  -1  -1  120
 5  1  -1   1   1  132
 5  1   1  -1   1  118
 5  1   1   1  -1  120
 5  2  -1  -1   1  127
 5  2  -1   1  -1  127
 5  2   1  -1  -1  118
 5  2   1   1   1  130
 6  1  -1  -1  -1  122
 6  1  -1   1   1  134
 6  1   1  -1   1  124
 6  1   1   1  -1  115
 6  2  -1  -1   1  123
 6  2  -1   1  -1  122
 6  2   1  -1  -1  123
 6  2   1   1   1  124
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.18                                     ---*/
proc glimmix data=fac_sp; 
   class a b c rep blk;
   model y=a|b|c / ddfm=kr;
   random rep blk(rep);
   lsmeans a*b b*c / slicediff=b;
   lsmeans a*b*c;
   ods select CovParms LSMeans SliceDiffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.19                                     ---*/
proc mixed data=fac_sp;
   class rep blk;
   model y=a|b|c / solution ddfm=satterth;
   random rep blk(rep);
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.20                                     ---*/
proc glm data=fac_sp;
   class a b c rep blk;
   model y=rep blk(rep) a|b|c/solution;
   random rep blk(rep)/test;
   lsmeans a*b*c;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.21                                     ---*/
proc glm data=fac_sp;
   class a b c rep blk;
   model y = a|b|c rep blk(rep) / e1;
   random rep blk(rep)/test;
   lsmeans a*b*c;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.22                                     ---*/
proc glm data=fac_sp; 
   class abc a b c rep ;
   model y=rep abc rep*abc a|b|c@2;
   random rep rep*abc / test;
   lsmeans a*b b*c / pdiff;
   estimate '(0)' intercept 1 abc 1 0 a 1 0 b 1 0 c 1 0 
                  a*b 1 0 0 0 a*c 1 0 0 0 b*c 1 0 0 0;
   estimate 'a'   intercept 1 abc 0 1 a 0 1 b 1 0 c 1 0 
                  a*b 0 0 1 0 a*c 0 0 1 0 b*c 1 0 0 0;
   estimate 'b'   intercept 1 abc 0 1 a 1 0 b 0 1 c 1 0 
                  a*b 0 1 0 0 a*c 1 0 0 0 b*c 0 0 1 0;
   estimate 'c'   intercept 1 abc 0 1 a 1 0 b 1 0 c 0 1 
                  a*b 1 0 0 0 a*c 0 1 0 0 b*c 0 1 0 0;
   estimate 'ab'  intercept 1 abc 1 0 a 0 1 b 0 1 c 1 0 
                  a*b 0 0 0 1 a*c 0 0 1 0 b*c 0 0 1 0;
   estimate 'ac'  intercept 1 abc 1 0 a 0 1 b 1 0 c 0 1 
                  a*b 0 0 1 0 a*c 0 0 0 1 b*c 0 1 0 0;
   estimate 'bc'  intercept 1 abc 1 0 a 1 0 b 0 1 c 0 1 
                  a*b 0 1 0 0 a*c 0 1 0 0 b*c 0 0 0 1;
   estimate 'abc' intercept 1 abc 0 1 a 0 1 b 0 1 c 0 1 
                  a*b 0 0 0 1 a*c 0 0 0 1 b*c 0 0 0 1;
   ods select Estimates;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 16.9, Edge Slope                        ---*/
data resist; 
   input rep blk a b c edslp;
   datalines;
 1 1 -1 -1 -1 3.6
 1 1 -1  1  1 4.5
 1 1  1 -1  1 4.2
 1 1  1  1 -1 4.0
 1 2 -1 -1  1 5.1
 1 2 -1  1 -1 3.9
 1 2  1 -1 -1 4.5
 1 2  1  1  1 4.9
 2 1 -1 -1 -1 5.2
 2 1 -1  1  1 5.9
 2 1  1 -1  1 5.3
 2 1  1  1 -1 5.2
 2 2 -1 -1  1 5.2
 2 2 -1  1 -1 4.6
 2 2  1 -1 -1 4.7
 2 2  1  1  1 5.2
 3 1 -1  1 -1 4.3
 3 1 -1  1  1 5.1
 3 1  1 -1 -1 4.5
 3 1  1 -1  1 4.6
 3 2 -1 -1 -1 4.8
 3 2 -1 -1  1 5.2
 3 2  1  1 -1 5.2
 3 2  1  1  1 5.9
 4 1 -1 -1  1 5.9
 4 1 -1  1  1 6.4
 4 1  1 -1 -1 5.7
 4 1  1  1 -1 5.6
 4 2 -1 -1 -1 4.3
 4 2 -1  1 -1 4.4
 4 2  1 -1  1 5.3
 4 2  1  1  1 5.6
 5 1 -1 -1  1 4.3
 5 1 -1  1 -1 4.2
 5 1  1 -1  1 4.3
 5 1  1  1 -1 4.4
 5 2 -1 -1 -1 4.5
 5 2 -1  1  1 5.5
 5 2  1 -1 -1 4.6
 5 2  1  1  1 5.2
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.23                                     ---*/
proc glimmix data=resist; 
   class a b c rep blk;
   model edslp = a|b|c / ddfm=kr;
   random rep blk(rep);
   lsmeans a*b b*c / slicediff=(a b c);
   ods select CovParms Tests3 LSMeans SliceDiffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.24                                     ---*/
proc mixed data=resist; 
   class rep blk;
   model edslp = a|b|c / solution ddfm=satterth;
   random rep blk(rep);
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 16.10, Use Products                     ---*/
data prior;
   input blk seq t1 t2 t3 person 
         y11 y12 y13 y21 y22 y23 y31 y32 y33;
   array yy{3,3}  y11-y13 y21-y23 y31-y33;
   array tt{3}  t1-t3;
   array ll{4}  l1-l4;
   do period = 1 to 3;
      prod = tt{period} ;
      do i = 1 to 4;
         ll{i}  = 0;
      end;
      if (period = 1) then priorprd = 0;
      else do;
         priorprd = tt{period - 1} ;
         ll{priorprd}  = 1;
      end;
      do time = 1 to 3;
         y = yy{period,time} ;
         output;
      end;
   end;
   drop i t1-t3 y11-y13 y21-y23 y31-y33;
   datalines;
1    1    1   2   3    101    5    4    3    5    5    5    5    4    4
1    2    1   3   2    102    4    4    3    6    6    6    5    5    4
1    3    2   1   3    103    5    4    4    5    5    4    5    5    5
1    4    2   3   1    104    4    4    4    4    4    4    4    4    4
1    5    3   2   1    105    5    5    5    5    5    5    6    6    5
1    6    3   1   2    106    6    5    5    6    6    5    7    6    6
2    1    1   2   4    201    3    2    1    3    3    3    2    3    3
2    2    1   4   2    202    4    4    3    4    5    5    4    3    3
2    3    2   1   4    203    4    3    3    3    3    2    4    5    5
2    4    2   4   1    204    4    4    3    4    4    4    3    3    2
2    5    4   2   1    205    4    4    4    3    3    2    4    3    3
2    6    4   1   2    206    4    4    4    3    3    2    4    4    4
3    1    1   3   4    301    4    4    3    5    5    5    4    5    5
3    2    1   4   3    302    3    3    3    4    4    4    3    4    3
3    3    3   1   4    303    4    4    4    4    4    3    4    4    4
3    4    3   4   1    304    3    2    2    3    3    3    3    2    2
3    5    4   3   1    305    2    2    2    2    2    2    2    2    1
3    6    4   1   3    306    4    4    4    4    3    2    4    4    4
4    1    2   3   4    401    3    3    3    3    3    3    4    4    4
4    2    2   4   3    402    3    2    2    4    4    4    3    3    3
4    3    3   2   4    403    4    4    4    5    5    4    4    4    4
4    4    3   4   2    404    2    2    2    3    3    3    4    4    3
4    5    4   3   2    405    4    4    4    4    4    4    4    4    4
4    6    4   2   3    406    3    4    3    4    3    4    3    3    3
;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 16.25                                     ---*/
proc mixed data=prior; 
   class blk person seq prod period time priorprd;
   model y=prod period time time*prod priorprd/ddfm=satterth;
   random blk person(blk) period*person(blk);
   lsmeans prod time*prod; 
   estimate 'prod 1 v 2' prod 1 -1 0 0;
   ods select CovParms Tests3 Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.26                                     ---*/
proc glimmix data=prior; 
   class blk person seq prod period time PRIORPRD;
   model y=prod period time time*prod L1 L2 L3 L4/ ddfm=satterth;
   random blk person(blk) prod*person (blk);
   lsmeans time*prod/slicediff=(time prod);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.27                                     ---*/
proc glimmix data=prior; 
   class blk person seq prod period time PRIORPRD;
   model y=prod period time time*prod L1 L2 L3 L4/ ddfm=satterth;
   random blk person(blk) prod*person (blk);
   lsmeans time*prod/slicediff=(time prod);
   ods select LSMeans SliceDiffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.28                                     ---*/
proc mixed data=prior; 
   class blk person seq prod period time priorprd;
   model y=prod period time time*prod priorprd/ ddfm=satterth;
   random blk person(blk) period(person blk);
   repeated time/subject=period*person(blk) type=ar(1);
   ods select CovParms FitStatistics Tests3;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 16.29                                     ---*/
 /*---Output 16.30                                     ---*/
proc glimmix data=prior; 
   class blk person seq prod period time priorprd;
   model y=prod period time time*prod L1 L2 L3 L4/ ddfm=kr;
   random blk person(blk) period*person (blk);
   random _residual_ / subject=period*person(blk) type=ar(1); 
   lsmeans time*prod / slicediff=(time prod);
   ods select CovParms FitStatistics Tests3 LSMeans SliceDiffs;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 16.31                                     ---*/ 
proc mixed data=prior; 
   class blk person seq prod period time priorprd;
   model y=prod period time time*prod priorprd / ddfm=kr;
   random int person / sub=blk;
   random period / type=ar(1) subject=person(blk);
   repeated time / subject=period*person(blk) type=ar(1);
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.32                                     ---*/
 /*---Output 16.33                                     ---*/
proc glimmix data=prior; 
   class blk person seq prod period time priorprd;
   model y=prod period time time*prod L1 L2 L3 L4/ddfm=kr s;
   random int person / sub=blk;
   random period / type=ar(1) subject=person(blk);
   random time / subject=period*person*blk type=ar(1) residual;
   lsmeans time*prod/slicediff=(time prod);
   ods select Tests3 LSMeans SliceDiffs;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 16.4, CD4 Counts                        ---*/
data cd4;
   input randgrp stratum unit @@;
   seq = _n_;
   do visit = 0,2,6,12,18;
      input cd4 @@;
      sqrtcd4 = sqrt(cd4);
      if visit ne 0 then notbase = 1;
      else notbase = 0;
      if visit ne 0 then visitm2 = visit - 2;
      else visitm2 = 0;
      output;
   end;
   datalines;
2   2    2   114      .     71     89      .
1   2    2    40      .     66     21     25
1   2    3    12     13     38      .      .
2   1    3    15     21      7      3      .
1   1    3    53     74     74     45      .
2   1    3    21      .      .      .      .
2   2    3    46     29     20     10      .
1   2    5    12      1      0      .      .
2   1    5     0     33      .      .      .
1   2    5   147    180    111     56      .
2   2    5    47      .      .      .      .
1   2    5   185    262    177     91    138
2   2    5     6     16      6      .      .
1   2    5     4      8      .      .      .
1   1    5   138     97     83     79      .
2   2    5     3      1     26      .      .
2   2    5    43     24     25     25      .
2   2    5    32     29      9      7      .
1   2    5     9      .      .      .      .
2   1    6   363    364    270    279      .
1   2    6    52     29     11      .      .
1   2    6     3      3      2      4      .
1   2    6    15      .      .      .      .
2   2    6   197    255      .    235    206
2   1    6     5      .      .      .      .
1   2    6   295    394    411    291    185
2   2    6    17      .      5      2      3
1   1    6   285      .      .      .      .
1   1    6    21      .      .      .      .
2   2    6    33      .     19      .      .
2   2    6    83    112     31      .      .
1   2    6     3      .      1      .      .
1   1    6    60     43      .      .     12
2   2    6     1      .      2      .      7
1   2    6   157    101     51     47     40
2   2    6     0      .      1      .      .
2   2    6    15      9      5      .      .
1   2    6   280    233      .      .      .
2   2    6   100      .     61     20      .
1   2    6   263    204      .      .      .
2   2    6    22     11      .      2      .
2   2    6    69      .      .      .      .
2   2    6   272      .      .      .      .
1   2    6    21     29     12      .      .
2   1    6     3      .      .      .      .
1   2    6    39     24      7      .      .
2   1    6    16     13      .      .      .
2   1    6     1      2      .      .      .
1   2    6     1      .      .      .      .
1   2    6   190    207    147     16      .
1   2    6     9     20      .      .      .
2   2    6     2      0      .      .      .
2   1    6    13      .      .      .      .
2   1    7   111    187    130     81      .
2   2    7     6     10     23      4      .
2   1    7    48     53     13     20      .
1   2    7    11     32     10      .      .
1   2    7     6      3      3      .      .
2   2    7   130     27     33      .      .
2   1    7     8      .      5      1      .
2   2    7   154    177      .      .      .
2   2    7   271    250    125    169      .
2   1    7   194    307    142     99      .
1   2    7    32     31      6      .      .
1   1    7    15      .      .      .      .
1   1    7    50      .     21      .      .
1   1    7    17      .      6      .      .
1   1    7   192     78     33     11      .
2   1    7     5      .      .      .      .
1   2    7    46     61     79      .      .
2   2    7     4      5      .      .      .
2   2    7   226    187    190    187      .
1   2    7     1      .      .      .      .
1   2    7    21     37      4      8      .
1   1    7   110     66     58      .      .
2   2    7    19     19     16     10      .
2   1    7    14      1      2      .      .
1   2    7    52    137    104    130      .
2   2    7    21     31     32      8      .
2   2    8   120    300    220    272      .
1   2    8     5      5      .      .      .
1   1    8    42     34     15      .      7
1   1    8    50     50      .      .      .
2   2    8    64     15      .      .      .
1   2    8    15     54     45     25      .
1   2    8   242    390    264    332      .
2   1    8    39      2     24      .      .
2   1    8     8     30      3      .      .
2   1    8     4     11      2     21     19
1   2    8   199    203    286    255    183
2   2    8    65     51     46      5     37
1   1    8    45     48     60     61     42
2   2    8   291    314    453    382    273
1   2    8    39     30     21     16      .
2   2    8   115     90    139    141      .
2   2    8   224      .    363    262      .
1   1    8    40     16      .      .      .
2   1    8    40     26     36      .      .
2   2    8    24      .      3      .      .
2   1    8    21     35     28      .      .
1   1    8   176    198     98     22      .
1   1    8     6      2      .      .      .
2   2    8    13    162      .     42      .
2   1    8    15     20     20      .      .
2   2    8    11      5      .      .      .
1   2    8   275    415    284    308      .
1   1    8    50     72     36      .      .
2   1    8     2      .      .      .      .
2   1    8    61      .      .      .      .
1   1    8   274    265      .      .      .
1   1    8    28     42     16      .      .
2   2    8    41     30      .      .      .
1   1    8    54      .      .      .      .
1   2    8     4      4      2      .      .
2   1    8    54     21      .      .      .
2   1    8    29     21      .      .      .
1   1    8   100      .     14     29      .
2   1    8    10      .      .      .      .
1   2    8   156      .     39      .      .
1   2    8     0      .      .      .      .
1   2    8    59     43     61     25      .
2   2    8     6      4      .      .      .
2   2    8    71      .      .      6      .
1   2    8    27      8     13     18      .
2   2    9    15      3      3      4      .
2   2    9    63     30     22      4      .
1   2    9    25    163    113     59      .
1   1    9    14      .      .      .      .
2   2    9    21     15      5      .      .
2   2    9   197    154    135    110     31
1   2    9   130    582      .      .      .
2   2    9    16     37     10      8      .
2   1    9    37     26      0      8      .
1   2    9    10     12      9      .      .
2   2    9    50     40     20     10      .
2   2    9   109     42     18      .      .
1   2    9    89     19     43      9      6
1   2    9    52     15     26      .      .
2   2    9    42     23     30     11     15
1   1    9     7      .      1      .      .
1   2    9    10      0      5      .      .
1   2    9   232    221    166    141      .
2   1    9   117     17      .     55      .
1   2    9   288    268    150    298      .
2   2    9   168    226    129    144      .
2   1    9   169    149     93     45      .
2   2    9    12     16      0      .      .
1   2    9   126    246    153    140      .
1   2    9   136    112      .     86      .
2   2    9     1      3      0      0      .
1   2    9    91     37      .      .      .
2   2    9   280      .    319      .      .
2   2    9   160    115     57     69      .
1   2    9    46     31      8     10      .
1   2    9     5      3      3      7      .
1   1    9     0      .      .      .      .
1   2   10   246    333      .    232    177
1   2   10   224      .    204    141      .
1   2   10   240    360      .    310      .
2   2   10   198    172      .    286      .
2   1   10    66     89     81     18      .
1   1   10    40     15     34      5      .
1   1   10    10     30      .      .      .
1   1   10    30      .      .      .      .
2   2   10   120    160    120    130     80
2   1   10    50      .     20     10      .
1   2   10    47    110     63     20      .
2   1   10    20     10     20      .      .
2   2   10    30     40     95     50      .
2   2   10    80     50     60     10      .
2   1   10    30      4     40     10      .
1   1   10    76    110      .      .      .
2   2   10   250      .    210    220      .
2   2   10    30     40     40    320      .
2   1   10   100     40      .      .      .
2   1   10   140    105      .     89      .
2   1   10    20     20     10     20      .
2   2   10   270    290    220    240      .
1   2   10    40     20     30      .      .
2   2   10   190     90    130     80      .
1   1   10    40      .      .      .      .
1   2   10    40     80     20     20      .
2   2   10    70     40     30      0      .
1   2   10   180    260    160    180      .
1   1   10     0      .     60     70      .
2   2   10   190    280    130    200      .
2   2   10   270    370    360    350      .
1   2   10     7      4      6    287      .
1   2   10   370      .      .      .      .
2   2   10    24      3     11      7      .
1   2   10   144    237    242    119      .
1   1   10    13     27      .     19      .
1   2   10   104    174    194      .      .
2   1   10    25      0      9     23      .
1   2   10   110    250    170     80      .
1   2   10    20      .      .      .      .
2   2   10   130      .      .      .      .
1   2   10   160    230    300    200      .
1   2   10   190    300    150    240      .
2   2   10    20     10      0      4      .
1   1   10     5      0      .      .      .
2   1   11    59      .      .      .      .
1   1   11     5     14      5      .      .
1   2   11    28      .     46      .      .
1   1   12     6      5      .      .      .
2   2   12   107    126     72     14      .
1   1   12    23      .      .      .      .
2   1   12     4      5      4      9      .
1   1   12    32     39     46     30     34
1   2   12   143    154    264    176      .
2   1   12    14      8      .      .      .
2   2   12   273    383    263    369      .
1   1   12    72     20      9      .      .
2   2   12    77     19      .      .      .
1   2   12    95    234    216     98      .
2   1   12    94     53     29      5      .
1   2   12   165      .     35      .      .
1   2   12     6     18      .      .      .
2   2   12   281    207    160     71     62
2   2   12    17     10      .      .      .
1   2   12     7     15     11      .      .
1   2   12   109     92     85      .     68
2   2   12   222    136      .    179      .
1   2   12     6     10      8      5     11
2   2   12    10      8      3      .      .
1   2   12    21     17      8      .      .
1   2   12    10      .      .      .      .
2   1   12     0     21      .      .      .
2   2   12    13      .      .      .      .
2   2   12    14      .      .      .      .
1   2   12     9      .     10     30      .
1   2   12    11      7     14     16      .
2   1   12    53     27      .      .      .
2   2   12   131    129    122     66      .
1   1   12     3      7      .      .      .
1   2   12   216    249     14    139      .
1   1   12     8      7      .      .      .
1   2   12    37     30     21     16      .
2   2   12   200      .    203    209      .
2   2   12    32     57     13      7      .
2   2   12    67     40     32     54      .
2   2   12   235      .    134     53      .
2   2   12    43     55      .      .      .
1   2   12    35     19     11      .      .
1   2   12   228    235     29    294      .
1   2   12   109    124     88      .      .
1   1   12    11      .      .      .      .
2   2   12    82      .      .      .      .
2   1   12   112      9      5      .      .
1   2   12   181    110      .      .      .
2   1   12    76     18     11      7      .
2   1   12   152    168    144     68      .
2   1   12     7      8      5      2      .
2   2   12   230    253     17    170      .
2   1   13     2      3      2      4      .
2   1   13     1      2      1      1      .
2   2   13     9     22      8     11      .
2   2   13   281    300    368    202    130
1   2   13     5      .      .      .      .
2   2   13    12     35     34     14     14
2   2   13   277     84      .      .      .
1   1   13     4      3      1      1      .
2   1   13     2      2      2      2      .
1   2   13   254    284    291    204      .
2   2   13    51     75     78      .      .
1   1   13     6      2      1      .      .
1   2   13    19     27     34     12      .
2   2   13    16     10      3      4      .
1   2   13     2      6      1      1      .
1   2   13     8     12      4      .      .
2   1   14    17      4      7      .      .
1   2   14    11      8      .      5      .
1   2   14    41     52     30      1      .
1   1   14    54     39     23     14     19
1   1   14    16      .     10      2      4
1   2   14    70     35     49     26      .
1   1   14    10      .      .      .      .
2   2   14    10     10      4      .      .
1   1   14     8      9      6      9      .
2   2   14    12      .      6      .      .
2   1   14    10      8      3      7      .
1   2   14    17      3      1      .      .
1   1   14    15      5      1      1      .
1   1   14    31     26     27     12      .
1   2   14    40      9      .      .      .
1   2   14    44     30      .      .      .
2   1   14    40      6      .      .      .
1   1   14    12      .      .      .      .
1   1   14    80     35     47      3      .
1   2   14    99    200    152    191      .
2   1   14     8      .      .      5      .
2   2   14     3      .      .      .      .
2   2   14    34     34     36     13      .
1   2   14    60     33     37     14      .
2   2   14    38     17     12     55      .
2   1   14    31     22     10      .      .
2   1   14    34     13      9      .      .
1   1   14    11     11      3      .      .
1   1   14    77     51     37      .      .
1   2   14     9     21      .      .      .
1   2   14   122    112     77     72      .
2   2   14   273    129    163    154      .
2   1   14    81     52     26      .      .
1   1   14    10      7     14     10      .
2   1   14     4      .      6      .      .
2   1   14    35      .     11      4      .
2   2   14    65     58     22     15      .
2   1   14     7      4      6      .      .
2   2   14   180    238    171     65      .
2   1   14     4      8      3      .      .
2   2   14    93    142      .     15      .
2   2   14   297    122     89     40      .
2   2   14   300    330    290    270    340
2   2   15    13     10      .      .      .
1   1   15     8     15     17     12      8
2   1   15     3      3      8      6      3
1   1   15     7      9      2      .      .
1   1   15   273    152     65     38     21
1   2   15   137    121    146    138      .
2   2   15    42      .      .      .      .
1   1   15     8      .      .      .      .
2   2   15    62      .      .      .      .
1   2   15     3      4      3      4      .
2   1   15    13      7      3      .      .
2   1   15    37     17     20      1      .
2   1   15     6      3      1      .      .
1   2   15   128      .     24     15      .
1   2   15    64     28      .      .      .
1   1   15     2      .      .      .      .
1   2   15   125    147    203    113      .
2   1   15    18     30     22      .      .
2   2   15    21      .      8      7      .
2   2   15    47     56      .      .      .
1   2   15     5      5      4      .      .
2   1   15    11     12      8      .      .
2   2   15   184    138     37      .      .
1   1   15    12      .      .      .      .
2   1   15     7     10      9      4      .
1   2   15    40     29     28     20      .
2   2   15   100    145     88     45      .
1   2   15   113    116    173    126      .
1   2   15    74     56     29     27      .
2   2   15   161    176      .     30      .
2   2   15     5      .      .      .      .
2   2   15    31     24     31      .      .
1   1   15   233    269    182     71      .
1   2   15    63     71     16     16      .
1   1   15   247    289    219      .      .
1   1   15    10     20      .      .      .
2   2   15   291    367    323    267      .
2   2   15    30     41     22     16      .
2   2   15     5      .      .      .      .
1   2   15   108    475    284    151      .
1   2   15    13     15      .      .      .
1   2   15   341      .      .      .      .
1   1   15     6      6      .      .      .
2   1   15     7     12      9      0      .
1   2   16    23     54      .      .      .
1   1   16    27     33     18      5     12
1   2   16    52     48     84     63     20
1   1   16     0      .     15      .      .
2   1   16     0      .      .      .      .
2   2   16     4     10      0      .      .
1   2   16    14      .      .      0      .
2   2   16    48    143      .      .      .
2   2   16    49     77      .     90      .
2   2   16     5      2      .      .      .
1   2   16    63    110     55     26      .
2   1   16     6      0      .      5      .
2   1   16     8      0      .      .      .
2   1   16    10      .      7      .      .
2   2   16   237    306    286    276      .
1   2   16    66     70      .      .      .
2   1   16   155    104      .    184      .
1   2   16   281      .      .      .      .
1   1   16     0      .      .      .      .
2   2   16   201    238    240    418      .
1   1   16     6      0      .      .      .
1   2   17    20     12     12      .      .
2   2   17    27     20     11      .      .
2   2   17   110     57     41      .      .
2   1   17    37     40      .      .      .
2   2   17     3      5      1      .      .
1   2   17   176    207    383    161      .
2   1   17   217     90     97      9      .
2   1   17    84     39      .      .      .
2   2   17    22     14      6      .      .
2   1   17     8     29     16      7      .
1   2   17    80     51      .      .      .
2   1   17   224    194    125      .      .
1   2   17    13     19      .      3      2
2   2   17    96     53      .      .      .
2   1   17    10     17      9      .      .
1   2   17    30      .      .      .      .
2   2   17    57     55      .     11      .
1   1   17     2      3     11      .      .
2   2   17    19      .      .      .      .
1   2   17    39     14     16      .      .
1   2   17   288    323    357    369      .
2   1   17    15     11      3      .      .
1   2   17    43     13      .      .      .
1   1   17    14     14     10      .      .
1   2   17   125      .      .      .      .
1   1   17     7      7      3     11      .
1   2   17    14      9     10      7      .
1   1   17     2      8      .      .      .
2   2   17    11      7      8      0      .
2   2   17     5      7      .      .      .
1   1   17    46     47     35     25      .
2   2   17     3      2      .      .      .
2   2   17   132     90     60     23      .
1   1   17    84     57     54      .      .
1   1   17    26      .      .      .      .
1   2   17   239    200     89     51      .
2   2   17     4      .      .      .      .
2   2   17    29     23     35      .      .
1   2   17    21    113      5      .      .
1   2   17   166      .      .      .      .
1   2   17   273     87    359    285      .
2   2   17   181      .      .      .      .
1   2   17     2      4      2      0      .
2   1   17    28     43     28     28      .
2   2   17    70     60     66     49      .
1   2   17    76    105     40      .      .
2   2   17    78      .      .      .      .
1   2   18    75    132      .      .      .
2   1   18    36      .      .      .      .
2   2   18    12      6     16     13      .
2   1   18    40      .     28      .      .
2   2   18    16     50     17      5      .
2   1   18     5      .      .      .      .
1   1   18     3     12      .      .      .
1   1   18    56     45      9      8      .
2   2   18    66     78     50     32      .
2   2   18    65     96     60     91      .
1   2   18   272    240    234     98      .
2   1   18    60     24     90     76      .
1   2   18   105    272    375    150      .
1   2   18    36     32     42      .      .
2   1   18    24      4      .      .      .
2   1   18   300    270    143    160      .
2   2   18    20     18     10      .      .
2   2   18    13     14      6      7      7
1   2   18    42     20     30     18      .
2   2   18    27     42      6      6      .
1   1   18     7      9     21      .      .
1   2   18    70     63     30      .      .
1   2   18   159     73      .      .      .
1   1   18    14     16      5      .      .
1   1   18   138    140    154    120    126
1   2   18   169    144     84      .      .
2   1   18    40     36      .     10      .
1   1   18    40      .      .      .      .
1   2   18    24     15      5      5      3
2   2   18    21     12     24    102      .
2   2   18     6     24      .      .      .
2   1   18    10     20     14      3      .
1   2   18   190    136      .      .      .
1   2   18   220    400    240      .      .
1   1   18   247    300    220    242      .
1   1   18     9     30     10      .      .
1   1   18     3     21      .      .      .
1   2   18     7     10      6      7      .
2   2   18    24      .      .      .      .
1   1   18    10      6     12      .      .
2   2   18     9     10      .      .      .
2   1   18    30      5      .      .      .
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.34                                     ---*/
proc mixed data=cd4;
   class randgrp stratum unit seq;
   model sqrtcd4 = stratum unit notbase
                   notbase*randgrp notbase*stratum
                   visitm2 visitm2*randgrp visitm2*stratum 
                   / ddfm=kr;
   random int notbase visitm2 / type=un sub=seq g gcorr;
   ods select CovParms FitStatistics G Gcorr Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.35                                     ---*/
proc mixed data=cd4;
   class randgrp stratum unit seq visit;
   model sqrtcd4 = stratum unit notbase 
                   notbase*randgrp notbase*stratum
                   visitm2 visitm2*randgrp visitm2*stratum 
                  / ddfm=kr;
   random int notbase visitm2 / type=un sub=seq;
   repeated visit / sub=seq group=randgrp*stratum;
   ods select CovParms FitStatistics Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.36                                     ---*/
proc mixed data=cd4;
   class randgrp stratum visit seq;
   model sqrtcd4 = stratum notbase notbase*randgrp 
                   notbase*stratum visitm2 /solution ddfm=kr;
   random int notbase visitm2 / type=un sub=seq g gcorr;
   repeated visit / sub=seq group=randgrp*stratum;
   estimate 'ddI 2   base s 2' 
            notbase 1 notbase*randgrp 1 0 visitm2 0 / cl;
   estimate 'ddC 2   base s 2' 
            notbase 1 notbase*randgrp 0 1 visitm2 0;
   estimate 'ddI 6   base s 2' 
            notbase 1 notbase*randgrp 1 0 visitm2 4;
   estimate 'ddC 6   base s 2' 
            notbase 1 notbase*randgrp 0 1 visitm2 4;
   estimate 'ddI   ddC s 2' notbase*randgrp 1 -1;
   estimate 'ddI 24 s 1' int 1 stratum 1 0 notbase 1 
            notbase*randgrp 1 0 notbase*stratum 1 0 visitm2 22;
   estimate 'ddC 24 s 1' int 1 stratum 1 0 notbase 1 
            notbase*randgrp 0 1 notbase*stratum 1 0 visitm2 22;
   estimate 'ddI 24 s 2' int 1 notbase 1 notbase*randgrp 1 0 
            visitm2 22;
   estimate 'ddC 24 s 2' int 1 notbase 1 notbase*randgrp 0 1 
             visitm2 22;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 16.10                                     ---*/
data cd4x;
   input seq randgrp stratum sqrtcd4 visit notbase;
   if (visit ne 0) then visitm2 = visit - 2;
   else visitm2 = 0;
   datalines;
1000 1 1 .  0 0
1000 1 1 .  2 1
1000 1 1 .  6 1
1000 1 1 . 12 1
1000 1 1 . 18 1
1001 1 2 .  0 0
1001 1 2 .  2 1
1001 1 2 .  6 1
1001 1 2 . 12 1
1001 1 2 . 18 1
1002 2 1 .  0 0
1002 2 1 .  2 1
1002 2 1 .  6 1
1002 2 1 . 12 1
1002 2 1 . 18 1
1003 2 2 .  0 0
1003 2 2 .  2 1
1003 2 2 .  6 1
1003 2 2 . 12 1
1003 2 2 . 18 1
;
proc append base=cd4 data=cd4x;
run;
proc mixed data=cd4;
   class randgrp stratum visit seq;
   model sqrtcd4 = stratum  
         notbase notbase*randgrp notbase*stratum
         visitm2 / ddfm=res outp=p;
   random int notbase visitm2 / type=un sub=seq g gcorr;
   repeated visit / sub=seq group=randgrp*stratum;
   id visit seq;
run;
symbol1 i=join c=green w=1 r=467;
symbol2 i=join c=black w=4 r=4;
proc gplot data=p;
  plot pred*visit=seq / nolegend
                        vaxis=0 to 25 by 5 vminor=0
                        haxis=0 to 18 by 2 hminor=0;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 16.12, Microarray                       ---*/
data microarray;
   input array dye$ trt row @@;
   input pin @@;
   do dip=1 to 2;
      input gene log_intensity @@;
         output;
   end;
   input pin @@;
   do dip=3 to 4;
     input gene log_intensity @@;
     output;
   end;
   datalines;
1 g 0 1 1 1  0.1907 2 -0.0829 3 1  0.3392 3  0.3193
1 g 0 2 2 3  0.2378 5  0.2329 4 2  0.7002 4  0.5768
1 g 0 3 1 2  0.1554 4 -0.0289 3 3  0.4332 5  0.3022
1 g 0 4 2 5  0.1443 7  0.0782 4 4  0.3772 6  0.2524
1 g 0 5 1 4  0.0174 6  0.0325 3 5  0.3553 7  0.2871
1 g 0 6 2 7 -0.2612 8  0.4427 4 6  0.6877 8  0.4636
1 g 0 7 1 6  0.0052 1 -0.2233 3 7  0.3867 1  0.1974
1 g 0 8 2 8 -0.307  3  0.1465 4 8  0.4864 2  0.308
1 r 1 1 1 1 -0.0668 2 -0.0327 3 1  0.2827 3  0.2519
1 r 1 2 2 3  0.1057 5  0.1137 4 2  0.6827 4  0.1942
1 r 1 3 1 2  0.125  4 -0.1126 3 3  0.1751 5  0.1315
1 r 1 4 2 5 -0.3206 7  0.1833 4 4  0.4353 6  0.4331
1 r 1 5 1 4 -0.1133 6 -0.1678 3 5  0.2912 7 -0.0462
1 r 1 6 2 7 -0.0602 8  0.2357 4 6  0.6294 8  0.2211
1 r 1 7 1 6 -0.1195 1 -0.352  3 7  0.3998 1  0.1125
1 r 1 8 2 8  0.1973 3 -0.002  4 8  0.2742 2  0.6028
2 g 1 1 1 1 -0.0688 2 -0.0833 3 1  0.1697 4 -0.1348
2 g 1 2 2 3 -0.4062 4 -0.4153 4 2 -0.1338 3  0.1829
2 g 1 3 1 2 -0.2492 5 -0.3246 3 4 -0.078  7 -0.0966
2 g 1 4 2 4 -0.4785 7 -0.3383 4 3 -0.2376 5  0.2191
2 g 1 5 1 5 -0.3406 6 -0.0904 3 7 -0.2738 8  0.3622
2 g 1 6 2 7 -0.2332 8 -0.4752 4 5 -0.0378 6  0.124
2 g 1 7 1 6 -0.467  1 -0.2558 3 8 -0.1252 1 -0.0634
2 g 1 8 2 8 -0.2724 3 -0.3642 4 6  0.2625 2 0.1457
2 r 2 1 1 1 -0.2336 2 -0.1691 3 1 -0.191  4 -0.1016
2 r 2 2 2 3 -0.4213 4 -0.1866 4 2  0.1008 3  0.0796
2 r 2 3 1 2 -0.2382 5 -0.3198 3 4 -0.0585 7 -0.0311
2 r 2 4 2 4 -0.4483 7 -0.5769 4 3 -0.1174 5 -0.3397
2 r 2 5 1 5 -0.2762 6 -0.2164 3 7 -0.359  8 -0.0886
2 r 2 6 2 7 -0.5948 8 -0.3436 4 5 -0.2083 6  0.1619
2 r 2 7 1 6 -0.1384 1 -0.2169 3 8 -0.0239 1  0.2815
2 r 2 8 2 8 -0.4022 3 -0.5579 4 6  0.1493 2 -0.0618
3 g 2 1 1 1  0.1867 2  0.4189 3 1  0.046  3 -0.0247
3 g 2 2 2 3  0.4205 4  0.7581 4 2  0.1829 5  0.2073
3 g 2 3 1 2  0.4308 5  0.3575 3 3  0.2484 4  0.1089
3 g 2 4 2 4  0.5159 6  0.7167 4 5  0.3128 7  0.1482
3 g 2 5 1 5  0.3008 7  0.3432 3 4  0.2077 6  0.1775
3 g 2 6 2 6  0.5234 8  0.1952 4 7  0.2487 8  0.295
3 g 2 7 1 7  0.2528 1  0.3054 3 6  0.2741 1 -0.1375
3 g 2 8 2 8  0.5686 3  0.5857 4 8  0.4427 2  0.1475
3 r 3 1 1 1  0.2709 2  0.3207 3 1 -0.0084 3 -0.1043
3 r 3 2 2 3  0.2363 4  0.5667 4 2  0.1772 5 -0.0501
3 r 3 3 1 2  0.6945 5  0.3878 3 3 -0.0911 4  0.0087
3 r 3 4 2 4  0.483  6  0.5148 4 5  0.2867 7 -0.1861
3 r 3 5 1 5  0.3144 7  0.0367 3 4  0.2272 6  0.105
3 r 3 6 2 6  0.8022 8  0.3158 4 7 -0.0186 8 -0.1071
3 r 3 7 1 7  0.0252 1  0.1669 3 6  0.0354 1 -0.0262
3 r 3 8 2 8  0.2114 3  0.0767 4 8  0.2971 2  0.3306
4 g 3 1 1 5 -0.0666 4  0.0908 3 8  0.2564 6  0.2192
4 g 3 2 2 8  0.388  7  0.3491 4 7  0.2873 5  0.482
4 g 3 3 1 4 -0.0118 2  0.2273 3 6  0.263  3  0.2995
4 g 3 4 2 7 -0.0124 6  0.5433 4 5  0.267  4  0.1209
4 g 3 5 1 2  0.1084 1  0.093  3 3 -0.0907 1 -0.0277
4 g 3 6 2 6  0.4487 3  0.316  4 4  0.4768 2  0.1686
4 g 3 7 1 1  0.1208 5  0.116  3 1 -0.0509 8 -0.0348
4 g 3 8 2 3  0.4648 8  0.2003 4 2  0.3766 7  0.1611
4 r 4 1 1 5 -0.1773 4  0.2046 3 8  0.2864 6  0.2656
4 r 4 2 2 8  0.335  7  0.2224 4 7 -0.1175 5  0.187
4 r 4 3 1 4 -0.2345 2  0.261  3 6  0.068  3 -0.1159
4 r 4 4 2 7 -0.0606 6  0.5218 4 5  0.061  4 -0.0182
4 r 4 5 1 2  0.3213 1 -0.2191 3 3  0.0857 1 -0.2704
4 r 4 6 2 6  0.4291 3  0.4206 4 4  0.1548 2  0.3084
4 r 4 7 1 1  0.1591 5 -0.1249 3 1  0.0118 8 -0.2502
4 r 4 8 2 3  0.3317 8  0.3393 4 2  0.3033 7  0.1212
5 g 4 1 1 5  0.5517 4 -0.0644 3 8  0.4244 7  0.4454
5 g 4 2 2 8 -0.3676 7 -0.3789 4 6  0.461  5  0.4221
5 g 4 3 1 4  0.1899 2  0.3064 3 7  0.1654 3  0.4978
5 g 4 4 2 7 -0.2358 6 -0.0055 4 5  0.2014 4  0.1544
5 g 4 5 1 2  0.6772 1  0.1971 3 3  0.183  1  0.3266
5 g 4 6 2 6 -0.0406 3 -0.4498 4 4  0.3124 2  0.5508
5 g 4 7 1 1  0.4595 5  0.2712 3 1  0.591  8  0.337
5 g 4 8 2 3 -0.0274 8 -0.4286 4 2  0.5265 6  0.6042
5 r 5 1 1 5  0.1724 4  0.2798 3 8  0.4042 7  0.5652
5 r 5 2 2 8 -0.4007 7 -0.2172 4 6  0.2638 5  0.472
5 r 5 3 1 4  0.121  2  0.3221 3 7  0.2502 3  0.4138
5 r 5 4 2 7 -0.2406 6 -0.1723 4 5  0.0341 4  0.3078
5 r 5 5 1 2  0.6888 1  0.2805 3 3  0.296  1  0.3515
5 r 5 6 2 6  0.2289 3 -0.5382 4 4 -0.1745 2  0.6739
5 r 5 7 1 1  0.1696 5  0.2032 3 1  0.0848 8  0.1495
5 r 5 8 2 3 -0.2606 8 -0.3536 4 2  0.1644 6  0.3109
6 g 5 1 1 7  0.2351 6  0.5415 3 2  0.3471 8  0.0274
6 g 5 2 2 5  0.0921 4 -0.1718 4 4 -0.2356 5  0.177
6 g 5 3 1 6  0.5824 8  0.1855 3 8 -0.1587 1 -0.3407
6 g 5 4 2 4 -0.1562 3  0.1223 4 5 -0.0096 6  0.4527
6 g 5 5 1 8  0.1985 1  0.0622 3 1 -0.1452 3 -0.0113
6 g 5 6 2 3  0.0961 2  0.2304 4 6  0.5136 7 -0.0875
6 g 5 7 1 1 -0.0128 7  0.1124 3 3 -0.1161 2 -0.0076
6 g 5 8 2 2  0.1381 5  0.0285 4 7  0.1501 4 -0.1956
6 r 0 1 1 7  0.0143 6 -0.0559 3 2 -0.0582 8 -0.2804
6 r 0 2 2 5 -0.1531 4 -0.3912 4 4 -0.2513 5  0.0966
6 r 0 3 1 6  0.2103 8 -0.1462 3 8 -0.0697 1 -0.2384
6 r 0 4 2 4 -0.2152 3  0.0462 4 5  0.0437 6  0.2255
6 r 0 5 1 8  0.0637 1 -0.1448 3 1 -0.294  3 -0.1107
6 r 0 6 2 3 -0.2533 2 -0.1884 4 6  0.0765 7 -0.0643
6 r 0 7 1 1  0.2061 7  0.1384 3 3 -0.1363 2 -0.5183
6 r 0 8 2 2 -0.2306 5  0.0531 4 7 -0.2809 4 -0.2613
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.37                                     ---*/
proc glimmix data=microarray;
   class array dye trt gene pin dip;
   model log_intensity = dye trt gene dye*gene 
                         trt*gene pin / ddfm=kr;
   random array array*gene dip(array) pin*array;
   lsmeans trt*gene / slice=gene
                      slicediff=gene
                      slicedifftype=control('0' '2');
run;
 /*-------------------------------------------------------*/

