 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---CHAPTER 2: Randomized Block Designs              ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 2.2, Bond                               ---*/
data bond;
  input ingot metal $ pres;
  datalines;
1   n   67.0
1   i   71.9
1   c   72.2
2   n   67.5
2   i   68.8
2   c   66.4
3   n   76.0
3   i   82.6
3   c   74.5
4   n   72.7
4   i   78.1
4   c   67.3
5   n   73.1
5   i   74.2
5   c   73.2
6   n   65.8
6   i   70.8
6   c   68.7
7   n   75.6
7   i   84.9
7   c   69.0
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.1 and 2.2                               ---*/
proc mixed data=bond covtest cl method=type3;
   class ingot metal;
   model pres = metal / ddfm=kr;
   random ingot;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.3                                       ---*/
proc mixed data=bond method=reml;
   class ingot metal;
   model pres=metal;
   random ingot;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.4 and 2.5                               ---*/
proc mixed data=bond;
   class ingot metal;
   model pres = metal / solution; 
   random ingot;
   lsmeans metal / diff cl;
   estimate 'nickel mean' intercept 1 metal 0  0 1;
   estimate 'copper vs iron'          metal 1 -1 0;
   contrast 'copper vs iron'          metal 1 -1 0;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.6                                       ---*/
proc mixed data=bond method=reml;
   class ingot metal;
   model pres=metal;
   random ingot;
   lsmeans metal / diff cl
                  adjust=simulate(report seed=4943838 cvadjust);
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figures 2.1 and 2.2                              ---*/
ods html;
ods graphics on;
proc glimmix data=bond plots=diffplot;
   class ingot metal;
   model pres=metal; 
   random ingot;
   lsmeans metal;
   lsmeans metal / adjust=simulate(seed=4943838);
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 2.7                                       ---*/
proc mixed data=bond covtest cl method=type3;
   class ingot metal;
   model pres=metal / ddfm=kr;
   random ingot;
   ods select Type3 CovParms;
   ods output type3=type3;
run;
data est_var_ingot;
   merge type3(where=(source='ingot')
               rename=(ms=msingot df=dfingot))
         type3(where=(source='Residual')
               rename=(ms=mserror df=dferror));
   var_Ingot    = (msingot-mserror)/3;
    df_var_ingot = (var_ingot**2)/((((msingot/3)**2)/dfingot)+
                   (((mserror/3)**2)/dferror));
    low_var_ingot= df_var_ingot*var_ingot/cinv(.975,df_var_ingot);
    up_var_ingot = df_var_ingot*var_ingot/cinv(.025,df_var_ingot);
run;
proc print data=est_var_ingot;
  var msingot dfingot mserror dferror 
      var_ingot df_var_ingot
      low_var_ingot up_var_ingot;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 2.8                                       ---*/
proc glm data=bond;
   class ingot metal;
   model pres = metal ingot / ss3;
   random ingot;
   lsmeans metal / pdiff 
                   adjust=simulate(report seed=4943838 cvadjust);
   estimate 'nickel mean' intercept 1 metal 0  0 1;
   estimate 'copper vs iron'          metal 1 -1 0;
   contrast 'nickel mean' intercept 1 metal 0  0 1;
   contrast 'copper vs iron'          metal 1 -1 0;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 2.5 PBIB                                ---*/
data pbib_mv;
  input blk trt1 y1 trt2 y2 trt3 y3 trt4 y4;
  datalines;
1   15  2.4 9   2.5 1   2.6 13  2.0
2   5   2.7 7   2.8 8   2.4 1   2.7
3   10  2.6 1   2.8 14  2.4 2   2.4
4   15  3.4 11  3.1 2   2.1 3   2.3
5   6   4.1 15  3.3 4   3.3 7   2.9
6   12  3.4 4   3.2 3   2.8 1   3.0
7   12  3.2 14  2.5 15  2.4 8   2.6
8   6   2.3 3   2.3 14  2.4 5   2.7
9   5   2.8 4   2.8 2   2.6 13  2.5
10  10  2.5 12  2.7 13  2.8 6   2.6
11  9   2.6 7   2.6 10  2.3 3   2.4
12  8   2.7 6   2.7 2   2.5 9   2.6
13  5   3.0 9   3.6 11  3.2 12  3.2
14  7   3.0 13  2.8 14  2.4 11  2.5
15  10  2.4 4   2.5 8   3.2 11  3.1
;
 /*---convert data set to univariate form              ---*/
data pbib; 
   set pbib_mv;
   array tx{4} trt1-trt4;
   array yy{4} y1-y4;
   do i=1 to 4;
      treat    = tx{i};
      response = yy{i};
      output;
   end;
   keep blk treat response;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 2.9                                       ---*/
proc glm data=pbib;
   class blk treat;
   model response=blk treat;
   random blk;
   lsmeans treat / stderr pdiff;
   estimate 'treat 1 mean' intercept 1 treat 1;
   estimate 'trt 1 mean' intercept 15 treat 15
             blk 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 / divisor=15;
   estimate 'trt 1 blk 1' intercept 1 treat 1 blk 1;
   estimate 'trt 1 vs trt 2' treat 1 -1;
   contrast 'trt 1 vs trt 2' treat 1 -1; 
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 2.10                                      ---*/
proc mixed data=pbib;
   class blk treat;
   model response=treat;
   random blk;
   estimate 'treat 1 mean' intercept 1  treat 1;
   estimate 'trt 1 mean'   intercept 15 treat 15 |
             blk 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 / divisor=15;
   estimate 'trt 1 vs trt 2' treat 1 -1;
   contrast 'trt 1 vs trt 2' treat 1 -1;
   lsmeans treat / diff;
   ods exclude diffs; 
   ods output diffs=difmix;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.11                                      ---*/
 /*---Construct a data set containing all pairs of     ---*/
 /*---treatments that occur together in a block        ---*/
data pairs; 
   set pbib_mv;
   array tx{4} trt1-trt4;
   array yy{4} y1-y4;
   do i=1 to 3; do j=(i+1) to 4;
      treat    = min(tx{i},tx{j});
      _treat   = max(tx{i},tx{j});
      output;
   end; end;
   keep blk treat _treat;
run;
proc sort data=pairs nodupkey; by treat _treat; run;
proc print data=pairs(obs=23); run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.12 and Output 2.13                      ---*/
proc sort data=difmix; by treat _treat;
data diffs; 
   merge difmix pairs; by treat _treat;
run;

proc print data=diffs(where=(blk=.)) noobs; 
   var treat _treat estimate stderr probt;
run;

proc print data=diffs(where=((blk ne .) and (treat <=2))) noobs; 
   var treat _treat estimate stderr probt;
run;
 /*-------------------------------------------------------*/


