 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/


 

 /*-------------------------------------------------------*/
 /*---CHAPTER 3: Random Effects Models                 ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 3.3, Mississippi River                  ---*/
data influent;
  input influent y type @@;
  datalines;
1   21  2 1   27  2 1   29  2 1   17  2 1   19  2
1   12  2 1   29  2 1   20  2 1   20  2 2   21  2
2   11  2 2   18  2 2   9   2 2   13  2 2   23  2
2   2   2 3   20  1 3   19  1 3   20  1 3   11  1
3   14  1 4   14  2 4   24  2 4   30  2 4   21  2
4   31  2 4   27  2 5   7   1 5   15  1 5   18  1
5   4   1 5   28  1 6   41  3 6   42  3 6   35  3
6   34  3 6   30  3
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.1                                       ---*/
proc mixed data=influent covtest cl;
   class influent;
   model y = /solution;
   random influent / solution;

   estimate 'influent 1' intercept 1 | influent 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 | influent 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 | influent 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 | influent 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 | influent 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 | influent 0 0 0 0 0 1;

   estimate 'influent 1U' | influent 1 0 0 0 0 0;
   estimate 'influent 2U' | influent 0 1 0 0 0 0;
   estimate 'influent 3U' | influent 0 0 1 0 0 0;
   estimate 'influent 4U' | influent 0 0 0 1 0 0;
   estimate 'influent 5U' | influent 0 0 0 0 1 0;
   estimate 'influent 6U' | influent 0 0 0 0 0 1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.2                                       ---*/
proc mixed data=influent method=ml;
   class influent;
   model y = / solution;
   random influent / solution;
   estimate 'influent 1' intercept 1 | influent 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 | influent 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 | influent 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 | influent 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 | influent 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 | influent 0 0 0 0 0 1;

   estimate 'influent 1U' | influent 1 0 0 0 0 0;
   estimate 'influent 2U' | influent 0 1 0 0 0 0;
   estimate 'influent 3U' | influent 0 0 1 0 0 0;
   estimate 'influent 4U' | influent 0 0 0 1 0 0;
   estimate 'influent 5U' | influent 0 0 0 0 1 0;
   estimate 'influent 6U' | influent 0 0 0 0 0 1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.3                                       ---*/
proc mixed data=influent method=mivque0;
   class influent;
   model y = / solution;
   random influent / solution;
   estimate 'influent 1' intercept 1 | influent 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 | influent 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 | influent 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 | influent 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 | influent 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 | influent 0 0 0 0 0 1;

   estimate 'influent 1U' | influent 1 0 0 0 0 0;
   estimate 'influent 2U' | influent 0 1 0 0 0 0;
   estimate 'influent 3U' | influent 0 0 1 0 0 0;
   estimate 'influent 4U' | influent 0 0 0 1 0 0;
   estimate 'influent 5U' | influent 0 0 0 0 1 0;
   estimate 'influent 6U' | influent 0 0 0 0 0 1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.4                                       ---*/
proc mixed data=influent method=type1;
   class influent;
   model y = / solution;
   random influent / solution;
   estimate 'influent 1' intercept 1 | influent 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 | influent 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 | influent 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 | influent 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 | influent 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 | influent 0 0 0 0 0 1;

   estimate 'influent 1U' | influent 1 0 0 0 0 0;
   estimate 'influent 2U' | influent 0 1 0 0 0 0;
   estimate 'influent 3U' | influent 0 0 1 0 0 0;
   estimate 'influent 4U' | influent 0 0 0 1 0 0;
   estimate 'influent 5U' | influent 0 0 0 0 1 0;
   estimate 'influent 6U' | influent 0 0 0 0 0 1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.5                                       ---*/
proc mixed data=influent noprofile; 
   class influent;
   model y = / solution;
   random influent / solution;
   parms (70) (25) / noiter;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.6                                       ---*/    
proc glm data=influent; 
   class influent;
   model y = influent;
   random influent / test;

   estimate 'Mean'       intercept 6 influent 1 1 1 1 1 1 / divisor=6;
   estimate 'Influent 1' intercept 6 influent 6 0 0 0 0 0 / divisor=6;
   estimate 'Influent 2' intercept 6 influent 0 6 0 0 0 0 / divisor=6;
   estimate 'Influent 3' intercept 6 influent 0 0 6 0 0 0 / divisor=6;
   estimate 'Influent 4' intercept 6 influent 0 0 0 6 0 0 / divisor=6;
   estimate 'Influent 5' intercept 6 influent 0 0 0 0 6 0 / divisor=6;
   estimate 'Influent 6' intercept 6 influent 0 0 0 0 0 6 / divisor=6;

   estimate 'Influent 1U' influent  5 -1 -1 -1 -1 -1 / divisor=5;
   estimate 'Influent 1U' influent -1  5 -1 -1 -1 -1 / divisor=5;
   estimate 'Influent 1U' influent -1 -1  5 -1 -1 -1 / divisor=5;
   estimate 'Influent 1U' influent -1 -1 -1  5 -1 -1 / divisor=5;
   estimate 'Influent 1U' influent -1 -1 -1 -1  5 -1 / divisor=5;
   estimate 'Influent 1U' influent -1 -1 -1 -1 -1  5 / divisor=5;
run;
quit;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.7                                       ---*/
data satt;
   /* c = coefficient of var(influent) in e(ms influent) */
   c      = 6.0973;
   mssite = 1319.77936508/31;  * ms error;
   msi    = 1925.19360789/5;   * ms influent;
   sa2    = 56.16672059;       *estimate of var(influent);
   /* approximate degrees of freedom*/;
   v      = (sa2**2)/((((msi/c)**2)/5)+(((mssite/c)**2)/31)); 
   c025   = cinv(.025,v); * lower  2.5 chi square percentage point;
   c975   = cinv(.975,v); * upper 97.5 chi square percentage point;
   low    = v*sa2/C975;   * lower limit;
   high   = v*sa2/C025;   * upper limit;
run; 
proc print data=satt; 
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 3.8 and Output 3.9                        ---*/
proc mixed data=influent covtest cl; 
   class type influent;
   model y=type/solution;
   random influent(type)/solution;
   estimate 'influent 1' intercept 1 type 0 1 0 | 
                         influent(type) 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 type 0 1 0 | 
                         influent(type) 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 type 1 0 0 | 
                         influent(type) 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 type 0 1 0 | 
                         influent(type) 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 type 1 0 0 | 
                         influent(type) 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 type 0 0 1 | 
                         influent(type) 0 0 0 0 0 1;
   lsmeans type / diff;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.10                                      ---*/
proc mixed data=influent method=type3; 
   class type influent;
   model y=type/solution;
   random influent(type)/solution;
   estimate 'influent 1' intercept 1 type 0 1 0 | 
                         influent(type) 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 type 0 1 0 | 
                         influent(type) 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 type 1 0 0 | 
                         influent(type) 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 type 0 1 0 | 
                         influent(type) 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 type 1 0 0 | 
                         influent(type) 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 type 0 0 1 | 
                         influent(type) 0 0 0 0 0 1;
   lsmeans type / diff;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.11                                      ---*/
proc glm data=influent; 
   class type influent;
   model y = type influent(type);
   random influent(type) / test;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 3.4, Semiconductor                      ---*/
data e_3_4;
  input source lot wafer site Thick @@;
  datalines;
1 1 1 1 2006 1 1 1 2 1999 1 1 1 3 2007 1 1 2 1 1980
1 1 2 2 1988 1 1 2 3 1982 1 1 3 1 2000 1 1 3 2 1998
1 1 3 3 2007 1 2 1 1 1991 1 2 1 2 1990 1 2 1 3 1988
1 2 2 1 1987 1 2 2 2 1989 1 2 2 3 1988 1 2 3 1 1985
1 2 3 2 1983 1 2 3 3 1989 1 3 1 1 2000 1 3 1 2 2004
1 3 1 3 2004 1 3 2 1 2001 1 3 2 2 1996 1 3 2 3 2004
1 3 3 1 1999 1 3 3 2 2000 1 3 3 3 2002 1 4 1 1 1997
1 4 1 2 1994 1 4 1 3 1996 1 4 2 1 1996 1 4 2 2 2000
1 4 2 3 2002 1 4 3 1 1987 1 4 3 2 1990 1 4 3 3 1995
2 5 1 1 2013 2 5 1 2 2004 2 5 1 3 2009 2 5 2 1 2023
2 5 2 2 2018 2 5 2 3 2010 2 5 3 1 2020 2 5 3 2 2023
2 5 3 3 2015 2 6 1 1 2032 2 6 1 2 2036 2 6 1 3 2030
2 6 2 1 2018 2 6 2 2 2022 2 6 2 3 2026 2 6 3 1 2009
2 6 3 2 2010 2 6 3 3 2011 2 7 1 1 1984 2 7 1 2 1993
2 7 1 3 1993 2 7 2 1 1992 2 7 2 2 1992 2 7 2 3 1990
2 7 3 1 1996 2 7 3 2 1993 2 7 3 3 1987 2 8 1 1 1996
2 8 1 2 1989 2 8 1 3 1996 2 8 2 1 1997 2 8 2 2 1993
2 8 2 3 1996 2 8 3 1 1990 2 8 3 2 1989 2 8 3 3 1992
;

 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.12                                      ---*/
proc mixed data=e_3_4 Method=REML;
   class lot wafer site;
   Model Thick=;
   random lot wafer(lot);
run; 
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.13                                      ---*/ 
proc mixed data=e_3_4 Method=Type1;
   class lot wafer site;
   Model Thick=;
   random lot wafer(lot);
   ods select type1 CovParms;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.14                                      ---*/
proc mixed data=e_3_4;
   class source lot wafer site;
   model Thick = source / ddfm=KR;
   random lot(source) wafer(source lot);
   lsmeans source / diff;
   ods select CovParms LsMeans Diffs;
run; 
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.15                                      ---*/
proc mixed data=e_3_4 scoring=4;
   class source lot wafer site;
   model Thick = source/ ddfm=KR;
   random lot / group=source;
   random wafer(source lot);
   lsmeans source / diff;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 3.5, Genetics                           ---*/
data e_3_5;
 input loc block fam Yield @@;
  datalines;
1  1  1  268 1  2  1  279 1  3  1  261 1  1  2  242
1  2  2  261 1  3  2  258 1  1  3  242 1  2  3  245
1  3  3  234 1  1  4  225 1  2  4  231 1  3  4  219
1  1  5  236 1  2  5  260 1  3  5  248 2  1  1  238
2  2  1  220 2  3  1  243 2  1  2  215 2  2  2  192
2  3  2  226 2  1  3  198 2  2  3  151 2  3  3  191
2  1  4  195 2  2  4  182 2  3  4  202 2  1  5  201
2  2  5  161 2  3  5  196 3  1  1  221 3  2  1  216
3  3  1  224 3  1  2  208 3  2  2  197 3  3  2  201
3  1  3  186 3  2  3  173 3  3  3  161 3  1  4  207
3  2  4  183 3  3  4  186 3  1  5  200 3  2  5  207
3  3  5  190 4  1  1  194 4  2  1  194 4  3  1  197
4  1  2  203 4  2  2  191 4  3  2  204 4  1  3  177
4  2  3  170 4  3  3  180 4  1  4  180 4  2  4  195
4  3  4  193 4  1  5  199 4  2  5  183 4  3  5  208
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.16                                      ---*/
proc mixed data=e_3_5 covtest cl;
   class loc fam block;
   model Yield =;
   random loc fam loc*fam block(loc);
run; 
 /*-------------------------------------------------------*/
 
 /*-------------------------------------------------------*/
 /*---Output 3.17                                      ---*/
proc mixed data=e_3_5 method=type3;
   class loc fam block;
   model Yield=;
   random loc fam loc*fam block(loc);
   ods select CovParms type3;
run; 
 /*-------------------------------------------------------*/

