
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/


/*-------------------------------------------------------*/
 /*---CHAPTER 4: Multi-Factor Treatment Designs with   ---*/
 /*---           Multiple Error Terms                  ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 4.4, Semiconductor Split-Plot Experiment --*/
data ex_4_4;
  input resistance et wafer position @@;
  datalines;
5.22  1  1  1 5.61  1  1  2 6.11  1  1  3
6.33  1  1  4 6.13  1  2  1 6.14  1  2  2
5.60  1  2  3 5.91  1  2  4 5.49  1  3  1
4.60  1  3  2 4.95  1  3  3 5.42  1  3  4
5.78  2  1  1 6.52  2  1  2 5.90  2  1  3
5.67  2  1  4 5.77  2  2  1 6.23  2  2  2
5.57  2  2  3 5.96  2  2  4 6.43  2  3  1
5.81  2  3  2 5.83  2  3  3 6.12  2  3  4
5.66  3  1  1 6.25  3  1  2 5.46  3  1  3
5.08  3  1  4 6.53  3  2  1 6.50  3  2  2
6.23  3  2  3 6.84  3  2  4 6.22  3  3  1
6.29  3  3  2 5.63  3  3  3 6.36  3  3  4
6.75  4  1  1 6.97  4  1  2 6.02  4  1  3
6.88  4  1  4 6.22  4  2  1 6.54  4  2  2
6.12  4  2  3 6.61  4  2  4 6.05  4  3  1
6.15  4  3  2 5.55  4  3  3 6.13  4  3  4
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.1                                       ---*/
proc mixed data=ex_4_4;
   class et wafer position;
   model resistance=et position et*position;
   random wafer(et);
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.2                                       ---*/
proc mixed data=ex_4_4 method=Type3;
   class et wafer position;
   model resistance=et position et*position;
   random wafer(et);
   ods select Type3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.3                                       ---*/
proc mixed data=ex_4_4;
   class et wafer position;
   model resistance=et position et*position;
   random wafer(et);
   lsmeans et position et*position;
   ods select lsmeans;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.4                                       ---*/
proc mixed data=ex_4_4;
   class et wafer position;
   model resistance=et position et*position;
   random wafer(et);
   lsmeans position / df=18.7;
   ods select lsmeans;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.5                                       ---*/
proc mixed data=ex_4_4;
   class wafer et position;
   model resistance=et|position / ddfm=satterth;
   random wafer(et);
   lsmeans position / diff;
   estimate 'pos1 vs pos3'       position 1 0 -1 0;
   contrast 'pos1 vs pos3'       position 1 0 -1 0;
   estimate 'pos 3 vs others'    position 1 1 -3 1 / divisor=3; 
   estimate 'pos3 v oth - wrong' position 1 1 -3 1; 
   contrast 'pos 3 vs others'    position 1 1 -3 1;
   ods select Estimates Contrasts Diffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.6                                       ---*/
proc mixed data=ex_4_4;
   class wafer et position;
   model resistance=et|position / ddfm=satterth;
   random wafer(et);
   lsmeans position/diff=control('3') adjust=dunnett;
   ods select Diffs;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 4.7                                       ---*/
proc mixed data=ex_4_4;
   class wafer et position;
   model resistance=et|position / ddfm=satterth;
   random wafer(et);
   lsmeans et*position / slice=(et position);
   estimate 'pos 1 vs 3 in et4' 
             position 1 0 -1 0 
             et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 0 -1 0;
   estimate 'pos 1 vs 3 in et1' 
             position 1 0 -1 0 
             et*position 1 0 -1 0;
   estimate 'pos3 vs others in et=4' 
             position 1 1 -3 1 
             et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 1 -3 1 / divisor=3;
   estimate 'pos3 vs others in et<4' 
             position 3 3 -9 3 
             et*position 1 1 -3 1 1 1 -3 1 1 1 -3 1 0/ divisor=9;
   estimate 'et1 vs et2 in pos 2' 
             et 1 -1 0 0 
             et*position 0 1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0;
   estimate 'et1 vs others in pos 1' 
             et -3 1 1 1 
             et*position -3 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0 / divisor=3;
   estimate 'et1 vs others in pos 2' 
             et -3 1 1 1 
             et*position 0 -3 0 0 0 1 0 0 0 1 0 0 0 1 0  / divisor=3;
   contrast 'pos 1 vs 3 in et4' 
             position 1 0 -1 0 
             et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 0 -1 0;
   contrast 'pos 1 vs 3 in et1' 
             position 1 0 -1 0 
             et*position 1 0 -1 0;
   contrast 'pos3 vs others in et=4' 
             position 1 1 -3 1 
             et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 1 -3 1;
   contrast 'pos3 vs others in et<4' 
             position 3 3 -9 3 
             et*position 1 1 -3 1 1 1 -3 1 1 1 -3 1 0;
   contrast 'et1 vs et2 in pos 2' 
             et 1 -1 0 0 
             et*position 0 1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0;
   contrast 'et1 vs others in pos 1' 
             et -3 1 1 1 
             et*position -3 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0;
   contrast 'et1 vs others in pos 2' 
             et -3 1 1 1 
             et*position 0 -3 0 0 0 1 0 0 0 1 0 0 0 1 0;
   ods select Slices Estimates Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.8                                       ---*/
proc mixed data=ex_4_4;
   class wafer et position;
   model resistance=et|position / ddfm=satterth;
   random wafer(et);
   lsmeans et*position / diff=control('1' '1');
   lsmeans et*position / diff=control('1' '2');
   lsmeans et*position / diff=control('1' '3');
   lsmeans et*position / diff=control('1' '4');
   ods exclude lsmeans diffs;
   ods output diffs=simpeff;
run;
 
data smpeff_dunnett;
   set simpeff;
   if position=_position;
proc print data=smpeff_dunnett;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 4.9                                       ---*/
proc glimmix data=ex_4_4;
   class et wafer position;
   model resistance=et position et*position/ddfm=kr;
   random wafer(et);
   lsmeans et*position / slice=(et position) diff=control ('1' '2');
   lsmestimate et*position 
      'pos 1 vs 3 in et1' 1 0 -1 0,
      'pos 1 vs 3 in et4' 0 0 0 0 0 0 0 0 0 0 0 0 1 0 -1 0; 
   lsmestimate et*position 
      'pos3 vs others in et=4' 0 0 0 0 0 0 0 0 0 0 0 0 1 1 -3 1,
      'pos3 vs others in et<4' 1 1 -3 1 1 1 -3 1 1 1 -3 1 0 /
                               divisor=3,9;
   lsmestimate et*position
      'et1 vs et2 in pos 2'  0 1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0;
   lsmestimate et*position 
      'et1 vs others in pos 1' -3 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0, 
      'et1 vs others in pos 2'  0 -3 0 0 0 1 0 0 0 1 0 0 0 1 0 / 
                                divisor=3;
run;

 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.10, Output 4.11, Output 4.12            ---*/
proc glm data=ex_4_4;
   class et wafer position;
   model resistance=et wafer(et) position et*position;
   random wafer(et)/test;
   lsmeans et/ e=wafer(et) stderr tdiff;
   lsmeans position/ stderr tdiff;
   lsmeans et*position / slice=(et position);
   estimate 'pos 1 vs 3 in et4' 
            position 1 0 -1 0 
            et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 0 -1 0;
   estimate 'pos 1 vs 3 in et1' 
            position 1 0 -1 0 
            et*position 1 0 -1 0;
   estimate 'pos3 vs others in et=4' 
            position 1 1 -3 1 
            et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 1 -3 1 / 
            divisor=3;
   estimate 'pos3 vs others in et<4' 
            position 3 3 -9 3 
            et*position 1 1 -3 1 1 1 -3 1 1 1 -3 1 0/ divisor=9;
   estimate 'et1 vs et2 in pos 2' 
            et 1 -1 0 0 
            et*position 0 1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0;
   estimate 'et1 vs others in pos 1' 
            et -3 1 1 1 
            et*position -3 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0 / 
            divisor=3;
   estimate 'et1 vs others in pos 2' 
            et -3 1 1 1 
            et*position 0 -3 0 0 0 1 0 0 0 1 0 0 0 1 0  / 
            divisor=3;
   contrast 'pos 1 vs 3 in et4' 
            position 1 0 -1 0 
            et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 0 -1 0;
   contrast 'pos 1 vs 3 in et1' 
            position 1 0 -1 0 
            et*position 1 0 -1 0;
   contrast 'pos3 vs others in et=4' 
            position 1 1 -3 1 
            et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 1 -3 1;
   contrast 'pos3 vs others in et<4' 
            position 3 3 -9 3 
            et*position 1 1 -3 1 1 1 -3 1 1 1 -3 1 0;
   contrast 'et1 vs et2 in pos 2' 
            et 1 -1 0 0 
            et*position 0 1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0;
   contrast 'et1 vs others in pos 1' 
            et -3 1 1 1 
            et*position -3 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0;
   contrast 'et1 vs others in pos 2' 
            et -3 1 1 1 
            et*position 0 -3 0 0 0 1 0 0 0 1 0 0 0 1 0;
   lsmeans et*position / tdiff=control('1' '1');
   lsmeans et*position / tdiff=control('1' '2');
   lsmeans et*position / tdiff=control('1' '3');
   lsmeans et*position / tdiff=control('1' '4');
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 4.6, Variety-Pesticide Evaluation       ---*/
data variety_eval;
  input block type $ dose logdose y;
  datalines;
1  r  1  0  15.7
2  r  1  0  23.1
3  r  1  0  15.9
4  r  1  0  20.8
5  r  1  0  24.5
1  r  2  1  25.1
2  r  2  1  29.2
3  r  2  1  29.7
4  r  2  1  28.6
5  r  2  1  26.6
1  r  4  2  27.9
2  r  4  2  29.7
3  r  4  2  24.0
4  r  4  2  29.7
5  r  4  2  29.6
1  r  8  3  23.8
2  r  8  3  31.2
3  r  8  3  21.8
4  r  8  3  23.3
5  r  8  3  23.9
1  s  1  0  19.8
2  s  1  0  17.8
3  s  1  0  13.2
4  s  1  0  14.8
5  s  1  0  19.7
1  s  2  1  21.2
2  s  2  1  29.3
3  s  2  1  26.0
4  s  2  1  27.5
5  s  2  1  22.0
1  s  4  2  29.3
2  s  4  2  27.2
3  s  4  2  26.0
4  s  4  2  31.5
5  s  4  2  27.9
1  s  8  3  22.8
2  s  8  3  33.0
3  s  8  3  25.2
4  s  8  3  27.2
5  s  8  3  20.8
;
 /*-------------------------------------------------------*/
 
 /*-------------------------------------------------------*/
 /*---Output 4.13 and Output 4.14                      ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y = type|dose / ddfm=satterth;
   random block block*dose;
   lsmeans type*dose / slice=(type dose);
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 4.2                                       ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y = type|dose / ddfm=satterth;
   random block block*dose;
   lsmeans type*dose;
   ods output lsmeans=typedosemeans;
run;

axis1 value=(font=swiss h=2) 
      label=(angle=90 f=swiss h=2 'Dose x Type Mean');
axis2 value=(font=swiss h=2)
      label=(f=swiss h=2 'Dose');
axis3 value=(font=swiss h=2)
      label=(f=swiss h=2 'LogDose');
legend1 value=(font=swiss h=2) 
        label=(f=swiss h=2 'Variety Type');
symbol1 color=black interpol=join line=1 value=square; 
symbol2 color=black interpol=join line=2 value=circle; 

data to_plot;
   set typedosemeans;
   logdose=log2(dose);
run;
proc gplot data=to_plot;
   plot estimate*logdose=type/haxis=axis3 
                              vaxis=axis1 
                              legend=legend1;
   plot estimate*dose   =type/haxis=axis2
                              vaxis=axis1
                              legend=legend1;
run; quit;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 4.3                                       ---*/
ods html file="test.html";
ods graphics on;
ods select MeanPlot;
proc glimmix data=variety_eval;
   class block type dose;
   model y = type|dose / ddfm=satterth;
   random block block*dose;
   lsmeans type*dose / plot=meanplot(sliceby=type join cl);
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.15                                      ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y = dose|type / ddfm=satterth;
   random block block*dose;
   contrast 'dose linear'   dose -11 -7   1 17;
   contrast 'dose quad'     dose  20 -4 -29 13;
   contrast 'dose cubic'    dose  -8 14  -7  1;
   contrast 'type x linear' dose*type -11 -7   1 17  11  7  -1 -17;
   contrast 'type x quad'   dose*type  20 -4 -29 13 -20   4 29 -13;
   contrast 'type x cubic'  dose*type -8  14  -7  1   8 -14  7  -1;
   ods select Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.16                                      ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y = dose|type / ddfm=satterth;
   random block block*dose;
   contrast 'logdose linear' dose -3 -1  1 3;
   contrast 'logdose quad'   dose  1 -1 -1 1;
   contrast 'logdose cubic'  dose -1  3 -3 1;
   contrast 'type x linear'  dose*type -3 -1  1 3  3  1 -1 -3;
   contrast 'type x quad'    dose*type  1 -1 -1 1 -1  1  1 -1;
   contrast 'type x cubic'   dose*type -1  3 -3 1  1 -3  3 -1;
   ods select Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.17                                      ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y = type dose(type) / ddfm=satterth;
   random block block*dose;
   contrast 'linear LogD | type R' dose(type) -3 -1  1 3 0;
   contrast 'quad LogD   | type R' dose(type)  1 -1 -1 1 0;
   contrast 'cubic LogD  | type R' dose(type) -1  3 -3 1 0;
   contrast 'linear LogD | type S' dose(type) 0 0 0 0 -3 -1  1 3;
   contrast 'quad LogD   | type S' dose(type) 0 0 0 0  1 -1 -1 1;
   contrast 'cubic LogD  | type S' dose(type) 0 0 0 0 -1  3 -3 1;
   ods select Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.18                                      ---*/
proc mixed data=variety_eval;
   class block type dose; 
   model y=type|logdose|logdose / ddfm=satterth 
                                  solution htype=1;
   random block block*dose;
   ods select Tests1 SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.19                                      ---*/
proc mixed data=variety_eval;
   class block type dose; 
   model y=type|logdose|logdose / ddfm=satterth 
                                  solution htype=1;
   random block block*dose;

   estimate 'B_0    for type R' intercept 1 type 1 0;
   estimate 'B_Lin  for type R' logdose 1 logdose*type 1 0;
   estimate 'B_quad for type R' logdose*logdose 1 
                                logdose*logdose*type 1 0;
   estimate 'B_0    for type S' intercept 1 type 0 1;
   estimate 'B_Lin  for type S' logdose 1 logdose*type 0 1;
   estimate 'B_quad for type S' logdose*logdose 1
                                logdose*logdose*type 0 1;
   ods select Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.20                                      ---*/
data variety_eval;
   set variety_eval;
   ld_sq = (log2(dose))**2;
run;
proc mixed data=variety_eval;
   class block type dose;
   model y = type logdose(type) ld_sq(type) / noint ddfm=satterth 
                                              solution;
   random block block*dose;
   contrast 'equal quad by type?' ld_sq(type) 1 -1;
   ods select SolutionF Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.21                                      ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y=type logdose(type) ld_sq /noint ddfm=satterth solution;
   random block block*dose;
   ods select SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 4.7 Mouse Condition--Diet Experiment    ---*/
data mice;
  input cage condition diet $ gain;
  datalines;
1   1   normal    58
1   1   restrict    58
1   1   suppleme    58
1   2   normal      54
1   2   restrict    46
1   2   suppleme    57
2   1   normal      49
2   1   restrict    50
2   1   suppleme    57
2   3   normal      57
2   3   restrict    53
2   3   suppleme    62
3   1   normal      59
3   1   restrict    58
3   1   suppleme    57
3   4   normal      63
3   4   restrict    61
3   4   suppleme    65
4   2   normal      57
4   2   restrict    64
4   2   suppleme    52
4   3   normal      63
4   3   restrict    67
4   3   suppleme    51
5   2   normal      53
5   2   restrict    46
5   2   suppleme    51
5   4   normal      58
5   4   restrict    52
5   4   suppleme    61
6   3   normal      65
6   3   restrict    64
6   3   suppleme    54
6   4   normal      59
6   4   restrict    47
6   4   suppleme    73
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.23                                      ---*/ 
proc mixed data=mice;
   class cage condition diet;
   model gain = condition|diet/ddfm=satterth;
   random cage cage*condition;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.24                                     ---*/ 
proc glm data=mice;
   class cage condition diet;
   model gain = cage condition cage*condition / ss3;
   ods output ModelAnova=anova;
run;
data anova; set anova(where=(HypothesisType=3));
   if Source='cage*condition' then do;
       source = 'Error';
       Fvalue = .;
       ProbF  = .;
   end;
proc print data=anova label;
   var source df ss MS;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 4.25                                      ---*/
title 'NOBOUND';
proc mixed data=mice nobound;
   class cage condition diet;
   model gain = condition | diet / ddfm=kr;
   random cage cage*condition;
   ods select CovParms Tests3;
run;
title 'Method=Type3';
proc mixed data=mice method=type3;
   class cage condition diet;
   model gain = condition | diet / ddfm=kr;
   random cage cage*condition;
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.26                                      ---*/
proc mixed data=mice;
   class cage condition diet;
   model gain=condition|diet / ddfm=kr;
   random cage; 
   repeated / type=cs subject=cage*condition r rcorr;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.27                                      ---*/
proc glm data=mice;
   class cage condition diet;
   model gain=condition|diet cage cage*condition;
   lsmeans condition diet condition*diet;
run; 
 /*-------------------------------------------------------*/



