
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/

 
 /*-------------------------------------------------------*/
 /*---CHAPTER 6: Best Linear Unbiased Prediction       ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 6.4, Genetic Evaluation                 ---*/
data genetic_evaluation;
   input sire dam adg;
   datalines;
1  1  2.24
1  1  1.85
1  2  2.05
1  2  2.41
2  1  1.99
2  1  1.93
2  2  2.72
2  2  2.32
3  1  2.33
3  1  2.68
3  2  2.69
3  2  2.71
4  1  2.42
4  1  2.01
4  2  1.86
4  2  1.79
5  1  2.82
5  1  2.64
5  2  2.58
5  2  2.56
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.1                                       ---*/
proc mixed data=genetic_evaluation;
   class sire dam;
   model adg= / ddfm=kr;
   random sire dam(sire);
   estimate 'sire 1 BLUP "broad" '  
            intercept 1 | sire 1 0;
   estimate 'sire 1 BLUP "narrow" ' 
            intercept 2 | sire 2 0 
            dam(sire) 1 1  0 0  0 0  0 0  0 0  / divisor=2;
   estimate 'sire 1 BLUP with dam 1' 
            intercept 1 | sire 1 0
            dam(sire) 1 0;
   ods select CovParms Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.2                                       ---*/
proc glm data=genetic_evaluation;
   class sire dam;
   model adg=sire dam(sire);
   random sire dam(sire);
   lsmeans sire / stderr;
   lsmeans sire / e=dam(sire) stderr;
   estimate 'sire 1 BLUP "broad" '   
            intercept 1 sire 1 0;
   estimate 'sire 1 BLUP "narrow" '  
            intercept 2 sire 2 0 
            dam(sire) 1 1  0 0  0 0  0 0  0 0 / divisor=2;
   estimate 'sire 1 BLUP with dam 1' 
            intercept 1  sire 1 0
            dam(sire) 1 0;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.3                                       ---*/
proc mixed data=genetic_evaluation;
   class sire dam;
   model adg=sire/ddfm=kr;
   random dam(sire);
   lsmeans sire;
   estimate 'sire 1 BLUP "broad" ' 
            intercept 1 sire 1 0;
   estimate 'sire 1 BLUP "narrow" ' 
            intercept 2 sire 2 0 |
            dam(sire) 1 1  0 0  0 0  0 0  0 0  / divisor=2;
   estimate 'sire 1 BLUP with dam 1' 
            intercept 1 sire 1 0 | 
            dam(sire) 1 0;
   ods select LSMeans Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 6.5, Machine Operators                  ---*/
data machine;
   input machine operator y;
   datalines;
1  1  51.43
1  1  51.28
1  2  50.93
1  2  50.75
1  3  50.47
1  3  50.83
2  1  51.91
2  1  52.43
2  2  52.26
2  2  52.33
2  3  51.58
2  3  51.23
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.4                                       ---*/
proc mixed data=machine;
   class machine operator;
   model y=machine/ddfm=kr;
   random operator machine*operator;
   lsmeans machine;
   estimate 'BLUE - mach 1'  
             intercept 1 
             machine 1 0;
   estimate 'BLUE - diff' 
             machine 1 -1;
   estimate 'BLUP - m 1 narrow' 
             intercept 3 
             machine 3 0 | 
             operator 1 1 1
             machine*operator 1 1 1 0 0 0 / divisor=3;
   estimate 'BLUP - diff narrow' 
             machine 3 -3 | 
             machine*operator 1 1 1 -1 -1 -1 / divisor=3;
   estimate 'BLUP - oper 1' 
             intercept 2 
             machine 1 1  | 
             operator 2 0 0
             machine*operator 1 0 0 1 0 0 / divisor=2;
   estimate 'BLUP -  m 1 op 1' 
             intercept 1 
             machine 1 0 | 
             operator 1 0 0
             machine*operator 1 0 0 0 0 0;
   estimate 'BLUP - diff op 1' 
             machine 1 -1 | 
             machine*operator 1 0 0 -1 0 0;
   ods select CovParms Estimates LsMeans;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.5, Output 6.6                           ---*/
proc glm data=machine;
   class machine operator;
   model y = machine|operator;
   random operator machine*operator/test;
   lsmeans machine operator machine*operator/stderr;
   lsmeans machine/stderr e=machine*operator;
   estimate 'diff' machine 1 -1/e;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 6.6, Multicenter                        ---*/
data multicenter;
   input location $ block treatment response @@;
   datalines;
A  1  3  3.13 A  1  4  3.22 A  1  2  3.16 A  1  1  3.25
A  2  2  2.71 A  2  1  3.20 A  2  3  2.99 A  2  4  2.96
A  3  1  2.69 A  3  2  2.87 A  3  3  2.87 A  3  4  3.12
B  1  3  2.09 B  1  4  2.67 B  1  2  2.10 B  1  1  2.35
B  2  4  2.61 B  2  1  2.25 B  2  3  2.15 B  2  2  2.69
B  3  2  2.15 B  3  3  2.34 B  3  4  2.45 B  3  1  2.53
C  1  4  3.05 C  1  2  3.24 C  1  3  3.22 C  1  1  3.05
C  2  3  3.23 C  2  2  2.71 C  2  1  3.07 C  2  4  2.81
C  3  4  3.13 C  3  3  3.08 C  3  1  3.16 C  3  2  3.03
D  1  1  2.47 D  1  3  2.54 D  1  2  2.41 D  1  4  2.39
D  2  3  2.75 D  2  2  2.65 D  2  1  2.55 D  2  4  3.01
D  3  3  2.60 D  3  4  3.07 D  3  2  2.40 D  3  1  2.20
E  1  3  2.81 E  1  4  2.74 E  1  2  2.47 E  1  1  2.87
E  2  2  2.57 E  2  1  2.97 E  2  4  3.04 E  2  3  3.06
E  3  1  2.70 E  3  2  2.76 E  3  3  3.05 E  3  4  3.21
F  1  1  3.21 F  1  2  2.90 F  1  4  3.46 F  1  3  3.10
F  2  2  3.19 F  2  1  3.30 F  2  4  3.19 F  2  3  3.37
F  3  3  3.43 F  3  2  3.05 F  3  1  3.44 F  3  4  3.70
G  1  2  2.65 G  1  1  3.18 G  1  4  3.01 G  1  3  3.21
G  2  4  2.68 G  2  3  2.67 G  2  1  3.13 G  2  2  2.61
G  3  4  2.64 G  3  3  2.88 G  3  2  2.75 G  3  1  3.14
H  1  3  3.37 H  1  2  3.12 H  1  4  3.27 H  1  1  3.70
H  2  2  2.95 H  2  3  3.42 H  2  4  3.38 H  2  1  3.38
H  3  4  3.74 H  3  1  3.28 H  3  3  3.40 H  3  2  3.05
I  1  2  2.37 I  1  1  3.16 I  1  4  2.49 I  1  3  2.91
I  2  1  2.29 I  2  4  2.34 I  2  3  2.52 I  2  2  2.50
I  3  2  2.66 I  3  1  2.31 I  3  4  2.51 I  3  3  2.65
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.7                                       ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=location treatment location*treatment;
   random block(location);
   lsmeans treatment;
   lsmeans location*treatment / slice=location;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.8                                       ---*/
ods exclude all;
proc mixed data=MultiCenter;
   class location block treatment;
   model response=location treatment location*treatment;
   random block(location);
   lsmeans location*treatment;
   ods output lsmeans=lsm;
run;
ods exclude none;
data lsm; set lsm;
  if location in ('D','E','G','H');
proc print data=lsm;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.9                                       ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=treatment / ddfm=KR;
   random location block(location) location*treatment;
   lsmeans treatment / diff;
   ods select CovParms LsMeans Diffs;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 6.10                                      ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=treatment / ddfm=KR;
   random location block(location) location*treatment;
   estimate 'trt 1 LS Mean' 
             intercept 1
             treatment 1 0 0 0; 
   estimate 'trt 1 BLUP "Narrow"' 
             intercept 9
             treatment 9 | 
             location 1 1 1 1 1 1 1 1 1  
             location*treatment 1 0 0 0  1 0 0 0  1 0 0 0  1 0 0 0
                                1 0 0 0  1 0 0 0  1 0 0 0  1 0 0 0
                                1 0 0 0 /divisor=9; 
    estimate 'trt 1 BLUP "alt"' 
              intercept 9
              treatment 9 | 
              location 1 1 1 1 1 1 1 1 1 / divisor=9; 
    estimate 'trt1 vs trt2' 
              treatment 1 -1 0;
    estimate 'trt 1 v 2 BLUP' 
              treatment 9 -9 0 0 | 
              location*treatment 1 -1 0 0  1 -1 0 0  1 -1 0 0  
                                 1 -1 0 0  1 -1 0 0  1 -1 0 0  
                                 1 -1 0 0  1 -1 0 0  1 -1 0 0 / 
                                 divisor=9;
    ods select Estimates;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 6.11                                      ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=treatment/ddfm=KR;
   random location block(location) location*treatment;
   estimate 'trt1 at loc A blup' 
             intercept 1 
             treatment 1 0 0 0 | 
             location 1 0 
             location*treatment 1 0;
   estimate 'trt2 at loc A blup' 
             intercept 1 
             treatment 0 1 0 0 | 
             location 1 0  
             location*treatment 0 1 0;
   estimate 'trt3 at loc A blup' 
             intercept 1 
             treatment 0 0 1 0 | 
             location 1 0  
             location*treatment 0 0 1 0;
   estimate 'trt4 at loc A blup' 
             intercept 1 
             treatment 0 0 0 1 | 
             location 1 0  
             location*treatment 0 0 0 1;
   estimate 'trt1 at loc B blup' 
             intercept 1 
             treatment 1 0 0 0 | 
             location 0 1 0 
             location*treatment 0 0 0 0  1 0;
   estimate 'trt2 at loc B blup' 
             intercept 1 
             treatment 0 1 0 0 | 
             location 0 1 0  
             location*treatment 0 0 0 0  0 1 0;
   estimate 'trt3 at loc B blup' 
             intercept 1 
             treatment 0 0 1 0 | 
             location 0 1 0  
             location*treatment 0 0 0 0  0 0 1 0;
   estimate 'trt4 at loc B blup' 
             intercept 1 
             treatment 0 0 0 1 | 
             location 0 1 0  
             location*treatment 0 0 0 0  0 0 0 1; 
   estimate 'trt 1 v 2 at loc A' 
             treatment 1 -1 0 | 
             location*treatment 1 -1 0;
   estimate 'trt 1 v 3 at loc A' 
             treatment 1 -1 0 | 
             location*treatment 0 1 -1 0;
   estimate 'trt 1 v 4 at loc A' 
             treatment 1 -1 0 | 
             location*treatment 0 0 1 -1;
   contrast 'slice at loc A' 
             treatment 1 -1  0    | 
             location*treatment 1 -1 0,
             treatment 0  1 -1  0 | 
             location*treatment 0 1 -1 0,
             treatment 0  1  0 -1 | 
              location*treatment 0 1 0 -1;
   contrast 'slice at loc A' 
             treatment 1-1  0    | 
             location*treatment 1 -1 0,
             treatment 1 0 -1  0 | 
             location*treatment 1 0 -1 0,
             treatment 1 0  0 -1 | 
             location*treatment 1 0 0 -1;
   contrast 'slice at loc B' 
             treatment 1 -1  0    | 
             location*treatment 0 0 0 0  1 -1  0,
             treatment 1  0 -1  0 | 
             location*treatment 0 0 0 0  1  0 -1 0,
             treatment 1  0  0 -1 | 
             location*treatment 0 0 0 0  1  0  0 -1;
   ods select Estimates Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.12                                      ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=treatment;
   random location block(location) location*treatment;
   contrast 'slice at loc A' 
             treatment 1 -1  0    | 
             location*treatment 1 -1 0,
             treatment 0  1 -1  0 | 
             location*treatment 0 1 -1 0,
             treatment 0  1  0 -1 | 
              location*treatment 0 1 0 -1;
   contrast 'slice at loc A' 
             treatment 1-1  0    | 
             location*treatment 1 -1 0,
             treatment 1 0 -1  0 | 
             location*treatment 1 0 -1 0,
             treatment 1 0  0 -1 | 
             location*treatment 1 0 0 -1;
   contrast 'slice at loc B' 
             treatment 1 -1  0    | 
             location*treatment 0 0 0 0  1 -1  0,
             treatment 1  0 -1  0 | 
             location*treatment 0 0 0 0  1  0 -1 0,
             treatment 1  0  0 -1 | 
             location*treatment 0 0 0 0  1  0  0 -1;
   ods select Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.13                                      ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=treatment;
   random location block(location) location*treatment;
   estimate 'trt1 @ Locs A,C' 
          intercept 2 
          treatment 2 0 0 0 | 
          location 1 0 1 0 0 0 0 0 0
          location*treatment 1 0 0 0  0 0 0 0  1 0 0 0  0 0 0 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0
                             0 0 0 0 / divisor=2;
   estimate 'trt2 @ Locs A,C' 
          intercept 2 
          treatment 0 2 0 0 | 
          location 1 0 1 0 0 0 0 0 0
          location*treatment 0 1 0 0  0 0 0 0  0 1 0 0  0 0 0 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 0 0 / divisor=2;
   estimate 'trt3 @ Locs A,C' 
          intercept 2 
          treatment 0 0 2 0 | 
          location 1 0 1 0 0 0 0 0 0
          location*treatment 0 0 1 0  0 0 0 0  0 0 1 0  0 0 0 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 0 0 / divisor=2;
   estimate 'trt4 @ Locs A,C' 
          intercept 2 
          treatment 0 0 0 2 | 
          location 1 0 1 0 0 0 0 0 0
          location*treatment 0 0 0 1  0 0 0 0  0 0 0 1  0 0 0 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 0 0 / divisor=2;
   estimate 'trt1 @ Locs B,D,I' 
          intercept 3 
          treatment 3 0 0 0 | 
          location 0 1 0 1 0 0 0 0 1
          location*treatment 0 0 0 0  1 0 0 0  0 0 0 0  1 0 0 0  
                             0 0 0 0  0 0 0 0  000 0 0  0 0 0 0  
                             1 0 0 0 / divisor=3;
   estimate 'trt2 @ Locs B,D,I' 
          intercept 3 
          treatment 0 3 0 0 | 
          location 0 1 0 1 0 0 0 0 1
          location*treatment 0 0 0 0  0 1 0 0  0 0 0 0  0 1 0 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 1 0 0 / divisor=3;
   estimate 'trt3 @ Locs B,D,I' 
          intercept 3 
          treatment 0 0 3 0 | 
          location 0 1 0 1 0 0 0 0 1
          location*treatment 0 0 0 0  0 0 1 0  0 0 0 0  0 0 1 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 1 0 / divisor=3;
   estimate 'trt4 @ Locs B,D,I' 
          intercept 3 
          treatment 0 0 0 3 | 
          location 0 1 0 1 0 0 0 0 1
                    location*treatment 0 0 0 0  0 0 0 1  0 0 0 0  0 0 0 1  
                                       0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                                       0 0 0 1/divisor=3;
   estimate 'trt1 @ Locs E,F,G,H' 
          intercept 4 
          treatment 4 0 0 0 | 
          location 0 0 0 0 1 1 1 1 0
          location*treatment 0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             1 0 0 0  1 0 0 0  1 0 0 0  1 0 0 0  
                             0 0 0 0 / divisor=4;
   estimate 'trt2 @ Locs E,F,G,H' 
          intercept 4 
          treatment 0 4 0 0 | 
          location 0 0 0 0 1 1 1 1 0
          location*treatment 0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 1 0 0  0 1 0 0  0 1 0 0  0 1 0 0  
                             0 0 0 0 / divisor=4;
   estimate 'trt3 @ Locs E,F,G,H' 
          intercept 4 
          treatment 0 0 4 0 | 
          location 0 0 0 0 1 1 1 1 0
          location*treatment 0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 1 0  0 0 1 0  0 0 1 0  0 0 1 0  
                             0 0 0 0 / divisor=4;
   estimate 'trt4 @ Locs E,F,G,H' 
          intercept 4 
          treatment 0 0 0 4 | 
          location 0 0 0 0 1 1 1 1 0
          location*treatment 0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 0 1  0 0 0 1  0 0 0 1  0 0 0 1  
                             0 0 0 0 / divisor=4;
   contrast 'slice at locs A,C'
          treatment 2 -2 0 | 
          location*treatment 1 -1 0 0  0 0 0 0  1 -1 0 0  0 0 0 0  
                             0  0 0 0  0 0 0 0  0  0 0 0  0 0 0 0  
                             0  0 0 0,
          treatment 2 0 -2 0 | 
          location*treatment 1 0 -1 0  0 0 0 0  1 0 -1 0  0 0 0 0  
                             0 0  0 0  0 0 0 0  0 0  0 0  0 0 0 0  
                             0 0  0 0,
          treatment 2 0 0 -2 | 
          location*treatment 1 0 0 -1  0 0 0 0  1 0 0 -1  0 0 0 0  
                             0 0 0  0  0 0 0 0  0 0 0  0  0 0 0 0  
                             0 0 0  0;
   contrast 'slice at locs B,D,I'
          treatment 3 -3 0 | 
          location*treatment 0  0 0 0  1 -1 0 0  0 0 0 0  1 -1 0 0  
                             0  0 0 0  0  0 0 0  0 0 0 0  0  0 0 0
                             1 -1 0 0,
          treatment 3 0 -3 0 | 
          location*treatment 0 0  0 0  1 0 -1 0  0 0 0 0  1 0 -1 0  
                             0 0  0 0  0 0  0 0  0 0 0 0  0 0  0 0  
                             1 0 -1 0,
          treatment 3 0 0 -3 | 
          location*treatment 0 0 0  0  1 0 0 -1  0 0 0 0  1 0 0 -1  
                             0 0 0  0  0 0 0  0  0 0 0 0  0 0 0  0  
                             1 0 0 -1;
   contrast 'slice at locs E,F,G,H'
          treatment 4 -4 0 | 
          location*treatment 0  0 0 0  0  0 0 0  0  0 0 0  0  0 0 0  
                             1 -1 0 0  1 -1 0 0  1 -1 0 0  1 -1 0 0  
                             0 0 0 0,
          treatment 4 0 -4 0 | 
          location*treatment 0 0  0 0  0 0  0 0  0 0  0 0  0 0  0 0  
                             1 0 -1 0  1 0 -1 0  1 0 -1 0  1 0 -1 0  
                             0 0  0 0,
          treatment 4 0 0 -4 | 
          location*treatment 0 0 0  0  0 0 0  0  0 0 0 0   0 0 0 0  
                             1 0 0 -1  1 0 0 -1  1 0 0 -1  1 0 0 -1  
                             0 0 0  0;
   ods select Estimates Contrasts;
run;
 /*-------------------------------------------------------*/

