 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/

  /*-------------------------------------------------------*/
 /*---CHAPTER 7: Analysis of Covariance                ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.3, Average Daily Gain                 ---*/
data ex7_3_rcb;
   input id blk trt adg iwt;
   datalines;
 1  1   0  1.03  338
 2  1  10  1.54  477
 3  1  20  1.82  444
 4  1  30  1.86  370
 5  2   0  1.31  403
 6  2  10  2.16  451
 7  2  20  2.13  450
 8  2  30  2.23  393
 9  3   0  1.59  394
10  3  10  2.53  499
11  3  20  2.33  482
12  3  30  1.80  317
13  4   0  2.09  499
14  4  10  2.20  411
15  4  20  2.21  391
16  4  30  2.82  396
17  5   0  1.66  371
18  5  10  2.30  418
19  5  20  2.65  486
20  5  30  2.18  333
21  6   0  1.42  395
22  6  10  1.93  325
23  6  20  1.58  316
24  6  30  1.49  311
25  7   0  1.41  414
26  7  10  1.65  313
27  7  20  1.08  309
28  7  30  1.34  323
29  8   0  0.18  315
30  8  10  0.64  376
31  8  20  0.76  308
32  8  30  0.70  439
;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 7.1                                       ---*/
proc mixed data=ex7_3_rcb;
   class trt blk;
   model adg=trt iwt*trt/noint solution ddfm=kr;
   random blk;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.2                                       ---*/
proc mixed data=ex7_3_rcb;
   class trt blk;
   model adg=trt iwt iwt*trt/solution ddfm=kr;
   random blk;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.3                                       ---*/
proc mixed data=ex7_3_rcb;
   class trt blk;
   model adg=trt iwt/ solution ddfm=kr;
   random blk;
   estimate 'linear' trt -3 -1  1  3;
   estimate 'quad'   trt -1  1  1 -1;
   estimate 'cubic'  trt -1  3 -3  1;
   lsmeans trt / diff;
   lsmeans trt / at iwt=300;
   lsmeans trt / at iwt=500;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.4                                       ---*/
proc mixed data=ex7_3_rcb;
   class blk trt;
   model adg= trt iwt blk/solution;
   ods select CovParms SolutionF Tests3;
run; 
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.5                                       ---*/
proc sort data=ex7_3_rcb; by blk;
proc means mean n data=ex7_3_rcb noprint;
  by blk;
  var adg iwt; 
  output out=means mean = madg miwt 
                   n    = nadg niwt;
run;
proc mixed data=means; 
   model madg = miwt / solution;
   weight nadg;
   ods select ModelInfo CovParms SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.6                                       ---*/
proc mixed data=ex7_3_rcb covtest; 
   class trt blk;
   model adg=trt iwt / solution;
   random blk;
   parms (.1926) (.0500)/ hold=1,2;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.4, Cooking Times                      ---*/
data long;
   input block container $ amount time;
   datalines;
1  A  2   71.36
1  A  4  123.33
1  A  6  155.59
1  A  8  194.90
1  B  4  118.64
1  B  2   61.95
1  B  6  174.46
1  B  8  222.71
1  C  4  132.55
1  C  8  230.96
1  C  2   73.15
1  C  6  180.46
2  A  6  153.37
2  A  2   74.77
2  A  8  203.97
2  A  4  120.62
2  B  6  174.24
2  B  4  122.24
2  B  2   69.87
2  B  8  231.12
2  C  4  139.63
2  C  8  242.67
2  C  2   80.94
2  C  6  183.37
3  A  2   96.46
3  C  4  145.55
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.7                                       ---*/
proc mixed data=long;
   class container block;
   model time=container amount container*amount / 
                        solution outp=pred ddfm=kr;
   random block;
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.8                                       ---*/
proc mixed data=long;
   class container block;
   model time = container container*amount /
                noint solution outp=pred ddfm=kr;
   lsmeans container / at amount=2 diff;
   lsmeans container / at amount=4 diff;
   lsmeans container / at amount=6 diff;
   lsmeans container / at amount=8 diff;
   random block;
   ods select CovParms SolutionF Tests3 Lsmeans Diffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.9                                       ---*/
data linear; 
   set long;
   class_amt = amount;
run;
proc mixed data=linear;
   class container class_amt block;
   model time=container amount container*amount
              container*class_amt / ddfm=kr;
   random block;
   ods select ClassLevels CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.10                                      ---*/
proc mixed data=linear;
   class container  block;
   model time=container container*amount /ddfm=kr NOINT solution;
   random block;
   contrast 'Models = at 2oz' 
          container 1 -1  0 container*amount 2 -2  0,
          container 1  0 -1 container*amount 2  0 -2;
   ods select CovParms SolutionF Tests3 Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.11                                      ---*/
data test; set long;
  amt_2 = amount-2;
  amt_4 = amount-4;
  amt_6 = amount-6;
  amt_8 = amount-8;
run;

title2 "Compare the lines at 2 oz";
proc mixed data=test;
   class container block;
   model time=container container*amt_2 / 
              solution outp=pred ddfm=kr;
   random block;
   ods select CovParms Tests3;
run;

title2 "Compare the lines at 4 oz";
proc mixed data=test;
   class container block;
   model time = container container*amt_4 / 
                solution outp=pred ddfm=kr;
   random block;
   ods select Tests3;
run;
title2 "Compare the lines at 6 oz";
proc mixed data=test;
   class container block;
   model time = container container*amt_6 / 
                solution outp=pred ddfm=kr;
   random block;
   ods select Tests3;
run;
title2 "Compare the lines at 8 oz";
proc mixed data=test;
   class container block;
   model time = container container*amt_8 / 
                solution outp=pred ddfm=kr;
   random block;
   ods select Tests3;
run;
title;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.5, Balanced Incomplete Blocks         ---*/
data bib;
  input id blk trt y x grp;
  datalines;
 1  1  1  31  20  13
 2  1  2  29  18  24
 3  1  3  31  11  13
 4  2  1  29  37  13
 5  2  2  34  37  24
 6  2  4  33  39  24
 7  3  1  31  29  13
 8  3  3  28  12  13
 9  3  4  34  31  24
10  4  2  39  37  24
11  4  3  35  29  13
12  4  4  32  28  24
13  5  1  33  12  13
14  5  2  35  19  24
15  5  3  38  16  13
16  6  1  35  31  13
17  6  2  31  13  24
18  6  4  42  39  24
19  7  1  42  38  13
20  7  3  43  30  13
21  7  4  42  25  24
22  8  2  27  13  24
23  8  3  37  39  13
24  8  4  29  21  24
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.12                                      ---*/
proc mixed data=bib;
   class blk trt;
   model y=trt x*trt/solution ddfm=kr;
   random blk;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.13                                      ---*/
proc mixed data=bib;
   class blk trt; 
   model y = trt x x*trt / solution ddfm=kr;
   estimate 'b1-b2' x*trt 1 -1  0  0; 
   estimate 'b1-b3' x*trt 1  0 -1  0;
   estimate 'b1-b4' x*trt 1  0  0 -1; 
   estimate 'b2-b3' x*trt 0  1 -1  0;
   estimate 'b2-b4' x*trt 0  1  0 -1; 
   estimate 'b3-b4' x*trt 0  0  1 -1;
   random blk;
   ods select CovParms Estimates Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.14                                      ---*/
data bib2; set bib;
   grp = 13; 
   if trt=2 or trt=4 then grp = 24;
run;
proc mixed data=bib2 covtest cl; 
   class blk trt grp; 
   model y = trt x*grp / solution ddfm=kr;
   random blk;
   estimate 'trt1 at xx%= 10.0' intercept 1 trt 1 0 0 0 x*grp 10   0;
   estimate 'trt1 at xx%= 40.0' intercept 1 trt 1 0 0 0 x*grp 40   0;
   estimate 'trt1 at 25%= 17.0' intercept 1 trt 1 0 0 0 x*grp 17   0;
   estimate 'trt1 at 50%= 28.5' intercept 1 trt 1 0 0 0 x*grp 28.5 0;
   estimate 'trt1 at 75%= 37.0' intercept 1 trt 1 0 0 0 x*grp 37   0;
   estimate 'trt1 at mean=26.0' intercept 1 trt 1 0 0 0 x*grp 26   0;

   estimate 'trt3 at xx%= 10.0' intercept 1 trt 0 0 1 0 x*grp 10   0;
   estimate 'trt3 at xx%= 40.0' intercept 1 trt 0 0 1 0 x*grp 40   0;
   estimate 'trt3 at 25%= 17.0' intercept 1 trt 0 0 1 0 x*grp 17   0;
   estimate 'trt3 at 50%= 28.5' intercept 1 trt 0 0 1 0 x*grp 28.5 0;
   estimate 'trt3 at 75%= 37.0' intercept 1 trt 0 0 1 0 x*grp 37   0;
   estimate 'trt3 at mean=26.0' intercept 1 trt 0 0 1 0 x*grp 26   0;

   estimate 'trt2 at xx%= 10.0' intercept 1 trt 0 1 0 0 x*grp 0 10;
   estimate 'trt2 at xx%= 40.0' intercept 1 trt 0 1 0 0 x*grp 0 40;
   estimate 'trt2 at 25%= 17.0' intercept 1 trt 0 1 0 0 x*grp 0 17;
   estimate 'trt2 at 50%= 28.5' intercept 1 trt 0 1 0 0 x*grp 0 28.5;
   estimate 'trt2 at 75%= 37.0' intercept 1 trt 0 1 0 0 x*grp 0 37;
   estimate 'trt2 at mean=26.0' intercept 1 trt 0 1 0 0 x*grp 0 26;

   estimate 'trt4 at xx%= 10.0' intercept 1 trt 0 0 0 1 x*grp 0 10;
   estimate 'trt4 at xx%= 40.0' intercept 1 trt 0 0 0 1 x*grp 0 40;
   estimate 'trt4 at 25%= 17.0' intercept 1 trt 0 0 0 1 x*grp 0 17;
   estimate 'trt4 at 50%= 28.5' intercept 1 trt 0 0 0 1 x*grp 0 28.5;
   estimate 'trt4 at 75%= 37.0' intercept 1 trt 0 0 0 1 x*grp 0 37;
   estimate 'trt4 at mean=26.0' intercept 1 trt 0 0 0 1 x*grp 0 26;

   ****comparisons of means at 25%, 75%, and 50%;
   estimate 't1-t2 75%=37'   trt 1 -1  0  0 x*grp 37   -37  ;
   estimate 't1-t2 50%=28.5' trt 1 -1  0  0 x*grp 28.5 -28.5;
   estimate 't1-t2 25%=17'   trt 1 -1  0  0 x*grp 17   -17  ;
   estimate 't1-t4 75%=37'   trt 1  0  0 -1 x*grp 37   -37  ;
   estimate 't1-t4 50%=28.5' trt 1  0  0 -1 x*grp 28.5 -28.5;
   estimate 't1-t4 25%=17'   trt 1  0  0 -1 x*grp 17   -17  ;
   estimate 't3-t2 75%=37'   trt 0 -1  1  0 x*grp 37   -37  ;
   estimate 't3-t2 50%=28.5' trt 0 -1  1  0 x*grp 28.5 -28.5;
   estimate 't3-t2 25%=17'   trt 0 -1  1  0 x*grp 17   -17  ;
   estimate 't3-t4 75%=37'   trt 0  0  1 -1 x*grp 37   -37  ;
   estimate 't3-t4 50%=28.5' trt 0  0  1 -1 x*grp 28.5 -28.5;
   estimate 't3-t4 25%=17'   trt 0  0  1 -1 x*grp 17   -17  ;

   ***comparison of LSMEANS at X=26***;
   estimate 't1-t2 at mean' trt 1 -1  0  0 x*grp 26 -26;
   estimate 't1-t3 at mean' trt 1  0 -1  0             ;
   estimate 't1-t4 at mean' trt 1  0  0 -1 x*grp 26 -26;
   estimate 't2-t3 at mean' trt 0  1 -1  0 x*grp 26 -26;
   estimate 't2-t4 at mean' trt 0  1  0 -1             ;
   estimate 't3-t4 at mean' trt 0  0  1 -1 x*grp 26 -26;
   lsmeans trt / diff e at mean;
   lsmeans trt / diff e at x=13;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*--Data Set 7.6, Unbalanced Incomplete Block        ----*/
data eX7_6_ubib;
   input blk trt y x;
   datalines;
 1  1  0.62  0.078
 1  2  0.91  0.010
 2  1  0.41  0.032
 2  2  0.48  0.050
 3  1  0.41  0.000
 3  2  0.49  0.015
 4  1  0.26  0.010
 4  2  0.28  0.016
 5  1  0.29  0.053
 5  2  0.37  0.069
 6  1  0.73  0.007
 6  2  0.72  0.062
 7  3  0.33  0.036
 7  4  0.31  0.068
 8  3  0.18  0.068
 8  4  0.18  0.057
 9  3  0.19  0.077
 9  4  0.25  0.090
10  3  0.28  0.023
10  4  0.32  0.039
11  3  0.33  0.017
11  4  0.27  0.062
12  3  0.24  0.058
12  4  0.23  0.082
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.15                                      ---*/
proc mixed data=EX7_6_ubib; 
   class blk trt;
   model y=trt x*trt/noint solution ddfm=kr;
   random blk;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.16                                      ---*/
proc mixed data=EX7_6_ubib;
   class blk trt;
   model y=trt x x*trt/noint solution ddfm=kr;
   random blk;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.17                                      ---*/
proc mixed data=EX7_6_ubib;
   class blk trt;
   model y=trt x  /noint solution ddfm=kr;
   lsmeans trt / diff;
   random blk;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.7, Teaching Methods I                 ---*/
data Ex_7_7sp;
    input met teacher gen $ student score y_ex @@;
    datalines;
1  1  f  1  15  11 1  1  f  2  17  11 1  1  f  3  16  11
1  1  f  4  16  11 1  1  m  1  17  11 1  1  m  2  16  11
1  1  m  3  17  11 1  1  m  4  17  11 1  2  f  1  18   8
1  2  f  2  17   8 1  2  f  3  17   8 1  2  f  4  16   8
1  2  m  1  16   8 1  2  m  2  17   8 1  2  m  3  18   8
1  2  m  4  17   8 1  3  f  1  15   9 1  3  f  2  15   9
1  3  f  3  15   9 1  3  f  4  16   9 1  3  m  1  15   9
1  3  m  2  15   9 1  3  m  3  15   9 1  3  m  4  16   9
1  4  f  1  16  17 1  4  f  2  17  17 1  4  f  3  16  17
1  4  f  4  15  17 1  4  m  1  14  17 1  4  m  2  17  17
1  4  m  3  17  17 1  4  m  4  16  17 2  1  f  1  21   6
2  1  f  2  22   6 2  1  f  3  22   6 2  1  f  4  21   6
2  1  m  1  20   6 2  1  m  2  20   6 2  1  m  3  21   6
2  1  m  4  22   6 2  2  f  1  21  11 2  2  f  2  20  11
2  2  f  3  20  11 2  2  f  4  21  11 2  2  m  1  18  11
2  2  m  2  19  11 2  2  m  3  20  11 2  2  m  4  19  11
2  3  f  1  23  13 2  3  f  2  23  13 2  3  f  3  24  13
2  3  f  4  23  13 2  3  m  1  21  13 2  3  m  2  20  13
2  3  m  3  21  13 2  3  m  4  22  13 2  4  f  1  23  18
2  4  f  2  22  18 2  4  f  3  22  18 2  4  f  4  22  18
2  4  m  1  19  18 2  4  m  2  19  18 2  4  m  3  19  18
2  4  m  4  20  18 3  1  f  1  33   8 3  1  f  2  31   8
3  1  f  3  31   8 3  1  f  4  32   8 3  1  m  1  27   8
3  1  m  2  28   8 3  1  m  3  27   8 3  1  m  4  27   8
3  2  f  1  28  18 3  2  f  2  27  18 3  2  f  3  27  18
3  2  f  4  29  18 3  2  m  1  23  18 3  2  m  2  23  18
3  2  m  3  24  18 3  2  m  4  23  18 3  3  f  1  30  12
3  3  f  2  29  12 3  3  f  3  29  12 3  3  f  4  30  12
3  3  m  1  25  12 3  3  m  2  25  12 3  3  m  3  26  12
3  3  m  4  24  12 3  4  f  1  28   6 3  4  f  2  27   6
3  4  f  3  28   6 3  4  f  4  30   6 3  4  m  1  25   6
3  4  m  2  25   6 3  4  m  3  22   6 3  4  m  4  25   6
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.18                                      ---*/
title2 'Means model for intercepts and slopes';
proc mixed data=Ex_7_7sp; 
   class teacher met gen;
   model score = gen*met y_ex*gen*met/solution noint ddfm=kr;
   random teacher(met);
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.19                                      ---*/
title2 'Effects model for intercepts and slopes';
proc mixed data=Ex_7_7sp; 
   class teacher met gen;
   model score = met gen gen*met
                 y_ex y_ex*met y_ex*gen y_ex*gen*met/ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;

 /*-------------------------------------------------------*/
 /*---Output 7.20                                      ---*/
title2 'Effects model for intercepts and additive model for slopes';
proc mixed data=Ex_7_7sp;
   class teacher met gen;
   model score = met gen gen*met y_ex y_ex*met y_ex*gen/ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.21                                      ---*/
title2 'two-way for intercepts and one way for slopes';
proc mixed data=Ex_7_7sp;
   class teacher met gen;
   model score = met gen gen*met y_ex y_ex*gen/ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
title;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.22                                      ---*/
 /*---Output 7.23                                      ---*/
 /*---Output 7.24                                      ---*/
 /*---Output 7.25                                      ---*/ 
title2 "means model for intercepts and slopes for y_ex for each gender";
proc mixed data=Ex_7_7sp;
   class teacher met gen;
   model score =gen*met y_ex*gen/noint solution ddfm=kr;
   random teacher(met);

   lsmeans gen*met / diff at means;
   lsmeans gen*met / diff at y_ex=5;
   lsmeans gen*met / diff at y_ex=10;
   lsmeans gen*met / diff at y_ex=20;

   estimate 'f-m m=1 y_ex=5'     gen*met 1 -1 0  0 0  0 y_ex*gen  5  -5;
   estimate 'f-m m=1 y_ex=10'    gen*met 1 -1 0  0 0  0 y_ex*gen 10 -10;
   estimate 'f-m m=1 y_ex=20'    gen*met 1 -1 0  0 0  0 y_ex*gen 20 -20;
   estimate 'f-m m=2 y_ex=5'     gen*met 0  0 1 -1 0  0 y_ex*gen  5  -5;
   estimate 'f-m m=2 y_ex=10'    gen*met 0  0 1 -1 0  0 y_ex*gen 10 -10;
   estimate 'f-m m=2 y_ex=20'    gen*met 0  0 1 -1 0  0 y_ex*gen 20 -20;
   estimate 'f-m m=3 y_ex=5'     gen*met 0  0 0  0 1 -1 y_ex*gen  5  -5;
   estimate 'f-m m=3 y_ex=10'    gen*met 0  0 0  0 1 -1 y_ex*gen 10 -10;
   estimate 'f-m m=3 y_ex=20'    gen*met 0  0 0  0 1 -1 y_ex*gen 20 -20;

   estimate 'male m=1 y_ex=5'    gen*met 1  0 0  0 0  0 y_ex*gen  5   0;
   estimate 'male m=1 y_ex=10'   gen*met 1  0 0  0 0  0 y_ex*gen 10   0;
   estimate 'male m=1 y_ex=20'   gen*met 1  0 0  0 0  0 y_ex*gen 20   0;
   estimate 'male m=2 y_ex=5'    gen*met 0  0 1  0 0  0 y_ex*gen  5   0;
   estimate 'male m=2 y_ex=10'   gen*met 0  0 1  0 0  0 y_ex*gen 10   0;
   estimate 'male m=2 y_ex=20'   gen*met 0  0 1  0 0  0 y_ex*gen 20   0;
   estimate 'male m=3 y_ex=5'    gen*met 0  0 0  0 1  0 y_ex*gen  5   0;
   estimate 'male m=3 y_ex=10'   gen*met 0  0 0  0 1  0 y_ex*gen 10   0;
   estimate 'male m=3 y_ex=20'   gen*met 0  0 0  0 1  0 y_ex*gen 20   0;

   estimate 'female m=1 y_ex=5'  gen*met 0  1 0  0 0  0 y_ex*gen  0   5;
   estimate 'female m=1 y_ex=10' gen*met 0  1 0  0 0  0 y_ex*gen  0  10;
   estimate 'female m=1 y_ex=20' gen*met 0  1 0  0 0  0 y_ex*gen  0  20;
   estimate 'female m=2 y_ex=5'  gen*met 0  0 0  1 0  0 y_ex*gen  0   5;
   estimate 'female m=2 y_ex=10' gen*met 0  0 0  1 0  0 y_ex*gen  0  10;
   estimate 'female m=2 y_ex=20' gen*met 0  0 0  1 0  0 y_ex*gen  0  20;
   estimate 'female m=3 y_ex=5'  gen*met 0  0 0  0 0  1 y_ex*gen  0   5;
   estimate 'female m=3 y_ex=10' gen*met 0  0 0  0 0  1 y_ex*gen  0  10;
   estimate 'female m=3 y_ex=20' gen*met 0  0 0  0 0  1 y_ex*gen  0  20;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.8, Teaching Methods II                ---*/
data EX_7_8_spcv;
   input met teacher gen $ iq score @@;
   datalines;
1  1  f   89  54 1  1  f  105  55 1  1  f  108  54
1  1  f  116  64 1  1  m   95  59 1  1  m  103  58
1  1  m   91  42 1  1  m   82  48 1  2  f   83  48
1  2  f  103  56 1  2  f  123  67 1  2  f  103  54
1  2  m  118  65 1  2  m  101  65 1  2  m  101  50
1  2  m   82  55 1  3  f  115  71 1  3  f   91  66
1  3  f  109  69 1  3  f   85  59 1  3  m   98  76
1  3  m   84  64 1  3  m   91  63 1  3  m  110  74
1  4  f  120  75 1  4  f   98  60 1  4  f   99  64
1  4  f   91  59 1  4  m   80  55 1  4  m  112  70
1  4  m  105  63 1  4  m   94  62 2  1  f   97  67
2  1  f  105  74 2  1  f  120  78 2  1  f   92  69
2  1  m   91  67 2  1  m   96  64 2  1  m   95  65
2  1  m   84  52 2  2  f  105  73 2  2  f  110  78
2  2  f   98  75 2  2  f   92  65 2  2  m  104  75
2  2  m  105  78 2  2  m   82  58 2  2  m  109  75
2  3  f  141  97 2  3  f  107  68 2  3  f  116  82
2  3  f  105  86 2  3  m   93  71 2  3  m  113  82
2  3  m   92  72 2  3  m  115  77 2  4  f  112  74
2  4  f   96  76 2  4  f  103  78 2  4  f  105  77
2  4  m  111  75 2  4  m  121  86 2  4  m   87  68
2  4  m   90  74 3  1  f   87  71 3  1  f   78  71
3  1  f  117  85 3  1  f  108  87 3  1  m   92  65
3  1  m  111  72 3  1  m  126  85 3  1  m  123  78
3  2  f  126  91 3  2  f  112  80 3  2  f  108  75
3  2  f   92  65 3  2  m   95  73 3  2  m  109  73
3  2  m  115  78 3  2  m  115  71 3  3  f  102  82
3  3  f   96  72 3  3  f  113  87 3  3  f  127  91
3  3  m  112  85 3  3  m   96  68 3  3  m  114  86
3  3  m  101  78 3  4  f   95  86 3  4  f  105  91
3  4  f   95  81 3  4  f  102  85 3  4  m   80  68
3  4  m   97  81 3  4  m  114  89 3  4  m  100  87
;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 7.26                                      ---*/
title2 "Factorial effects for both intercepts and slopes";
proc mixed data=EX_7_8_spcv;
   class teacher met gen;
   model score = met gen gen*met iq iq*gen iq*met 
                 iq*gen*met / ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.27                                      ---*/
title2 "Factorial effects for intercepts and main effects for slopes";
proc mixed data=EX_7_8_spcv;
   class teacher met gen;
   model score = met gen gen*met iq iq*gen iq*met/ ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
title;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.28                                      ---*/
proc mixed data=EX_7_8_spcv;
   class teacher met gen;
   model score = met gen gen*met iq  iq*met / ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.29                                      ---*/
proc mixed data=EX_7_8_spcv;
   class teacher met gen;
   model score = met gen gen*met iq / ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.30                                      ---*/
 /*---Output 7.31                                      ---*/
title2 "Means model for intercepts and common slope";
proc mixed data=EX_7_8_spcv;
   class teacher met gen;
   model score = gen*met iq / noint solution ddfm=kr;
   random teacher(met);
   lsmeans gen*met/diff;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.32                                      ---*/ 
proc glimmix data=EX_7_8_spcv; 
   class teacher met gen;
   model score = gen*met iq / ddfm=kr;
   random teacher(met);
   lsmeans gen*met / slicediff=(gen met);
   ods select CovParms SliceDiffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.33                                      ---*/
title2 "Means model for  intercepts and common slope";
proc glm data=EX_7_8_spcv; 
   class teacher met gen;
   model score = gen*met teacher(met) iq / noint solution;
   random teacher(met) / test;
   lsmeans gen*met / pdiff stderr;
   estimate 'met 1 female' 
             met*gen 4 0 0 0 0 0  
             teacher(met) 1 1 1 1 0 0 0 0 0 0 0 0 / divisor=4; 
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.9, Wafer Types                        ---*/
data ex_7_9_lots;
   input grp temp type $ wafer site delta thick;
   datalines;
1   900  A  1  1  291  1919
1   900  A  1  2  295  1919
1   900  A  1  3  294  1919
1   900  A  2  1  318  2113
1   900  A  2  2  315  2113
1   900  A  2  3  315  2113
1   900  B  1  1  349  1965
1   900  B  1  2  348  1965
1   900  B  1  3  345  1965
1   900  B  2  1  332  1829
1   900  B  2  2  334  1829
1   900  B  2  3  331  1829
1  1000  A  1  1  319  2098
1  1000  A  1  2  315  2098
1  1000  A  1  3  321  2098
1  1000  A  2  1  290  1823
1  1000  A  2  2  289  1823
1  1000  A  2  3  292  1823
1  1000  B  1  1  358  2059
1  1000  B  1  2  357  2059
1  1000  B  1  3  362  2059
1  1000  B  2  1  365  2145
1  1000  B  2  2  367  2145
1  1000  B  2  3  367  2145
1  1100  A  1  1  264  1846
1  1100  A  1  2  266  1846
1  1100  A  1  3  268  1846
1  1100  A  2  1  276  2028
1  1100  A  2  2  280  2028
1  1100  A  2  3  278  2028
1  1100  B  1  1  352  2086
1  1100  B  1  2  353  2086
1  1100  B  1  3  350  2086
1  1100  B  2  1  330  1899
1  1100  B  2  2  330  1899
1  1100  B  2  3  334  1899
2   900  A  1  1  306  1841
2   900  A  1  2  302  1841
2   900  A  1  3  305  1841
2   900  A  2  1  342  2170
2   900  A  2  2  341  2170
2   900  A  2  3  336  2170
2   900  B  1  1  342  1981
2   900  B  1  2  341  1981
2   900  B  1  3  340  1981
2   900  B  2  1  366  2190
2   900  B  2  2  363  2190
2   900  B  2  3  361  2190
2  1000  A  1  1  299  1915
2  1000  A  1  2  296  1915
2  1000  A  1  3  297  1915
2  1000  A  2  1  329  2161
2  1000  A  2  2  330  2161
2  1000  A  2  3  332  2161
2  1000  B  1  1  348  2072
2  1000  B  1  2  346  2072
2  1000  B  1  3  346  2072
2  1000  B  2  1  350  2082
2  1000  B  2  2  346  2082
2  1000  B  2  3  347  2082
2  1100  A  1  1  285  1854
2  1100  A  1  2  292  1854
2  1100  A  1  3  289  1854
2  1100  A  2  1  306  2046
2  1100  A  2  2  303  2046
2  1100  A  2  3  304  2046
2  1100  B  1  1  357  2062
2  1100  B  1  2  360  2062
2  1100  B  1  3  359  2062
2  1100  B  2  1  361  2055
2  1100  B  2  2  361  2055
2  1100  B  2  3  360  2055
3   900  A  1  1  318  2019
3   900  A  1  2  323  2019
3   900  A  1  3  323  2019
3   900  A  2  1  307  1872
3   900  A  2  2  308  1872
3   900  A  2  3  308  1872
3   900  B  1  1  372  2182
3   900  B  1  2  371  2182
3   900  B  1  3  370  2182
3   900  B  2  1  348  1973
3   900  B  2  2  349  1973
3   900  B  2  3  352  1973
3  1000  A  1  1  264  1828
3  1000  A  1  2  265  1828
3  1000  A  1  3  265  1828
3  1000  A  2  1  274  1827
3  1000  A  2  2  268  1827
3  1000  A  2  3  275  1827
3  1000  B  1  1  332  2109
3  1000  B  1  2  337  2109
3  1000  B  1  3  335  2109
3  1000  B  2  1  322  2003
3  1000  B  2  2  326  2003
3  1000  B  2  3  321  2003
3  1100  A  1  1  273  1925
3  1100  A  1  2  275  1925
3  1100  A  1  3  276  1925
3  1100  A  2  1  276  1942
3  1100  A  2  2  273  1942
3  1100  A  2  3  273  1942
3  1100  B  1  1  333  1893
3  1100  B  1  2  332  1893
3  1100  B  1  3  332  1893
3  1100  B  2  1  349  2170
3  1100  B  2  2  350  2170
3  1100  B  2  3  352  2170
4   900  A  1  1  295  1862
4   900  A  1  2  297  1862
4   900  A  1  3  296  1862
4   900  A  2  1  326  2149
4   900  A  2  2  326  2149
4   900  A  2  3  328  2149
4   900  B  1  1  322  1888
4   900  B  1  2  325  1888
4   900  B  1  3  327  1888
4   900  B  2  1  335  1998
4   900  B  2  2  332  1998
4   900  B  2  3  334  1998
4  1000  A  1  1  258  1815
4  1000  A  1  2  260  1815
4  1000  A  1  3  260  1815
4  1000  A  2  1  280  1981
4  1000  A  2  2  276  1981
4  1000  A  2  3  278  1981
4  1000  B  1  1  319  2012
4  1000  B  1  2  322  2012
4  1000  B  1  3  317  2012
4  1000  B  2  1  311  1892
4  1000  B  2  2  313  1892
4  1000  B  2  3  313  1892
4  1100  A  1  1  282  2083
4  1100  A  1  2  282  2083
4  1100  A  1  3  279  2083
4  1100  A  2  1  271  2036
4  1100  A  2  2  271  2036
4  1100  A  2  3  270  2036
4  1100  B  1  1  335  2174
4  1100  B  1  2  339  2174
4  1100  B  1  3  338  2174
4  1100  B  2  1  304  1802
4  1100  B  2  2  303  1802
4  1100  B  2  3  303  1802
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.34                                      ---*/
title2 "intercept is means model and slope is fct of temp";
proc mixed data=ex_7_9_lots;
   class grp temp type;
   model delta=temp*type thick*temp / ddfm=kr noint solution;
   random grp grp*temp grp*type 
          grp*type*temp wafer(grp temp type);
   lsmeans temp*type / at thick=1828;
   lsmeans temp*type / at thick=2000;
   lsmeans temp*type / at thick=2170;
run; 
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.35                                      ---*/
proc glimmix data=ex_7_9_lots; 
   class grp temp type;
   model delta=temp*type thick*temp / ddfm=kr noint solution;
   random grp grp*temp grp*type 
          grp*type*temp wafer(grp temp type);
   lsmeans temp*type / slicediff=(temp type) at thick=1828;
   lsmeans temp*type / slicediff=(temp type) at thick=2000;
   lsmeans temp*type / slicediff=(temp type) at thick=2170;
   ods select SliceDiffs;
run;
 /*-------------------------------------------------------*/


