 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---CHAPTER 8: Random Coefficient Models             ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 8.2, Winter Wheat                       ---*/
data wheat;
   input variety yield moist @@;
   datalines;
 1  41  10  1  69  57  1  53  32  1  66  52  1  64  47  1  64  48
 2  49  30  2  44  21  2  44  20  2  46  26  2  57  44  2  42  19
 3  69  50  3  62  40  3  50  23  3  76  58  3  48  21  3  55  30
 4  48  22  4  60  40  4  45  17  4  47  21  4  62  44  4  43  13
 5  65  49  5  63  44  5  71  57  5  68  51  5  52  27  5  68  52
 6  76  55  6  46  11  6  45  11  6  67  43  6  65  38  6  79  60
 7  35  17  7  37  20  7  30  11  7  30  10  7  57  48  7  49  36
 8  75  57  8  64  41  8  46  15  8  54  28  8  52  23  8  52  23
 9  51  26  9  63  44  9  42  13  9  61  40  9  67  48  9  69  53
10  60  37 10  73  58 10  66  44 10  71  53 10  67  48 10  74  59
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.1                                       ---*/
 /*---Output 8.2                                       ---*/
proc mixed data=wheat covtest cl scoring=8;
   class variety;
   model yield = moist / solution;
   random int moist / type=un sub=variety solution G Gcorr;
   ods output solutionf=fixed solutionr=random;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.3                                       ---*/
data lines;
   merge random(where=(effect='Intercept') rename=(estimate=rint))
         random(where=(effect='moist'    ) rename=(estimate=rslope));
   if _n_ = 1 then merge 
        fixed(where=(effect='Intercept') rename=(estimate=fint))
        fixed(where=(effect='moist'    ) rename=(estimate=fslope));
   intercept = fint   + rint;
   slope     = fslope + rslope;
   keep variety fint fslope rint rslope intercept slope;
run;
proc print data=lines; 
   var variety fint rint intercept fslope rslope slope;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.4                                       ---*/
proc mixed data=wheat scoring=8; 
   class variety;
   model yield = moist/solution;
   random int moist/sub=variety type=un(1) solution G Gcorr; 
   ods select G GCorr CovParms FitStatistics SolutionF Tests3;
run;
 /*-------------------------------------------------------*/
 
  
 /*-------------------------------------------------------*/
 /*---Data Set 8.3, Mathematics Study                  ---*/
data class;
   input size @@;
   retain class 1;
   do i = 1 to size;
      output;
   end;
   drop size i;
   class + 1;
   datalines;
   21   29   16   24   20   19
   16    8   19   18   14   14
   13   19   22   17   11    9
   22   18   19   24   30   20
   16   21   29   22   18   19 
   11   16   15    8   13   20
   21   17   20   19   17   17
   21   28   19   17   21   24
   26   35   21   20   22   18
   21   22   11   18    7   26
   19    7   25   18   17   18
   10   17   16    9   23   18
   17   19   17   13   20   17 
    8   20   16   20   26   14
   17   27   16   23   25   20
   24   28    8   22   17   21
   25   14   21   23   13   28
   13   22   25   24   14   18
   38   14   21   21   25   27
   34   34   23   19   22   23
   23   26   25   26   14   24 
   24   10   18   22   17   22
   20   19   14   16   17   19
    7    9   23   13   18   24
   24   19   30   21   17   26
   29   32   21    8    8   24
   15   27   15   18   15   18
   18   26   23    7   21   22
   23   15   20   18   29   25 
   22   21   12   16   12   12
   15   17   20   20   21   15
   18   18   32   25
run;

data sims;
   input pretot gain @@;
   datalines;
 29    2   38    0   31    6   31    6   29    5   23    9   23    7
 33    2   30    1   32    3   22    4   29    6   34    2   30   -1
 35    1   25    1   22    3   31    1   33    3   31    1   35    2
 20    2   18   -3   12    5    9    1   11   -3   12    3   12   -8
 18   -6   13   -4    8    4   21    1    4    4   10    1    8    4
 12   -6   14   -2    9    2   11    3   11   -5   12    7   12    2
 17   -7    7    3   17   -6    9    2   16    2    4    1    5    8
 12   -4    7   -2   13    1   16  -10   11   -4    9   -1   11    6
  6    1    9    3    5    9   12   -5    8    1   12   -4    8    4
  9    2    9    5   11   -4   11    1   16   13   17    4   21    6
 18    9   21    0   18   -2   11    9   14   10   11   -4   13    4
 13    4   10    7   11    3   17    9   14    2   17    4   12    1
 12    8   13   -2   10    5   14    6   12   15   13   -5   20    5
 10    9   16    1   10    7   28   -4   11    5   14   -2   24    5
 13    7    5    5   23    8   11    5   18    4   21    5   24    4
 18   12   29    4   18    0    9   11   15    2   25    4   21    0
 20   10   30   -3   18  -10   26   -2   23   -4   18   -4   19    8
 18   -6   24    1   21    8   19   -1   31    0   14   -5   24    0
 19  -13   22  -10   21    6   20    2   11    6   10    7   24  -10
 24   -7   12    5   15   -4   14   -3    8    0    8   -2   16   14
 16   -4   18    4    4    0   21  -15   21  -12    9   -5   14   -6
  7   -1   13   -7   12   -5    4   10   17   -4   13   -7   16    5
 17   10   30    0   19   10   17   -7    9    2   17    0   15   -8
 12   10   14   -2   24  -11   24    1    6    4   15   -4   20    3
  5    3    8    2   10    5   14    8    6    4   18    2    9    0
 12    5    9    3    9    1   16   10   10    6    5   11    9    0
  9    1   11    1   13    0    7    5   27   -4    8   -2   12    2
 16   -7   14    5    8    4   11    4   16    4    8    2   11    7
  6    0    9    4   12    3   27    1   11    2   10   -1   17   -2
 10   -1   11   -1   15    4    7   -3    7    1    4    8    2   16
  7    8    5    1   16    0   12   -5   19   -2    5    3    6    2
 18    7    3    5    9    4    6    5    7    2   13   -7    8    3
  7    7    6    3    9    1    7    1    9    5    8    5    7    6
 22    2    9   16   18    7   27    6   28    8   14    7   13    0
 21   11   20    5   22    5   19    3   13   15   20    3   24    2
 32    4   17    0   17   11   12   13   19    3    8    7   17    7
 20   -1   14    0   12    3   12   12   17   -8   16   12   26   -2
 18   11   12   17   12    9   22    9   16    5   10    3   14    6
  7    2    6    6   19    5   12    9   10    8   17   -3    9    3
 13   10    8    2    8    5   21   10   12    1   12    2   27    6
 10    6   28    3   15    7   16    3   13    9   24   12   11   11
 15    4   19    8   10   -8   17  -10    6   -4   17   -6   16   -1
  9    1   11    2   13   -3    9    4    4    2    6    1   15   -3
 10    1   21    2   13    1   23    3   21   -7   31   -4   19   -4
 11    1    5    6   12    2   11    4   14    9    8    1   16    1
 16    4    8    4   11    1    9    0    4    6   13    8   13    1
 12   -4   12   -2   16    2   14    9   16    5   13   -1    9    0
  8    7   10    9   23    6   26    7   15    9   13    5   31    2
 31    4   22    5   18   13   26    6   31    4   22    2   23    9
 19    1   21   10   36    3   22   -2   21    6   15    5    8    2
 12   -1   11    7    7   15   13   -5   12   -2    4   11    7   -1
 12    0    7    3    4    7    8    3    8    5   21   -6   11    5
  6    5   12   11    7    2   18    4   23   -7   34   -5   33   -1
 30  -23   22    6   31  -22   32    6   30    5   26    6   33    3
 22    1   26   -2   29    4   24    7   34    0   30    7   30    4
 21    6   21    4   28    5   22   12   27   -3   16    9   36    2
 26   -1   37   -1   25   -2   30    6   28    8   32    2   34    2
 30    2   33    4   36    1   33    2   35    0   29    1   30    5
 37    1   30    1   27    3   36   -2   27    8   30    1   26    9
 32   -1   35   -2   33    3   27    7   28    4   34    3   32    6
 27    6   34    3   26    7   18   10   26    8    7   17   29    8
 33   -1   35    1   17   -9   32   -1   11   10   20    7   24    1
 31    6   20    4   21   10   14   12   25   11   15   12   18   11
 32    4   30    4   18   13   23    8   25    6   24    5   17   10
 15    9   26   11   25    5   16    2   12   18   27    6   13    5
 27    7   26    3   24    5   12    4   24   -1   15  -10   15   -1
  9    7   26   -1   15   -1   11    1   18    1   16    3    8    0
 14    7   15    1    5   10    9    5   21  -12   23    5   13    1
 13   -1   17    7   16    5   14    5   18    7   22    0   20    1
  9    9   16    4   19    3   22    6   22    8   24    4    9   11
 22    4   19    4   19    4   19    6   11    6    7    5   12    8
 16    7   12    1    7    2    6   15   10    0   19   -1   13    4
 12    9   13   -3   14    9   21    2   22    5   11    4   18    6
 19    4   23    1   12   -5   12    9   31   -2    9    8   31    4
 17    4   20    7   28    8   11    0   11   14   25    6   18   -5
 13    2   10    3   14   -3   15  -11    7    0    4    1   15    4
  5    9   14    3   12   -1    8   10   19    4    8    7   15   11
 20  -12   16    6    4    3   15    4    9   -3    7   -4   12   11
  7    3   13    6   20    4   20   11    8    7   23    5   23    9
 19    5   12    6   31    0   15    4    9   11   23    8   12   11
 15    8   11   16   28    4   10    8   22    9   17   13   10   14
 12   -2   10   22   21   -1    7    4   28  -13   12   19   15   13
  9   17   12   -5   29    1    9   10   11   11   20   14   20   11
 19    7   18    4   18   14   21    2   30   -3   21    9   14   11
 22    4    9   16   21    7    9    3   12    4   17    5   23    6
 13    7   33    0   23    2   23    7   28    3   27    2   11    1
 19    6   31    0   14    3   11   -3   14    8   11    7   25    5
 11   13   22   -7   16   15   17   11    7   24   28   -6   20   -7
 11    8   15    3   23    4   33    2   17    3   21   -9   20    2
 25    6   11   19   25   -1   19   13   29    9   28    5    9    2
 18   11   21   11   11   14    6   16   10   -1   14    5   28    7
 20   14   17   16   22    4   10    2   19    6   11    6   24    9
  9    6   18    8   16   15   18    7   13    4   24    5   31    6
 11    4   28   -6   17   13   21    5   23    7   10   -4    8    5
 28    6   22   -6   19    6   27    0   15    5   18    9   27    3
 25   -2   10   10   26    7   16    2   20    2   19   10   26    7
  9    3   18   16    9   12   10   17   32    2   16    6   16   10
 13   -3   15   14   17   -1   20    5   16   10   27   -3   28    2
 19    0   16    0   16   11   15    1   30    2   36   -1   12    9
 23   10   11    1   13   10   20    9   23   11   20   14   21    8
 20    7   23    7   23    9   30    7    7    4   23    6   12   11
 18   13   21    7   11    4   20   10   17    4   17    4   17    3
 10    3   22    3   18    7   19    7   28    7   23    6   26    6
 15    7   22    6    5    7   24   10   18    2   17   16   17    0
 11   -4   26    4   17    6   17    9   26    2   19   -1   16    3
 25   -1   20   -1   13   10   29   -2   23    1   28    7   25    8
 24    1   23   11   21    2   18    5    8    5   13    5   30    4
 17    7   24    5   26    8   19    5   17   -9   16   10   10    4
 15    3   16    8   20   14   20    3   12   11   10    4   10    8
 13    3   11    3   28    8   25    6   17   14   18   13   10    9
  6    6   11   16   25   10   14   12   24    4   20    3   20   10
 17   17   20   14   16    9   27    4   11    7   14   -4   13    4
 19    2    8   11   14    5   18    8   13    2   11    2    7    7
 11    2   12    7   12    8    9    3   28    4   15    5   11    7
 14   -4   12    6   24    5   19    5    8    4   15   -6    9   18
 13    3   22    4   24    8   16    9   12    3    9   -2    7    3
  6   -2   11   -6    9   -2    6    2    3    3   18    5   15   -1
 11    0    8   -1   10    7    6   -2    9   -2    8    5   10    1
  8    2    6   -1    5    0   15    5   23    5   34    0   15    8
  9    3   18    6   18   11    8    2   14    1    9    3   13   -4
 25    7   16    4   12    1    7    6   16    1   23    1   14   -3
 14    2   29    4   20   10   15    4   13   -3    8    0   26   -3
 25    3   12    6   20    2   14   17   11   13   17    4    7    2
 15    8   17   11   15    0   10   15   28    5   17    8   15   11
 17   15   16    4   18    7   14    8   20   10   37    0   17    6
  9   12   27    8   26    0   16   12   25    7   35   -2   22   12
 30    1   27   10   26    0   29    1   19    6   24   11   28    4
 29    7   14    8   16   12   24    5   15    5   25   -5   19    6
 14    5   10    6   16    0   17    8   23   10   22    9   17    8
 10    6   16   15   25   -2    7   10   14    5   12    9   23    3
 16    2   16    1   25    8   10   13   21   -5   12   11   19    3
 19    7   26   -3   31    4   26    4   27    2   19   11   22    7
 22   10   21   11   29    6   14    8   15    3   31    3   22    1
 19    5   33  -24   25    7   19   12   23    5   24    1   16   10
 30    4   29    4   23    4   30    4   16   12   23   10   25    6
 19    9   28    4   20   -4   21   12   26    2   27   -1   23    0
  9    2   12    4   18    9   27    2   11   -5    8    4   11    7
 25    1   11   -1   11    1   15    5   22    2   14    9   13    2
  9    2   10   -1   13    3   15    3   13   10   19   10   27    7
 21    5   35   -2   28   -2    7    7   15    5   18   -2    8    3
 28    1   12    9   17    8   25    2   10   -2   17    6    9    5
 15    4   30    0   22   -1   17    0   25    1   22   -3   26    4
 17    1   16    4   27    8   14    9   24   -1   17   10   25    9
 36    2   18    5   27    2   17    8   13   11   22    3   24    7
 11    6   25    4   17   13   23    1   16    6   11   11   11    7
 23    8   22   11   18   15   31    2   27    6   16   12   31    3
 22   15   28    8   23    8   29    1   22    8   30    4   24    5
 29  -20   27    6   28    6   24   12   10    8   10   11    9    6
 18    9   19    3   12   13   10   13   14    7    6   15   21    9
 14    4   12    9   14   14   21   10    6    6   17    9   11   11
 12   10   12    6   11    8   18    9   16   10   27    8   21    6
 20    9   30    1   23    7   18   10   31    6   15   10    9    6
 22   12   21    1   13   14   26    6   16   10   26    6   29    5
 24   10   18   11   21    0   21    0   25    7    9    2   10    1
 15    1   10   -1   17   -5    5    8   10   10   12    3    6    1
 10    6   11    5    7    3    6    9    7    0    8    0   10   -4
 15   -2    7    0    7    8    8    0   10    3    7    0    9   -2
  9    1    4    6    3    6   12   -7    5    6    4    6    7   -5
  3    6   10   -5    8   -7   14  -13   10   -2    9    3    9    5
  8   11   16    4   17   16   11    5    8    6   23    9   10    6
 15  -10   16   -3   19    2    8    9   18    3   18   14   15   -2
 18   10   10   20   18   -4   12    6   10    0   23   13   19    1
 18   12   10   12   26    2   13   -2   17    2   18   11   15    5
 10   14   17    7   20    0   18    2   10   -5   12    8   14    6
 12   -5   10   12   14   15   13    4   11    6   14    0   16   11
 19    7   16   14   10    4    6   -2    5    1    3    3    4   -4
 12   -8    6   -1   28    4   24    1   24   12   23    0   23   -1
 25    5   30  -11   30   -3   34   -3   34    0   33    3   24    4
 27  -12   25    1   16    6   31   -4   25   -5   22    4   15    2
 19   -1   27    6   17   -5   24   -3   31  -14   37   -9   11   -1
  7   -3   16    4   16    3   11   -4   13    8   10   10   23    1
 10    7   11   -5   13   -1   11    2   15   -1   23    3   18  -13
 25   -2   16    9   14   -1    6    0   14   -1   14    9   14   -4
 19   -1   11   -4   19    0    7    2    2    0   13    4    8    6
 11    2    5    0    6    0    8    1   12   -2   10    2   13    8
 16   13   15    0   18    3   17    4   11   12   15    4   12    2
 16   14   14    5   15    8   17    6   16    4   15   11   13    7
 11    6   12    5   15    2   13    6    7    5    6    3   14    1
 12    2   16    4   16   -5    6   -1   14   -4    8    5   14    6
 16   -4   13   -4    6    5    9    1   12    5   15    5   18    8
 14    2   13    0   12    5   15   10   14   13   27    4    9    9
 12    3   12    2    8    1    8    0    7   18   10   10   12    4
  7    5    6   13   11   15   12   13   17    4    9    6    8   16
 15   13    9    7   11    4    9    4    6   -2   13   -3    4    2
  7    2    9    4    5    0    6    5    8   -1    6    0   16    6
  9    1   22   10   19    4   18   -1   18  -14   13    5   10   -1
 13   -3   19    6   25    0   19  -10   13    4    8    3   13   -8
 17    2   26   -6   18    2   21    1   10    1   17    7   10    0
 18   -3    9    6   13    1   11   -4   15   15   11    2   17    5
 16   10   19   11   22    9   13   16    8   19    9   14   23   10
 18   14   14    7   12    5   15   21   17   11   21   11   13    6
  8   12   17   16   18   18   17   11   15   11    7   19   17   16
 19    4    6   16   15   16   14    5   14   11   21    5   11   17
  6   11   20   10   25    6   12    1   13   -1   15   10   19    4
  8    6    9   20   26    7   24    6   16   10    6    7    7    3
 24    7   10    3    9   13   13    7   19    9   17   11   21   11
 18    6   13    0    4    6   20   11   14   12   24    1   20   10
 14    4   27    6   31    5   25    8   15   11   16   -1    7    0
 17    9   22    0   12   -6    8    1    9    5    9    5    8    7
  8    5    8   12   20    2    9    0    4    4    5    1    8    8
  6    2   12   -1    7    6    6    8   17    9   11    5    3    9
 13   -9   22    1   16    4   10    4   10    1   10   -2    8   11
 13    5   10    2   14    7   23    9   14    2   13    9   11   13
  4    9   11    0   15    2   18    7    7   -1    4   12   16    6
 17    8    9    8    7    3   12   -1   12   -4   13    1   14    3
  8   -2   10  -10   16   -5    6    1    9   -3    5    1    3    7
  7   -2    6    2    8   -2    8   -1    4    2    6    9    6   -6
 15   -7   16    9    7   -2    8   -1    4    8    7    3   22    3
 15    4   11   -1   13   -7    7    2   14   -8   11    5   17    7
 11   -3   14    1    9    8   17    2   19    6   24   -5   17  -13
 19  -10   15   -1   32    1   21    3   10    4   25  -12   13    2
 18    3   20    5   16    1   13   -2   28   -5   15    3    6    5
 15   -9   11   -8   13   -2    6    1   10    6    6    3   13    1
 13   -2   13    6   10   -1    5   11   14    4   10   -3   15    3
 11    4   15   -2   19   -2   10   -5   23    3   24   -1   11    5
 19    9   16   10   16    6   14    6   10    9   25   -3   12    5
 12   12   18    8   21    9   12    4   14    1   19    5   11    5
 17    4   19   -3   12    2   12    1   16    3   22    4   18    3
 12    4   20   10    5    5    7   11   11    1   10    8    6    9
  7    3   14    4    6    4    6    5   19   -2    8    7   17    5
 10    4   13    3   26    6   13    7   19    6   12    2   12    8
 17    5   19    9   16   12   12   10   18    1   20   13   11   11
 28    4   10   12   11   13   18    8   24    2    9    5    8    3
  6    6    8    2    6   11    9   -2    7    6    9    3    9    5
  8   -6    5    7    9    1    6    2   13    0    9   -5    9    3
  7    4   13   -1    9    7    7    5    5    0   12   -6    6    2
  7    2   10   -3   14    1    6    4   11    4   11    1    6    5
  8   -1    9    0   11    1    7    7    8    4   18    4    7    2
 10    1   11    7    5    2   14    2   14   -1   12    1   11    0
 10   -2   10   -1    9    1    5   -1    9    4    6    1    5    1
  7    8    8   -2    5    2    7    1    4    3    8    1    9   -1
  6   -3   10    0   12    1    3    5    9   -1    8    0   11   -3
  8   -4   17    6    8    4   16    1   27    3   21    0   13    9
 23   -3   29  -10   29    5   14    8   14    4   31    3   16   10
 22    4   28    1   29    9   26    3   14   -3   32    4   22    5
 17   10    9    9   26    3   16   11   21   12   15    3   12   -2
 11    9   12   -3    7   -2    8    1   10   -2    9   -2   19    4
 10    2    8    2    8   -5   11   -2    7    2   18    0    9   -1
 11    2   12    0    9    1    8    2    9    1    6    2   20    5
 14   -2   17    1    9   12   13   -1   18    0   11    4   10    6
 12    2   10    8   10    2   16   14   12    2   14   16   28    5
 12   15   11   -1   10    6   12    9   13    7   10   16   18    0
 17    6   16    4   31    4   16   11   13    6   11   14    7    1
 21    3   21    4    9    7   10    5   14    7   12   11   12    0
 23    4   23    1   25    4   12    4   22    0   21    3   11   11
  9   -4   27    4   15    7   27    4   12    7   13    0   25    1
 11   -1   20    0    6   14   15    4   12    8   15   -1    3    9
 23   -5    8   11   10   10   10    5    7    6    7   11    7   15
  8   19    7   12    9   15   15   18   13    6   10    3   10    8
 19    6    5   16   13    4    7    5    8   12    6    6    9   11
  8   13   16   13    8   10   17    8    9    8   11    8   10    3
  9    8   10   16   11   17   27    2   14    3    9   19    8   19
  9    9    8   11    6   14    9   15    8    5   12    9   17   -9
 12    5   13    6   17   -5   11   -2   11   -4    8    1   10    7
  7   -1   13   -3   11   -1    7    2    7    5    6    7    8   -1
 14    2   14    2   15   -3   13    0   16    1   36   -2   28    3
 24    2   29    2   21    5   26    1   19  -18   21    9   33    6
 29    6   22  -19   23    6   31   -1   22    3   18    9   24    6
 14    2   31    1   13    8   36    1   19    5   36   -5   29   -4
 29  -22   23    1   10   -3    9   -1    1    2   10   -3    6    0
  6    3    8    4    8    4    3    3    9    0    6    3    5    1
  4    6   10   -2   13   13   14    4   15   -3   13   14   13   14
 10    3   17    5    9    7   16    4   13   17   14    4   14    3
 16   13   10    0   16    1   19    5   12   11   12    8   13   10
 10   13   14    3   16   12   18    5   14   -6   15    1   10    4
 15   13   22    5    6   10   21    1   21   -2   11    9   13    8
 15   -2   13    8   15    9   14    3   16    9   16    3   12    4
 11   14   11    7   18   11   15    7   13   -5   12    2    7    0
  8    0   11    6   14   -1    8   15    9   -1    8   -1    7   12
 10    4    5    3   17    0   24    5   33    4   17    5   17    4
 23    6   21   13   10   12   28    8   23    5   13    8   16    3
 20    5   24    4   20   10   21    9   16    4   14    8   25   10
 23    5   13    9   27    2   18    2   16    4   31    2   29    4
 21    6   26    2   12    9    8    4   17    8    7    5   26    1
 10    5    9    2   14   -1    8    8   14    2    8    2    7    3
 12    1    9    8   18    3   15   10   13    4   17   12   13   -7
 16   10   15   11   12    9   13   16    9   15   26    9   23   12
 16    9   16    6   24    4   24    4   10   10   18   12   17    2
 22    7   19    6   27    1   24    2   17    6   17    4    4    8
  9    3   10    0   20    9   10    8   30    2   32    0    7    5
 21    3   13    7   24    2   15   -1   10   -2    8   -3   16    1
  9    4   33    3   22    6   10    9   20    1   12    3   15   11
 16  -10   23    0   21   11   10    3   16    4   23    8   11    3
  8   11   19    7   26    1   13   -3   30   -4   10   14   18    2
 29    1   14    2   16   12   29    5   16    8   16    1   12    6
 14    9   22   12   15    9   30    0   37    2   32    1   25    9
 26    8   24    6   22   10   32   -1   32   -3   30    8   27    9
 31    1   24    2   25    1   17   -4   25    5   20    6   12   15
 23    5   13    4   18    5   14   14   11   15   14    8   20    6
 18   10   15    2   12    6   12   -4   18   10   16    8   13    3
  6    4   19   15   16   10   26   10   14    7   15   16   24    5
 20    4   10    6   16    4   19    8   21    5   16    4    6   12
 15   10   24    9   23   10    2    4   15    0   11    9   13   10
 14    3   11    6   17    6   17   11   21    4   16    8   25   10
 21    1   16    0   22    5   19    7   11   10   18   -2   17    6
 14    9   23    3   20    8   23  -16   12   16    3    3    7    9
  8    4   23   12   13    6   22    4   15   -1   13    5    6   25
 16    5    9    5   10    5   10    0   10   -3    9   -2   12    0
 17   -1   18   -1    8    2   18   -5   15   -2   10   -1   10   -4
  9   11   14    5   16    5   20    2    8    5    7    2   12    4
 20    1   10    9   13    5    5   -1   11   -5   13    8   25    2
 13    2   14   10   15    0    9    2    5    6   12    7    9    8
 19   -2   15    0    9    0    8    4    3    9   10    4   12    2
 12    4   12    1    6    7   19    4    7   16   13    9    5   11
  6    4   11    0   24    2   11   14   13    0    9    8   32    0
 15   11    8    1    6   12   22    1   11   -3   17    9   19   -6
 10    2    5    6   13   -3   24   -6   14    9   17    5   12    5
 19    7    9   -3   11    3    6   -1   26    1    7    4   14    5
  9    9   19   11   17    8   12   -5   20    9   10    3    8    2
  5    8    8    7   13    4   10    4    8    0    5    7   10   17
  7    7   14    4    8    1    9    1   11    5   20   14   16    8
 21    8   11   10   19   -9   17    7   27   -3   22    4   25    6
 24    8   16   10   21    2   28    3   17    0   19    3   21   13
 21   12   18    8   25    8   27    3   18    9   24    3   22    1
 19    0   28    6   34    3   25    3   20    9   22    4   28    7
 20   13   25    7   26   -8   27    0   20    3   11    9   17   -3
 13    4   12    1   10   12   16    0   15    5   10    1   15    9
 12    1   13   -1   17   -5   22    2    9    1    7    3   17   -1
 18    5   10   -1   18    5   20    3    6    7   14    9   10    4
 21    3    8   -1   15   -5   13    1   13   -3   17   -1   13   -4
 15    0    9    8   18   -3    7   -1   19   13   18    9   31    3
 17    3   25    2   13    6   16    1   14    9   10   10   14    5
 23   10   11    2   18    4   16   11   17   10   13    5   18   12
 17   11   17   15   21    5   24    9   24    5   21    7   13   -1
 18    9   10   -1   11   -3   10    5    6   -1    7    2    7    4
  5    0   14   11   11   -3   11    3    9    3   13   -2   27    7
 10    4    9    0   12   -4   12    2   29    1   27    4   22   12
 19   10   19    5   28    2   27    4   25   11   20   -2   19    2
 16    9   21    8   27    4   29    5   16   16   23    6   30    3
 33    2   30    5   28    5   27   -2   27    7   22    8   25    6
 16    1   19   -1   14    9   19    4   17    9   14    8   13    6
 13    9   17   -1   13    3   21    1   18   10   10    4   17    8
 12   12   18    5   17    4   30    3   14    3   27    7   29   -3
 15    8    6    0   12    6   14    2   15   -2   10    5   10    4
  7    0   13    0   10   10   18    0   15    0   19    5    6    7
  9    3   16    0   10    8    8    6   13    1    8    5   13   -5
  8    7    9    8   13   16   18    3   22   10   22    1   30    3
 13    1   20    8   27    6   23   -8   16   -5   19   11   21    3
 14    9   14   -7   10    5   15    0    7    9   18  -13   34    0
 14    1   11    6   22    6   20    2   16    6   16   -5   14    2
 14   19   11   13   20    9   15    6   10   11    6    3   24    4
 18   12    8    4   21   13   12   -2   31    0   24    8   25    4
  9    1   16    6   15   13   24   12   27    2   16    8   17    2
 12   13   13    1   32    6    8   12   18   10   24   11   21    7
 22    8   10   14   15   12   22   10   31    5   23    8    9    4
  8    0   18   10   11   16   10    7    9   14   14   13   28    4
 20    8   20    3   27    4   17   16   20    6   11    3   28    8
 19    8   12    7   19   -3    6    2    5    6   11   -5    7    5
 14    6   24   12   10  -10    6    0   10    7   11    7   20   -3
 13   -2   17   -1   30    3   11   13   30    1   32    4   30    2
 18    0   11    8   20    9    8   25   14   15   18   19   17   14
 10    2   21    6   22    5   22   12   16   13   19   -5   33   -1
 30   -4   26    6   34    0   10    8   14   11   28    6   12   12
 33    2   21    4   14    6   25    6   24    7   24    1   20    7
 25    7   25    9   32    2   33    3   13    6   18   -2   28    9
 22    9   31    0   16    6   35    3   21   12   32    3   22   12
 16    8   10    6    8   12    8    0    6    8    9   10    8    1
  7    7    8    4    7    5    5   12   26    1   29    6   31    3
 32   -7   28    8   10   13   30    7   18   16   27    4   25    7
 16   12   22    6   30    2   22    9   23   11   29    6   30    5
 20    6   22    7   19    8   19   13   18    6   10   16   25    7
 23    3   27    4   15    7   26    6   20   11   26    8   13    0
 23   11   15    4   20    0   26    9   21   12   25    6   19   13
 16   16    7    4   17    8   18    4   19    3   25    5   26    4
 12   11   16    8   30    6   16    5   28   10   25   12   26    8
 26    6   28    4   18    4   33    1   11   11   29    0   14   16
 25    1   22    8   31    6   27    4   24   -5   15    4   25    7
 23    7   19    1   26    3   29   -1   29    7   18    1   30    5
 21   -4   16   12   23   10   31    4   31    3   25    7   21    7
 19    8   26    7   18   10   22    4   16    9   19    8   27    2
 25   11   19    9   20    6   19    7   20   10   23    4   20    3
 18    6   22   10   18   12   21    6   14   14   31    5   31    8
 34    3   27    6   26    5   25    2   35   -4   32   -1   26    4
 29    8   33    2   32    2   29    6   21    5   32    2   38   -2
 34    1   24    5   29    1   10   10    4    3    7    3    6    4
 10   17   11   -1    6   10   16    0   10    5    8    4    8    1
 15   12   12   12   18   12    7    8   18    8    7    1    9    3
  3    1    8   12   23    8   15   10    8    3   13   15    9    2
  7    0    4    5    9    0   12   -6    9    4   11   14    8   -1
  7    8    8   -1    5    3    4    2    6   -1    6    2    6    4
 28    6    9    6   12    1   16    0    5    9   13    2    4    7
  6    0   10    1   24   11   11   -5   13    5   11    0   17   -3
 14   -1    6   11   13    7   16   13   12   -2   13    3   21    8
 13    0   16    9   20    9   14   12    9    2   27   10   18   -6
 15    8    9   10    5   13   10    7   12    4   12    2   13    0
 10   -6    6   -3   11    6    7   -1    4    1   10    0    8    4
  7    6   12    3   23    5   27    5   20    4   17    5   17    1
 16    5   18    2   19    7   18    0   16    9   25    4   11    6
 20    1   26   -6   12    0   23    0   19    8   20    2   14   11
 25    7   28    8   13    6   24    8   23    8   20   12   22    3
 18    5   29    4   23    5   18    4   16    6   11    8   13    1
 14    6   29    4    4    6    1    5    8    3    5    5    7    1
  8   -2   10   -2   12   -5    9   -6    7   -3    7    1    4    5
  4    6    4   10   10    2    6    9    7    3    7    1   14    4
 26    9   18    9   33    0   14    5   27    6   25   -6   26    7
 25    1   22    8   20    9   21    6   22   12   38    0   22   10
 21    3   26    6   33    5   27    6   25    2   25   11   19   14
 20   12   19    7    7    6   11    7    8    4   12    3   11    9
 22    7    6    6   17   10   12    5   11    4    8    5   18   13
 13    6   15  -10   17    6   21    8   15    5   22    9    8   -1
 26    4    7    3   10    0   14   11   13   13   15   10   13    6
 19   14   34    4   21    4   26   11   20    0   24    6    9   17
  7   16   14    4   12    8   14    8   23   -2   30   -1   29    3
  9    6    5    7   13   15   14   -7   18    3    9    1   12   -5
 10   -1   19  -11   30   -1   12   -9    9   -2   23    3   14   -6
 16   15   26    4    8   -1    6    8   11   -2   13    8   10    0
 12    1   29    0   22    4   16    3   13   -7   18    3   15    6
 16   -4   12    1   20    8    9    3   26   -9   10   -2    4    8
  7    1    7    0   13   -6   10   -3    8    3   11   -6    9   -4
 11    0   10   -3    5   -1    4    2   13   -1    5    2    7    3
  7    4   10   -6    4   10    9   -2    8    0    9    4   14   -2
 11    4    5    6   15   11   19    6    6    6    7    5   14    6
  8   13   11    1    4    9   11    3   12    6   14    3    9    3
  6    3   12    1   24   -2   23   -1   13   -1   14    6   22   -3
 12   -1   19   -1    7    7   16    6   15   -5   27   -2   16    2
 12   -1    8    1   15    5   10    9    2    6   17   -3   19    3
 16   -6   14    3   10    2   14    4    8    2   13   -5    9    2
 17   11   12   14   30    5    6    4   15   18    7    7    9    3
  8    2   11   -3    9    3    8   -1    9   -3   18    6    4    6
 14    2   20    2    7   -3    9    1    8   12   21    6   21   10
 11    0   16   12   17    2   22    5   16    2   14    2    9    6
 25   -1   30    1   24   -7   31    6   26   -6   16   13   27    3
 22  -13   22    3   16    3   17    5   29    1   35   -3   31    0
 21   -3   16    2   26   -7   26   -4   25    2   32    3   18   12
 22   -7   20    7   24    8   30    1   27    4   15    0   27   -1
 21    4   16    8   24    9   32    5   13    5   18   14   19    6
  8    3   10    9   20    5   12   16   14   12   24   13   15    9
 12    8   14    6   15   14   16    1    9    6   15   10   19    7
 21   11   11   -3    9    8   18   11   19    8   18    9   29    0
 20    6   26    9   19    8   27    6   12   20   19    7   11    6
 10    7    6   -2   12   -2   11    5   19   11   21    6   14    4
 12    6   15    4   21    0   11    9    7   26   18   -3   12    7
 16    5   18    7   26    6   13    4   19    2   27    8   23    0
 17    9   16    4   12    7   16    0   23    9    9    8   17    8
 21    1    6   15    8   14   19   11   32    5   25   12   29    6
 24   10   21    7   32    6   18    8   19    2   30    4   24   11
 22    9   15   15   20    8   22   12   17   -1   19   11   11   13
 16    9   15   18   23    9   24    5   31   -1   23    4   24    7
 19   13    9   20   12   11   24    8   17   -1   16    8   25    7
 11   19   11   12   20   15    8    5   15    7   23   10   20    5
 16   14   10   14   15    9   21    3   20    9   14    2   11    6
 20    8   13    7   25    5   17    9   13    4   12    9   29    3
  7    9    9    1   16   -1   13    2    8    2    7   11   17    7
 17    9   15   -2   16    3    7    8    8    8   10    3   11   -2
  9    8   14   13    9   10   17    7   12    8   15   15    8    2
  8    8   13    5   13    4   10   -2    8   -4    9    3    9    0
  9    1    5    6   18   12   12    9    9    4   11    4    5    8
  9   -4   17    9   23    5   17    4   10   12    7    6   11    5
  6   11   11    4   15   16   17   15   23    7   16    6   10    0
 12    3   11    6    9    6   18    9   23    9   13   -1    7    7
  4    8   13    5    6    3   10    4   13   -2    8    6   10    3
  6    7   10   -2    6   10    6    0   18    0   21  -11    8   -2
  4    8   11   -2   16   14   24    9   30    2   19   13   27    6
 25    4   30    8   20    8   28    8   23    4   24   -2   22    3
 28    4   35    1   30    5   27    3   26    3   35    3   21    4
 25    9   30    3   18   11   27    6   23   10   24    7   22    6
 24    9   17    4   15    5   12   10   13    6   27    4   10    3
 18    8   19    2   19    6   13   11   11    3   13   12   17   13
 14   15   15    7   22   -3   11    3   22   10   14    6   25    6
 23    3   20   12   33    4   25    4   16   12   25    2   24    5
 31    1   24    8   37   -1   35    0   33    2   28    6   32   -2
 31    1   15   -3   33    3   36    0   30    0   18    7   28    6
 32    3   28    7   32    3   30    1   34    4   33   -1   14   12
 32   -8   22   10   21    3    6    2   12   13   18    0   14    6
 20    4   14   -7   14    6   15    9   14    0   12   -1   13    9
 23    2   13   -2   13    1   25    1   17   -4   22    2   13    9
 12   11   18   -5   15   -1   26  -14   25   -5   25    2   22    0
 20    9   20   -3   18    7   16   -2   14   -1   21    4   21   -5
 12    1   29    3   22    0   35    0   23    2   27    3   14    3
 31    4   18    3   20    6   12    2   15    5    6   10   15    1
 21    2   15   -4   13   -2    7    7   13    3   10    7   11   10
 10   -2   12    2   12   -2   16    3    6    5    7    5   11   17
 13   15   16    7   18   11    8   13   10    8   11    4   14   -4
 14    8    6    7    7   11   11    1   21    7   14    0   10    3
 10    1    6    3    8    0   18   14   22    7   15    1   24   -8
  9   10   17   -2   17    7   22    6   12    9   17    4   22    8
 15   -5   17    3   20    6   22   -2   10    5    6    5   22    6
 20   -4   13    5   24    6   27    6   24    9   27    2   17    8
 14    6   10   11   27    7   13    0   33    6    5   14    9    3
 27    0    7   11   16   15   32    4   15   11   17   17   18   11
 16    7   15    8   24    8   16   15    9    3   21    8    8    7
 12    5   18    1   33   -3   12   11   12    3   20   12   10    8
 27    4   21   10   12   12   17   10   13    5   14    0    8    5
 18   11   17   11   14   15   22    6   13    4    9   18   14    2
 11   14   17    6   24    7   15   11   21    5   11   10   15    7
 16    0   19    3   16    3   13    9   15    7   24    6   16    9
 19   12   15    4   14    5   15    3   15    8   10   14   16    2
  7    9   13    5   16   14   20    4   16   15   15   16   21    7
 18    3   11    0   14   -5   20   -1   20   -8    9    1   15    3
 11    1   16   -4   21  -14   17   -1   13    5   19    5   16   -3
 19   -2   30    0   23   -8   15   -6   20   -2   21   -2   25  -10
 15    3    9    1   11    3   10    5   12    9   12    0   16    1
  9    1   14   -1    9   -3    3    1    7    9   17    7    8    6
 10   -2   10    7   14    1   13   -3   14   -6   11    8   10    3
 14    1   10    3   13   10   14   11   10    8   11    6   12   -1
 13    3    9   -3    7   -1    4   -1   12   -9    6   -1   13   -8
  6    4   13   -6    6    2    8    1    2    1    9   -5    7   -1
  5    4    4    5    8   -2   10   -4   13   -7    9   -5   10    4
  8    4    5    6   11   -5   10    3    7    1    9    0   12   -3
  6    4    8    1    8    3    7    4    8    2    8   -1    8    0
 10   -5    6    1    8    1    7    5    4    4    7   -3    4    0
  5    3    6   -1   11   -3   10   -2    2    4    5    0    8   -1
 13   -1    8   -7    5    0    8    0    4    4    6    2    4    6
  9   -1    8    3    7    0   10    0   12   -3   13    1    9   -1
 10    1    9    6    5    3   14   -1    9    1   18   -2   18   -1
 12   -3   12   -3    8    7   12    7   12   -1   12    6    7    7
 10    5    7    9    8    2    7    0    7    2   15   -3   11   -1
  9    2    9   -2    9   -2   11   -3   11    5    6   12    7   10
 13   -2    9    2   14   -9    8   -3   11    6    7    2   10    2
 10   -2    6   -1    5    2    9   -5   12    5    8    0    7    4
  6    1    7   -2   12    3   11    8    9    5    9    1    7   -1
  8   -1    4    1    6    2    5    4   10    1   12   -1   11   -1
 10    4   16    4   11   -4    5    0    6    5    6    1   11   -1
 11    7    7    2   12   -5    9   -2    9    2   10   -3   11   11
 13   -1   17    5   14   -4    4    5    8    0   11   -3    4    1
  4    4   26    5    8   -5    5    5    6    3    7    3    9    4
  5    0    8    3   11    5    7   -2   21    3   10    0   14    1
  7    2    5    3   11   -2    9    3   12    1   12   -4    5    3
 13   -4   14    3   19   -1    6   -1    5   -1   12    1    7    1
  6    2   31    4   33    4   20    5   30    2   32    1   29    2
 29    6   13    7   31   -2   22    5   31    6   37    1   32    1
 28    7   37    0   29    5   32    2   31    0   28   -2   29    3
 22   11   35   -2   29    4   33   -1   31    3   31   -6   28    4
 24    2   30    2   36   -2   32    0   31    6   16    5   13    5
 11   -2   14   -1   10    1   13    7    8    9   15    9    5   14
 18    3    8    6    6    0    7   15   17    1   20    6   10    6
  9    6   11    1   20   -3    7   -1   13    8   11    1   12    5
 16    3   12   12
;

data sims; merge sims class;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 8.5                                       ---*/
proc mixed data=sims covtest cl;
   class class;
   model gain = pretot / s ddfm=kr;
   random int pretot / sub=class type=un s; 
   ods output solutionf=est solutionr=rand;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.6                                       ---*/
proc mixed data=sims info;
   model gain = pretot / s ddfm=satterth;
   random int pretot / sub=class type=un;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 8.4, Pig Growth                         ---*/
data pigsx;
   input trt pig day0 day6 day12 day18 day24 day30;
   datalines;
1   1  14.0  22.1  27.7  31.8  35.3  32.6
1   2  15.2  23.8  32.6  40.0  42.4  44.6
1   3  13.9  22.1  28.1  29.8  33.6  32.9
1   4  16.7  27.1  32.7  38.0  39.9  43.8
1   5  17.0  26.9  36.0  41.9  47.7  50.8
1   6  16.2  25.4  28.7  39.8  43.4  40.2
1   7  11.5  24.8  29.9  37.1  42.4  43.5
1   8  14.9  25.0  28.1  35.9  36.2  35.6
1   9  16.9  21.0  29.8  31.6  34.6  33.7
1  10  13.5  22.7  28.1  37.2  39.2  37.8
1  11  15.3  23.5  30.0  34.3  35.1  36.1
1  12  14.5  25.5  31.8  37.1  43.7  44.7
1  13  15.7  26.0  30.4  39.0  41.3  43.4
1  14  13.2  22.9  31.7  34.4  36.4  34.0
1  15  18.0  27.0  34.4  41.6  45.4  48.0
1  16  17.1  28.2  36.7  44.6  47.9  53.3
1  17  14.8  23.0  31.1  35.9  37.1  40.4
1  18  13.9  23.4  28.5  34.2  36.0  34.6
1  19  15.7  22.8  31.7  38.1  40.2  40.2
1  20  10.9  23.4  30.0  35.6  37.4  38.7
2   1  15.1  27.7  35.1  37.2  45.0  41.2
2   2  14.6  26.2  31.4  36.7  34.2  31.6
2   3  15.3  22.4  29.0  34.8  34.9  32.3
2   4  14.6  26.3  33.2  39.8  41.2  40.1
2   5  18.7  28.2  39.0  43.8  51.2  50.8
2   6  13.4  24.0  32.8  39.7  38.1  40.0
2   7  17.7  25.2  36.0  44.2  47.0  47.5
2   8  14.3  28.9  32.3  40.3  45.0  39.6
2   9  11.5  25.4  29.9  33.1  36.5  30.7
2  10  15.6  23.7  30.3  35.0  34.1  34.6
2  11  16.2  24.5  32.5  40.8  44.0  44.8
2  12  16.6  26.9  33.8  42.3  46.3  46.9
2  13  15.1  27.6  36.7  40.4  41.7  42.3
2  14  14.9  22.0  33.6  34.7  38.2  33.7
2  15  16.6  26.7  35.0  40.9  46.5  42.9
2  16  11.8  25.1  29.9  33.6  34.0  32.0
2  17  15.1  25.1  33.4  33.1  37.3  34.5
2  18  12.9  23.8  30.3  33.4  35.6  31.7
2  19  17.1  27.3  34.2  40.1  47.5  42.2
2  20  15.4  22.1  31.2  35.5  35.4  32.7
3   1  16.6  25.3  27.2  30.9  35.7  33.3
3   2  13.0  20.0  26.9  30.4  30.4  32.5
3   3  14.0  17.6  22.0  25.6  29.4  24.3
3   4   9.2  18.7  27.0  26.5  30.3  28.2
3   5  17.3  23.4  29.5  30.9  33.7  33.9
3   6  16.5  25.8  30.3  37.5  43.2  44.6
3   7  13.5  24.6  28.0  35.1  34.8  33.2
3   8  15.1  19.7  25.0  31.1  32.2  28.0
3   9  17.8  22.5  28.6  33.0  33.6  35.5
3  10  15.0  23.2  27.7  35.3  35.4  36.7
3  11  11.3  20.1  25.4  29.7  27.9  30.4
3  12  17.6  21.8  26.9  32.8  35.8  40.4
3  13  14.3  22.8  28.6  28.1  34.5  36.3
3  14  14.7  24.2  30.5  37.4  39.8  41.3
3  15  13.0  21.6  30.0  35.7  39.9  39.3
3  16  10.0  19.7  26.0  30.2  32.7  31.9
3  17  13.5  22.4  25.5  28.6  30.8  27.1
3  18  13.7  20.5  28.0  30.1  33.1  35.1
3  19  16.0  25.2  31.3  37.7  39.6  43.2
3  20  15.8  20.6  29.7  31.2  32.2  33.2
;

data pigs;
  set pigsx;
  array days{6} day:;
  do i=1 to 6;
     day = (i-1)*6;
     weight = days{i};
     output;
  end;
  keep trt pig weight day;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.7                                       ---*/
proc mixed data=pigs;
   class trt day pig;
   model weight=trt day day*trt / ddfm=kr;
   random pig / subject=trt;
   repeated day / subject=pig(trt) type=ar(1);
   lsmeans day*trt;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.8                                       ---*/
 /*---Output 8.9                                       ---*/
proc mixed data=pigs;
   class trt pig;
   model weight=trt day day*trt day*day day*day*trt/ddfm=kr;
   random int day day*day / subject=pig(trt) type=un; 

   lsmeans trt / at day=0 diff;
   lsmeans trt / at day=6 diff;
   lsmeans trt / at day=12 diff;
   lsmeans trt / at day=18 diff;
   lsmeans trt / at day=24 diff;
   lsmeans trt / at day=30 diff;
   ods output lsmeans=lsm diffs=diffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.10                                      ---*/
data pigs; set pigs;
  xday=day;
run;
proc mixed data=pigs;
  class trt pig xday;
  model weight=trt day day*trt day*day day*day*trt xday*trt/
                   ddfm=kr htype=1;
  random int day day*day/subject=pig(trt) type=un;
  ods select CovParms Tests1;
run;
 /*-------------------------------------------------------*/

