 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 31JAN06                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---CHAPTER 9: Heterogeneous Variance Models         ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 9.2, TV                                 ---*/
data tv;
   input child age sex $ time age_sex $;
   datalines;
 1  2  F  12  2F
 2  3  M  17  3M
 3  2  M  10  2M
 4  4  M  24  4M
 5  2  M  13  2M
 6  3  F  19  3F
 7  4  F  22  4F
 8  3  F  20  3F
 9  4  M  31  4M
10  4  F  32  4F
11  3  M  23  3M
12  3  F  16  3F
13  2  F   8  2F
14  2  M  14  2M
15  2  F   9  2F
16  4  F  39  4F
17  4  M  37  4M
18  3  F  11  3F
19  3  F  14  3F
20  3  M  22  3M
21  2  M  11  2M
22  2  F   7  2F
23  2  M  11  2M
24  3  M  16  3M
25  4  F  12  4F
26  4  M  49  4M
27  2  M  15  2M
;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 9.1                                       ---*/
proc glm data=tv;
   class age sex;
   model time=age*sex;
   means age*sex / hovtest=levene(type=abs) welch;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.2                                       ---*/
proc mixed data=tv covtest cl ic;
   class age sex;
   model time = sex|age / outp=R;
   lsmeans age sex / diff adjust=Tukey;
   ods select CovParms InfoCrit Lsmeans Diffs Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 9.1                                       ---*/
ods html;
ods graphics on;

proc mixed data=tv boxplot;
   class age_sex;
   model time = age_sex;
run;

ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.3                                       ---*/
data R1; set R;**Compute the absolute value of residuals;
   ABSR = ABS(RESID);
run;
proc glm data=R1;
   class age sex;
   model ABSR = age*sex;
run;

 /*-------------------------------------------------------*/
 /*---Output 9.4                                       ---*/
proc glm data=R1;
   class age sex;
   model ABSR = age sex age*sex;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.5                                       ---*/
proc mixed data=TV ic;
   class age sex;
   model time = sex|age / ddfm=KR outp=R;
   repeated / group=sex*age;
   lsmeans age sex / diff adjust=Tukey;
   ods select CovParms InfoCrit Lsmeans Diffs Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.6                                       ---*/
proc mixed data=TV ic;
   class age sex;
   model time=sex|age / DDFM=KR OUTP=R;
   repeated / group=age;
   lsmeans age sex / diff adjust=Tukey;
   ods select CovParms InfoCrit Lsmeans Diffs Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 9.3, LR                                 ---*/
data lr;
  input x y;
  datalines;
0.1  4
0.4  9
0.7  6
0.8  10
1.0  15
1.2  7
1.3  25
1.4  15
1.9  32
2.0  21
2.1  10
2.4  28
2.6  36
2.7  12
2.8  9
3.0  22
3.2  34
3.3  42
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.7                                       ---*/
proc mixed data=LR;
   model y = x / outp=preml outpm=pm_reml solution;
   repeated / local=exp(x);
   parms (1.0) (4.3);
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.8                                       ---*/
proc mixed data=LR method=ml;
   model y = x / outp=pml outpm=pm_ml solution;
   repeated / local=exp(x);
   parms (1.0) (4.3);
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.9                                       ---*/
proc nlmixed data=LR;
   parms a=4.5 b=7.5 c=.01 sig2=5;
   mean = a+b*x;
   model y ~ normal(mean,sig2*exp(c*x));
   predict mean out=mean df=16;
   ods select ParameterEstimates;
run;
 /*-------------------------------------------------------*/
 
 /*-------------------------------------------------------*/
 /*---Output 9.10                                      ---*/
proc mixed data=LR;
   model y = x / solution;
   ods output solutionf=est;
   ods select CovParms SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.11                                      ---*/
proc mixed data=LR;
   model y = x / solution;
   ods output solutionf=est;
   ods select CovParms SolutionF;
run;
data cov;
   input estimate;
   datalines;
 2
.2
;
proc mixed data=LR;
   model y=x/outp=pml outpm=pm_ml solution;
   repeated  / local=pom(est);
   parms /pdata=cov;
   ods select CovParms SolutionF;
   ods output covparms=cov1 solutionf=est1;
run;
proc compare data=est compare=est1;
   var estimate;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.12                                      ---*/
proc mixed data=LR;
   model y = x / solution;
   ods output solutionf=est;
   ods select CovParms SolutionF;
run;
data cov;
   input estimate;
   datalines;
 2
.2
;
%macro iterate;
  %let iter = 1;
  %let maxiter = 20;
  %let converged = 0;
  %do %while ((&iter < &maxiter) & (&converged = 0));
     proc mixed data=LR;
        model y=x / solution;
        repeated  / local=pom(est);
        parms /pdata=cov;
        ods select CovParms SolutionF;
        ods output covparms=cov1 solutionf=est1;
     run;
     data crit;
        merge est(rename=(estimate=est_old)) est1;
        diff = abs(est_old - estimate);
     run;
     proc means data=crit noprint;
        var diff;
        output out=max max=crit;
     run;
     data _null_; set max;
        converged = (crit < 1e-6);
        call symput('converged',left(put(converged,1.)));
     run;
     data est; set est1;
     data cov; set cov1;
     run;
     %let iter = %eval(&iter+1);
     %put iter = &iter;
     %put converged = &converged;
  %end;
  %if (&converged = 1) %then %do;
     /*---final run---*/
     proc mixed data=LR;
        model y=x / solution;
        repeated  / local=pom(est);
        parms / pdata=cov;
     run;
  %end;
%mend iterate;
%iterate;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.13                                      ---*/
proc mixed data=LR;
   model y=x/ solution;
   ods select covparms solutionf tests3;
   ods output solutionf=est;
run;
data cov;
   input estimate;
   datalines;
.1
3
;
%macro iterate;
  %let iter = 1;
  %let maxiter = 20;
  %let converged = 0;
  %do %while ((&iter < &maxiter) & (&converged = 0));
     proc mixed data=LR method=ml;
        model y=x / solution;
        repeated  / local=pom(est);
        parms /pdata=cov;
        ods select CovParms SolutionF;
        ods output covparms=cov1 solutionf=est1;
     run;
     data crit;
        merge est(rename=(estimate=est_old)) est1;
        diff = abs(est_old - estimate);
     run;
     proc means data=crit noprint;
        var diff;
        output out=max max=crit;
     run;
     data _null_; set max;
        converged = (crit < 1e-6);
        call symput('converged',left(put(converged,1.)));
     run;
     data est; set est1;
     data cov; set cov1;
     run;
     %let iter = %eval(&iter+1);
     %put iter = &iter;
     %put converged = &converged;
  %end;
  %if (&converged = 1) %then %do;
     /*---final run---*/
     proc mixed data=LR method=ml;
        model y=x / solution;
        repeated  / local=pom(est);
        parms / pdata=cov;
     run;
  %end;
%mend iterate;
%iterate;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.14                                      ---*/
proc nlmixed data=LR;
   parms a=4.5 b=7.5 T=1 sig2=5;
   mean = a+b*x;
   model y ~ normal(mean,sig2*abs(mean)**T);
   predict mean out=mean df=16;
   ods select ParameterEstimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*--Data Set 9.4, Sales                              ----*/
data sales;
   input region $ dist s1-s8;
   datalines;
NC  1  42.9  47.4  41.0  46.6  42.9  39.8  43.4    .
NC  2  38.7  47.7  42.3  42.8  42.0  41.4  42.7  41.5
NC  3  37.6  43.5  37.8  39.0  39.5  42.2  39.0  45.7
NE  1  42.4  44.6  36.9  43.8  37.4  43.4  44.4  37.7
NE  2  41.5  41.2  41.4  41.7  41.3  41.8  .       .
NE  3  42.0  48.9  40.6  45.8  45.8  45.5  .       .
NE  4  42.2  44.8  36.9  37.1  41.3  39.9  38.4  41.9
NE  5  43.6  40.7  39.7  44.4  47.9  49.1  49.0  44.8
NE  6  47.6  49.1  45.8  45.2    .     .     .     .
NE  7  42.5  41.1  38.4  40.4  37.0  35.3  41.9  43.0
NE  8  29.9  36.0  30.4  33.7  38.5  41.0  33.0  35.9
NW  1  33.1  40.7  37.5  34.8  36.2  38.7    .     .
NW  2  28.7  36.3  36.0  28.8    .     .     .     .
NW  3  35.5  32.8  33.3  32.5  35.6  34.9  28.4  32.7
SC  1  33.6  32.0  35.5  35.4  33.4  32.9  35.4  34.6
SC  2  35.6  31.0  42.1  34.8  34.7    .     .     .
SC  3  37.6  35.4  33.4  35.5  31.6  32.0  38.5    .
SC  4  32.6  31.0  32.1  31.3  25.7    .     .     .
SC  5  29.9  27.0  33.0  30.0  31.2  32.5    .     .
SC  6  28.3  30.0  35.7  33.4  24.7  26.9  31.4  32.3
SE  1  38.9  40.3  42.1  41.6  44.7  37.8  39.3  40.0
SE  2  47.6  38.8  41.1  43.2  47.0    .     .     .
SE  3  35.8  40.5  39.1  37.7  43.7  40.3  42.1    .
SE  4  27.7  33.6  31.1  31.5  31.6    .     .     .
SE  5  34.0  29.8  27.4  33.0  29.4  32.6  28.2    .
SE  6  22.0  28.2  29.3  25.5  19.6  26.5  27.3  21.8
SW  1  41.3  39.2  38.0  38.0  33.9    .     .     .
SW  2  49.2  47.4  45.8  52.1  48.5    .     .     .
SW  3  36.9  31.3  32.2  36.5  39.8  30.3  36.6  34.0
;
data sales_univ; 
   set sales;
   array sale{8} s1-s8;
   do i=1 to 8;
      sales = sale{i};
	  output; 
   end;
   drop s1-s8;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 9.15                                      ---*/
proc mixed data=sales_univ ic;
   title2 'Fit Equal variance model';
   class region dist;
   model sales = region / ddfm=kr outp=r;
   random dist(region) /solution;
   lsmeans region /diff adjust=tukey;
   ods output solutionr=random;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 9.7                                       ---*/
ods html;
ods graphics on;

proc mixed data=random boxplot;
   class region;
   model estimate = region;
run;

ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.16                                      ---*/
data random1; set random;
   absdist=abs(estimate);
run;
proc mixed data=random1 ic;
   class region;
   model absdist=region;
   lsmeans region/diff;
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/
 
 /*-------------------------------------------------------*/
 /*---Output 9.17                                      ---*/
data r1; set r;
   absr=abs(resid);
run;
title2 'Test equality of residual means for regions and district within regions';
proc mixed data=r1;
   class region dist;
   model absr=region dist(region);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.18                                      ---*/
title2 'Fit model to Sales data with unequal district within region variances';
proc mixed data=sales_univ ic;
   class region dist;
   model sales = region / ddfm=kr;
   random dist / group=region;
   lsmeans region / diff adjust=tukey;
run;
title;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 9.5, Dial                               ---*/
data dial;
   input sub qb tmp ufr index type;
   datalines;
 1  200  0.240   0.645  1  1
 1  200  0.505  20.115  2  1
 1  200  0.995  38.460  3  1
 1  200  1.485  44.985  4  1
 1  200  2.020  51.765  5  1
 1  200  2.495  46.575  6  1
 1  200  2.970  40.815  7  1
 2  200  0.240   3.720  1  1
 2  200  0.540  18.885  2  1
 2  200  0.995  34.695  3  1
 2  200  1.475  40.305  4  1
 2  200  2.000  44.475  5  1
 2  200  2.500  42.435  6  1
 2  200  3.010  44.655  7  1
 3  200  0.245   2.985  1  1
 3  200  0.480  17.700  2  1
 3  200  1.010  35.295  3  1
 3  200  1.505  41.955  4  1
 3  200  2.000  47.610  5  1
 3  200  2.515  44.730  6  1
 3  200  2.970  46.035  7  1
 4  200  0.255   3.930  1  1
 4  200  0.495  19.830  2  1
 4  200  0.995  40.425  3  1
 4  200  1.480  52.260  4  1
 4  200  1.995  49.395  5  1
 4  200  2.490  45.975  6  1
 4  200  3.030  41.910  7  1
 5  200  0.255   3.210  1  1
 5  200  0.515  17.700  2  1
 5  200  1.000  32.490  3  1
 5  200  1.505  42.330  4  1
 5  200  2.020  45.735  5  1
 5  200  2.490  47.850  6  1
 5  200  3.010  48.045  7  1
 6  200  0.260   3.660  1  1
 6  200  0.500  16.950  2  1
 6  200  1.020  36.090  3  1
 6  200  1.490  42.630  4  1
 6  200  1.990  46.470  5  1
 6  200  2.480  46.275  6  1
 6  200  2.995  43.980  7  1
 7  200  0.305   9.825  1  1
 7  200  0.505  21.630  2  1
 7  200  0.980  42.270  3  1
 7  200  1.505  50.280  4  1
 7  200  2.005  45.510  5  1
 7  200  2.505  44.250  6  1
 7  200  2.990  42.300  7  1
 8  200  0.305   9.480  1  1
 8  200  0.505  21.750  2  1
 8  200  0.995  37.230  3  1
 8  200  1.500  44.430  4  1
 8  200  1.990  42.165  5  1
 8  200  2.480  43.065  6  1
 8  200  3.000  36.615  7  1
 9  200  0.250   1.560  1  1
 9  200  0.495  16.650  2  1
 9  200  1.000  34.530  3  1
 9  200  1.500  43.815  4  1
 9  200  1.965  48.495  5  1
 9  200  2.485  47.520  6  1
 9  200  2.980  41.640  7  1
10  200  0.235   1.230  1  1
10  200  0.505  15.375  2  1
10  200  1.020  32.835  3  1
10  200  1.475  37.830  4  1
10  200  1.970  40.590  5  1
10  200  2.480  32.550  6  1
10  200  3.000  34.305  7  1
11  300  0.255   3.885  1  2
11  300  0.500  19.155  2  2
11  300  0.980  37.650  3  2
11  300  1.490  47.895  4  2
11  300  2.015  54.495  5  2
11  300  2.510  53.175  6  2
11  300  2.980  59.355  7  2
12  300  0.280   5.715  1  2
12  300  0.505  20.505  2  2
12  300  1.000  39.405  3  2
12  300  1.490  50.100  4  2
12  300  2.000  55.155  5  2
12  300  2.505  61.185  6  2
12  300  3.020  50.715  7  2
13  300  0.355  10.410  1  2
13  300  0.480  19.320  2  2
13  300  1.025  43.770  3  2
13  300  1.500  51.225  4  2
13  300  1.990  58.095  5  2
13  300  2.500  54.090  6  2
13  300  3.005  62.010  7  2
14  300  0.235   3.600  1  2
14  300  0.480  20.490  2  2
14  300  1.010  41.880  3  2
14  300  1.490  49.995  4  2
14  300  1.990  57.675  5  2
14  300  2.480  62.475  6  2
14  300  3.005  62.145  7  2
15  300  0.260   1.890  1  2
15  300  0.515  18.510  2  2
15  300  0.970  37.215  3  2
15  300  1.505  52.350  4  2
15  300  1.990  60.915  5  2
15  300  2.500  62.985  6  2
15  300  2.995  64.770  7  2
16  300  0.235   1.170  1  2
16  300  0.485  17.685  2  2
16  300  1.025  39.705  3  2
16  300  1.515  52.680  4  2
16  300  1.990  61.800  5  2
16  300  2.510  61.485  6  2
16  300  3.020  61.425  7  2
17  300  0.285   1.500  1  2
17  300  0.520  15.405  2  2
17  300  1.005  32.520  3  2
17  300  1.500  42.435  4  2
17  300  1.985  48.570  5  2
17  300  2.490  53.685  6  2
17  300  2.995  53.655  7  2
18  300  0.295   6.420  1  2
18  300  0.515  20.250  2  2
18  300  1.010  43.050  3  2
18  300  1.480  58.110  4  2
18  300  2.000  61.995  5  2
18  300  2.480  60.915  6  2
18  300  3.005  63.600  7  2
19  300  0.290   4.050  1  2
19  300  0.495  16.590  2  2
19  300  1.015  40.515  3  2
19  300  1.520  52.845  4  2
19  300  2.020  60.435  5  2
19  300  2.500  64.830  6  2
19  300  2.975  63.825  7  2
20  300  0.400  10.935  1  2
20  300  0.470  13.470  2  2
20  300  1.010  35.355  3  2
20  300  1.515  45.345  4  2
20  300  1.980  49.440  5  2
20  300  2.510  53.625  6  2
20  300  3.000  56.430  7  2
21  200  0.250    .     1  1
21  200  0.500    .     2  1
21  200  1.000    .     3  1
21  200  1.500    .     4  1
21  200  2.000    .     5  1
21  200  2.500    .     6  1
21  200  3.000    .     7  1
22  300  0.250    .     1  2
22  300  0.500    .     2  2
22  300  1.000    .     3  2
22  300  1.500    .     4  2
22  300  2.000    .     5  2
22  300  2.500    .     6  2
22  300  3.000    .     7  2
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 9.8                                       ---*/
axis2 value=( font=swiss height=.2 in)
      width=3
      value=(f=swissb h=.15 in ) ORDER = 0 TO 70 BY 10
      label=(f=swissb H=.16 in a=90 'UFR');
axis1 value=( font=swiss height=.2 in)
      width=3
      label=(f=swissb H=.16 in 'TMP')
      value=(f=swissb h=.15 in )  order=0 TO 3 By 1 ;
symbol1 v=none i=join r=11 l=1 c=black;
symbol2 v=none i=join r=11 l=3 c=black;
footnote f=swissb h=.15 in 
         "Solid lines are QB=200 and dashed lines are QB=300";
proc gplot data=dial;
   plot ufr*tmp=sub/nolegend vaxis=axis2 haxis=axis1;
run;
footnote;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.19                                      ---*/
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=un subject=sub r rcorr;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.20                                      ---*/
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=un subject=sub;
   ods output InfoCrit=icun;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=ar(1) subject=sub;
   ods output InfoCrit=icar;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=arh(1) subject=sub;
   ods output InfoCrit=icarh;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   random int tmp / subject=sub type=un;
   ods output InfoCrit=icrc;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=cs subject=sub;
   ods output InfoCrit=iccs;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=csh subject=sub;
   ods output InfoCrit=iccsh;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=fa(1) subject=sub;
   ods output InfoCrit=icfa;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=fa1(1) subject=sub;
   ods output InfoCrit=icfa1;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=hf subject=sub;
   ods output InfoCrit=ichf;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   random int tmp tmp*tmp / subject=sub type=un;
   ods output InfoCrit=icrcq;
   ods select InfoCrit;
run;
data ii;
   input parm row col1-col7;
   datalines;
1 1 1 1 1 1 1 1 1
1 2 1 1 1 1 1 1 1
1 3 1 1 1 1 1 1 1
1 4 1 1 1 1 1 1 1
1 5 1 1 1 1 1 1 1
1 6 1 1 1 1 1 1 1
1 7 1 1 1 1 1 1 1
2 2 0 1 1 1 1 1 1
2 3 0 1 1 1 1 1 1
2 4 0 1 1 1 1 1 1
2 5 0 1 1 1 1 1 1
2 6 0 1 1 1 1 1 1
2 7 0 1 1 1 1 1 1
3 3 0 0 1 1 1 1 1
3 4 0 0 1 1 1 1 1
3 5 0 0 1 1 1 1 1
3 6 0 0 1 1 1 1 1
3 7 0 0 1 1 1 1 1
4 4 0 0 0 1 1 1 1
4 5 0 0 0 1 1 1 1
4 6 0 0 0 1 1 1 1
4 7 0 0 0 1 1 1 1
5 5 0 0 0 0 1 1 1
5 6 0 0 0 0 1 1 1
5 7 0 0 0 0 1 1 1
6 6 0 0 0 0 0 1 1
6 7 0 0 0 0 0 1 1
7 7 0 0 0 0 0 0 1
;
 
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=lin(7) ldata=ii sub=sub r rcorr;
   ods output InfoCrit=iclin;
   ods select InfoCrit;
run;

data icun;  set icun ; length type $6; type="UN    ";
data icar;  set icar ; length type $6; type="AR(1) ";
data icarh; set icarh; length type $6; type="ARH(1)";
data iccs;  set iccs ; length type $6; type="CS    ";
data iccsh; set iccsh; length type $6; type="CSH   ";
data ichf;  set ichf ; length type $6; type="HF    ";
data icfa;  set icfa ; length type $6; type="FA(1) ";
data icfa1; set icfa1; length type $6; type="FA1(1)";
data icrc ; set icrc ; length type $6; type="RC    "; 
data icrcq; set icrcq; length type $6; type="RCQ   "; 
data iclin; set iclin; length type $6; type="I_I   "; 
run;

data models;
   set icun icar icarh iccs iccsh ichf icfa icfa1 icrc icrcq iclin;
   model = _n_;
proc print data=models;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 9.9                                       ---*/
 /*---Figure 9.10                                      ---*/
 /*---Figure 9.11                                      ---*/
 /*---Figure 9.12                                      ---*/
 /*---Figure 9.13                                      ---*/
 /*---Figure 9.14                                      ---*/
 /*---Figure 9.15                                      ---*/
 /*---Figure 9.16                                      ---*/
 /*---Figure 9.17                                      ---*/
symbol1  color=black font=swiss value='UN    ' repeat=1;
symbol2  color=black font=swiss value='AR(1) ' repeat=1;
symbol3  color=black font=swiss value='ARH(1)' repeat=1;
symbol4  color=black font=swiss value='CS    ' repeat=1;
symbol5  color=black font=swiss value='CSH   ' repeat=1;
symbol6  color=black font=swiss value='HF    ' repeat=1;
symbol7  color=black font=swiss value='FA(1) ' repeat=1;
symbol8  color=black font=swiss value='FA1(1)' repeat=1;
symbol9  color=black font=swiss value='RC    ' repeat=1;
symbol10 color=black font=swiss value='RCQ   ' repeat=1;
symbol11 color=black font=swiss value='I-I   ' repeat=1;

proc gplot data=models;
   plot aic *parms = model / nolegend;
   plot bic *parms = model / nolegend;
   plot aicc*parms = model / nolegend;
   plot hqic*parms = model / nolegend;
   plot caic*parms = model / nolegend;
   plot aic*bic    = model / nolegend;
   plot aic*aicc   = model / nolegend;
   plot aic*hqic   = model / nolegend;
   plot aic*caic   = model / nolegend;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.21                                      ---*/
proc mixed data=dial;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp / s;
   random int tmp tmp*tmp / type=un sub=sub;
   ods output solutionf=sf;
run;

data cp;
   input est;
   datalines;
  2.24606822 
 -3.73117853 
 24.08025511 
  0.68705846 
 -6.82952740 
  2.17225966
  1 
  0.0663507
;

%macro iterate;
  %let iter      = 1;
  %let maxiter   = 20;
  %let converged = 0;
  %do %while ((&iter < &maxiter) & (&converged = 0));
     proc mixed data=dial;
        class qb sub;
        model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp / s;
        random int tmp tmp*tmp / type=un sub=sub;
        repeated / local=pom(sf);
        parms / pdata=cp;
        ods output solutionf=sf1 covparms=cp1;
        ods select CovParms SolutionF;
     run;
     data crit;
        merge sf(rename=(estimate=est_old)) sf1;
        diff = abs(est_old - estimate);
     run;
     proc means data=crit noprint;
        var diff;
        output out=max max=crit;
     run;
     data _null_; set max;
        converged = (crit < 1e-6);
        call symput('converged',left(put(converged,1.)));
     run;
     data sf; set sf1;  
     data cp; set cp1; 
     run;
     %let iter = %eval(&iter+1);
     %put iter = &iter;
     %put converged = &converged;
  %end;
  %if (&converged = 1) %then %do;
     /*---final run---*/
     proc mixed data=dial;
        class qb sub;
        model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp / s;
        random int tmp tmp*tmp / type=un sub=sub;
        repeated / local=pom(sf);
        parms / pdata=cp;
     run;
  %end;
%mend iterate;
%iterate;
run;
 /*-------------------------------------------------------*/
 
 /*-------------------------------------------------------*/
 /*---Output 9.22                                      ---*/
proc mixed data=dial ic;
    class qb sub;
     model ufr = tmp tmp*tmp tmp*tmp*tmp 
                 tmp*tmp*tmp*tmp qb qb*tmp /outp=pred;
     random sub;
     repeated / type=arh(1) subject=sub;
     lsmeans qb / diff at tmp=.5;
     lsmeans qb / diff at tmp=.6;
     lsmeans qb / diff at tmp=.65;
     lsmeans qb / diff at tmp=.7;
     lsmeans qb / diff at tmp=.75;
     lsmeans qb / diff at tmp=1;
     lsmeans qb / diff at tmp=2;
     lsmeans qb / diff at tmp=3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 9.6, Grip                               ---*/
data grip; 
   input subject x trt Gender $ time t y;
   datalines;
26  175  1  M  1  1  161
26  175  1  M  2  2  210
26  175  1  M  3  3  230
27  165  1  M  1  1  215
27  165  1  M  2  2  245
27  165  1  M  3  3  265
29  175  1  M  1  1  134
29  175  1  M  2  2  215
29  175  1  M  3  3  139
34  178  1  M  1  1  165
34  178  1  M  2  2  140
34  178  1  M  3  3  175
35  220  1  M  1  1  220
35  220  1  M  2  2  189
35  220  1  M  3  3  158
38   90  1  M  1  1  146
38   90  1  M  2  2  140
38   90  1  M  3  3  130
42  300  1  M  1  1  300
42  300  1  M  2  2  300
42  300  1  M  3  3  300
44  238  1  M  1  1  278
44  238  1  M  2  2  170
44  238  1  M  3  3  158
54  200  1  M  1  1  230
54  200  1  M  2  2  220
54  200  1  M  3  3  240
57  130  1  M  1  1  155
57  130  1  M  2  2  170
57  130  1  M  3  3  125
74  215  1  M  1  1  230
74  215  1  M  2  2  243
74  215  1  M  3  3  245
76  207  1  M  1  1  220
76  207  1  M  2  2  .
76  207  1  M  3  3  .
79  225  1  M  1  1  220
79  225  1  M  2  2  250
79  225  1  M  3  3  235
 1  120  2  M  1  1  130
 1  120  2  M  2  2  150
 1  120  2  M  3  3  120
25  300  2  M  1  1  300
25  300  2  M  2  2  300
25  300  2  M  3  3  300
28  179  2  M  1  1  232
28  179  2  M  2  2  285
28  179  2  M  3  3  .
31  209  2  M  1  1  260
31  209  2  M  2  2  200
31  209  2  M  3  3  125
36  200  2  M  1  1  200
36  200  2  M  2  2  200
36  200  2  M  3  3  232
39  300  2  M  1  1  300
39  300  2  M  2  2  300
39  300  2  M  3  3  300
41  200  2  M  1  1  245
41  200  2  M  2  2  290
41  200  2  M  3  3  280
43  172  2  M  1  1  170
43  172  2  M  2  2  170
43  172  2  M  3  3  146
45  158  2  M  1  1  140
45  158  2  M  2  2  152
45  158  2  M  3  3  150
47  150  2  M  1  1  220
47  150  2  M  2  2  168
47  150  2  M  3  3  139
53  135  2  M  1  1  155
53  135  2  M  2  2  215
53  135  2  M  3  3  170
56   75  2  M  1  1  170
56   75  2  M  2  2  220
56   75  2  M  3  3  240
58  150  2  M  1  1  200
58  150  2  M  2  2  185
58  150  2  M  3  3  163
61  155  2  M  1  1  101
61  155  2  M  2  2   93
61  155  2  M  3  3  120
73  190  2  M  1  1  240
73  190  2  M  2  2  210
73  190  2  M  3  3  173
75  265  2  M  1  1  275
75  265  2  M  2  2  255
75  265  2  M  3  3  270
 2   80  1  F  1  1   80
 2   80  1  F  2  2   86
 2   80  1  F  3  3   80
 4   64  1  F  1  1   80
 4   64  1  F  2  2   80
 4   64  1  F  3  3   70
 5   40  1  F  1  1   60
 5   40  1  F  2  2  .
 5   40  1  F  3  3  .
 8   40  1  F  1  1   50
 8   40  1  F  2  2   30
 8   40  1  F  3  3   40
 9   70  1  F  1  1   90
 9   70  1  F  2  2  110
 9   70  1  F  3  3   90
15   70  1  F  1  1   80
15   70  1  F  2  2   95
15   70  1  F  3  3  110
18   70  1  F  1  1   80
18   70  1  F  2  2   86
18   70  1  F  3  3  .
19   70  1  F  1  1   60
19   70  1  F  2  2   70
19   70  1  F  3  3   80
21   50  1  F  1  1   80
21   50  1  F  2  2   90
21   50  1  F  3  3   90
24   40  1  F  1  1   60
24   40  1  F  2  2   60
24   40  1  F  3  3   65
40  140  1  F  1  1  156
40  140  1  F  2  2  140
40  140  1  F  3  3  150
46  110  1  F  1  1   82
46  110  1  F  2  2   98
46  110  1  F  3  3  110
48  180  1  F  1  1  165
48  180  1  F  2  2  150
48  180  1  F  3  3  160
50  155  1  F  1  1  150
50  155  1  F  2  2  170
50  155  1  F  3  3  185
52   55  1  F  1  1  105
52   55  1  F  2  2   70
52   55  1  F  3  3   88
59   95  1  F  1  1   90
59   95  1  F  2  2   90
59   95  1  F  3  3  116
63   90  1  F  1  1  135
63   90  1  F  2  2   95
63   90  1  F  3  3  .
64  145  1  F  1  1  140
64  145  1  F  2  2  164
64  145  1  F  3  3  .
70   34  1  F  1  1   51
70   34  1  F  2  2   87
70   34  1  F  3  3  .
 3   60  2  F  1  1   80
 3   60  2  F  2  2   60
 3   60  2  F  3  3   60
 6   50  2  F  1  1   70
 6   50  2  F  2  2   70
 6   50  2  F  3  3   70
 7   80  2  F  1  1   75
 7   80  2  F  2  2   90
 7   80  2  F  3  3   90
10   80  2  F  1  1  100
10   80  2  F  2  2   80
10   80  2  F  3  3   90
13   80  2  F  1  1   60
13   80  2  F  2  2   65
13   80  2  F  3  3   70
17   58  2  F  1  1   50
17   58  2  F  2  2   80
17   58  2  F  3  3   80
20   60  2  F  1  1   60
20   60  2  F  2  2   80
20   60  2  F  3  3   60
22   80  2  F  1  1   90
22   80  2  F  2  2  120
22   80  2  F  3  3  130
23   60  2  F  1  1   90
23   60  2  F  2  2   94
23   60  2  F  3  3  100
30   75  2  F  1  1  131
30   75  2  F  2  2   95
30   75  2  F  3  3  105
37  150  2  F  1  1  108
37  150  2  F  2  2  160
37  150  2  F  3  3  160
49   55  2  F  1  1   60
49   55  2  F  2  2   65
49   55  2  F  3  3   55
51  130  2  F  1  1  130
51  130  2  F  2  2  160
51  130  2  F  3  3  125
55  115  2  F  1  1   95
55  115  2  F  2  2  105
55  115  2  F  3  3  110
62  135  2  F  1  1  120
62  135  2  F  2  2  144
62  135  2  F  3  3  135
65   60  2  F  1  1   85
65   60  2  F  2  2   85
65   60  2  F  3  3  .
67   40  2  F  1  1   45
67   40  2  F  2  2   76
67   40  2  F  3  3   75
71  104  2  F  1  1  107
71  104  2  F  2  2  .
71  104  2  F  3  3  .
72   60  2  F  1  1   60
72   60  2  F  2  2   55
72   60  2  F  3  3   58
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.23                                      ---*/
proc mixed data=grip;
   class subject trt Gender time;
   model y = trt|Gender|time x time*x Gender*x trt*x;
   repeated / type=un subject=subject r rcorr;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.24                                      ---*/
proc mixed data=grip;
   class subject trt gender time;
   model y = trt|gender|time x time*x gender*x trt*x;
   repeated / type=un sub=subject group=gender
              r=1,2 rcorr=1,2;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 9.21                                      ---*/
 /*---Figure 9.22                                      ---*/
proc mixed data=grip;
   class subject trt gender time;
   model y = trt|gender|time x time*x gender*x trt*x / outp=p;
   id time subject gender;
run; 

symbol i=join c=black r=38;
proc gplot data=p;
   where gender = 'F';
   plot resid*time=subject / nolegend hminor=0;
run;

symbol i=join c=black r=29;
proc gplot data=p;
   where gender = 'M';
   plot resid*time=subject / nolegend hminor=0;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.25                                      ---*/
proc mixed data=grip;
   class subject trt gender time;
   model y = trt|gender|time x time*x gender*x trt*x;
   random int t / type=un sub=subject group=gender;
   ods select CovParms FitStatistics Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.26                                      ---*/
proc mixed data=grip;
   class subject trt gender time;
   model y = trt|gender|time x time*x gender*x trt*x;
   random int t / type=un sub=subject group=gender;
   repeated / sub=subject group=gender;
   ods select CovParms FitStatistics Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 9.7, Preetch                           ---*/
data preetch;
   input expt wafer mask viscos spin baketemp baketime 
          aperture expos develop etch y1-y5;
    y = y1; loc = 'top'; output;
    y = y2; loc = 'cen'; output;
    y = y3; loc = 'bot'; output;
    y = y4; loc = 'lef'; output;
    y = y5; loc = 'rig'; output;
    drop y1-y5;
    datalines;
 1  1  -1  -1  -1  -1  -1  -1  -1  -1  -1  2.43  2.52  2.63  2.52  2.50
 1  2  -1  -1  -1  -1  -1  -1  -1  -1  -1  2.36  2.50  2.62  2.43  2.49
 2  1  -1  -1   0  -1   0   0   0   0   0  2.76  2.66  2.74  2.60  2.53
 2  2  -1  -1   0  -1   0   0   0   0   0  2.66  2.73  2.95  2.57  2.64
 3  1  -1  -1   1  -1   1   1   1   1   1  2.82  2.71  2.78  2.55  2.36
 3  2  -1  -1   1  -1   1   1   1   1   1  2.76  2.67  2.90  2.62  2.43
 4  1  -1   1  -1  -1  -1   0   0   1   1  2.02  2.06  2.21  1.98  2.13
 4  2  -1   1  -1  -1  -1   0   0   1   1  1.85  1.66  2.07  1.81  1.83
 5  1  -1   1   0  -1   0   1   1  -1  -1  1.87  1.78  2.07  1.80  1.83
 6  1  -1   1   1  -1   1  -1  -1   0   0  2.51  2.56  2.55  2.45  2.53
 6  2  -1   1   1  -1   1  -1  -1   0   0  2.68  2.60  2.85  2.55  2.56
 7  1  -1  -1  -1   1   0  -1   1   0   1  1.99  1.99  2.11  1.99  2.00
 7  2  -1  -1  -1   1   0  -1   1   0   1  1.96  2.20  2.04  2.01  2.03
 8  1  -1  -1   0   1   1   0  -1   1  -1  3.15  3.44  3.67  3.09  3.06
 8  2  -1  -1   0   1   1   0  -1   1  -1  3.27  3.29  3.49  3.02  3.19
 9  1  -1  -1   1   1  -1   1   0  -1   0  3.00  2.91  3.07  2.66  2.74
 9  2  -1  -1   1   1  -1   1   0  -1   0  2.73  2.79  3.00  2.69  2.70
10  1   1  -1  -1  -1   1   1   0   0  -1  2.69  2.50  2.51  2.46  2.40
10  2   1  -1  -1  -1   1   1   0   0  -1  2.75  2.73  2.75  2.78  3.03
11  1   1  -1   0  -1  -1  -1   1   1   0  3.20  3.19  3.32  3.20  3.15
11  2   1  -1   0  -1  -1  -1   1   1   0  3.07  3.14  3.14  3.13  3.12
12  1   1  -1   1  -1   0   0  -1  -1   1  3.21  3.32  3.33  3.23  3.10
12  2   1  -1   1  -1   0   0  -1  -1   1  3.48  3.44  3.49  3.25  3.38
13  1   1   1  -1  -1   0   1  -1   1   0  2.60  2.56  2.62  2.55  2.56
13  2   1   1  -1  -1   0   1  -1   1   0  2.53  2.49  2.79  2.50  2.56
14  1   1   1   0  -1   1  -1   0  -1   1  2.18  2.20  2.45  2.22  2.32
14  2   1   1   0  -1   1  -1   0  -1   1  2.33  2.20  2.41  2.37  2.38
15  1   1   1   1  -1  -1   0   1   0  -1  2.45  2.50  2.51  2.43  2.43
16  1   1  -1  -1   1   1   0   1  -1   0  2.67  2.53  2.72  2.70  2.60
16  2   1  -1  -1   1   1   0   1  -1   0  2.76  2.67  2.73  2.69  2.60
17  1   1  -1   0   1  -1   1  -1   0   1  3.31  3.30  3.44  3.12  3.14
17  2   1  -1   0   1  -1   1  -1   0   1  3.12  2.97  3.18  3.03  2.95
18  1   1  -1   1   1   0  -1   0   1  -1  3.46  3.49  3.50  3.45  3.57
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.27                                     ---*/
title "Initial Model with Equal Variances";
proc mixed data=preetch ic;
   class expt wafer mask viscos spin baketemp 
         baketime aperture expos develop loc;
   model y = mask viscos spin baketemp 
             baketime aperture expos develop 
             loc loc*mask loc*viscos loc*spin loc*baketemp 
             loc*baketime loc*aperture 
             loc*expos loc*develop / outp=pred ddfm=kr;
   random int / sub=wafer(expt);
   ods select CovParms InfoCrit Tests3;
   ods output InfoCrit=ic_init
              Tests3  =t3_init;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.28                                      ---*/
proc mixed data=preetch covtest ic;
   title "Model with Local=exp(all terms)";
   class expt wafer mask viscos spin baketemp 
         baketime aperture expos develop loc;
   model y = mask viscos spin baketemp 
             baketime aperture expos develop loc loc*mask
             loc*viscos loc*spin loc*baketemp loc*baketime
             loc*aperture loc*expos loc*develop / 
                          outp=pred ddfm=kr;
   random int / sub=wafer(expt);
   repeated  / subject=wafer(expt)  
               local=exp(mask viscos spin baketemp baketime 
                         aperture expos develop); 
   ods select CovParms InfoCrit Tests3;
   ods output InfoCrit=ic_full
              Tests3  =t3_full;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.29                                      ---*/
proc mixed data=preetch ic;
   title "Model with Local=exp(reduced terms)";
   class expt wafer mask viscos spin baketemp 
         baketime aperture expos develop loc;
    model y = mask viscos spin baketemp 
          baketime aperture expos develop loc loc*mask
          loc*viscos loc*spin loc*baketemp loc*baketime
          loc*aperture loc*expos loc*develop/outp=pred ddfm=kr;
   random int / sub=wafer(expt);
   repeated/subject=wafer(expt) local=exp( develop expos);
   ods select CovParms InfoCrit Tests3;
   ods output InfoCrit=ic_red
              Tests3  =t3_red;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.30                                      ---*/
proc mixed data=preetch ic;
   title "UN cov matrix for locs";
   class expt wafer mask viscos spin baketemp 
         baketime aperture expos develop loc;
   model y = mask viscos spin baketemp baketime aperture
             expos develop loc loc loc*mask loc*viscos 
             loc*spin loc*baketemp loc*baketime 
             loc*aperture loc*expos loc*develop/ ddfm=bw;
   repeated loc/sub=wafer(expt) type=un;
   ods select CovParms InfoCrit Tests3;
   ods output InfoCrit=ic_un
              Tests3  =t3_un;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.31                                      ---*/
data ic_un;   set ic_un;   length model $7; model='Un     ';
data ic_red;  set ic_red;  length model $7; model='Reduced';
data ic_full; set ic_full; length model $7; model='Full   ';
data ic_init; set ic_init; length model $7; model='Initial';
run;
data models; set ic_init ic_full ic_red ic_un;
proc print data=models;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.32                                      ---*/
data tests;
   merge t3_init(rename=(ProbF=Initial))
         t3_full(rename=(ProbF=Full   ))
         t3_red (rename=(ProbF=Reduced))
         t3_un  (rename=(ProbF=UN     ));
   keep Effect NumDf Initial Full Reduced Un;
proc print data=tests;
run;
 /*-------------------------------------------------------*/

