 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* SAS for Mixed Models, Second Edition                              */
 /* by Ramon C. Littell, George A. Milliken, Walter W. Stroup,        */
 /*    Russell D. Wolfinger, Oliver Schabenberger                     */
 /* Copyright (c) 2006 by SAS Institute Inc., Cary, NC, USA           */
 /* SAS Publications order   1-59047-500-3                            */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /*                                                                   */
 /* This material is provided "as is" by SAS Institute Inc.  There    */
 /* are no warranties, expressed or implied, as to merchantability or */
 /* fitness for a particular purpose regarding the materials or code  */
 /* contained herein. The Institute is not responsible for errors     */
 /* in this material as it now exists or will exist, nor does the     */
 /* Institute provide technical support for it.                       */
 /*                                                                   */
 /*-------------------------------------------------------------------*/
 /* Date Last Updated: 25MAR09                                        */
 /*-------------------------------------------------------------------*/
 /* Questions or problem reports concerning this material may be      */
 /* addressed to the authors:                                         */
 /*                                                                   */
 /* SAS Institute Inc.                                                */
 /* SAS Press                                                         */
 /* Attn: Ramon C. Littell, George A. Milliken, Walter W. Stroup,     */
 /*       Russell D. Wolfinger, Oliver Schabenberger                  */
 /* SAS Campus Drive                                                  */
 /* Cary, NC   27513                                                  */
 /*                                                                   */
 /* If you prefer, you can send e-mail to:  saspress@sas.com          */
 /* Use this for subject field:                                       */
 /*    Comments for Ramon C. Littell, George A. Milliken,             */
 /*    Walter W. Stroup, Russell D. Wolfinger, Oliver Schabenberger   */ 
 /*                                                                   */
 /*-------------------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Notes                                            ---*/ 
 /*---                                                 ---*/
 /*---This file contains the SAS code for SAS for      ---*/
 /*---Mixed Models, Second Edition.                    ---*/
 /*---To run the code for the book successfully,       ---*/
 /*---you need the following                           ---*/
 /*---                                                 ---*/
 /*---  1) SAS 9.1 (or 9.1.2, 9.1.3) with the modules  ---*/
 /*---     SAS/BASE                                    ---*/
 /*---     SAS/STAT                                    ---*/
 /*---     SAS/GRAPH                                   ---*/
 /*---     SAS/IML (for Chapter 12 only)               ---*/
 /*---     licensed and installed                      ---*/
 /*---                                                 ---*/
 /*---  2) In SAS 9.1, to run examples that contain    ---*/
 /*---     PROC GLIMMIX code, you need to download     ---*/
 /*---     PROC GLIMMIX from www.sas.com/statistics    ---*/
 /*---     and install it. PROC GLIMMIX in SAS 9.1     ---*/
 /*---     requires a standalone installation of SAS   ---*/
 /*---     on the 32-bit Windows platform              ---*/
 /*---                                                 ---*/
 /*---The code is organized by chapters.               ---*/
 /*---                                                 ---*/
 /*---Many programs make use of the ODS SELECT state-  ---*/
 /*---ment in order to reduce the procedure output     ---*/
 /*---to what is shown in the book. For example,       ---*/
 /*---                                                 ---*/
 /*---    Output 4.21                                  ---*/
 /*---      proc mixed data=variety_eval;              ---*/
 /*---        class block type dose;                   ---*/
 /*---        model y=type logdose(type) ld_sq /noint  ---*/
 /*---                     ddfm=satterth solution;     ---*/
 /*---        random block block*dose;                 ---*/
 /*---        ods select SolutionF;                    ---*/
 /*---      run;                                       ---*/
 /*---                                                 ---*/
 /*---To see the full output of the procedure,         ---*/
 /*---remove the ODS SELECT statements.                ---*/
 /*-------------------------------------------------------*/



 /*-------------------------------------------------------*/
 /*---CHAPTER 2: Randomized Block Designs              ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 2.2, Bond                               ---*/
data bond;
  input ingot metal $ pres;
  datalines;
1   n   67.0
1   i   71.9
1   c   72.2
2   n   67.5
2   i   68.8
2   c   66.4
3   n   76.0
3   i   82.6
3   c   74.5
4   n   72.7
4   i   78.1
4   c   67.3
5   n   73.1
5   i   74.2
5   c   73.2
6   n   65.8
6   i   70.8
6   c   68.7
7   n   75.6
7   i   84.9
7   c   69.0
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.1 and 2.2                               ---*/
proc mixed data=bond covtest cl method=type3;
   class ingot metal;
   model pres = metal / ddfm=kr;
   random ingot;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.3                                       ---*/
proc mixed data=bond method=reml;
   class ingot metal;
   model pres=metal;
   random ingot;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.4 and 2.5                               ---*/
proc mixed data=bond;
   class ingot metal;
   model pres = metal / solution; 
   random ingot;
   lsmeans metal / diff cl;
   estimate 'nickel mean' intercept 1 metal 0  0 1;
   estimate 'copper vs iron'          metal 1 -1 0;
   contrast 'copper vs iron'          metal 1 -1 0;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.6                                       ---*/
proc mixed data=bond method=reml;
   class ingot metal;
   model pres=metal;
   random ingot;
   lsmeans metal / diff cl
                  adjust=simulate(report seed=4943838 cvadjust);
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figures 2.1 and 2.2                              ---*/
ods html;
ods graphics on;
proc glimmix data=bond plots=diffplot;
   class ingot metal;
   model pres=metal; 
   random ingot;
   lsmeans metal;
   lsmeans metal / adjust=simulate(seed=4943838);
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 2.7                                       ---*/
proc mixed data=bond covtest cl method=type3;
   class ingot metal;
   model pres=metal / ddfm=kr;
   random ingot;
   ods select Type3 CovParms;
   ods output type3=type3;
run;
data est_var_ingot;
   merge type3(where=(source='ingot')
               rename=(ms=msingot df=dfingot))
         type3(where=(source='Residual')
               rename=(ms=mserror df=dferror));
   var_Ingot    = (msingot-mserror)/3;
    df_var_ingot = (var_ingot**2)/((((msingot/3)**2)/dfingot)+
                   (((mserror/3)**2)/dferror));
    low_var_ingot= df_var_ingot*var_ingot/cinv(.975,df_var_ingot);
    up_var_ingot = df_var_ingot*var_ingot/cinv(.025,df_var_ingot);
run;
proc print data=est_var_ingot;
  var msingot dfingot mserror dferror 
      var_ingot df_var_ingot
      low_var_ingot up_var_ingot;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 2.8                                       ---*/
proc glm data=bond;
   class ingot metal;
   model pres = metal ingot / ss3;
   random ingot;
   lsmeans metal / pdiff 
                   adjust=simulate(report seed=4943838 cvadjust);
   estimate 'nickel mean' intercept 1 metal 0  0 1;
   estimate 'copper vs iron'          metal 1 -1 0;
   contrast 'nickel mean' intercept 1 metal 0  0 1;
   contrast 'copper vs iron'          metal 1 -1 0;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 2.5 PBIB                                ---*/
data pbib_mv;
  input blk trt1 y1 trt2 y2 trt3 y3 trt4 y4;
  datalines;
1   15  2.4 9   2.5 1   2.6 13  2.0
2   5   2.7 7   2.8 8   2.4 1   2.7
3   10  2.6 1   2.8 14  2.4 2   2.4
4   15  3.4 11  3.1 2   2.1 3   2.3
5   6   4.1 15  3.3 4   3.3 7   2.9
6   12  3.4 4   3.2 3   2.8 1   3.0
7   12  3.2 14  2.5 15  2.4 8   2.6
8   6   2.3 3   2.3 14  2.4 5   2.7
9   5   2.8 4   2.8 2   2.6 13  2.5
10  10  2.5 12  2.7 13  2.8 6   2.6
11  9   2.6 7   2.6 10  2.3 3   2.4
12  8   2.7 6   2.7 2   2.5 9   2.6
13  5   3.0 9   3.6 11  3.2 12  3.2
14  7   3.0 13  2.8 14  2.4 11  2.5
15  10  2.4 4   2.5 8   3.2 11  3.1
;
 /*---convert data set to univariate form              ---*/
data pbib; 
   set pbib_mv;
   array tx{4} trt1-trt4;
   array yy{4} y1-y4;
   do i=1 to 4;
      treat    = tx{i};
      response = yy{i};
      output;
   end;
   keep blk treat response;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 2.9                                       ---*/
proc glm data=pbib;
   class blk treat;
   model response=blk treat;
   random blk;
   lsmeans treat / stderr pdiff;
   estimate 'treat 1 mean' intercept 1 treat 1;
   estimate 'trt 1 mean' intercept 15 treat 15
             blk 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 / divisor=15;
   estimate 'trt 1 blk 1' intercept 1 treat 1 blk 1;
   estimate 'trt 1 vs trt 2' treat 1 -1;
   contrast 'trt 1 vs trt 2' treat 1 -1; 
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 2.10                                      ---*/
proc mixed data=pbib;
   class blk treat;
   model response=treat;
   random blk;
   estimate 'treat 1 mean' intercept 1  treat 1;
   estimate 'trt 1 mean'   intercept 15 treat 15 |
             blk 1 1 1 1 1 1 1 1 1 1 1 1 1 1 1 / divisor=15;
   estimate 'trt 1 vs trt 2' treat 1 -1;
   contrast 'trt 1 vs trt 2' treat 1 -1;
   lsmeans treat / diff;
   ods exclude diffs; 
   ods output diffs=difmix;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.11                                      ---*/
 /*---Construct a data set containing all pairs of     ---*/
 /*---treatments that occur together in a block        ---*/
data pairs; 
   set pbib_mv;
   array tx{4} trt1-trt4;
   array yy{4} y1-y4;
   do i=1 to 3; do j=(i+1) to 4;
      treat    = min(tx{i},tx{j});
      _treat   = max(tx{i},tx{j});
      output;
   end; end;
   keep blk treat _treat;
run;
proc sort data=pairs nodupkey; by treat _treat; run;
proc print data=pairs(obs=23); run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 2.12 and Output 2.13                      ---*/
proc sort data=difmix; by treat _treat;
data diffs; 
   merge difmix pairs; by treat _treat;
run;

proc print data=diffs(where=(blk=.)) noobs; 
   var treat _treat estimate stderr probt;
run;

proc print data=diffs(where=((blk ne .) and (treat <=2))) noobs; 
   var treat _treat estimate stderr probt;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---CHAPTER 3: Random Effects Models                 ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 3.3, Mississippi River                  ---*/
data influent;
  input influent y type @@;
  datalines;
1   21  2 1   27  2 1   29  2 1   17  2 1   19  2
1   12  2 1   29  2 1   20  2 1   20  2 2   21  2
2   11  2 2   18  2 2   9   2 2   13  2 2   23  2
2   2   2 3   20  1 3   19  1 3   20  1 3   11  1
3   14  1 4   14  2 4   24  2 4   30  2 4   21  2
4   31  2 4   27  2 5   7   1 5   15  1 5   18  1
5   4   1 5   28  1 6   41  3 6   42  3 6   35  3
6   34  3 6   30  3
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.1                                       ---*/
proc mixed data=influent covtest cl;
   class influent;
   model y = /solution;
   random influent / solution;

   estimate 'influent 1' intercept 1 | influent 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 | influent 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 | influent 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 | influent 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 | influent 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 | influent 0 0 0 0 0 1;

   estimate 'influent 1U' | influent 1 0 0 0 0 0;
   estimate 'influent 2U' | influent 0 1 0 0 0 0;
   estimate 'influent 3U' | influent 0 0 1 0 0 0;
   estimate 'influent 4U' | influent 0 0 0 1 0 0;
   estimate 'influent 5U' | influent 0 0 0 0 1 0;
   estimate 'influent 6U' | influent 0 0 0 0 0 1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.2                                       ---*/
proc mixed data=influent method=ml;
   class influent;
   model y = / solution;
   random influent / solution;
   estimate 'influent 1' intercept 1 | influent 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 | influent 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 | influent 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 | influent 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 | influent 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 | influent 0 0 0 0 0 1;

   estimate 'influent 1U' | influent 1 0 0 0 0 0;
   estimate 'influent 2U' | influent 0 1 0 0 0 0;
   estimate 'influent 3U' | influent 0 0 1 0 0 0;
   estimate 'influent 4U' | influent 0 0 0 1 0 0;
   estimate 'influent 5U' | influent 0 0 0 0 1 0;
   estimate 'influent 6U' | influent 0 0 0 0 0 1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.3                                       ---*/
proc mixed data=influent method=mivque0;
   class influent;
   model y = / solution;
   random influent / solution;
   estimate 'influent 1' intercept 1 | influent 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 | influent 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 | influent 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 | influent 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 | influent 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 | influent 0 0 0 0 0 1;

   estimate 'influent 1U' | influent 1 0 0 0 0 0;
   estimate 'influent 2U' | influent 0 1 0 0 0 0;
   estimate 'influent 3U' | influent 0 0 1 0 0 0;
   estimate 'influent 4U' | influent 0 0 0 1 0 0;
   estimate 'influent 5U' | influent 0 0 0 0 1 0;
   estimate 'influent 6U' | influent 0 0 0 0 0 1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.4                                       ---*/
proc mixed data=influent method=type1;
   class influent;
   model y = / solution;
   random influent / solution;
   estimate 'influent 1' intercept 1 | influent 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 | influent 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 | influent 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 | influent 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 | influent 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 | influent 0 0 0 0 0 1;

   estimate 'influent 1U' | influent 1 0 0 0 0 0;
   estimate 'influent 2U' | influent 0 1 0 0 0 0;
   estimate 'influent 3U' | influent 0 0 1 0 0 0;
   estimate 'influent 4U' | influent 0 0 0 1 0 0;
   estimate 'influent 5U' | influent 0 0 0 0 1 0;
   estimate 'influent 6U' | influent 0 0 0 0 0 1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.5                                       ---*/
proc mixed data=influent noprofile; 
   class influent;
   model y = / solution;
   random influent / solution;
   parms (70) (25) / noiter;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.6                                       ---*/    
proc glm data=influent; 
   class influent;
   model y = influent;
   random influent / test;

   estimate 'Mean'       intercept 6 influent 1 1 1 1 1 1 / divisor=6;
   estimate 'Influent 1' intercept 6 influent 6 0 0 0 0 0 / divisor=6;
   estimate 'Influent 2' intercept 6 influent 0 6 0 0 0 0 / divisor=6;
   estimate 'Influent 3' intercept 6 influent 0 0 6 0 0 0 / divisor=6;
   estimate 'Influent 4' intercept 6 influent 0 0 0 6 0 0 / divisor=6;
   estimate 'Influent 5' intercept 6 influent 0 0 0 0 6 0 / divisor=6;
   estimate 'Influent 6' intercept 6 influent 0 0 0 0 0 6 / divisor=6;

   estimate 'Influent 1U' influent  5 -1 -1 -1 -1 -1 / divisor=5;
   estimate 'Influent 1U' influent -1  5 -1 -1 -1 -1 / divisor=5;
   estimate 'Influent 1U' influent -1 -1  5 -1 -1 -1 / divisor=5;
   estimate 'Influent 1U' influent -1 -1 -1  5 -1 -1 / divisor=5;
   estimate 'Influent 1U' influent -1 -1 -1 -1  5 -1 / divisor=5;
   estimate 'Influent 1U' influent -1 -1 -1 -1 -1  5 / divisor=5;
run;
quit;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.7                                       ---*/
data satt;
   /* c = coefficient of var(influent) in e(ms influent) */
   c      = 6.0973;
   mssite = 1319.77936508/31;  * ms error;
   msi    = 1925.19360789/5;   * ms influent;
   sa2    = 56.16672059;       *estimate of var(influent);
   /* approximate degrees of freedom*/;
   v      = (sa2**2)/((((msi/c)**2)/5)+(((mssite/c)**2)/31)); 
   c025   = cinv(.025,v); * lower  2.5 chi square percentage point;
   c975   = cinv(.975,v); * upper 97.5 chi square percentage point;
   low    = v*sa2/C975;   * lower limit;
   high   = v*sa2/C025;   * upper limit;
run; 
proc print data=satt; 
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 3.8 and Output 3.9                        ---*/
proc mixed data=influent covtest cl; 
   class type influent;
   model y=type/solution;
   random influent(type)/solution;
   estimate 'influent 1' intercept 1 type 0 1 0 | 
                         influent(type) 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 type 0 1 0 | 
                         influent(type) 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 type 1 0 0 | 
                         influent(type) 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 type 0 1 0 | 
                         influent(type) 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 type 1 0 0 | 
                         influent(type) 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 type 0 0 1 | 
                         influent(type) 0 0 0 0 0 1;
   lsmeans type / diff;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.10                                      ---*/
proc mixed data=influent method=type3; 
   class type influent;
   model y=type/solution;
   random influent(type)/solution;

   estimate 'influent 1' intercept 1 type 0 1 0 | 
                         influent(type) 1 0 0 0 0 0;
   estimate 'influent 2' intercept 1 type 0 1 0 | 
                         influent(type) 0 1 0 0 0 0;
   estimate 'influent 3' intercept 1 type 1 0 0 | 
                         influent(type) 0 0 1 0 0 0;
   estimate 'influent 4' intercept 1 type 0 1 0 | 
                         influent(type) 0 0 0 1 0 0;
   estimate 'influent 5' intercept 1 type 1 0 0 | 
                         influent(type) 0 0 0 0 1 0;
   estimate 'influent 6' intercept 1 type 0 0 1 | 
                         influent(type) 0 0 0 0 0 1;
   lsmeans type / diff;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.11                                      ---*/
proc glm data=influent; 
   class type influent;
   model y = type influent(type);
   random influent(type) / test;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 3.4, Semiconductor                      ---*/
data e_3_4;
  input source lot wafer site Thick @@;
  datalines;
1 1 1 1 2006 1 1 1 2 1999 1 1 1 3 2007 1 1 2 1 1980
1 1 2 2 1988 1 1 2 3 1982 1 1 3 1 2000 1 1 3 2 1998
1 1 3 3 2007 1 2 1 1 1991 1 2 1 2 1990 1 2 1 3 1988
1 2 2 1 1987 1 2 2 2 1989 1 2 2 3 1988 1 2 3 1 1985
1 2 3 2 1983 1 2 3 3 1989 1 3 1 1 2000 1 3 1 2 2004
1 3 1 3 2004 1 3 2 1 2001 1 3 2 2 1996 1 3 2 3 2004
1 3 3 1 1999 1 3 3 2 2000 1 3 3 3 2002 1 4 1 1 1997
1 4 1 2 1994 1 4 1 3 1996 1 4 2 1 1996 1 4 2 2 2000
1 4 2 3 2002 1 4 3 1 1987 1 4 3 2 1990 1 4 3 3 1995
2 5 1 1 2013 2 5 1 2 2004 2 5 1 3 2009 2 5 2 1 2023
2 5 2 2 2018 2 5 2 3 2010 2 5 3 1 2020 2 5 3 2 2023
2 5 3 3 2015 2 6 1 1 2032 2 6 1 2 2036 2 6 1 3 2030
2 6 2 1 2018 2 6 2 2 2022 2 6 2 3 2026 2 6 3 1 2009
2 6 3 2 2010 2 6 3 3 2011 2 7 1 1 1984 2 7 1 2 1993
2 7 1 3 1993 2 7 2 1 1992 2 7 2 2 1992 2 7 2 3 1990
2 7 3 1 1996 2 7 3 2 1993 2 7 3 3 1987 2 8 1 1 1996
2 8 1 2 1989 2 8 1 3 1996 2 8 2 1 1997 2 8 2 2 1993
2 8 2 3 1996 2 8 3 1 1990 2 8 3 2 1989 2 8 3 3 1992
;

 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.12                                      ---*/
proc mixed data=e_3_4 Method=REML;
   class lot wafer site;
   Model Thick=;
   random lot wafer(lot);
run; 
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 3.13                                      ---*/ 
proc mixed data=e_3_4 Method=Type1;
   class lot wafer site;
   Model Thick=;
   random lot wafer(lot);
   ods select type1 CovParms;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.14                                      ---*/
proc mixed data=e_3_4;
   class source lot wafer site;
   model Thick = source / ddfm=KR;
   random lot(source) wafer(source lot);
   lsmeans source / diff;
   ods select CovParms LsMeans Diffs;
run; 
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.15                                      ---*/
proc mixed data=e_3_4 scoring=4;
   class source lot wafer site;
   model Thick = source/ ddfm=KR;
   random lot / group=source;
   random wafer(source lot);
   lsmeans source / diff;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 3.5, Genetics                           ---*/
data e_3_5;
 input loc block fam Yield @@;
  datalines;
1  1  1  268 1  2  1  279 1  3  1  261 1  1  2  242
1  2  2  261 1  3  2  258 1  1  3  242 1  2  3  245
1  3  3  234 1  1  4  225 1  2  4  231 1  3  4  219
1  1  5  236 1  2  5  260 1  3  5  248 2  1  1  238
2  2  1  220 2  3  1  243 2  1  2  215 2  2  2  192
2  3  2  226 2  1  3  198 2  2  3  151 2  3  3  191
2  1  4  195 2  2  4  182 2  3  4  202 2  1  5  201
2  2  5  161 2  3  5  196 3  1  1  221 3  2  1  216
3  3  1  224 3  1  2  208 3  2  2  197 3  3  2  201
3  1  3  186 3  2  3  173 3  3  3  161 3  1  4  207
3  2  4  183 3  3  4  186 3  1  5  200 3  2  5  207
3  3  5  190 4  1  1  194 4  2  1  194 4  3  1  197
4  1  2  203 4  2  2  191 4  3  2  204 4  1  3  177
4  2  3  170 4  3  3  180 4  1  4  180 4  2  4  195
4  3  4  193 4  1  5  199 4  2  5  183 4  3  5  208
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 3.16                                      ---*/
proc mixed data=e_3_5 covtest cl;
   class loc fam block;
   model Yield =;
   random loc fam loc*fam block(loc);
run; 
 /*-------------------------------------------------------*/
 
 /*-------------------------------------------------------*/
 /*---Output 3.17                                      ---*/
proc mixed data=e_3_5 method=type3;
   class loc fam block;
   model Yield=;
   random loc fam loc*fam block(loc);
   ods select CovParms type3;
run; 
 /*-------------------------------------------------------*/

/*-------------------------------------------------------*/
 /*---CHAPTER 4: Multi-Factor Treatment Designs with   ---*/
 /*---           Multiple Error Terms                  ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 4.4, Semiconductor Split-Plot Experiment --*/
data ex_4_4;
  input resistance et wafer position @@;
  datalines;
5.22  1  1  1 5.61  1  1  2 6.11  1  1  3
6.33  1  1  4 6.13  1  2  1 6.14  1  2  2
5.60  1  2  3 5.91  1  2  4 5.49  1  3  1
4.60  1  3  2 4.95  1  3  3 5.42  1  3  4
5.78  2  1  1 6.52  2  1  2 5.90  2  1  3
5.67  2  1  4 5.77  2  2  1 6.23  2  2  2
5.57  2  2  3 5.96  2  2  4 6.43  2  3  1
5.81  2  3  2 5.83  2  3  3 6.12  2  3  4
5.66  3  1  1 6.25  3  1  2 5.46  3  1  3
5.08  3  1  4 6.53  3  2  1 6.50  3  2  2
6.23  3  2  3 6.84  3  2  4 6.22  3  3  1
6.29  3  3  2 5.63  3  3  3 6.36  3  3  4
6.75  4  1  1 6.97  4  1  2 6.02  4  1  3
6.88  4  1  4 6.22  4  2  1 6.54  4  2  2
6.12  4  2  3 6.61  4  2  4 6.05  4  3  1
6.15  4  3  2 5.55  4  3  3 6.13  4  3  4
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.1                                       ---*/
proc mixed data=ex_4_4;
   class et wafer position;
   model resistance=et position et*position;
   random wafer(et);
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.2                                       ---*/
proc mixed data=ex_4_4 method=Type3;
   class et wafer position;
   model resistance=et position et*position;
   random wafer(et);
   ods select Type3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.3                                       ---*/
proc mixed data=ex_4_4;
   class et wafer position;
   model resistance=et position et*position;
   random wafer(et);
   lsmeans et position et*position;
   ods select lsmeans;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.4                                       ---*/
proc mixed data=ex_4_4;
   class et wafer position;
   model resistance=et position et*position;
   random wafer(et);
   lsmeans position / df=18.7;
   ods select lsmeans;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.5                                       ---*/
proc mixed data=ex_4_4;
   class wafer et position;
   model resistance=et|position / ddfm=satterth;
   random wafer(et);
   lsmeans position / diff;
   estimate 'pos1 vs pos3'       position 1 0 -1 0;
   contrast 'pos1 vs pos3'       position 1 0 -1 0;
   estimate 'pos 3 vs others'    position 1 1 -3 1 / divisor=3; 
   estimate 'pos3 v oth - wrong' position 1 1 -3 1; 
   contrast 'pos 3 vs others'    position 1 1 -3 1;
   ods select Estimates Contrasts Diffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.6                                       ---*/
proc mixed data=ex_4_4;
   class wafer et position;
   model resistance=et|position / ddfm=satterth;
   random wafer(et);
   lsmeans position/diff=control('3') adjust=dunnett;
   ods select Diffs;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 4.7                                       ---*/
proc mixed data=ex_4_4;
   class wafer et position;
   model resistance=et|position / ddfm=satterth;
   random wafer(et);
   lsmeans et*position / slice=(et position);
   estimate 'pos 1 vs 3 in et4' 
             position 1 0 -1 0 
             et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 0 -1 0;
   estimate 'pos 1 vs 3 in et1' 
             position 1 0 -1 0 
             et*position 1 0 -1 0;
   estimate 'pos3 vs others in et=4' 
             position 1 1 -3 1 
             et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 1 -3 1 / divisor=3;
   estimate 'pos3 vs others in et<4' 
             position 3 3 -9 3 
             et*position 1 1 -3 1 1 1 -3 1 1 1 -3 1 0/ divisor=9;
   estimate 'et1 vs et2 in pos 2' 
             et 1 -1 0 0 
             et*position 0 1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0;
   estimate 'et1 vs others in pos 1' 
             et -3 1 1 1 
             et*position -3 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0 / divisor=3;
   estimate 'et1 vs others in pos 2' 
             et -3 1 1 1 
             et*position 0 -3 0 0 0 1 0 0 0 1 0 0 0 1 0  / divisor=3;
   contrast 'pos 1 vs 3 in et4' 
             position 1 0 -1 0 
             et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 0 -1 0;
   contrast 'pos 1 vs 3 in et1' 
             position 1 0 -1 0 

             et*position 1 0 -1 0;
   contrast 'pos3 vs others in et=4' 
             position 1 1 -3 1 
             et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 1 -3 1;
   contrast 'pos3 vs others in et<4' 
             position 3 3 -9 3 
             et*position 1 1 -3 1 1 1 -3 1 1 1 -3 1 0;
   contrast 'et1 vs et2 in pos 2' 
             et 1 -1 0 0 
             et*position 0 1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0;
   contrast 'et1 vs others in pos 1' 
             et -3 1 1 1 
             et*position -3 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0;
   contrast 'et1 vs others in pos 2' 
             et -3 1 1 1 
             et*position 0 -3 0 0 0 1 0 0 0 1 0 0 0 1 0;
   ods select Slices Estimates Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.8                                       ---*/
proc mixed data=ex_4_4;
   class wafer et position;
   model resistance=et|position / ddfm=satterth;
   random wafer(et);
   lsmeans et*position / diff=control('1' '1');
   lsmeans et*position / diff=control('1' '2');
   lsmeans et*position / diff=control('1' '3');
   lsmeans et*position / diff=control('1' '4');
   ods exclude lsmeans diffs;
   ods output diffs=simpeff;
run;
 
data smpeff_dunnett;
   set simpeff;
   if position=_position;
proc print data=smpeff_dunnett;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 4.9                                       ---*/
proc glimmix data=ex_4_4;
   class et wafer position;
   model resistance=et position et*position/ddfm=kr;
   random wafer(et);
   lsmeans et*position / slice=(et position) diff=control ('1' '2');
   lsmestimate et*position 
      'pos 1 vs 3 in et1' 1 0 -1 0,
      'pos 1 vs 3 in et4' 0 0 0 0 0 0 0 0 0 0 0 0 1 0 -1 0; 
   lsmestimate et*position 
      'pos3 vs others in et=4' 0 0 0 0 0 0 0 0 0 0 0 0 1 1 -3 1,
      'pos3 vs others in et<4' 1 1 -3 1 1 1 -3 1 1 1 -3 1 0 /
                               divisor=3,9;
   lsmestimate et*position
      'et1 vs et2 in pos 2'  0 1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0;
   lsmestimate et*position 
      'et1 vs others in pos 1' -3 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0, 
      'et1 vs others in pos 2'  0 -3 0 0 0 1 0 0 0 1 0 0 0 1 0 / 
                                divisor=3;
run;

 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.10, Output 4.11, Output 4.12            ---*/
proc glm data=ex_4_4;
   class et wafer position;
   model resistance=et wafer(et) position et*position;
   random wafer(et)/test;
   lsmeans et/ e=wafer(et) stderr tdiff;
   lsmeans position/ stderr tdiff;
   lsmeans et*position / slice=(et position);
   estimate 'pos 1 vs 3 in et4' 
            position 1 0 -1 0 
            et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 0 -1 0;
   estimate 'pos 1 vs 3 in et1' 
            position 1 0 -1 0 

            et*position 1 0 -1 0;
   estimate 'pos3 vs others in et=4' 
            position 1 1 -3 1 
            et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 1 -3 1 / 
            divisor=3;
   estimate 'pos3 vs others in et<4' 
            position 3 3 -9 3 
            et*position 1 1 -3 1 1 1 -3 1 1 1 -3 1 0/ divisor=9;
   estimate 'et1 vs et2 in pos 2' 
            et 1 -1 0 0 
            et*position 0 1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0;
   estimate 'et1 vs others in pos 1' 
            et -3 1 1 1 
            et*position -3 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0 / 
            divisor=3;
   estimate 'et1 vs others in pos 2' 
            et -3 1 1 1 
            et*position 0 -3 0 0 0 1 0 0 0 1 0 0 0 1 0  / 
            divisor=3;
   contrast 'pos 1 vs 3 in et4' 
            position 1 0 -1 0 
            et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 0 -1 0;
   contrast 'pos 1 vs 3 in et1' 
            position 1 0 -1 0 
            et*position 1 0 -1 0;
   contrast 'pos3 vs others in et=4' 
            position 1 1 -3 1 
            et*position 0 0 0 0 0 0 0 0 0 0 0 0 1 1 -3 1;
   contrast 'pos3 vs others in et<4' 
            position 3 3 -9 3 
            et*position 1 1 -3 1 1 1 -3 1 1 1 -3 1 0;
   contrast 'et1 vs et2 in pos 2' 
            et 1 -1 0 0 
            et*position 0 1 0 0 0 -1 0 0 0 0 0 0 0 0 0 0;
   contrast 'et1 vs others in pos 1' 
            et -3 1 1 1 
            et*position -3 0 0 0 1 0 0 0 1 0 0 0 1 0 0 0;
   contrast 'et1 vs others in pos 2' 
            et -3 1 1 1 
            et*position 0 -3 0 0 0 1 0 0 0 1 0 0 0 1 0;
   lsmeans et*position / tdiff=control('1' '1');
   lsmeans et*position / tdiff=control('1' '2');
   lsmeans et*position / tdiff=control('1' '3');
   lsmeans et*position / tdiff=control('1' '4');
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 4.6, Variety-Pesticide Evaluation       ---*/
data variety_eval;
  input block type $ dose logdose y;
  datalines;
1  r  1  0  15.7
2  r  1  0  23.1
3  r  1  0  15.9
4  r  1  0  20.8
5  r  1  0  24.5
1  r  2  1  25.1
2  r  2  1  29.2
3  r  2  1  29.7
4  r  2  1  28.6
5  r  2  1  26.6
1  r  4  2  27.9
2  r  4  2  29.7
3  r  4  2  24.0
4  r  4  2  29.7
5  r  4  2  29.6
1  r  8  3  23.8
2  r  8  3  31.2
3  r  8  3  21.8
4  r  8  3  23.3
5  r  8  3  23.9
1  s  1  0  19.8
2  s  1  0  17.8
3  s  1  0  13.2
4  s  1  0  14.8
5  s  1  0  19.7
1  s  2  1  21.2
2  s  2  1  29.3
3  s  2  1  26.0
4  s  2  1  27.5
5  s  2  1  22.0
1  s  4  2  29.3
2  s  4  2  27.2
3  s  4  2  26.0
4  s  4  2  31.5
5  s  4  2  27.9
1  s  8  3  22.8
2  s  8  3  33.0
3  s  8  3  25.2
4  s  8  3  27.2
5  s  8  3  20.8
;
 /*-------------------------------------------------------*/
 
 /*-------------------------------------------------------*/
 /*---Output 4.13 and Output 4.14                      ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y = type|dose / ddfm=satterth;
   random block block*dose;
   lsmeans type*dose / slice=(type dose);
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 4.2                                       ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y = type|dose / ddfm=satterth;
   random block block*dose;
   lsmeans type*dose;
   ods output lsmeans=typedosemeans;
run;

axis1 value=(font=swiss h=2) 
      label=(angle=90 f=swiss h=2 'Dose x Type Mean');
axis2 value=(font=swiss h=2)
      label=(f=swiss h=2 'Dose');
axis3 value=(font=swiss h=2)
      label=(f=swiss h=2 'LogDose');
legend1 value=(font=swiss h=2) 
        label=(f=swiss h=2 'Variety Type');
symbol1 color=black interpol=join line=1 value=square; 
symbol2 color=black interpol=join line=2 value=circle; 

data to_plot;
   set typedosemeans;
   logdose=log2(dose);
run;
proc gplot data=to_plot;
   plot estimate*logdose=type/haxis=axis3 
                              vaxis=axis1 
                              legend=legend1;
   plot estimate*dose   =type/haxis=axis2
                              vaxis=axis1
                              legend=legend1;
run; quit;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 4.3                                       ---*/
ods html file="test.html";
ods graphics on;
ods select MeanPlot;
proc glimmix data=variety_eval;
   class block type dose;
   model y = type|dose / ddfm=satterth;
   random block block*dose;
   lsmeans type*dose / plot=meanplot(sliceby=type join cl);
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.15                                      ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y = dose|type / ddfm=satterth;
   random block block*dose;
   contrast 'dose linear'   dose -11 -7   1 17;
   contrast 'dose quad'     dose  20 -4 -29 13;
   contrast 'dose cubic'    dose  -8 14  -7  1;
   contrast 'type x linear' dose*type -11 -7   1 17  11  7  -1 -17;
   contrast 'type x quad'   dose*type  20 -4 -29 13 -20   4 29 -13;
   contrast 'type x cubic'  dose*type -8  14  -7  1   8 -14  7  -1;
   ods select Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.16                                      ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y = dose|type / ddfm=satterth;
   random block block*dose;
   contrast 'logdose linear' dose -3 -1  1 3;
   contrast 'logdose quad'   dose  1 -1 -1 1;
   contrast 'logdose cubic'  dose -1  3 -3 1;
   contrast 'type x linear'  dose*type -3 -1  1 3  3  1 -1 -3;
   contrast 'type x quad'    dose*type  1 -1 -1 1 -1  1  1 -1;
   contrast 'type x cubic'   dose*type -1  3 -3 1  1 -3  3 -1;
   ods select Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.17                                      ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y = type dose(type) / ddfm=satterth;
   random block block*dose;
   contrast 'linear LogD | type R' dose(type) -3 -1  1 3 0;
   contrast 'quad LogD   | type R' dose(type)  1 -1 -1 1 0;
   contrast 'cubic LogD  | type R' dose(type) -1  3 -3 1 0;
   contrast 'linear LogD | type S' dose(type) 0 0 0 0 -3 -1  1 3;
   contrast 'quad LogD   | type S' dose(type) 0 0 0 0  1 -1 -1 1;
   contrast 'cubic LogD  | type S' dose(type) 0 0 0 0 -1  3 -3 1;
   ods select Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.18                                      ---*/
proc mixed data=variety_eval;
   class block type dose; 
   model y=type|logdose|logdose / ddfm=satterth 
                                  solution htype=1;
   random block block*dose;
   ods select Tests1 SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.19                                      ---*/
proc mixed data=variety_eval;
   class block type dose; 
   model y=type|logdose|logdose / ddfm=satterth 
                                  solution htype=1;
   random block block*dose;

   estimate 'B_0    for type R' intercept 1 type 1 0;
   estimate 'B_Lin  for type R' logdose 1 logdose*type 1 0;
   estimate 'B_quad for type R' logdose*logdose 1 
                                logdose*logdose*type 1 0;
   estimate 'B_0    for type S' intercept 1 type 0 1;
   estimate 'B_Lin  for type S' logdose 1 logdose*type 0 1;
   estimate 'B_quad for type S' logdose*logdose 1
                                logdose*logdose*type 0 1;
   ods select Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.20                                      ---*/
data variety_eval;
   set variety_eval;
   ld_sq = (log2(dose))**2;
run;
proc mixed data=variety_eval;
   class block type dose;
   model y = type logdose(type) ld_sq(type) / noint ddfm=satterth 
                                              solution;
   random block block*dose;
   contrast 'equal quad by type?' ld_sq(type) 1 -1;
   ods select SolutionF Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.21                                      ---*/
proc mixed data=variety_eval;
   class block type dose;
   model y=type logdose(type) ld_sq /noint ddfm=satterth solution;
   random block block*dose;
   ods select SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 4.7 Mouse Condition--Diet Experiment    ---*/
data mice;
  input cage condition diet $ gain;
  datalines;
1   1   normal    58
1   1   restrict    58
1   1   suppleme    58
1   2   normal      54
1   2   restrict    46
1   2   suppleme    57
2   1   normal      49
2   1   restrict    50
2   1   suppleme    57
2   3   normal      57
2   3   restrict    53
2   3   suppleme    62
3   1   normal      59
3   1   restrict    58
3   1   suppleme    57
3   4   normal      63
3   4   restrict    61
3   4   suppleme    65
4   2   normal      57
4   2   restrict    64
4   2   suppleme    52
4   3   normal      63
4   3   restrict    67
4   3   suppleme    51
5   2   normal      53
5   2   restrict    46
5   2   suppleme    51
5   4   normal      58
5   4   restrict    52
5   4   suppleme    61
6   3   normal      65
6   3   restrict    64
6   3   suppleme    54
6   4   normal      59
6   4   restrict    47
6   4   suppleme    73
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.23                                      ---*/ 
proc mixed data=mice;
   class cage condition diet;
   model gain = condition|diet/ddfm=satterth;
   random cage cage*condition;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.24                                     ---*/ 
proc glm data=mice;
   class cage condition diet;
   model gain = cage condition cage*condition / ss3;
   ods output ModelAnova=anova;
run;
data anova; set anova(where=(HypothesisType=3));
   if Source='cage*condition' then do;
       source = 'Error';
       Fvalue = .;
       ProbF  = .;
   end;
proc print data=anova label;
   var source df ss MS;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 4.25                                      ---*/
title 'NOBOUND';
proc mixed data=mice nobound;
   class cage condition diet;
   model gain = condition | diet / ddfm=kr;
   random cage cage*condition;
   ods select CovParms Tests3;
run;
title 'Method=Type3';
proc mixed data=mice method=type3;
   class cage condition diet;
   model gain = condition | diet / ddfm=kr;
   random cage cage*condition;
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.26                                      ---*/
proc mixed data=mice;
   class cage condition diet;
   model gain=condition|diet / ddfm=kr;
   random cage; 
   repeated / type=cs subject=cage*condition r rcorr;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 4.27                                      ---*/
proc glm data=mice;
   class cage condition diet;
   model gain=condition|diet cage cage*condition;
   lsmeans condition diet condition*diet;
run; 
 /*-------------------------------------------------------*/

*-------------------------------------------------------*/
 /*---CHAPTER 5: Analysis of Repeated Measures Data    ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 5.2 Respiratory Ability                 ---*/ 
data FEV1;
  input patient basefev1 fev11h fev12h fev13h fev14h fev15h 
        fev16h fev17h fev18h drug $;
  datalines;
 201  2.46  2.68 2.76 2.50 2.30 2.14 2.40 2.33 2.20 a
 202  3.50  3.95 3.65 2.93 2.53 3.04 3.37 3.14 2.62 a
 203  1.96  2.28 2.34 2.29 2.43 2.06 2.18 2.28 2.29 a
 204  3.44  4.08 3.87 3.79 3.30 3.80 3.24 2.98 2.91 a
 205  2.80  4.09 3.90 3.54 3.35 3.15 3.23 3.46 3.27 a
 206  2.36  3.79 3.97 3.78 3.69 3.31 2.83 2.72 3.00 a
 207  1.77  3.82 3.44 3.46 3.02 2.98 3.10 2.79 2.88 a
 208  2.64  3.67 3.47 3.19 2.19 2.85 2.68 2.60 2.73 a
 209  2.30  4.12 3.71 3.57 3.49 3.64 3.38 2.28 3.72 a
 210  2.27  2.77 2.77 2.75 2.75 2.71 2.75 2.52 2.60 a
 211  2.44  3.77 3.73 3.67 3.56 3.59 3.35 3.32 3.18 a
 212  2.04  2.00 1.91 1.88 2.09 2.08 1.98 1.70 1.40 a
 214  2.77  3.36 3.42 3.28 3.30 3.31 2.99 3.01 3.08 a
 215  2.96  4.31 4.02 3.38 3.31 3.46 3.49 3.38 3.35 a
 216  3.11  3.88 3.92 3.71 3.59 3.57 3.48 3.42 3.63 a
 217  1.47  1.97 1.90 1.45 1.45 1.24 1.24 1.17 1.27 a
 218  2.73  2.91 2.99 2.87 2.88 2.84 2.67 2.69 2.77 a
 219  3.25  3.59 3.54 3.17 2.92 3.48 3.05 3.27 2.96 a
 220  2.73  2.88 3.06 2.75 2.71 2.83 2.58 2.68 2.42 a
 221  3.30  4.04 3.94 3.84 3.99 3.90 3.89 3.89 2.98 a
 222  2.85  3.38 3.42 3.28 2.94 2.96 3.12 2.98 2.99 a
 223  2.72  4.49 4.35 4.38 4.36 3.77 4.23 3.83 3.89 a
 224  3.68  4.17 4.30 4.16 4.07 3.87 3.87 3.85 3.82 a
 232  2.49  3.73 3.51 3.16 3.26 3.07 2.77 2.92 3.00 a

 201  2.30  3.41 3.48 3.41 3.49 3.33 3.20 3.07 3.15 c
 202  2.91  3.92 4.02 4.04 3.64 3.29 3.10 2.70 2.69 c
 203  2.08  2.52 2.44 2.27 2.23 2.01 2.26 2.34 2.44 c
 204  3.02  4.43 4.30 4.08 4.01 3.62 3.23 2.46 2.97 c
 205  3.26  4.55 4.58 4.44 4.04 4.33 3.87 3.75 3.81 c
 206  2.29  4.25 4.37 4.10 4.20 3.84 3.43 3.79 3.74 c
 207  1.96  3.00 2.80 2.59 2.42 1.61 1.83 1.21 1.50 c
 208  2.70  4.06 3.98 4.06 3.93 3.61 2.91 2.07 2.67 c
 209  2.50  4.37 4.06 3.68 3.64 3.17 3.37 3.20 3.25 c
 210  2.35  2.83 2.79 2.82 2.79 2.80 2.76 2.64 2.69 c
 211  2.34  4.06 3.68 3.59 3.27 2.60 2.72 2.22 2.68 c
 212  2.20  2.82 1.90 2.57 2.30 1.67 1.90 2.07 1.76 c
 214  2.78  3.18 3.13 3.11 2.97 3.06 3.27 3.24 3.33 c
 215  3.43  4.39 4.63 4.19 4.00 4.01 3.66 3.47 3.22 c
 216  3.07  3.90 3.98 4.09 4.03 4.07 3.56 3.83 3.75 c
 217  1.21  2.31 2.19 2.21 2.09 1.75 1.72 1.80 1.36 c
 218  2.60  3.19 3.18 3.15 3.14 3.08 2.96 2.97 2.85 c
 219  2.61  3.54 3.45 3.25 3.01 3.07 2.65 2.47 2.55 c
 220  2.48  2.99 3.02 3.02 2.94 2.69 2.66 2.68 2.70 c
 221  3.73  4.37 4.20 4.17 4.19 4.07 3.86 3.89 3.89 c
 222  2.54  3.26 3.39 3.27 3.20 3.32 3.09 3.25 3.15 c
 223  2.83  4.72 4.97 4.99 4.96 4.95 4.82 4.56 4.49 c
 224  3.47  4.27 4.50 4.34 4.00 4.11 3.93 3.68 3.77 c
 232  2.79  4.10 3.85 4.27 4.01 3.78 3.14 3.94 3.69 c
 201  2.14  2.36 2.36 2.28 2.35 2.31 2.62 2.12 2.42 p
 202  3.37  3.03 3.02 3.19 2.98 3.01 2.75 2.70 2.84 p
 203  1.88  1.99 1.62 1.65 1.68 1.65 1.85 1.96 1.30 p
 204  3.10  3.24 3.37 3.54 3.31 2.81 3.58 3.76 3.05 p
 205  2.91  3.35 3.92 3.69 3.97 3.94 3.63 2.92 3.31 p
 206  2.29  3.04 3.28 3.17 2.99 3.31 3.21 2.98 2.82 p
 207  2.20  2.46 3.22 2.65 3.02 2.25 1.50 2.37 1.94 p
 208  2.70  2.85 2.81 2.96 2.69 2.18 1.91 2.21 1.71 p
 209  2.25  3.45 3.48 3.80 3.60 2.83 3.17 3.22 3.13 p
 210  2.48  2.56 2.52 2.67 2.60 2.68 2.64 2.65 2.61 p
 211  2.12  2.19 2.44 2.41 2.55 2.93 3.08 3.11 3.06 p
 212  2.37  2.14 1.92 1.75 1.58 1.51 1.94 1.84 1.76 p
 214  2.73  2.57 3.08 2.62 2.91 2.71 2.39 2.42 2.73 p
 215  3.15  2.90 2.80 3.17 2.39 3.01 3.22 2.75 3.14 p
 216  2.52  3.02 3.21 3.17 3.13 3.38 3.25 3.29 3.35 p
 217  1.48  1.35 1.15 1.24 1.32 0.95 1.24 1.04 1.16 p
 218  2.52  2.61 2.59 2.77 2.73 2.70 2.72 2.71 2.75 p
 219  2.90  2.91 2.89 3.01 2.74 2.71 2.86 2.95 2.66 p
 220  2.83  2.78 2.89 2.77 2.77 2.69 2.65 2.84 2.80 p
 221  3.50  3.81 3.77 3.78 3.90 3.80 3.78 3.70 3.61 p
 222  2.86  3.06 2.95 3.07 3.10 2.67 2.68 2.94 2.89 p
 223  2.42  2.87 3.08 3.02 3.14 3.67 3.84 3.55 3.75 p
 224  3.66  3.98 3.77 3.65 3.81 3.77 3.89 3.63 3.74 p
 232  2.88  3.04 3.00 3.24 3.37 2.69 2.89 2.89 2.76 p
;
 /*-------------------------------------------------------*/

 /*---convert data to univariate form                  ---*/
data fev1uni; set fev1;
   array f{8} fev1:;

   do hour=1 to 8; fev = f{hour}; output; end;
   drop fev1:;
run;
data fev1uni; set fev1uni; rename fev=fev1; run;
proc sort data=fev1uni; by drug hour;
run;


 /*-------------------------------------------------------*/
 /*---Output 5.1, Output 5.2, Output 5.3, Output 5.4   ---*/
 /*---Output 5.5, Output 5.6                           ---*/
proc mixed data=fev1uni;
   class drug patient hour;
   model fev1=drug hour drug*hour;
   repeated hour / subject=patient(drug) type=un r rcorr;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.7, Output 5.8, Output 5.9, Output 5.10  ---*/
proc mixed data=fev1uni;
   class drug patient hour;
   model fev1=drug hour drug*hour;
   repeated hour / sub=patient(drug) type=cs r rcorr;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.11                                      ---*/
proc mixed data=fev1uni;
   class drug patient hour;
   model fev1=drug hour drug*hour;
   repeated hour / sub=patient(drug) type=un;
   estimate 'drug a-c at hour 1'
                        drug 1 -1 
                        drug*hour 1 0 0 0 0 0 0 0 -1 0 0 0 0 0 0 0;
   estimate 'hour 1-2 drug a'
                        hour 1 -1 
                        drug*hour 1 -1 0 0 0 0 0 0; 
   ods select Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.12                                      ---*/
proc mixed data=fev1uni;
   class drug patient hour;
   model fev1=drug hour drug*hour;
   repeated hour / sub=patient(drug) type=cs;
   estimate 'drug a-c at hour 1'
                        drug 1 -1 
                        drug*hour 1 0 0 0 0 0 0 0 -1 0 0 0 0 0 0 0 /e ;
   estimate 'hour 1-2 drug a'
                        hour 1 -1 
                        drug*hour 1 -1 0 0 0 0 0 0; 
   ods select Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.13                                      ---*/
 /*---Figure 5.3                                       ---*/
proc mixed data=fev1uni;
   class drug patient hour;
   model fev1 = drug|hour;
   repeated / type=un subject=patient(drug) sscp rcorr;
   ods output covparms=cov rcorr=corr;
run;

data times;
  do time1=1 to 8;
    do time2=1 to time1;
      dist=time1-time2;
      output;
    end;
   end;
run;

data covplot; merge times cov;
run;

proc print data=covplot(where=((time1 <= 3) or (time1=8))) noobs;
run;

axis1 order = (0.34 to 0.58 by 0.04)
      minor = none
      offset= (0.2in, 0.2in)
      value = (font=swiss h=2 
               '0.34' '0.38' '0.42' '0.46' '0.50' '0.54' '0.58') 
      label = (angle=90 f=swiss h=2 
             'Covariance of Between Subj Effects');
axis2 order = (0 to 7 by 1)
      minor = none
      offset= (0.2in, 0.2in)
      value = (font=swiss h=2 )
      label = (f=swiss h=2 'Lag');
legend1 value=(font=swiss h=2  ) 
        label=(f=swiss h=2 'From Time')
		across=2
		mode  =protect
        position=(top right inside);
symbol1 color=black interpol=join line=1  value=square; 
symbol2 color=black interpol=join line=2  value=circle; 
symbol3 color=black interpol=join line=20 value=triangle;
symbol4 color=black interpol=join line=3  value=plus; 
symbol5 color=black interpol=join line=4  value=star; 
symbol6 color=black interpol=join line=5  value=dot; 
symbol7 color=black interpol=join line=6  value=_; 
symbol8 color=black interpol=join line=10 value==;

proc gplot data=covplot;
   plot estimate*dist=time2 / noframe
                              vaxis  = axis1 
                              haxis  = axis2 
                              legend = legend1;
run;

 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.14                                      ---*/
proc mixed data=fev1uni;
   class drug patient hour;
   model fev1 = drug hour drug*hour;
   repeated hour / sub=patient(drug) type=ar(1);
   ods select CovParms;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.15                                      ---*/
 /*---Output 5.17                                      ---*/
proc mixed data=fev1uni;
   class drug patient hour;
   model fev1 = drug hour drug*hour;
   repeated hour / sub=patient(drug) type=ar(1);
   random patient(drug);
   ods select CovParms FitStatistics;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.16                                      ---*/
 /*---Output 5.18                                      ---*/
proc mixed data=fev1uni;
   class drug patient hour;
   model fev1 = drug hour drug*hour;
   repeated hour / sub=patient(drug) type=toep;
   ods select CovParms FitStatistics;
run;
/*-------------------------------------------------------*/

/*-------------------------------------------------------*/
 /*---Figure 5.4                                      ---*/
data FEV1;
  input patient basefev1 fev11h fev12h fev13h fev14h fev15h 
        fev16h fev17h fev18h drug $;
  datalines;
 201  2.46  2.68 2.76 2.50 2.30 2.14 2.40 2.33 2.20 a
 202  3.50  3.95 3.65 2.93 2.53 3.04 3.37 3.14 2.62 a
 203  1.96  2.28 2.34 2.29 2.43 2.06 2.18 2.28 2.29 a
 204  3.44  4.08 3.87 3.79 3.30 3.80 3.24 2.98 2.91 a
 205  2.80  4.09 3.90 3.54 3.35 3.15 3.23 3.46 3.27 a
 206  2.36  3.79 3.97 3.78 3.69 3.31 2.83 2.72 3.00 a
 207  1.77  3.82 3.44 3.46 3.02 2.98 3.10 2.79 2.88 a
 208  2.64  3.67 3.47 3.19 2.19 2.85 2.68 2.60 2.73 a
 209  2.30  4.12 3.71 3.57 3.49 3.64 3.38 2.28 3.72 a
 210  2.27  2.77 2.77 2.75 2.75 2.71 2.75 2.52 2.60 a
 211  2.44  3.77 3.73 3.67 3.56 3.59 3.35 3.32 3.18 a
 212  2.04  2.00 1.91 1.88 2.09 2.08 1.98 1.70 1.40 a
 214  2.77  3.36 3.42 3.28 3.30 3.31 2.99 3.01 3.08 a
 215  2.96  4.31 4.02 3.38 3.31 3.46 3.49 3.38 3.35 a
 216  3.11  3.88 3.92 3.71 3.59 3.57 3.48 3.42 3.63 a
 217  1.47  1.97 1.90 1.45 1.45 1.24 1.24 1.17 1.27 a
 218  2.73  2.91 2.99 2.87 2.88 2.84 2.67 2.69 2.77 a
 219  3.25  3.59 3.54 3.17 2.92 3.48 3.05 3.27 2.96 a
 220  2.73  2.88 3.06 2.75 2.71 2.83 2.58 2.68 2.42 a
 221  3.30  4.04 3.94 3.84 3.99 3.90 3.89 3.89 2.98 a
 222  2.85  3.38 3.42 3.28 2.94 2.96 3.12 2.98 2.99 a
 223  2.72  4.49 4.35 4.38 4.36 3.77 4.23 3.83 3.89 a
 224  3.68  4.17 4.30 4.16 4.07 3.87 3.87 3.85 3.82 a
 232  2.49  3.73 3.51 3.16 3.26 3.07 2.77 2.92 3.00 a
 201  2.30  3.41 3.48 3.41 3.49 3.33 3.20 3.07 3.15 c
 202  2.91  3.92 4.02 4.04 3.64 3.29 3.10 2.70 2.69 c
 203  2.08  2.52 2.44 2.27 2.23 2.01 2.26 2.34 2.44 c
 204  3.02  4.43 4.30 4.08 4.01 3.62 3.23 2.46 2.97 c
 205  3.26  4.55 4.58 4.44 4.04 4.33 3.87 3.75 3.81 c
 206  2.29  4.25 4.37 4.10 4.20 3.84 3.43 3.79 3.74 c
 207  1.96  3.00 2.80 2.59 2.42 1.61 1.83 1.21 1.50 c
 208  2.70  4.06 3.98 4.06 3.93 3.61 2.91 2.07 2.67 c
 209  2.50  4.37 4.06 3.68 3.64 3.17 3.37 3.20 3.25 c
 210  2.35  2.83 2.79 2.82 2.79 2.80 2.76 2.64 2.69 c
 211  2.34  4.06 3.68 3.59 3.27 2.60 2.72 2.22 2.68 c
 212  2.20  2.82 1.90 2.57 2.30 1.67 1.90 2.07 1.76 c
 214  2.78  3.18 3.13 3.11 2.97 3.06 3.27 3.24 3.33 c
 215  3.43  4.39 4.63 4.19 4.00 4.01 3.66 3.47 3.22 c
 216  3.07  3.90 3.98 4.09 4.03 4.07 3.56 3.83 3.75 c
 217  1.21  2.31 2.19 2.21 2.09 1.75 1.72 1.80 1.36 c
 218  2.60  3.19 3.18 3.15 3.14 3.08 2.96 2.97 2.85 c
 219  2.61  3.54 3.45 3.25 3.01 3.07 2.65 2.47 2.55 c
 220  2.48  2.99 3.02 3.02 2.94 2.69 2.66 2.68 2.70 c
 221  3.73  4.37 4.20 4.17 4.19 4.07 3.86 3.89 3.89 c
 222  2.54  3.26 3.39 3.27 3.20 3.32 3.09 3.25 3.15 c
 223  2.83  4.72 4.97 4.99 4.96 4.95 4.82 4.56 4.49 c
 224  3.47  4.27 4.50 4.34 4.00 4.11 3.93 3.68 3.77 c
 232  2.79  4.10 3.85 4.27 4.01 3.78 3.14 3.94 3.69 c
 201  2.14  2.36 2.36 2.28 2.35 2.31 2.62 2.12 2.42 p
 202  3.37  3.03 3.02 3.19 2.98 3.01 2.75 2.70 2.84 p
 203  1.88  1.99 1.62 1.65 1.68 1.65 1.85 1.96 1.30 p
 204  3.10  3.24 3.37 3.54 3.31 2.81 3.58 3.76 3.05 p
 205  2.91  3.35 3.92 3.69 3.97 3.94 3.63 2.92 3.31 p
 206  2.29  3.04 3.28 3.17 2.99 3.31 3.21 2.98 2.82 p
 207  2.20  2.46 3.22 2.65 3.02 2.25 1.50 2.37 1.94 p
 208  2.70  2.85 2.81 2.96 2.69 2.18 1.91 2.21 1.71 p
 209  2.25  3.45 3.48 3.80 3.60 2.83 3.17 3.22 3.13 p
 210  2.48  2.56 2.52 2.67 2.60 2.68 2.64 2.65 2.61 p
 211  2.12  2.19 2.44 2.41 2.55 2.93 3.08 3.11 3.06 p
 212  2.37  2.14 1.92 1.75 1.58 1.51 1.94 1.84 1.76 p
 214  2.73  2.57 3.08 2.62 2.91 2.71 2.39 2.42 2.73 p
 215  3.15  2.90 2.80 3.17 2.39 3.01 3.22 2.75 3.14 p
 216  2.52  3.02 3.21 3.17 3.13 3.38 3.25 3.29 3.35 p
 217  1.48  1.35 1.15 1.24 1.32 0.95 1.24 1.04 1.16 p
 218  2.52  2.61 2.59 2.77 2.73 2.70 2.72 2.71 2.75 p
 219  2.90  2.91 2.89 3.01 2.74 2.71 2.86 2.95 2.66 p
 220  2.83  2.78 2.89 2.77 2.77 2.69 2.65 2.84 2.80 p
 221  3.50  3.81 3.77 3.78 3.90 3.80 3.78 3.70 3.61 p
 222  2.86  3.06 2.95 3.07 3.10 2.67 2.68 2.94 2.89 p
 223  2.42  2.87 3.08 3.02 3.14 3.67 3.84 3.55 3.75 p
 224  3.66  3.98 3.77 3.65 3.81 3.77 3.89 3.63 3.74 p
 232  2.88  3.04 3.00 3.24 3.37 2.69 2.89 2.89 2.76 p
;
 /*-------------------------------------------------------*/

 /*---convert data to univariate form                  ---*/
data fev1uni; set fev1;
   array f{8} fev1:;
   do hour=1 to 8; fev = f{hour}; output; end;
   drop fev1:;
run;
data fev1uni; set fev1uni; rename fev=fev1; run;
proc sort data=fev1uni; by drug hour;
run;

/*--Use covplot data for type=un from Figure 5.3--*/
proc mixed data=fev1uni;
  class drug patient hour;
  model fev1 = drug | hour;
  repeated / type=un subject=patient(drug) sscp rcorr;
  ods output covparms = cov
             rcorr    = corr;
run;

data times;
  do time1=1 to 8;
    do time2=1 to time1;
       dist=time1-time2;
       output;
    end;
   end;
run;

data covplot; merge times cov;
run;

/*------------------------------------------*/
  /*---Figure 5.4 Plot of covariance function-*/
  /*---for five covariance models          ---*/

  /*---The five covariance models          ---*/
  /*---UN                                  ---*/
proc mixed data=fev1uni;
  class drug patient hour;
  model fev1=drug hour drug*hour;
  repeated hour / sub=patient(drug) type=un r;
  ods select CovParms R;
  ods output r=r_un;
run;
 /*---CS                                  ---*/
proc mixed data=fev1uni;
  class drug patient hour;
  model fev1 = drug hour drug*hour;
  repeated hour / sub=patient(drug) type=cs r;
  ods select CovParms R;
  ods output r=r_cs; 
run;
  /*---AR(1)                               ---*/
proc mixed data=fev1uni;
  class drug patient hour;
  model fev1 = drug hour drug*hour;
  repeated hour / sub=patient(drug) type=ar(1) r;
  ods select CovParms R;
  ods output r=r_ar;
run;
  /*---AR(1) + RE                          ---*/
proc mixed data=fev1uni;
  class drug patient hour;
  model fev1 = drug hour drug*hour;
  repeated hour / sub=patient(drug) type=ar(1);
  random patient(drug) / V;
  ods select CovParms V;
  ods output V=r_arre;
run;
  /*---TOEP                                ---*/
proc mixed data=fev1uni;
  class drug patient hour;
  model fev1 = drug hour drug*hour;
  repeated hour / sub=patient(drug) type=toep r;
  ods select CovParms R;
  ods output r=r_toep;
run;

data toep; 
  set r_toep(obs=1); 
  array c{8} col1-col8;
  do lag=0 to 7; cov_toep = c{lag+1}; output; end;
  keep lag cov_toep;
run;
data arre; 
  set r_arre(obs=1); 
  array c{8} col1-col8;
  do lag=0 to 7; cov_arre = c{lag+1}; output; end;
  keep lag cov_arre;
data ar;   
  set r_ar  (obs=1); 
  array c{8} col1-col8;
  do lag=0 to 7; cov_ar = c{lag+1}; output; end;
  keep lag cov_ar;
data cs;   
  set r_cs  (obs=1); 
  array c{8} col1-col8;
  do lag=0 to 7; cov_cs = c{lag+1}; output; end;
  keep lag cov_cs;
run;

data plotthis; 
  merge toep cs ar arre
  covplot(keep=dist time2 estimate 
          rename=(estimate=cov_un dist=lag2));
run;

axis1 order = (0.25 to 0.60 by 0.05)
      minor = none
      offset= (0.2in, 0.2in)
      value = (font=swiss h=2)
      label = (angle=90 f=swiss h=2 
             'Covariance of Within Subj Effects');
axis2 order = (0 to 7 by 1)
      minor = none
      offset= (0.2in, 0.2in)
      value = (font=swiss h=2 )
      label = (f=swiss h=2 'Lag');
legend1 value=(font=swiss h=2  ) 
        label=(f=swiss h=2 'Cov. Type')
        value=(font=swiss Height=2
               'AR(1)'
               'AR(1) + RE'
               'CS' 'TOEP' 'UN')
        across=2
        mode  =protect
        position=(top right inside);
symbol1 color=black i=join line=1  value=square r=1; 
symbol2 color=black i=join line=2  value=dot; 
symbol3 color=black i=join line=20 value=triangle;
symbol4 color=black i=join line=3  value=plus; 
symbol5 color=black i=none         value=circle;
proc gplot data=plotthis;
  plot cov_ar  *lag=1
       cov_arre*lag=2
       cov_cs  *lag=3
       cov_toep*lag=4
       cov_un  *lag2=5 / overlay 
                         noframe 
                         vaxis=axis1
                         haxis=axis2
                         legend=legend1;
run; 
quit;
/*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 5.19                                      ---*/
proc mixed data=fev1uni;
   class drug hour patient;
   model fev1 = basefev1 drug|hour;
   random patient(drug);
   repeated hour / sub=patient(drug) type=ar(1);
   ods select Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.20                                      ---*/
proc mixed data=fev1uni;
   class drug hour patient;
   model fev1 = basefev1 drug|hour / ddfm=kr;
   random patient(drug);
   repeated / type=ar(1) subject=patient(drug);
   ods select Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 5.6                                       ---*/
ods html;
ods graphics on;
proc glimmix data=fev1uni;
   class drug hour patient;
   model fev1 = drug|hour basefev1 / ddfm=kr;
   random patient(drug);
   random _residual_ / type=ar(1) subject=patient(drug);
   lsmeans drug*hour / plot=meanplot(sliceby=drug join);
   nloptions tech=nrridg;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 5.21                                      ---*/
proc mixed data=fev1uni;
   class drug hour patient;
   model fev1 = basefev1 drug|hour / ddfm=kr;
   random patient(drug);
   repeated / type=ar(1) subject=patient(drug);
   lsmeans drug*hour/ diff slice=hour;
   contrast 'hr=1 vs hr=8 x P vs TRT' 
                        drug*hour 1 0 0 0 0 0 0 -1
                                  1 0 0 0 0 0 0 -1
                                 -2 0 0 0 0 0 0  2;
   contrast 'hr=1 vs hr=8 x A vs C' 
                          drug*hour 1 0 0 0 0 0 0 -1
                                   -1 0 0 0 0 0 0  1 0;
   ods select Contrasts Slices;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Simple effect differences with MIXED             ---*/
 /*---Output not shown                                 ---*/
proc mixed data=fev1uni;
   class drug hour patient;
   model fev1 = basefev1 drug|hour / ddfm=kr;
   random patient(drug);
   repeated / type=ar(1) subject=patient(drug);
   lsmeans drug*hour/ diff slice=hour;
   ods exclude lsmeans diffs;
   ods output diffs=dhdiff;
run;
data smpleff;
  set dhdiff;
  if drug=_drug or hour=_hour;
proc print data=smpleff;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.22                                      ---*/
ods select SliceDiffs;
proc glimmix data=fev1uni;
   class drug hour patient;
   model fev1 = drug|hour basefev1 / ddfm=kr;
   random patient(drug);
   random _residual_ / type=ar(1) subject=patient(drug);
   lsmeans drug*hour / slicediff=(hour);
   nloptions tech=nrridg;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.23                                      ---*/
ods select LSMEstimates LSMFtest;
proc glimmix data=fev1uni;
   class drug hour patient;
   model fev1 = drug|hour basefev1 / ddfm=kr;
   random patient(drug);
   random _residual_ / type=ar(1) subject=patient(drug);
   nloptions tech=nrridg;
   lsmestimate Drug*Hour 
              1 -1, 

              1  0 -1, 
              1  0  0 -1,
              1  0  0  0 -1,
              1  0  0  0  0 -1,
              1  0  0  0  0  0 -1,
              1  0  0  0  0  0  0 -1 / Ftest;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
data fev1regr;
   set fev1uni;
   h=hour;
   h2=hour*hour;
run;

proc mixed data=fev1regr;
   class drug hour patient;
   model fev1=basefev1 drug h h2 hour 
               drug*h drug*h2 drug*hour/htype=1;
   random patient(drug);
   repeated / type=ar(1) subject=patient(drug); 
run;

 /*-------------------------------------------------------*/
 /*---Output 5.24                                      ---*/
proc mixed data=fev1regr noprofile;
   class drug hour patient;
   model fev1 = basefev1 drug h h2 hour 
                drug*h drug*h2 drug*hour/htype=1;
   random patient(drug);
   repeated / type=ar(1) subject=patient(drug);
   parms (0.1848) (0.08309) (0.5401) / noiter;
   ods select Tests1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.25                                      ---*/
proc mixed data=fev1regr;
   class drug patient;
   model fev1=basefev1 drug h(drug) / noint solution
                                      ddfm=kr htype=1;
   random patient(drug);
   repeated / type=ar(1) subject=patient(drug);
   ods select SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.26                                      ---*/
proc mixed data=fev1regr;
   class drug patient;
   model fev1=basefev1 drug h(drug) / noint solution
                                      ddfm=kr htype=1;
   random patient(drug);
   repeated / type=ar(1) subject=patient(drug);
   contrast 'drug a vs c intercept' drug 1 -1 0;
   contrast 'drug a vs c slope'     h(drug) 1 -1 0;
   ods select Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 5.4, Heart Rates                        ---*/
data hr;
   input patient drug$ basehr hr1 hr5 hr15 hr30 hr1h;
   array hra{5} hr1 hr5 hr15 hr30 hr1h;
   do i = 1 to 5;
      if (i = 1) then minute = 1/60;
      else if (i = 2) then minute = 5;
      else if (i = 3) then minute = 15;
      else if (i = 4) then minute = 30;
      else minute = 60;
      time   = minute;
      hours  = minute / 60;
      hours1 = hours;
      HR = hra{i};
      output;
   end;
   drop i hr1 hr5 hr15 hr30 hr1h;
   datalines;
201 p  92  76  84 88 96 84
202 b  54  58  60 60 60 64
203 p  84  86  82 84 86 82
204 a  72  72  68 68 78 72
205 b  80  84  84 96 92 72
206 p  68  72  68 68 64 62
207 a 100 104 100 92 92 68
208 a  60  60  58 56 50 56
209 a  88 104  88 88 78 84
210 b  92  82  82 76 82 80
211 b  88  80  84 80 80 78
212 p 102  86  86 96 86 88
214 a  84  92 100 88 88 80
215 b 104 100  96 88 92 84
216 a  92  80  72 64 68 64
217 p  92  88  84 76 88 84
218 a  72  84  78 80 80 76
219 b  72 100  92 84 88 80
220 p  80  80  80 78 80 78
221 p  72  68  76 72 72 68
222 b  88  88  98 98 96 88
223 b  88  88  96 88 88 80
224 p  88  78  84 64 68 64
232 a  78  72  72 78 80 68
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 5.7                                       ---*/
symbol i=join r=24 c=black v=none;
proc gplot data=hr;
   plot hr*minute=patient / nolegend vminor=1 hminor=0;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 5.27                                      ---*/
proc mixed data=hr order=data;
   class drug hours patient;
   model hr = drug|hours basehr;
   repeated hours / type=sp(pow)(hours1) sub=patient r rcorr;
   random int / subject=patient v;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---CHAPTER 6: Best Linear Unbiased Prediction       ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 6.4, Genetic Evaluation                 ---*/
data genetic_evaluation;
   input sire dam adg;
   datalines;
1  1  2.24
1  1  1.85
1  2  2.05
1  2  2.41
2  1  1.99
2  1  1.93
2  2  2.72
2  2  2.32
3  1  2.33
3  1  2.68
3  2  2.69
3  2  2.71
4  1  2.42
4  1  2.01
4  2  1.86
4  2  1.79
5  1  2.82
5  1  2.64
5  2  2.58
5  2  2.56
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.1                                       ---*/
proc mixed data=genetic_evaluation;
   class sire dam;
   model adg= / ddfm=kr;
   random sire dam(sire);
   estimate 'sire 1 BLUP "broad" '  
            intercept 1 | sire 1 0;
   estimate 'sire 1 BLUP "narrow" ' 
            intercept 2 | sire 2 0 
            dam(sire) 1 1  0 0  0 0  0 0  0 0  / divisor=2;
   estimate 'sire 1 BLUP with dam 1' 
            intercept 1 | sire 1 0
            dam(sire) 1 0;
   ods select CovParms Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.2                                       ---*/
proc glm data=genetic_evaluation;
   class sire dam;
   model adg=sire dam(sire);
   random sire dam(sire);
   lsmeans sire / stderr;
   lsmeans sire / e=dam(sire) stderr;
   estimate 'sire 1 BLUP "broad" '   
            intercept 1 sire 1 0;
   estimate 'sire 1 BLUP "narrow" '  
            intercept 2 sire 2 0 
            dam(sire) 1 1  0 0  0 0  0 0  0 0 / divisor=2;
   estimate 'sire 1 BLUP with dam 1' 
            intercept 1  sire 1 0
            dam(sire) 1 0;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.3                                       ---*/
proc mixed data=genetic_evaluation;
   class sire dam;
   model adg=sire/ddfm=kr;
   random dam(sire);
   lsmeans sire;

   estimate 'sire 1 BLUP "broad" ' 
            intercept 1 sire 1 0;
   estimate 'sire 1 BLUP "narrow" ' 
            intercept 2 sire 2 0 |
            dam(sire) 1 1  0 0  0 0  0 0  0 0  / divisor=2;
   estimate 'sire 1 BLUP with dam 1' 
            intercept 1 sire 1 0 | 
            dam(sire) 1 0;
   ods select LSMeans Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 6.5, Machine Operators                  ---*/
data machine;
   input machine operator y;
   datalines;
1  1  51.43
1  1  51.28
1  2  50.93
1  2  50.75
1  3  50.47
1  3  50.83
2  1  51.91
2  1  52.43
2  2  52.26
2  2  52.33
2  3  51.58
2  3  51.23
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.4                                       ---*/
proc mixed data=machine;
   class machine operator;
   model y=machine/ddfm=kr;
   random operator machine*operator;
   lsmeans machine;
   estimate 'BLUE - mach 1'  
             intercept 1 
             machine 1 0;
   estimate 'BLUE - diff' 
             machine 1 -1;
   estimate 'BLUP - m 1 narrow' 
             intercept 3 
             machine 3 0 | 
             operator 1 1 1
             machine*operator 1 1 1 0 0 0 / divisor=3;
   estimate 'BLUP - diff narrow' 
             machine 3 -3 | 
             machine*operator 1 1 1 -1 -1 -1 / divisor=3;
   estimate 'BLUP - oper 1' 
             intercept 2 
             machine 1 1  | 
             operator 2 0 0
             machine*operator 1 0 0 1 0 0 / divisor=2;
   estimate 'BLUP -  m 1 op 1' 
             intercept 1 
             machine 1 0 | 
             operator 1 0 0
             machine*operator 1 0 0 0 0 0;
   estimate 'BLUP - diff op 1' 
             machine 1 -1 | 
             machine*operator 1 0 0 -1 0 0;
   ods select CovParms Estimates LsMeans;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.5, Output 6.6                           ---*/
proc glm data=machine;
   class machine operator;
   model y = machine|operator;
   random operator machine*operator/test;
   lsmeans machine operator machine*operator/stderr;
   lsmeans machine/stderr e=machine*operator;
   estimate 'diff' machine 1 -1/e;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 6.6, Multicenter                        ---*/
data multicenter;
   input location $ block treatment response @@;
   datalines;
A  1  3  3.13 A  1  4  3.22 A  1  2  3.16 A  1  1  3.25
A  2  2  2.71 A  2  1  3.20 A  2  3  2.99 A  2  4  2.96
A  3  1  2.69 A  3  2  2.87 A  3  3  2.87 A  3  4  3.12
B  1  3  2.09 B  1  4  2.67 B  1  2  2.10 B  1  1  2.35
B  2  4  2.61 B  2  1  2.25 B  2  3  2.15 B  2  2  2.69
B  3  2  2.15 B  3  3  2.34 B  3  4  2.45 B  3  1  2.53
C  1  4  3.05 C  1  2  3.24 C  1  3  3.22 C  1  1  3.05
C  2  3  3.23 C  2  2  2.71 C  2  1  3.07 C  2  4  2.81
C  3  4  3.13 C  3  3  3.08 C  3  1  3.16 C  3  2  3.03
D  1  1  2.47 D  1  3  2.54 D  1  2  2.41 D  1  4  2.39
D  2  3  2.75 D  2  2  2.65 D  2  1  2.55 D  2  4  3.01
D  3  3  2.60 D  3  4  3.07 D  3  2  2.40 D  3  1  2.20
E  1  3  2.81 E  1  4  2.74 E  1  2  2.47 E  1  1  2.87
E  2  2  2.57 E  2  1  2.97 E  2  4  3.04 E  2  3  3.06
E  3  1  2.70 E  3  2  2.76 E  3  3  3.05 E  3  4  3.21
F  1  1  3.21 F  1  2  2.90 F  1  4  3.46 F  1  3  3.10
F  2  2  3.19 F  2  1  3.30 F  2  4  3.19 F  2  3  3.37
F  3  3  3.43 F  3  2  3.05 F  3  1  3.44 F  3  4  3.70
G  1  2  2.65 G  1  1  3.18 G  1  4  3.01 G  1  3  3.21
G  2  4  2.68 G  2  3  2.67 G  2  1  3.13 G  2  2  2.61
G  3  4  2.64 G  3  3  2.88 G  3  2  2.75 G  3  1  3.14
H  1  3  3.37 H  1  2  3.12 H  1  4  3.27 H  1  1  3.70
H  2  2  2.95 H  2  3  3.42 H  2  4  3.38 H  2  1  3.38
H  3  4  3.74 H  3  1  3.28 H  3  3  3.40 H  3  2  3.05
I  1  2  2.37 I  1  1  3.16 I  1  4  2.49 I  1  3  2.91
I  2  1  2.29 I  2  4  2.34 I  2  3  2.52 I  2  2  2.50
I  3  2  2.66 I  3  1  2.31 I  3  4  2.51 I  3  3  2.65
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.7                                       ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=location treatment location*treatment;
   random block(location);
   lsmeans treatment;
   lsmeans location*treatment / slice=location;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.8                                       ---*/
ods exclude all;
proc mixed data=MultiCenter;
   class location block treatment;
   model response=location treatment location*treatment;
   random block(location);
   lsmeans location*treatment;
   ods output lsmeans=lsm;
run;
ods exclude none;
data lsm; set lsm;
  if location in ('D','E','G','H');
proc print data=lsm;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.9                                       ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=treatment / ddfm=KR;
   random location block(location) location*treatment;
   lsmeans treatment / diff;
   ods select CovParms LsMeans Diffs;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 6.10                                      ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=treatment / ddfm=KR;
   random location block(location) location*treatment;
   estimate 'trt 1 LS Mean' 
             intercept 1
             treatment 1 0 0 0; 
   estimate 'trt 1 BLUP "Narrow"' 
             intercept 9
             treatment 9 | 
             location 1 1 1 1 1 1 1 1 1  
             location*treatment 1 0 0 0  1 0 0 0  1 0 0 0  1 0 0 0
                                1 0 0 0  1 0 0 0  1 0 0 0  1 0 0 0
                                1 0 0 0 /divisor=9; 
    estimate 'trt 1 BLUP "alt"' 
              intercept 9
              treatment 9 | 
              location 1 1 1 1 1 1 1 1 1 / divisor=9; 
    estimate 'trt1 vs trt2' 
              treatment 1 -1 0;
    estimate 'trt 1 v 2 BLUP' 
              treatment 9 -9 0 0 | 
              location*treatment 1 -1 0 0  1 -1 0 0  1 -1 0 0  
                                 1 -1 0 0  1 -1 0 0  1 -1 0 0  
                                 1 -1 0 0  1 -1 0 0  1 -1 0 0 / 
                                 divisor=9;
    ods select Estimates;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 6.11                                      ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=treatment/ddfm=KR;
   random location block(location) location*treatment;
   estimate 'trt1 at loc A blup' 
             intercept 1 
             treatment 1 0 0 0 | 
             location 1 0 
             location*treatment 1 0;
   estimate 'trt2 at loc A blup' 
             intercept 1 
             treatment 0 1 0 0 | 
             location 1 0  
             location*treatment 0 1 0;
   estimate 'trt3 at loc A blup' 
             intercept 1 
             treatment 0 0 1 0 | 
             location 1 0  
             location*treatment 0 0 1 0;
   estimate 'trt4 at loc A blup' 
             intercept 1 
             treatment 0 0 0 1 | 
             location 1 0  
             location*treatment 0 0 0 1;
   estimate 'trt1 at loc B blup' 
             intercept 1 
             treatment 1 0 0 0 | 
             location 0 1 0 
             location*treatment 0 0 0 0  1 0;
   estimate 'trt2 at loc B blup' 
             intercept 1 
             treatment 0 1 0 0 | 
             location 0 1 0  
             location*treatment 0 0 0 0  0 1 0;
   estimate 'trt3 at loc B blup' 
             intercept 1 
             treatment 0 0 1 0 | 
             location 0 1 0  
             location*treatment 0 0 0 0  0 0 1 0;
   estimate 'trt4 at loc B blup' 
             intercept 1 
             treatment 0 0 0 1 | 
             location 0 1 0  
             location*treatment 0 0 0 0  0 0 0 1; 
   estimate 'trt 1 v 2 at loc A' 
             treatment 1 -1 0 | 
             location*treatment 1 -1 0;
   estimate 'trt 1 v 3 at loc A' 
             treatment 1 -1 0 | 
             location*treatment 0 1 -1 0;
   estimate 'trt 1 v 4 at loc A' 
             treatment 1 -1 0 | 
             location*treatment 0 0 1 -1;
   contrast 'slice at loc A' 
             treatment 1 -1  0    | 
             location*treatment 1 -1 0,
             treatment 0  1 -1  0 | 
             location*treatment 0 1 -1 0,
             treatment 0  1  0 -1 | 
              location*treatment 0 1 0 -1;
   contrast 'slice at loc A' 
             treatment 1-1  0    | 
             location*treatment 1 -1 0,
             treatment 1 0 -1  0 | 
             location*treatment 1 0 -1 0,
             treatment 1 0  0 -1 | 
             location*treatment 1 0 0 -1;
   contrast 'slice at loc B' 
             treatment 1 -1  0    | 
             location*treatment 0 0 0 0  1 -1  0,
             treatment 1  0 -1  0 | 
             location*treatment 0 0 0 0  1  0 -1 0,
             treatment 1  0  0 -1 | 
             location*treatment 0 0 0 0  1  0  0 -1;
   ods select Estimates Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.12                                      ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=treatment;
   random location block(location) location*treatment;
   contrast 'slice at loc A' 
             treatment 1 -1  0    | 
             location*treatment 1 -1 0,
             treatment 0  1 -1  0 | 
             location*treatment 0 1 -1 0,
             treatment 0  1  0 -1 | 

              location*treatment 0 1 0 -1;
   contrast 'slice at loc A' 
             treatment 1-1  0    | 
             location*treatment 1 -1 0,
             treatment 1 0 -1  0 | 
             location*treatment 1 0 -1 0,
             treatment 1 0  0 -1 | 
             location*treatment 1 0 0 -1;
   contrast 'slice at loc B' 
             treatment 1 -1  0    | 
             location*treatment 0 0 0 0  1 -1  0,
             treatment 1  0 -1  0 | 
             location*treatment 0 0 0 0  1  0 -1 0,
             treatment 1  0  0 -1 | 
             location*treatment 0 0 0 0  1  0  0 -1;
   ods select Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 6.13                                      ---*/
proc mixed data=MultiCenter;
   class location block treatment;
   model response=treatment;
   random location block(location) location*treatment;
   estimate 'trt1 @ Locs A,C' 
          intercept 2 
          treatment 2 0 0 0 | 
          location 1 0 1 0 0 0 0 0 0
          location*treatment 1 0 0 0  0 0 0 0  1 0 0 0  0 0 0 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0
                             0 0 0 0 / divisor=2;
   estimate 'trt2 @ Locs A,C' 
          intercept 2 
          treatment 0 2 0 0 | 
          location 1 0 1 0 0 0 0 0 0
          location*treatment 0 1 0 0  0 0 0 0  0 1 0 0  0 0 0 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 0 0 / divisor=2;
   estimate 'trt3 @ Locs A,C' 
          intercept 2 
          treatment 0 0 2 0 | 
          location 1 0 1 0 0 0 0 0 0
          location*treatment 0 0 1 0  0 0 0 0  0 0 1 0  0 0 0 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 0 0 / divisor=2;
   estimate 'trt4 @ Locs A,C' 
          intercept 2 
          treatment 0 0 0 2 | 
          location 1 0 1 0 0 0 0 0 0
          location*treatment 0 0 0 1  0 0 0 0  0 0 0 1  0 0 0 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 0 0 / divisor=2;
   estimate 'trt1 @ Locs B,D,I' 
          intercept 3 
          treatment 3 0 0 0 | 
          location 0 1 0 1 0 0 0 0 1
          location*treatment 0 0 0 0  1 0 0 0  0 0 0 0  1 0 0 0  
                             0 0 0 0  0 0 0 0  000 0 0  0 0 0 0  
                             1 0 0 0 / divisor=3;
   estimate 'trt2 @ Locs B,D,I' 
          intercept 3 
          treatment 0 3 0 0 | 
          location 0 1 0 1 0 0 0 0 1
          location*treatment 0 0 0 0  0 1 0 0  0 0 0 0  0 1 0 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 1 0 0 / divisor=3;
   estimate 'trt3 @ Locs B,D,I' 
          intercept 3 
          treatment 0 0 3 0 | 
          location 0 1 0 1 0 0 0 0 1
          location*treatment 0 0 0 0  0 0 1 0  0 0 0 0  0 0 1 0  
                             0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 1 0 / divisor=3;
   estimate 'trt4 @ Locs B,D,I' 
          intercept 3 
          treatment 0 0 0 3 | 
          location 0 1 0 1 0 0 0 0 1
                    location*treatment 0 0 0 0  0 0 0 1  0 0 0 0  0 0 0 1  
                                       0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                                       0 0 0 1/divisor=3;
   estimate 'trt1 @ Locs E,F,G,H' 
          intercept 4 
          treatment 4 0 0 0 | 
          location 0 0 0 0 1 1 1 1 0
          location*treatment 0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             1 0 0 0  1 0 0 0  1 0 0 0  1 0 0 0  
                             0 0 0 0 / divisor=4;
   estimate 'trt2 @ Locs E,F,G,H' 
          intercept 4 
          treatment 0 4 0 0 | 
          location 0 0 0 0 1 1 1 1 0
          location*treatment 0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 1 0 0  0 1 0 0  0 1 0 0  0 1 0 0  
                             0 0 0 0 / divisor=4;
   estimate 'trt3 @ Locs E,F,G,H' 
          intercept 4 
          treatment 0 0 4 0 | 
          location 0 0 0 0 1 1 1 1 0
          location*treatment 0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 1 0  0 0 1 0  0 0 1 0  0 0 1 0  
                             0 0 0 0 / divisor=4;
   estimate 'trt4 @ Locs E,F,G,H' 
          intercept 4 
          treatment 0 0 0 4 | 
          location 0 0 0 0 1 1 1 1 0
          location*treatment 0 0 0 0  0 0 0 0  0 0 0 0  0 0 0 0  
                             0 0 0 1  0 0 0 1  0 0 0 1  0 0 0 1  
                             0 0 0 0 / divisor=4;
   contrast 'slice at locs A,C'
          treatment 2 -2 0 | 
          location*treatment 1 -1 0 0  0 0 0 0  1 -1 0 0  0 0 0 0  
                             0  0 0 0  0 0 0 0  0  0 0 0  0 0 0 0  
                             0  0 0 0,
          treatment 2 0 -2 0 | 
          location*treatment 1 0 -1 0  0 0 0 0  1 0 -1 0  0 0 0 0  
                             0 0  0 0  0 0 0 0  0 0  0 0  0 0 0 0  
                             0 0  0 0,
          treatment 2 0 0 -2 | 
          location*treatment 1 0 0 -1  0 0 0 0  1 0 0 -1  0 0 0 0  
                             0 0 0  0  0 0 0 0  0 0 0  0  0 0 0 0  
                             0 0 0  0;
   contrast 'slice at locs B,D,I'
          treatment 3 -3 0 | 
          location*treatment 0  0 0 0  1 -1 0 0  0 0 0 0  1 -1 0 0  
                             0  0 0 0  0  0 0 0  0 0 0 0  0  0 0 0
                             1 -1 0 0,
          treatment 3 0 -3 0 | 
          location*treatment 0 0  0 0  1 0 -1 0  0 0 0 0  1 0 -1 0  
                             0 0  0 0  0 0  0 0  0 0 0 0  0 0  0 0  
                             1 0 -1 0,
          treatment 3 0 0 -3 | 
          location*treatment 0 0 0  0  1 0 0 -1  0 0 0 0  1 0 0 -1  
                             0 0 0  0  0 0 0  0  0 0 0 0  0 0 0  0  
                             1 0 0 -1;
   contrast 'slice at locs E,F,G,H'
          treatment 4 -4 0 | 
          location*treatment 0  0 0 0  0  0 0 0  0  0 0 0  0  0 0 0  
                             1 -1 0 0  1 -1 0 0  1 -1 0 0  1 -1 0 0  
                             0 0 0 0,
          treatment 4 0 -4 0 | 
          location*treatment 0 0  0 0  0 0  0 0  0 0  0 0  0 0  0 0  
                             1 0 -1 0  1 0 -1 0  1 0 -1 0  1 0 -1 0  
                             0 0  0 0,
          treatment 4 0 0 -4 | 
          location*treatment 0 0 0  0  0 0 0  0  0 0 0 0   0 0 0 0  
                             1 0 0 -1  1 0 0 -1  1 0 0 -1  1 0 0 -1  
                             0 0 0  0;
   ods select Estimates Contrasts;
run;
 /*-------------------------------------------------------*/





 /*-------------------------------------------------------*/
 /*---CHAPTER 7: Analysis of Covariance                ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.3, Average Daily Gain                 ---*/
data ex7_3_rcb;
   input id blk trt adg iwt;
   datalines;
 1  1   0  1.03  338
 2  1  10  1.54  477
 3  1  20  1.82  444
 4  1  30  1.86  370
 5  2   0  1.31  403
 6  2  10  2.16  451
 7  2  20  2.13  450
 8  2  30  2.23  393
 9  3   0  1.59  394
10  3  10  2.53  499
11  3  20  2.33  482
12  3  30  1.80  317
13  4   0  2.09  499
14  4  10  2.20  411
15  4  20  2.21  391
16  4  30  2.82  396
17  5   0  1.66  371
18  5  10  2.30  418
19  5  20  2.65  486
20  5  30  2.18  333
21  6   0  1.42  395
22  6  10  1.93  325
23  6  20  1.58  316
24  6  30  1.49  311
25  7   0  1.41  414
26  7  10  1.65  313
27  7  20  1.08  309
28  7  30  1.34  323
29  8   0  0.18  315
30  8  10  0.64  376
31  8  20  0.76  308
32  8  30  0.70  439
;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 7.1                                       ---*/
proc mixed data=ex7_3_rcb;
   class trt blk;
   model adg=trt iwt*trt/noint solution ddfm=kr;
   random blk;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.2                                       ---*/
proc mixed data=ex7_3_rcb;
   class trt blk;
   model adg=trt iwt iwt*trt/solution ddfm=kr;
   random blk;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.3                                       ---*/
proc mixed data=ex7_3_rcb;
   class trt blk;
   model adg=trt iwt/ solution ddfm=kr;
   random blk;
   estimate 'linear' trt -3 -1  1  3;
   estimate 'quad'   trt -1  1  1 -1;
   estimate 'cubic'  trt -1  3 -3  1;
   lsmeans trt / diff;
   lsmeans trt / at iwt=300;
   lsmeans trt / at iwt=500;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.4                                       ---*/
proc mixed data=ex7_3_rcb;
   class blk trt;
   model adg= trt iwt blk/solution;
   ods select CovParms SolutionF Tests3;
run; 
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.5                                       ---*/
proc sort data=ex7_3_rcb; by blk;
proc means mean n data=ex7_3_rcb noprint;
  by blk;
  var adg iwt; 

  output out=means mean = madg miwt 
                   n    = nadg niwt;
run;
proc mixed data=means; 
   model madg = miwt / solution;
   weight nadg;
   ods select ModelInfo CovParms SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.6                                       ---*/
proc mixed data=ex7_3_rcb covtest; 
   class trt blk;
   model adg=trt iwt / solution;
   random blk;
   parms (.1926) (.0500)/ hold=1,2;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.4, Cooking Times                      ---*/
data long;
   input block container $ amount time;
   datalines;
1  A  2   71.36
1  A  4  123.33
1  A  6  155.59
1  A  8  194.90
1  B  4  118.64
1  B  2   61.95
1  B  6  174.46
1  B  8  222.71
1  C  4  132.55
1  C  8  230.96
1  C  2   73.15
1  C  6  180.46
2  A  6  153.37
2  A  2   74.77
2  A  8  203.97
2  A  4  120.62
2  B  6  174.24
2  B  4  122.24
2  B  2   69.87
2  B  8  231.12
2  C  4  139.63
2  C  8  242.67
2  C  2   80.94
2  C  6  183.37
3  A  2   96.46
3  C  4  145.55
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.7                                       ---*/
proc mixed data=long;
   class container block;
   model time=container amount container*amount / 
                        solution outp=pred ddfm=kr;
   random block;
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.8                                       ---*/
proc mixed data=long;
   class container block;
   model time = container container*amount /
                noint solution outp=pred ddfm=kr;
   lsmeans container / at amount=2 diff;
   lsmeans container / at amount=4 diff;
   lsmeans container / at amount=6 diff;
   lsmeans container / at amount=8 diff;
   random block;
   ods select CovParms SolutionF Tests3 Lsmeans Diffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.9                                       ---*/
data linear; 
   set long;
   class_amt = amount;
run;
proc mixed data=linear;
   class container class_amt block;
   model time=container amount container*amount
              container*class_amt / ddfm=kr;
   random block;
   ods select ClassLevels CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.10                                      ---*/
proc mixed data=linear;
   class container  block;
   model time=container container*amount /ddfm=kr NOINT solution;
   random block;
   contrast 'Models = at 2oz' 
          container 1 -1  0 container*amount 2 -2  0,
          container 1  0 -1 container*amount 2  0 -2;
   ods select CovParms SolutionF Tests3 Contrasts;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.11                                      ---*/
data test; set long;
  amt_2 = amount-2;
  amt_4 = amount-4;
  amt_6 = amount-6;
  amt_8 = amount-8;
run;

title2 "Compare the lines at 2 oz";
proc mixed data=test;
   class container block;
   model time=container container*amt_2 / 
              solution outp=pred ddfm=kr;
   random block;
   ods select CovParms Tests3;
run;

title2 "Compare the lines at 4 oz";

proc mixed data=test;
   class container block;
   model time = container container*amt_4 / 
                solution outp=pred ddfm=kr;
   random block;
   ods select Tests3;
run;
title2 "Compare the lines at 6 oz";
proc mixed data=test;
   class container block;
   model time = container container*amt_6 / 
                solution outp=pred ddfm=kr;
   random block;
   ods select Tests3;
run;
title2 "Compare the lines at 8 oz";
proc mixed data=test;
   class container block;
   model time = container container*amt_8 / 
                solution outp=pred ddfm=kr;
   random block;
   ods select Tests3;
run;
title;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.5, Balanced Incomplete Blocks         ---*/
data bib;
  input id blk trt y x grp;
  datalines;
 1  1  1  31  20  13
 2  1  2  29  18  24
 3  1  3  31  11  13
 4  2  1  29  37  13
 5  2  2  34  37  24
 6  2  4  33  39  24
 7  3  1  31  29  13
 8  3  3  28  12  13
 9  3  4  34  31  24
10  4  2  39  37  24
11  4  3  35  29  13
12  4  4  32  28  24
13  5  1  33  12  13
14  5  2  35  19  24
15  5  3  38  16  13
16  6  1  35  31  13
17  6  2  31  13  24
18  6  4  42  39  24
19  7  1  42  38  13
20  7  3  43  30  13
21  7  4  42  25  24
22  8  2  27  13  24
23  8  3  37  39  13
24  8  4  29  21  24
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.12                                      ---*/
proc mixed data=bib;
   class blk trt;
   model y=trt x*trt/solution ddfm=kr;
   random blk;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.13                                      ---*/
proc mixed data=bib;
   class blk trt; 
   model y = trt x x*trt / solution ddfm=kr;
   estimate 'b1-b2' x*trt 1 -1  0  0; 
   estimate 'b1-b3' x*trt 1  0 -1  0;
   estimate 'b1-b4' x*trt 1  0  0 -1; 
   estimate 'b2-b3' x*trt 0  1 -1  0;
   estimate 'b2-b4' x*trt 0  1  0 -1; 
   estimate 'b3-b4' x*trt 0  0  1 -1;
   random blk;
   ods select CovParms Estimates Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.14                                      ---*/
data bib2; set bib;
   grp = 13; 
   if trt=2 or trt=4 then grp = 24;
run;
proc mixed data=bib2 covtest cl; 
   class blk trt grp; 
   model y = trt x*grp / solution ddfm=kr;
   random blk;
   estimate 'trt1 at xx%= 10.0' intercept 1 trt 1 0 0 0 x*grp 10   0;
   estimate 'trt1 at xx%= 40.0' intercept 1 trt 1 0 0 0 x*grp 40   0;
   estimate 'trt1 at 25%= 17.0' intercept 1 trt 1 0 0 0 x*grp 17   0;
   estimate 'trt1 at 50%= 28.5' intercept 1 trt 1 0 0 0 x*grp 28.5 0;
   estimate 'trt1 at 75%= 37.0' intercept 1 trt 1 0 0 0 x*grp 37   0;
   estimate 'trt1 at mean=26.0' intercept 1 trt 1 0 0 0 x*grp 26   0;

   estimate 'trt3 at xx%= 10.0' intercept 1 trt 0 0 1 0 x*grp 10   0;
   estimate 'trt3 at xx%= 40.0' intercept 1 trt 0 0 1 0 x*grp 40   0;
   estimate 'trt3 at 25%= 17.0' intercept 1 trt 0 0 1 0 x*grp 17   0;
   estimate 'trt3 at 50%= 28.5' intercept 1 trt 0 0 1 0 x*grp 28.5 0;
   estimate 'trt3 at 75%= 37.0' intercept 1 trt 0 0 1 0 x*grp 37   0;
   estimate 'trt3 at mean=26.0' intercept 1 trt 0 0 1 0 x*grp 26   0;

   estimate 'trt2 at xx%= 10.0' intercept 1 trt 0 1 0 0 x*grp 0 10;
   estimate 'trt2 at xx%= 40.0' intercept 1 trt 0 1 0 0 x*grp 0 40;
   estimate 'trt2 at 25%= 17.0' intercept 1 trt 0 1 0 0 x*grp 0 17;
   estimate 'trt2 at 50%= 28.5' intercept 1 trt 0 1 0 0 x*grp 0 28.5;
   estimate 'trt2 at 75%= 37.0' intercept 1 trt 0 1 0 0 x*grp 0 37;
   estimate 'trt2 at mean=26.0' intercept 1 trt 0 1 0 0 x*grp 0 26;

   estimate 'trt4 at xx%= 10.0' intercept 1 trt 0 0 0 1 x*grp 0 10;
   estimate 'trt4 at xx%= 40.0' intercept 1 trt 0 0 0 1 x*grp 0 40;
   estimate 'trt4 at 25%= 17.0' intercept 1 trt 0 0 0 1 x*grp 0 17;
   estimate 'trt4 at 50%= 28.5' intercept 1 trt 0 0 0 1 x*grp 0 28.5;
   estimate 'trt4 at 75%= 37.0' intercept 1 trt 0 0 0 1 x*grp 0 37;
   estimate 'trt4 at mean=26.0' intercept 1 trt 0 0 0 1 x*grp 0 26;

   ****comparisons of means at 25%, 75%, and 50%;
   estimate 't1-t2 75%=37'   trt 1 -1  0  0 x*grp 37   -37  ;
   estimate 't1-t2 50%=28.5' trt 1 -1  0  0 x*grp 28.5 -28.5;
   estimate 't1-t2 25%=17'   trt 1 -1  0  0 x*grp 17   -17  ;
   estimate 't1-t4 75%=37'   trt 1  0  0 -1 x*grp 37   -37  ;
   estimate 't1-t4 50%=28.5' trt 1  0  0 -1 x*grp 28.5 -28.5;
   estimate 't1-t4 25%=17'   trt 1  0  0 -1 x*grp 17   -17  ;
   estimate 't3-t2 75%=37'   trt 0 -1  1  0 x*grp 37   -37  ;
   estimate 't3-t2 50%=28.5' trt 0 -1  1  0 x*grp 28.5 -28.5;
   estimate 't3-t2 25%=17'   trt 0 -1  1  0 x*grp 17   -17  ;
   estimate 't3-t4 75%=37'   trt 0  0  1 -1 x*grp 37   -37  ;
   estimate 't3-t4 50%=28.5' trt 0  0  1 -1 x*grp 28.5 -28.5;
   estimate 't3-t4 25%=17'   trt 0  0  1 -1 x*grp 17   -17  ;

   ***comparison of LSMEANS at X=26***;
   estimate 't1-t2 at mean' trt 1 -1  0  0 x*grp 26 -26;
   estimate 't1-t3 at mean' trt 1  0 -1  0             ;
   estimate 't1-t4 at mean' trt 1  0  0 -1 x*grp 26 -26;
   estimate 't2-t3 at mean' trt 0  1 -1  0 x*grp 26 -26;
   estimate 't2-t4 at mean' trt 0  1  0 -1             ;
   estimate 't3-t4 at mean' trt 0  0  1 -1 x*grp 26 -26;
   lsmeans trt / diff e at mean;
   lsmeans trt / diff e at x=13;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*--Data Set 7.6, Unbalanced Incomplete Block        ----*/
data eX7_6_ubib;
   input blk trt y x;
   datalines;
 1  1  0.62  0.078
 1  2  0.91  0.010
 2  1  0.41  0.032
 2  2  0.48  0.050
 3  1  0.41  0.000
 3  2  0.49  0.015
 4  1  0.26  0.010
 4  2  0.28  0.016
 5  1  0.29  0.053
 5  2  0.37  0.069
 6  1  0.73  0.007
 6  2  0.72  0.062
 7  3  0.33  0.036
 7  4  0.31  0.068
 8  3  0.18  0.068
 8  4  0.18  0.057
 9  3  0.19  0.077
 9  4  0.25  0.090
10  3  0.28  0.023
10  4  0.32  0.039
11  3  0.33  0.017
11  4  0.27  0.062
12  3  0.24  0.058
12  4  0.23  0.082
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.15                                      ---*/
proc mixed data=EX7_6_ubib; 
   class blk trt;
   model y=trt x*trt/noint solution ddfm=kr;
   random blk;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.16                                      ---*/
proc mixed data=EX7_6_ubib;
   class blk trt;
   model y=trt x x*trt/noint solution ddfm=kr;
   random blk;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.17                                      ---*/
proc mixed data=EX7_6_ubib;
   class blk trt;
   model y=trt x  /noint solution ddfm=kr;
   lsmeans trt / diff;
   random blk;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.7, Teaching Methods I                 ---*/
data Ex_7_7sp;
    input met teacher gen $ student score y_ex @@;
    datalines;
1  1  f  1  15  11 1  1  f  2  17  11 1  1  f  3  16  11
1  1  f  4  16  11 1  1  m  1  17  11 1  1  m  2  16  11
1  1  m  3  17  11 1  1  m  4  17  11 1  2  f  1  18   8
1  2  f  2  17   8 1  2  f  3  17   8 1  2  f  4  16   8
1  2  m  1  16   8 1  2  m  2  17   8 1  2  m  3  18   8
1  2  m  4  17   8 1  3  f  1  15   9 1  3  f  2  15   9
1  3  f  3  15   9 1  3  f  4  16   9 1  3  m  1  15   9
1  3  m  2  15   9 1  3  m  3  15   9 1  3  m  4  16   9
1  4  f  1  16  17 1  4  f  2  17  17 1  4  f  3  16  17
1  4  f  4  15  17 1  4  m  1  14  17 1  4  m  2  17  17
1  4  m  3  17  17 1  4  m  4  16  17 2  1  f  1  21   6
2  1  f  2  22   6 2  1  f  3  22   6 2  1  f  4  21   6
2  1  m  1  20   6 2  1  m  2  20   6 2  1  m  3  21   6
2  1  m  4  22   6 2  2  f  1  21  11 2  2  f  2  20  11
2  2  f  3  20  11 2  2  f  4  21  11 2  2  m  1  18  11
2  2  m  2  19  11 2  2  m  3  20  11 2  2  m  4  19  11
2  3  f  1  23  13 2  3  f  2  23  13 2  3  f  3  24  13
2  3  f  4  23  13 2  3  m  1  21  13 2  3  m  2  20  13
2  3  m  3  21  13 2  3  m  4  22  13 2  4  f  1  23  18
2  4  f  2  22  18 2  4  f  3  22  18 2  4  f  4  22  18
2  4  m  1  19  18 2  4  m  2  19  18 2  4  m  3  19  18
2  4  m  4  20  18 3  1  f  1  33   8 3  1  f  2  31   8
3  1  f  3  31   8 3  1  f  4  32   8 3  1  m  1  27   8
3  1  m  2  28   8 3  1  m  3  27   8 3  1  m  4  27   8
3  2  f  1  28  18 3  2  f  2  27  18 3  2  f  3  27  18
3  2  f  4  29  18 3  2  m  1  23  18 3  2  m  2  23  18
3  2  m  3  24  18 3  2  m  4  23  18 3  3  f  1  30  12
3  3  f  2  29  12 3  3  f  3  29  12 3  3  f  4  30  12
3  3  m  1  25  12 3  3  m  2  25  12 3  3  m  3  26  12
3  3  m  4  24  12 3  4  f  1  28   6 3  4  f  2  27   6
3  4  f  3  28   6 3  4  f  4  30   6 3  4  m  1  25   6
3  4  m  2  25   6 3  4  m  3  22   6 3  4  m  4  25   6
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.18                                      ---*/
title2 'Means model for intercepts and slopes';
proc mixed data=Ex_7_7sp; 
   class teacher met gen;
   model score = gen*met y_ex*gen*met/solution noint ddfm=kr;
   random teacher(met);
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.19                                      ---*/
title2 'Effects model for intercepts and slopes';
proc mixed data=Ex_7_7sp; 
   class teacher met gen;
   model score = met gen gen*met
                 y_ex y_ex*met y_ex*gen y_ex*gen*met/ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;

 /*-------------------------------------------------------*/
 /*---Output 7.20                                      ---*/
title2 'Effects model for intercepts and additive model for slopes';
proc mixed data=Ex_7_7sp;
   class teacher met gen;
   model score = met gen gen*met y_ex y_ex*met y_ex*gen/ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.21                                      ---*/
title2 'two-way for intercepts and one way for slopes';
proc mixed data=Ex_7_7sp;
   class teacher met gen;
   model score = met gen gen*met y_ex y_ex*gen/ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
title;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.22                                      ---*/
 /*---Output 7.23                                      ---*/
 /*---Output 7.24                                      ---*/
 /*---Output 7.25                                      ---*/ 
title2 "means model for intercepts and slopes for y_ex for each gender";
proc mixed data=Ex_7_7sp;
   class teacher met gen;
   model score =gen*met y_ex*gen/noint solution ddfm=kr;
   random teacher(met);

   lsmeans gen*met / diff at means;
   lsmeans gen*met / diff at y_ex=5;
   lsmeans gen*met / diff at y_ex=10;
   lsmeans gen*met / diff at y_ex=20;

   estimate 'f-m m=1 y_ex=5'     gen*met 1 -1 0  0 0  0 y_ex*gen  5  -5;
   estimate 'f-m m=1 y_ex=10'    gen*met 1 -1 0  0 0  0 y_ex*gen 10 -10;
   estimate 'f-m m=1 y_ex=20'    gen*met 1 -1 0  0 0  0 y_ex*gen 20 -20;
   estimate 'f-m m=2 y_ex=5'     gen*met 0  0 1 -1 0  0 y_ex*gen  5  -5;
   estimate 'f-m m=2 y_ex=10'    gen*met 0  0 1 -1 0  0 y_ex*gen 10 -10;
   estimate 'f-m m=2 y_ex=20'    gen*met 0  0 1 -1 0  0 y_ex*gen 20 -20;
   estimate 'f-m m=3 y_ex=5'     gen*met 0  0 0  0 1 -1 y_ex*gen  5  -5;
   estimate 'f-m m=3 y_ex=10'    gen*met 0  0 0  0 1 -1 y_ex*gen 10 -10;
   estimate 'f-m m=3 y_ex=20'    gen*met 0  0 0  0 1 -1 y_ex*gen 20 -20;

   estimate 'male m=1 y_ex=5'    gen*met 1  0 0  0 0  0 y_ex*gen  5   0;
   estimate 'male m=1 y_ex=10'   gen*met 1  0 0  0 0  0 y_ex*gen 10   0;
   estimate 'male m=1 y_ex=20'   gen*met 1  0 0  0 0  0 y_ex*gen 20   0;
   estimate 'male m=2 y_ex=5'    gen*met 0  0 1  0 0  0 y_ex*gen  5   0;
   estimate 'male m=2 y_ex=10'   gen*met 0  0 1  0 0  0 y_ex*gen 10   0;
   estimate 'male m=2 y_ex=20'   gen*met 0  0 1  0 0  0 y_ex*gen 20   0;
   estimate 'male m=3 y_ex=5'    gen*met 0  0 0  0 1  0 y_ex*gen  5   0;
   estimate 'male m=3 y_ex=10'   gen*met 0  0 0  0 1  0 y_ex*gen 10   0;
   estimate 'male m=3 y_ex=20'   gen*met 0  0 0  0 1  0 y_ex*gen 20   0;

   estimate 'female m=1 y_ex=5'  gen*met 0  1 0  0 0  0 y_ex*gen  0   5;
   estimate 'female m=1 y_ex=10' gen*met 0  1 0  0 0  0 y_ex*gen  0  10;
   estimate 'female m=1 y_ex=20' gen*met 0  1 0  0 0  0 y_ex*gen  0  20;
   estimate 'female m=2 y_ex=5'  gen*met 0  0 0  1 0  0 y_ex*gen  0   5;
   estimate 'female m=2 y_ex=10' gen*met 0  0 0  1 0  0 y_ex*gen  0  10;
   estimate 'female m=2 y_ex=20' gen*met 0  0 0  1 0  0 y_ex*gen  0  20;
   estimate 'female m=3 y_ex=5'  gen*met 0  0 0  0 0  1 y_ex*gen  0   5;
   estimate 'female m=3 y_ex=10' gen*met 0  0 0  0 0  1 y_ex*gen  0  10;
   estimate 'female m=3 y_ex=20' gen*met 0  0 0  0 0  1 y_ex*gen  0  20;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.8, Teaching Methods II                ---*/
data EX_7_8_spcv;
   input met teacher gen $ iq score @@;
   datalines;
1  1  f   89  54 1  1  f  105  55 1  1  f  108  54
1  1  f  116  64 1  1  m   95  59 1  1  m  103  58
1  1  m   91  42 1  1  m   82  48 1  2  f   83  48
1  2  f  103  56 1  2  f  123  67 1  2  f  103  54
1  2  m  118  65 1  2  m  101  65 1  2  m  101  50
1  2  m   82  55 1  3  f  115  71 1  3  f   91  66
1  3  f  109  69 1  3  f   85  59 1  3  m   98  76
1  3  m   84  64 1  3  m   91  63 1  3  m  110  74
1  4  f  120  75 1  4  f   98  60 1  4  f   99  64
1  4  f   91  59 1  4  m   80  55 1  4  m  112  70
1  4  m  105  63 1  4  m   94  62 2  1  f   97  67
2  1  f  105  74 2  1  f  120  78 2  1  f   92  69
2  1  m   91  67 2  1  m   96  64 2  1  m   95  65
2  1  m   84  52 2  2  f  105  73 2  2  f  110  78
2  2  f   98  75 2  2  f   92  65 2  2  m  104  75
2  2  m  105  78 2  2  m   82  58 2  2  m  109  75
2  3  f  141  97 2  3  f  107  68 2  3  f  116  82
2  3  f  105  86 2  3  m   93  71 2  3  m  113  82
2  3  m   92  72 2  3  m  115  77 2  4  f  112  74
2  4  f   96  76 2  4  f  103  78 2  4  f  105  77
2  4  m  111  75 2  4  m  121  86 2  4  m   87  68
2  4  m   90  74 3  1  f   87  71 3  1  f   78  71
3  1  f  117  85 3  1  f  108  87 3  1  m   92  65
3  1  m  111  72 3  1  m  126  85 3  1  m  123  78
3  2  f  126  91 3  2  f  112  80 3  2  f  108  75
3  2  f   92  65 3  2  m   95  73 3  2  m  109  73
3  2  m  115  78 3  2  m  115  71 3  3  f  102  82
3  3  f   96  72 3  3  f  113  87 3  3  f  127  91
3  3  m  112  85 3  3  m   96  68 3  3  m  114  86
3  3  m  101  78 3  4  f   95  86 3  4  f  105  91
3  4  f   95  81 3  4  f  102  85 3  4  m   80  68
3  4  m   97  81 3  4  m  114  89 3  4  m  100  87
;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 7.26                                      ---*/
title2 "Factorial effects for both intercepts and slopes";
proc mixed data=EX_7_8_spcv;
   class teacher met gen;
   model score = met gen gen*met iq iq*gen iq*met 
                 iq*gen*met / ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.27                                      ---*/
title2 "Factorial effects for intercepts and main effects for slopes";
proc mixed data=EX_7_8_spcv;
   class teacher met gen;
   model score = met gen gen*met iq iq*gen iq*met/ ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
title;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.28                                      ---*/
proc mixed data=EX_7_8_spcv;
   class teacher met gen;
   model score = met gen gen*met iq  iq*met / ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.29                                      ---*/
proc mixed data=EX_7_8_spcv;
   class teacher met gen;
   model score = met gen gen*met iq / ddfm=kr;
   random teacher(met);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.30                                      ---*/
 /*---Output 7.31                                      ---*/
title2 "Means model for intercepts and common slope";
proc mixed data=EX_7_8_spcv;
   class teacher met gen;
   model score = gen*met iq / noint solution ddfm=kr;
   random teacher(met);
   lsmeans gen*met/diff;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.32                                      ---*/ 
proc glimmix data=EX_7_8_spcv; 
   class teacher met gen;
   model score = gen*met iq / ddfm=kr;
   random teacher(met);
   lsmeans gen*met / slicediff=(gen met);
   ods select CovParms SliceDiffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.33                                      ---*/
title2 "Means model for  intercepts and common slope";
proc glm data=EX_7_8_spcv; 
   class teacher met gen;
   model score = gen*met teacher(met) iq / noint solution;
   random teacher(met) / test;
   lsmeans gen*met / pdiff stderr;
   estimate 'met 1 female' 
             met*gen 4 0 0 0 0 0  
             teacher(met) 1 1 1 1 0 0 0 0 0 0 0 0 / divisor=4; 
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.9, Wafer Types                        ---*/
data ex_7_9_lots;
   input grp temp type $ wafer site delta thick;
   datalines;
1   900  A  1  1  291  1919
1   900  A  1  2  295  1919
1   900  A  1  3  294  1919
1   900  A  2  1  318  2113
1   900  A  2  2  315  2113
1   900  A  2  3  315  2113
1   900  B  1  1  349  1965
1   900  B  1  2  348  1965
1   900  B  1  3  345  1965
1   900  B  2  1  332  1829
1   900  B  2  2  334  1829
1   900  B  2  3  331  1829
1  1000  A  1  1  319  2098
1  1000  A  1  2  315  2098
1  1000  A  1  3  321  2098
1  1000  A  2  1  290  1823
1  1000  A  2  2  289  1823
1  1000  A  2  3  292  1823
1  1000  B  1  1  358  2059
1  1000  B  1  2  357  2059
1  1000  B  1  3  362  2059
1  1000  B  2  1  365  2145
1  1000  B  2  2  367  2145
1  1000  B  2  3  367  2145
1  1100  A  1  1  264  1846
1  1100  A  1  2  266  1846
1  1100  A  1  3  268  1846
1  1100  A  2  1  276  2028
1  1100  A  2  2  280  2028
1  1100  A  2  3  278  2028
1  1100  B  1  1  352  2086
1  1100  B  1  2  353  2086
1  1100  B  1  3  350  2086
1  1100  B  2  1  330  1899
1  1100  B  2  2  330  1899
1  1100  B  2  3  334  1899
2   900  A  1  1  306  1841
2   900  A  1  2  302  1841
2   900  A  1  3  305  1841
2   900  A  2  1  342  2170
2   900  A  2  2  341  2170
2   900  A  2  3  336  2170
2   900  B  1  1  342  1981
2   900  B  1  2  341  1981
2   900  B  1  3  340  1981
2   900  B  2  1  366  2190
2   900  B  2  2  363  2190
2   900  B  2  3  361  2190
2  1000  A  1  1  299  1915
2  1000  A  1  2  296  1915
2  1000  A  1  3  297  1915
2  1000  A  2  1  329  2161
2  1000  A  2  2  330  2161
2  1000  A  2  3  332  2161
2  1000  B  1  1  348  2072
2  1000  B  1  2  346  2072
2  1000  B  1  3  346  2072
2  1000  B  2  1  350  2082
2  1000  B  2  2  346  2082
2  1000  B  2  3  347  2082
2  1100  A  1  1  285  1854
2  1100  A  1  2  292  1854
2  1100  A  1  3  289  1854
2  1100  A  2  1  306  2046
2  1100  A  2  2  303  2046
2  1100  A  2  3  304  2046
2  1100  B  1  1  357  2062
2  1100  B  1  2  360  2062
2  1100  B  1  3  359  2062
2  1100  B  2  1  361  2055
2  1100  B  2  2  361  2055
2  1100  B  2  3  360  2055
3   900  A  1  1  318  2019
3   900  A  1  2  323  2019
3   900  A  1  3  323  2019
3   900  A  2  1  307  1872
3   900  A  2  2  308  1872
3   900  A  2  3  308  1872
3   900  B  1  1  372  2182
3   900  B  1  2  371  2182
3   900  B  1  3  370  2182
3   900  B  2  1  348  1973
3   900  B  2  2  349  1973
3   900  B  2  3  352  1973
3  1000  A  1  1  264  1828
3  1000  A  1  2  265  1828
3  1000  A  1  3  265  1828
3  1000  A  2  1  274  1827
3  1000  A  2  2  268  1827
3  1000  A  2  3  275  1827
3  1000  B  1  1  332  2109
3  1000  B  1  2  337  2109
3  1000  B  1  3  335  2109
3  1000  B  2  1  322  2003
3  1000  B  2  2  326  2003
3  1000  B  2  3  321  2003
3  1100  A  1  1  273  1925
3  1100  A  1  2  275  1925
3  1100  A  1  3  276  1925
3  1100  A  2  1  276  1942
3  1100  A  2  2  273  1942
3  1100  A  2  3  273  1942
3  1100  B  1  1  333  1893
3  1100  B  1  2  332  1893
3  1100  B  1  3  332  1893
3  1100  B  2  1  349  2170
3  1100  B  2  2  350  2170
3  1100  B  2  3  352  2170
4   900  A  1  1  295  1862
4   900  A  1  2  297  1862
4   900  A  1  3  296  1862
4   900  A  2  1  326  2149
4   900  A  2  2  326  2149
4   900  A  2  3  328  2149
4   900  B  1  1  322  1888
4   900  B  1  2  325  1888
4   900  B  1  3  327  1888
4   900  B  2  1  335  1998
4   900  B  2  2  332  1998
4   900  B  2  3  334  1998
4  1000  A  1  1  258  1815
4  1000  A  1  2  260  1815
4  1000  A  1  3  260  1815
4  1000  A  2  1  280  1981
4  1000  A  2  2  276  1981
4  1000  A  2  3  278  1981
4  1000  B  1  1  319  2012
4  1000  B  1  2  322  2012
4  1000  B  1  3  317  2012
4  1000  B  2  1  311  1892
4  1000  B  2  2  313  1892
4  1000  B  2  3  313  1892
4  1100  A  1  1  282  2083
4  1100  A  1  2  282  2083
4  1100  A  1  3  279  2083
4  1100  A  2  1  271  2036
4  1100  A  2  2  271  2036
4  1100  A  2  3  270  2036
4  1100  B  1  1  335  2174
4  1100  B  1  2  339  2174
4  1100  B  1  3  338  2174
4  1100  B  2  1  304  1802
4  1100  B  2  2  303  1802
4  1100  B  2  3  303  1802
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.34                                      ---*/
title2 "intercept is means model and slope is fct of temp";
proc mixed data=ex_7_9_lots;
   class grp temp type;
   model delta=temp*type thick*temp / ddfm=kr noint solution;
   random grp grp*temp grp*type 
          grp*type*temp wafer(grp temp type);
   lsmeans temp*type / at thick=1828;
   lsmeans temp*type / at thick=2000;
   lsmeans temp*type / at thick=2170;
run; 
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 7.35                                      ---*/
proc glimmix data=ex_7_9_lots; 
   class grp temp type;
   model delta=temp*type thick*temp / ddfm=kr noint solution;
   random grp grp*temp grp*type 
          grp*type*temp wafer(grp temp type);
   lsmeans temp*type / slicediff=(temp type) at thick=1828;
   lsmeans temp*type / slicediff=(temp type) at thick=2000;
   lsmeans temp*type / slicediff=(temp type) at thick=2170;
   ods select SliceDiffs;

run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---CHAPTER 8: Random Coefficient Models             ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 8.2, Winter Wheat                       ---*/
data wheat;
   input variety yield moist @@;
   datalines;
 1  41  10  1  69  57  1  53  32  1  66  52  1  64  47  1  64  48
 2  49  30  2  44  21  2  44  20  2  46  26  2  57  44  2  42  19
 3  69  50  3  62  40  3  50  23  3  76  58  3  48  21  3  55  30
 4  48  22  4  60  40  4  45  17  4  47  21  4  62  44  4  43  13
 5  65  49  5  63  44  5  71  57  5  68  51  5  52  27  5  68  52
 6  76  55  6  46  11  6  45  11  6  67  43  6  65  38  6  79  60
 7  35  17  7  37  20  7  30  11  7  30  10  7  57  48  7  49  36
 8  75  57  8  64  41  8  46  15  8  54  28  8  52  23  8  52  23
 9  51  26  9  63  44  9  42  13  9  61  40  9  67  48  9  69  53
10  60  37 10  73  58 10  66  44 10  71  53 10  67  48 10  74  59
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.1                                       ---*/
 /*---Output 8.2                                       ---*/
proc mixed data=wheat covtest cl scoring=8;
   class variety;
   model yield = moist / solution;
   random int moist / type=un sub=variety solution G Gcorr;
   ods output solutionf=fixed solutionr=random;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.3                                       ---*/
data lines;
   merge random(where=(effect='Intercept') rename=(estimate=rint))
         random(where=(effect='moist'    ) rename=(estimate=rslope));
   if _n_ = 1 then merge 
        fixed(where=(effect='Intercept') rename=(estimate=fint))
        fixed(where=(effect='moist'    ) rename=(estimate=fslope));
   intercept = fint   + rint;
   slope     = fslope + rslope;
   keep variety fint fslope rint rslope intercept slope;
run;
proc print data=lines; 
   var variety fint rint intercept fslope rslope slope;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.4                                       ---*/
proc mixed data=wheat scoring=8; 
   class variety;
   model yield = moist/solution;
   random int moist/sub=variety type=un(1) solution G Gcorr; 
   ods select G GCorr CovParms FitStatistics SolutionF Tests3;
run;
 /*-------------------------------------------------------*/
 
  
 /*-------------------------------------------------------*/
 /*---Data Set 8.3, Mathematics Study                  ---*/
data class;
   input size @@;
   retain class 1;
   do i = 1 to size;
      output;
   end;
   drop size i;
   class + 1;
   datalines;
   21   29   16   24   20   19
   16    8   19   18   14   14
   13   19   22   17   11    9
   22   18   19   24   30   20
   16   21   29   22   18   19 
   11   16   15    8   13   20
   21   17   20   19   17   17
   21   28   19   17   21   24
   26   35   21   20   22   18
   21   22   11   18    7   26
   19    7   25   18   17   18
   10   17   16    9   23   18
   17   19   17   13   20   17 
    8   20   16   20   26   14
   17   27   16   23   25   20
   24   28    8   22   17   21
   25   14   21   23   13   28
   13   22   25   24   14   18
   38   14   21   21   25   27
   34   34   23   19   22   23
   23   26   25   26   14   24 
   24   10   18   22   17   22
   20   19   14   16   17   19
    7    9   23   13   18   24
   24   19   30   21   17   26
   29   32   21    8    8   24
   15   27   15   18   15   18
   18   26   23    7   21   22
   23   15   20   18   29   25 
   22   21   12   16   12   12
   15   17   20   20   21   15
   18   18   32   25
run;

data sims;
   input pretot gain @@;
   datalines;
 29    2   38    0   31    6   31    6   29    5   23    9   23    7
 33    2   30    1   32    3   22    4   29    6   34    2   30   -1
 35    1   25    1   22    3   31    1   33    3   31    1   35    2
 20    2   18   -3   12    5    9    1   11   -3   12    3   12   -8
 18   -6   13   -4    8    4   21    1    4    4   10    1    8    4
 12   -6   14   -2    9    2   11    3   11   -5   12    7   12    2
 17   -7    7    3   17   -6    9    2   16    2    4    1    5    8
 12   -4    7   -2   13    1   16  -10   11   -4    9   -1   11    6
  6    1    9    3    5    9   12   -5    8    1   12   -4    8    4
  9    2    9    5   11   -4   11    1   16   13   17    4   21    6
 18    9   21    0   18   -2   11    9   14   10   11   -4   13    4
 13    4   10    7   11    3   17    9   14    2   17    4   12    1
 12    8   13   -2   10    5   14    6   12   15   13   -5   20    5
 10    9   16    1   10    7   28   -4   11    5   14   -2   24    5
 13    7    5    5   23    8   11    5   18    4   21    5   24    4
 18   12   29    4   18    0    9   11   15    2   25    4   21    0
 20   10   30   -3   18  -10   26   -2   23   -4   18   -4   19    8
 18   -6   24    1   21    8   19   -1   31    0   14   -5   24    0
 19  -13   22  -10   21    6   20    2   11    6   10    7   24  -10
 24   -7   12    5   15   -4   14   -3    8    0    8   -2   16   14
 16   -4   18    4    4    0   21  -15   21  -12    9   -5   14   -6
  7   -1   13   -7   12   -5    4   10   17   -4   13   -7   16    5
 17   10   30    0   19   10   17   -7    9    2   17    0   15   -8
 12   10   14   -2   24  -11   24    1    6    4   15   -4   20    3
  5    3    8    2   10    5   14    8    6    4   18    2    9    0
 12    5    9    3    9    1   16   10   10    6    5   11    9    0
  9    1   11    1   13    0    7    5   27   -4    8   -2   12    2
 16   -7   14    5    8    4   11    4   16    4    8    2   11    7
  6    0    9    4   12    3   27    1   11    2   10   -1   17   -2
 10   -1   11   -1   15    4    7   -3    7    1    4    8    2   16
  7    8    5    1   16    0   12   -5   19   -2    5    3    6    2
 18    7    3    5    9    4    6    5    7    2   13   -7    8    3
  7    7    6    3    9    1    7    1    9    5    8    5    7    6
 22    2    9   16   18    7   27    6   28    8   14    7   13    0
 21   11   20    5   22    5   19    3   13   15   20    3   24    2
 32    4   17    0   17   11   12   13   19    3    8    7   17    7
 20   -1   14    0   12    3   12   12   17   -8   16   12   26   -2
 18   11   12   17   12    9   22    9   16    5   10    3   14    6
  7    2    6    6   19    5   12    9   10    8   17   -3    9    3
 13   10    8    2    8    5   21   10   12    1   12    2   27    6
 10    6   28    3   15    7   16    3   13    9   24   12   11   11
 15    4   19    8   10   -8   17  -10    6   -4   17   -6   16   -1
  9    1   11    2   13   -3    9    4    4    2    6    1   15   -3
 10    1   21    2   13    1   23    3   21   -7   31   -4   19   -4
 11    1    5    6   12    2   11    4   14    9    8    1   16    1
 16    4    8    4   11    1    9    0    4    6   13    8   13    1
 12   -4   12   -2   16    2   14    9   16    5   13   -1    9    0
  8    7   10    9   23    6   26    7   15    9   13    5   31    2
 31    4   22    5   18   13   26    6   31    4   22    2   23    9
 19    1   21   10   36    3   22   -2   21    6   15    5    8    2
 12   -1   11    7    7   15   13   -5   12   -2    4   11    7   -1
 12    0    7    3    4    7    8    3    8    5   21   -6   11    5
  6    5   12   11    7    2   18    4   23   -7   34   -5   33   -1
 30  -23   22    6   31  -22   32    6   30    5   26    6   33    3
 22    1   26   -2   29    4   24    7   34    0   30    7   30    4
 21    6   21    4   28    5   22   12   27   -3   16    9   36    2
 26   -1   37   -1   25   -2   30    6   28    8   32    2   34    2
 30    2   33    4   36    1   33    2   35    0   29    1   30    5
 37    1   30    1   27    3   36   -2   27    8   30    1   26    9
 32   -1   35   -2   33    3   27    7   28    4   34    3   32    6
 27    6   34    3   26    7   18   10   26    8    7   17   29    8
 33   -1   35    1   17   -9   32   -1   11   10   20    7   24    1
 31    6   20    4   21   10   14   12   25   11   15   12   18   11
 32    4   30    4   18   13   23    8   25    6   24    5   17   10
 15    9   26   11   25    5   16    2   12   18   27    6   13    5
 27    7   26    3   24    5   12    4   24   -1   15  -10   15   -1
  9    7   26   -1   15   -1   11    1   18    1   16    3    8    0
 14    7   15    1    5   10    9    5   21  -12   23    5   13    1
 13   -1   17    7   16    5   14    5   18    7   22    0   20    1
  9    9   16    4   19    3   22    6   22    8   24    4    9   11
 22    4   19    4   19    4   19    6   11    6    7    5   12    8
 16    7   12    1    7    2    6   15   10    0   19   -1   13    4
 12    9   13   -3   14    9   21    2   22    5   11    4   18    6
 19    4   23    1   12   -5   12    9   31   -2    9    8   31    4
 17    4   20    7   28    8   11    0   11   14   25    6   18   -5
 13    2   10    3   14   -3   15  -11    7    0    4    1   15    4
  5    9   14    3   12   -1    8   10   19    4    8    7   15   11
 20  -12   16    6    4    3   15    4    9   -3    7   -4   12   11
  7    3   13    6   20    4   20   11    8    7   23    5   23    9
 19    5   12    6   31    0   15    4    9   11   23    8   12   11
 15    8   11   16   28    4   10    8   22    9   17   13   10   14
 12   -2   10   22   21   -1    7    4   28  -13   12   19   15   13
  9   17   12   -5   29    1    9   10   11   11   20   14   20   11
 19    7   18    4   18   14   21    2   30   -3   21    9   14   11
 22    4    9   16   21    7    9    3   12    4   17    5   23    6
 13    7   33    0   23    2   23    7   28    3   27    2   11    1
 19    6   31    0   14    3   11   -3   14    8   11    7   25    5
 11   13   22   -7   16   15   17   11    7   24   28   -6   20   -7
 11    8   15    3   23    4   33    2   17    3   21   -9   20    2
 25    6   11   19   25   -1   19   13   29    9   28    5    9    2
 18   11   21   11   11   14    6   16   10   -1   14    5   28    7
 20   14   17   16   22    4   10    2   19    6   11    6   24    9
  9    6   18    8   16   15   18    7   13    4   24    5   31    6
 11    4   28   -6   17   13   21    5   23    7   10   -4    8    5
 28    6   22   -6   19    6   27    0   15    5   18    9   27    3
 25   -2   10   10   26    7   16    2   20    2   19   10   26    7
  9    3   18   16    9   12   10   17   32    2   16    6   16   10
 13   -3   15   14   17   -1   20    5   16   10   27   -3   28    2
 19    0   16    0   16   11   15    1   30    2   36   -1   12    9
 23   10   11    1   13   10   20    9   23   11   20   14   21    8
 20    7   23    7   23    9   30    7    7    4   23    6   12   11
 18   13   21    7   11    4   20   10   17    4   17    4   17    3
 10    3   22    3   18    7   19    7   28    7   23    6   26    6
 15    7   22    6    5    7   24   10   18    2   17   16   17    0
 11   -4   26    4   17    6   17    9   26    2   19   -1   16    3
 25   -1   20   -1   13   10   29   -2   23    1   28    7   25    8
 24    1   23   11   21    2   18    5    8    5   13    5   30    4
 17    7   24    5   26    8   19    5   17   -9   16   10   10    4
 15    3   16    8   20   14   20    3   12   11   10    4   10    8
 13    3   11    3   28    8   25    6   17   14   18   13   10    9
  6    6   11   16   25   10   14   12   24    4   20    3   20   10
 17   17   20   14   16    9   27    4   11    7   14   -4   13    4
 19    2    8   11   14    5   18    8   13    2   11    2    7    7
 11    2   12    7   12    8    9    3   28    4   15    5   11    7
 14   -4   12    6   24    5   19    5    8    4   15   -6    9   18
 13    3   22    4   24    8   16    9   12    3    9   -2    7    3
  6   -2   11   -6    9   -2    6    2    3    3   18    5   15   -1
 11    0    8   -1   10    7    6   -2    9   -2    8    5   10    1
  8    2    6   -1    5    0   15    5   23    5   34    0   15    8
  9    3   18    6   18   11    8    2   14    1    9    3   13   -4
 25    7   16    4   12    1    7    6   16    1   23    1   14   -3
 14    2   29    4   20   10   15    4   13   -3    8    0   26   -3
 25    3   12    6   20    2   14   17   11   13   17    4    7    2
 15    8   17   11   15    0   10   15   28    5   17    8   15   11
 17   15   16    4   18    7   14    8   20   10   37    0   17    6
  9   12   27    8   26    0   16   12   25    7   35   -2   22   12
 30    1   27   10   26    0   29    1   19    6   24   11   28    4
 29    7   14    8   16   12   24    5   15    5   25   -5   19    6
 14    5   10    6   16    0   17    8   23   10   22    9   17    8
 10    6   16   15   25   -2    7   10   14    5   12    9   23    3
 16    2   16    1   25    8   10   13   21   -5   12   11   19    3
 19    7   26   -3   31    4   26    4   27    2   19   11   22    7
 22   10   21   11   29    6   14    8   15    3   31    3   22    1
 19    5   33  -24   25    7   19   12   23    5   24    1   16   10
 30    4   29    4   23    4   30    4   16   12   23   10   25    6
 19    9   28    4   20   -4   21   12   26    2   27   -1   23    0
  9    2   12    4   18    9   27    2   11   -5    8    4   11    7
 25    1   11   -1   11    1   15    5   22    2   14    9   13    2
  9    2   10   -1   13    3   15    3   13   10   19   10   27    7
 21    5   35   -2   28   -2    7    7   15    5   18   -2    8    3
 28    1   12    9   17    8   25    2   10   -2   17    6    9    5
 15    4   30    0   22   -1   17    0   25    1   22   -3   26    4
 17    1   16    4   27    8   14    9   24   -1   17   10   25    9
 36    2   18    5   27    2   17    8   13   11   22    3   24    7
 11    6   25    4   17   13   23    1   16    6   11   11   11    7
 23    8   22   11   18   15   31    2   27    6   16   12   31    3
 22   15   28    8   23    8   29    1   22    8   30    4   24    5
 29  -20   27    6   28    6   24   12   10    8   10   11    9    6
 18    9   19    3   12   13   10   13   14    7    6   15   21    9
 14    4   12    9   14   14   21   10    6    6   17    9   11   11
 12   10   12    6   11    8   18    9   16   10   27    8   21    6
 20    9   30    1   23    7   18   10   31    6   15   10    9    6
 22   12   21    1   13   14   26    6   16   10   26    6   29    5
 24   10   18   11   21    0   21    0   25    7    9    2   10    1
 15    1   10   -1   17   -5    5    8   10   10   12    3    6    1
 10    6   11    5    7    3    6    9    7    0    8    0   10   -4
 15   -2    7    0    7    8    8    0   10    3    7    0    9   -2
  9    1    4    6    3    6   12   -7    5    6    4    6    7   -5
  3    6   10   -5    8   -7   14  -13   10   -2    9    3    9    5
  8   11   16    4   17   16   11    5    8    6   23    9   10    6
 15  -10   16   -3   19    2    8    9   18    3   18   14   15   -2
 18   10   10   20   18   -4   12    6   10    0   23   13   19    1
 18   12   10   12   26    2   13   -2   17    2   18   11   15    5
 10   14   17    7   20    0   18    2   10   -5   12    8   14    6
 12   -5   10   12   14   15   13    4   11    6   14    0   16   11
 19    7   16   14   10    4    6   -2    5    1    3    3    4   -4
 12   -8    6   -1   28    4   24    1   24   12   23    0   23   -1
 25    5   30  -11   30   -3   34   -3   34    0   33    3   24    4
 27  -12   25    1   16    6   31   -4   25   -5   22    4   15    2
 19   -1   27    6   17   -5   24   -3   31  -14   37   -9   11   -1
  7   -3   16    4   16    3   11   -4   13    8   10   10   23    1
 10    7   11   -5   13   -1   11    2   15   -1   23    3   18  -13
 25   -2   16    9   14   -1    6    0   14   -1   14    9   14   -4
 19   -1   11   -4   19    0    7    2    2    0   13    4    8    6
 11    2    5    0    6    0    8    1   12   -2   10    2   13    8
 16   13   15    0   18    3   17    4   11   12   15    4   12    2
 16   14   14    5   15    8   17    6   16    4   15   11   13    7
 11    6   12    5   15    2   13    6    7    5    6    3   14    1
 12    2   16    4   16   -5    6   -1   14   -4    8    5   14    6
 16   -4   13   -4    6    5    9    1   12    5   15    5   18    8
 14    2   13    0   12    5   15   10   14   13   27    4    9    9
 12    3   12    2    8    1    8    0    7   18   10   10   12    4
  7    5    6   13   11   15   12   13   17    4    9    6    8   16
 15   13    9    7   11    4    9    4    6   -2   13   -3    4    2
  7    2    9    4    5    0    6    5    8   -1    6    0   16    6
  9    1   22   10   19    4   18   -1   18  -14   13    5   10   -1
 13   -3   19    6   25    0   19  -10   13    4    8    3   13   -8
 17    2   26   -6   18    2   21    1   10    1   17    7   10    0
 18   -3    9    6   13    1   11   -4   15   15   11    2   17    5
 16   10   19   11   22    9   13   16    8   19    9   14   23   10
 18   14   14    7   12    5   15   21   17   11   21   11   13    6
  8   12   17   16   18   18   17   11   15   11    7   19   17   16
 19    4    6   16   15   16   14    5   14   11   21    5   11   17
  6   11   20   10   25    6   12    1   13   -1   15   10   19    4
  8    6    9   20   26    7   24    6   16   10    6    7    7    3
 24    7   10    3    9   13   13    7   19    9   17   11   21   11
 18    6   13    0    4    6   20   11   14   12   24    1   20   10
 14    4   27    6   31    5   25    8   15   11   16   -1    7    0
 17    9   22    0   12   -6    8    1    9    5    9    5    8    7
  8    5    8   12   20    2    9    0    4    4    5    1    8    8
  6    2   12   -1    7    6    6    8   17    9   11    5    3    9
 13   -9   22    1   16    4   10    4   10    1   10   -2    8   11
 13    5   10    2   14    7   23    9   14    2   13    9   11   13
  4    9   11    0   15    2   18    7    7   -1    4   12   16    6
 17    8    9    8    7    3   12   -1   12   -4   13    1   14    3
  8   -2   10  -10   16   -5    6    1    9   -3    5    1    3    7
  7   -2    6    2    8   -2    8   -1    4    2    6    9    6   -6
 15   -7   16    9    7   -2    8   -1    4    8    7    3   22    3
 15    4   11   -1   13   -7    7    2   14   -8   11    5   17    7
 11   -3   14    1    9    8   17    2   19    6   24   -5   17  -13
 19  -10   15   -1   32    1   21    3   10    4   25  -12   13    2
 18    3   20    5   16    1   13   -2   28   -5   15    3    6    5
 15   -9   11   -8   13   -2    6    1   10    6    6    3   13    1
 13   -2   13    6   10   -1    5   11   14    4   10   -3   15    3
 11    4   15   -2   19   -2   10   -5   23    3   24   -1   11    5
 19    9   16   10   16    6   14    6   10    9   25   -3   12    5
 12   12   18    8   21    9   12    4   14    1   19    5   11    5
 17    4   19   -3   12    2   12    1   16    3   22    4   18    3
 12    4   20   10    5    5    7   11   11    1   10    8    6    9
  7    3   14    4    6    4    6    5   19   -2    8    7   17    5
 10    4   13    3   26    6   13    7   19    6   12    2   12    8
 17    5   19    9   16   12   12   10   18    1   20   13   11   11
 28    4   10   12   11   13   18    8   24    2    9    5    8    3
  6    6    8    2    6   11    9   -2    7    6    9    3    9    5
  8   -6    5    7    9    1    6    2   13    0    9   -5    9    3
  7    4   13   -1    9    7    7    5    5    0   12   -6    6    2
  7    2   10   -3   14    1    6    4   11    4   11    1    6    5
  8   -1    9    0   11    1    7    7    8    4   18    4    7    2
 10    1   11    7    5    2   14    2   14   -1   12    1   11    0
 10   -2   10   -1    9    1    5   -1    9    4    6    1    5    1
  7    8    8   -2    5    2    7    1    4    3    8    1    9   -1
  6   -3   10    0   12    1    3    5    9   -1    8    0   11   -3
  8   -4   17    6    8    4   16    1   27    3   21    0   13    9
 23   -3   29  -10   29    5   14    8   14    4   31    3   16   10
 22    4   28    1   29    9   26    3   14   -3   32    4   22    5
 17   10    9    9   26    3   16   11   21   12   15    3   12   -2
 11    9   12   -3    7   -2    8    1   10   -2    9   -2   19    4
 10    2    8    2    8   -5   11   -2    7    2   18    0    9   -1
 11    2   12    0    9    1    8    2    9    1    6    2   20    5
 14   -2   17    1    9   12   13   -1   18    0   11    4   10    6
 12    2   10    8   10    2   16   14   12    2   14   16   28    5
 12   15   11   -1   10    6   12    9   13    7   10   16   18    0
 17    6   16    4   31    4   16   11   13    6   11   14    7    1
 21    3   21    4    9    7   10    5   14    7   12   11   12    0
 23    4   23    1   25    4   12    4   22    0   21    3   11   11
  9   -4   27    4   15    7   27    4   12    7   13    0   25    1
 11   -1   20    0    6   14   15    4   12    8   15   -1    3    9
 23   -5    8   11   10   10   10    5    7    6    7   11    7   15
  8   19    7   12    9   15   15   18   13    6   10    3   10    8
 19    6    5   16   13    4    7    5    8   12    6    6    9   11
  8   13   16   13    8   10   17    8    9    8   11    8   10    3
  9    8   10   16   11   17   27    2   14    3    9   19    8   19
  9    9    8   11    6   14    9   15    8    5   12    9   17   -9
 12    5   13    6   17   -5   11   -2   11   -4    8    1   10    7
  7   -1   13   -3   11   -1    7    2    7    5    6    7    8   -1
 14    2   14    2   15   -3   13    0   16    1   36   -2   28    3
 24    2   29    2   21    5   26    1   19  -18   21    9   33    6
 29    6   22  -19   23    6   31   -1   22    3   18    9   24    6
 14    2   31    1   13    8   36    1   19    5   36   -5   29   -4
 29  -22   23    1   10   -3    9   -1    1    2   10   -3    6    0
  6    3    8    4    8    4    3    3    9    0    6    3    5    1
  4    6   10   -2   13   13   14    4   15   -3   13   14   13   14
 10    3   17    5    9    7   16    4   13   17   14    4   14    3
 16   13   10    0   16    1   19    5   12   11   12    8   13   10
 10   13   14    3   16   12   18    5   14   -6   15    1   10    4
 15   13   22    5    6   10   21    1   21   -2   11    9   13    8
 15   -2   13    8   15    9   14    3   16    9   16    3   12    4
 11   14   11    7   18   11   15    7   13   -5   12    2    7    0
  8    0   11    6   14   -1    8   15    9   -1    8   -1    7   12
 10    4    5    3   17    0   24    5   33    4   17    5   17    4
 23    6   21   13   10   12   28    8   23    5   13    8   16    3
 20    5   24    4   20   10   21    9   16    4   14    8   25   10
 23    5   13    9   27    2   18    2   16    4   31    2   29    4
 21    6   26    2   12    9    8    4   17    8    7    5   26    1
 10    5    9    2   14   -1    8    8   14    2    8    2    7    3
 12    1    9    8   18    3   15   10   13    4   17   12   13   -7
 16   10   15   11   12    9   13   16    9   15   26    9   23   12
 16    9   16    6   24    4   24    4   10   10   18   12   17    2
 22    7   19    6   27    1   24    2   17    6   17    4    4    8
  9    3   10    0   20    9   10    8   30    2   32    0    7    5
 21    3   13    7   24    2   15   -1   10   -2    8   -3   16    1
  9    4   33    3   22    6   10    9   20    1   12    3   15   11
 16  -10   23    0   21   11   10    3   16    4   23    8   11    3
  8   11   19    7   26    1   13   -3   30   -4   10   14   18    2
 29    1   14    2   16   12   29    5   16    8   16    1   12    6
 14    9   22   12   15    9   30    0   37    2   32    1   25    9
 26    8   24    6   22   10   32   -1   32   -3   30    8   27    9
 31    1   24    2   25    1   17   -4   25    5   20    6   12   15
 23    5   13    4   18    5   14   14   11   15   14    8   20    6
 18   10   15    2   12    6   12   -4   18   10   16    8   13    3
  6    4   19   15   16   10   26   10   14    7   15   16   24    5
 20    4   10    6   16    4   19    8   21    5   16    4    6   12
 15   10   24    9   23   10    2    4   15    0   11    9   13   10
 14    3   11    6   17    6   17   11   21    4   16    8   25   10
 21    1   16    0   22    5   19    7   11   10   18   -2   17    6
 14    9   23    3   20    8   23  -16   12   16    3    3    7    9
  8    4   23   12   13    6   22    4   15   -1   13    5    6   25
 16    5    9    5   10    5   10    0   10   -3    9   -2   12    0
 17   -1   18   -1    8    2   18   -5   15   -2   10   -1   10   -4
  9   11   14    5   16    5   20    2    8    5    7    2   12    4
 20    1   10    9   13    5    5   -1   11   -5   13    8   25    2
 13    2   14   10   15    0    9    2    5    6   12    7    9    8
 19   -2   15    0    9    0    8    4    3    9   10    4   12    2
 12    4   12    1    6    7   19    4    7   16   13    9    5   11
  6    4   11    0   24    2   11   14   13    0    9    8   32    0
 15   11    8    1    6   12   22    1   11   -3   17    9   19   -6
 10    2    5    6   13   -3   24   -6   14    9   17    5   12    5
 19    7    9   -3   11    3    6   -1   26    1    7    4   14    5
  9    9   19   11   17    8   12   -5   20    9   10    3    8    2
  5    8    8    7   13    4   10    4    8    0    5    7   10   17
  7    7   14    4    8    1    9    1   11    5   20   14   16    8
 21    8   11   10   19   -9   17    7   27   -3   22    4   25    6
 24    8   16   10   21    2   28    3   17    0   19    3   21   13
 21   12   18    8   25    8   27    3   18    9   24    3   22    1
 19    0   28    6   34    3   25    3   20    9   22    4   28    7
 20   13   25    7   26   -8   27    0   20    3   11    9   17   -3
 13    4   12    1   10   12   16    0   15    5   10    1   15    9
 12    1   13   -1   17   -5   22    2    9    1    7    3   17   -1
 18    5   10   -1   18    5   20    3    6    7   14    9   10    4
 21    3    8   -1   15   -5   13    1   13   -3   17   -1   13   -4
 15    0    9    8   18   -3    7   -1   19   13   18    9   31    3
 17    3   25    2   13    6   16    1   14    9   10   10   14    5
 23   10   11    2   18    4   16   11   17   10   13    5   18   12
 17   11   17   15   21    5   24    9   24    5   21    7   13   -1
 18    9   10   -1   11   -3   10    5    6   -1    7    2    7    4
  5    0   14   11   11   -3   11    3    9    3   13   -2   27    7
 10    4    9    0   12   -4   12    2   29    1   27    4   22   12
 19   10   19    5   28    2   27    4   25   11   20   -2   19    2
 16    9   21    8   27    4   29    5   16   16   23    6   30    3
 33    2   30    5   28    5   27   -2   27    7   22    8   25    6
 16    1   19   -1   14    9   19    4   17    9   14    8   13    6
 13    9   17   -1   13    3   21    1   18   10   10    4   17    8
 12   12   18    5   17    4   30    3   14    3   27    7   29   -3
 15    8    6    0   12    6   14    2   15   -2   10    5   10    4
  7    0   13    0   10   10   18    0   15    0   19    5    6    7
  9    3   16    0   10    8    8    6   13    1    8    5   13   -5
  8    7    9    8   13   16   18    3   22   10   22    1   30    3
 13    1   20    8   27    6   23   -8   16   -5   19   11   21    3
 14    9   14   -7   10    5   15    0    7    9   18  -13   34    0
 14    1   11    6   22    6   20    2   16    6   16   -5   14    2
 14   19   11   13   20    9   15    6   10   11    6    3   24    4
 18   12    8    4   21   13   12   -2   31    0   24    8   25    4
  9    1   16    6   15   13   24   12   27    2   16    8   17    2
 12   13   13    1   32    6    8   12   18   10   24   11   21    7
 22    8   10   14   15   12   22   10   31    5   23    8    9    4
  8    0   18   10   11   16   10    7    9   14   14   13   28    4
 20    8   20    3   27    4   17   16   20    6   11    3   28    8
 19    8   12    7   19   -3    6    2    5    6   11   -5    7    5
 14    6   24   12   10  -10    6    0   10    7   11    7   20   -3
 13   -2   17   -1   30    3   11   13   30    1   32    4   30    2
 18    0   11    8   20    9    8   25   14   15   18   19   17   14
 10    2   21    6   22    5   22   12   16   13   19   -5   33   -1
 30   -4   26    6   34    0   10    8   14   11   28    6   12   12
 33    2   21    4   14    6   25    6   24    7   24    1   20    7
 25    7   25    9   32    2   33    3   13    6   18   -2   28    9
 22    9   31    0   16    6   35    3   21   12   32    3   22   12
 16    8   10    6    8   12    8    0    6    8    9   10    8    1
  7    7    8    4    7    5    5   12   26    1   29    6   31    3
 32   -7   28    8   10   13   30    7   18   16   27    4   25    7
 16   12   22    6   30    2   22    9   23   11   29    6   30    5
 20    6   22    7   19    8   19   13   18    6   10   16   25    7
 23    3   27    4   15    7   26    6   20   11   26    8   13    0
 23   11   15    4   20    0   26    9   21   12   25    6   19   13
 16   16    7    4   17    8   18    4   19    3   25    5   26    4
 12   11   16    8   30    6   16    5   28   10   25   12   26    8
 26    6   28    4   18    4   33    1   11   11   29    0   14   16
 25    1   22    8   31    6   27    4   24   -5   15    4   25    7
 23    7   19    1   26    3   29   -1   29    7   18    1   30    5
 21   -4   16   12   23   10   31    4   31    3   25    7   21    7
 19    8   26    7   18   10   22    4   16    9   19    8   27    2
 25   11   19    9   20    6   19    7   20   10   23    4   20    3
 18    6   22   10   18   12   21    6   14   14   31    5   31    8
 34    3   27    6   26    5   25    2   35   -4   32   -1   26    4
 29    8   33    2   32    2   29    6   21    5   32    2   38   -2
 34    1   24    5   29    1   10   10    4    3    7    3    6    4
 10   17   11   -1    6   10   16    0   10    5    8    4    8    1
 15   12   12   12   18   12    7    8   18    8    7    1    9    3
  3    1    8   12   23    8   15   10    8    3   13   15    9    2
  7    0    4    5    9    0   12   -6    9    4   11   14    8   -1
  7    8    8   -1    5    3    4    2    6   -1    6    2    6    4
 28    6    9    6   12    1   16    0    5    9   13    2    4    7
  6    0   10    1   24   11   11   -5   13    5   11    0   17   -3
 14   -1    6   11   13    7   16   13   12   -2   13    3   21    8
 13    0   16    9   20    9   14   12    9    2   27   10   18   -6
 15    8    9   10    5   13   10    7   12    4   12    2   13    0
 10   -6    6   -3   11    6    7   -1    4    1   10    0    8    4
  7    6   12    3   23    5   27    5   20    4   17    5   17    1
 16    5   18    2   19    7   18    0   16    9   25    4   11    6
 20    1   26   -6   12    0   23    0   19    8   20    2   14   11
 25    7   28    8   13    6   24    8   23    8   20   12   22    3
 18    5   29    4   23    5   18    4   16    6   11    8   13    1
 14    6   29    4    4    6    1    5    8    3    5    5    7    1
  8   -2   10   -2   12   -5    9   -6    7   -3    7    1    4    5
  4    6    4   10   10    2    6    9    7    3    7    1   14    4
 26    9   18    9   33    0   14    5   27    6   25   -6   26    7
 25    1   22    8   20    9   21    6   22   12   38    0   22   10
 21    3   26    6   33    5   27    6   25    2   25   11   19   14
 20   12   19    7    7    6   11    7    8    4   12    3   11    9
 22    7    6    6   17   10   12    5   11    4    8    5   18   13
 13    6   15  -10   17    6   21    8   15    5   22    9    8   -1
 26    4    7    3   10    0   14   11   13   13   15   10   13    6
 19   14   34    4   21    4   26   11   20    0   24    6    9   17
  7   16   14    4   12    8   14    8   23   -2   30   -1   29    3
  9    6    5    7   13   15   14   -7   18    3    9    1   12   -5
 10   -1   19  -11   30   -1   12   -9    9   -2   23    3   14   -6
 16   15   26    4    8   -1    6    8   11   -2   13    8   10    0
 12    1   29    0   22    4   16    3   13   -7   18    3   15    6
 16   -4   12    1   20    8    9    3   26   -9   10   -2    4    8
  7    1    7    0   13   -6   10   -3    8    3   11   -6    9   -4
 11    0   10   -3    5   -1    4    2   13   -1    5    2    7    3
  7    4   10   -6    4   10    9   -2    8    0    9    4   14   -2
 11    4    5    6   15   11   19    6    6    6    7    5   14    6
  8   13   11    1    4    9   11    3   12    6   14    3    9    3
  6    3   12    1   24   -2   23   -1   13   -1   14    6   22   -3
 12   -1   19   -1    7    7   16    6   15   -5   27   -2   16    2
 12   -1    8    1   15    5   10    9    2    6   17   -3   19    3
 16   -6   14    3   10    2   14    4    8    2   13   -5    9    2
 17   11   12   14   30    5    6    4   15   18    7    7    9    3
  8    2   11   -3    9    3    8   -1    9   -3   18    6    4    6
 14    2   20    2    7   -3    9    1    8   12   21    6   21   10
 11    0   16   12   17    2   22    5   16    2   14    2    9    6
 25   -1   30    1   24   -7   31    6   26   -6   16   13   27    3
 22  -13   22    3   16    3   17    5   29    1   35   -3   31    0
 21   -3   16    2   26   -7   26   -4   25    2   32    3   18   12
 22   -7   20    7   24    8   30    1   27    4   15    0   27   -1
 21    4   16    8   24    9   32    5   13    5   18   14   19    6
  8    3   10    9   20    5   12   16   14   12   24   13   15    9
 12    8   14    6   15   14   16    1    9    6   15   10   19    7
 21   11   11   -3    9    8   18   11   19    8   18    9   29    0
 20    6   26    9   19    8   27    6   12   20   19    7   11    6
 10    7    6   -2   12   -2   11    5   19   11   21    6   14    4
 12    6   15    4   21    0   11    9    7   26   18   -3   12    7
 16    5   18    7   26    6   13    4   19    2   27    8   23    0
 17    9   16    4   12    7   16    0   23    9    9    8   17    8
 21    1    6   15    8   14   19   11   32    5   25   12   29    6
 24   10   21    7   32    6   18    8   19    2   30    4   24   11
 22    9   15   15   20    8   22   12   17   -1   19   11   11   13
 16    9   15   18   23    9   24    5   31   -1   23    4   24    7
 19   13    9   20   12   11   24    8   17   -1   16    8   25    7
 11   19   11   12   20   15    8    5   15    7   23   10   20    5
 16   14   10   14   15    9   21    3   20    9   14    2   11    6
 20    8   13    7   25    5   17    9   13    4   12    9   29    3
  7    9    9    1   16   -1   13    2    8    2    7   11   17    7
 17    9   15   -2   16    3    7    8    8    8   10    3   11   -2
  9    8   14   13    9   10   17    7   12    8   15   15    8    2
  8    8   13    5   13    4   10   -2    8   -4    9    3    9    0
  9    1    5    6   18   12   12    9    9    4   11    4    5    8
  9   -4   17    9   23    5   17    4   10   12    7    6   11    5
  6   11   11    4   15   16   17   15   23    7   16    6   10    0
 12    3   11    6    9    6   18    9   23    9   13   -1    7    7
  4    8   13    5    6    3   10    4   13   -2    8    6   10    3
  6    7   10   -2    6   10    6    0   18    0   21  -11    8   -2
  4    8   11   -2   16   14   24    9   30    2   19   13   27    6
 25    4   30    8   20    8   28    8   23    4   24   -2   22    3
 28    4   35    1   30    5   27    3   26    3   35    3   21    4
 25    9   30    3   18   11   27    6   23   10   24    7   22    6
 24    9   17    4   15    5   12   10   13    6   27    4   10    3
 18    8   19    2   19    6   13   11   11    3   13   12   17   13
 14   15   15    7   22   -3   11    3   22   10   14    6   25    6
 23    3   20   12   33    4   25    4   16   12   25    2   24    5
 31    1   24    8   37   -1   35    0   33    2   28    6   32   -2
 31    1   15   -3   33    3   36    0   30    0   18    7   28    6
 32    3   28    7   32    3   30    1   34    4   33   -1   14   12
 32   -8   22   10   21    3    6    2   12   13   18    0   14    6
 20    4   14   -7   14    6   15    9   14    0   12   -1   13    9
 23    2   13   -2   13    1   25    1   17   -4   22    2   13    9
 12   11   18   -5   15   -1   26  -14   25   -5   25    2   22    0
 20    9   20   -3   18    7   16   -2   14   -1   21    4   21   -5
 12    1   29    3   22    0   35    0   23    2   27    3   14    3
 31    4   18    3   20    6   12    2   15    5    6   10   15    1
 21    2   15   -4   13   -2    7    7   13    3   10    7   11   10
 10   -2   12    2   12   -2   16    3    6    5    7    5   11   17
 13   15   16    7   18   11    8   13   10    8   11    4   14   -4
 14    8    6    7    7   11   11    1   21    7   14    0   10    3
 10    1    6    3    8    0   18   14   22    7   15    1   24   -8
  9   10   17   -2   17    7   22    6   12    9   17    4   22    8
 15   -5   17    3   20    6   22   -2   10    5    6    5   22    6
 20   -4   13    5   24    6   27    6   24    9   27    2   17    8
 14    6   10   11   27    7   13    0   33    6    5   14    9    3
 27    0    7   11   16   15   32    4   15   11   17   17   18   11
 16    7   15    8   24    8   16   15    9    3   21    8    8    7
 12    5   18    1   33   -3   12   11   12    3   20   12   10    8
 27    4   21   10   12   12   17   10   13    5   14    0    8    5
 18   11   17   11   14   15   22    6   13    4    9   18   14    2
 11   14   17    6   24    7   15   11   21    5   11   10   15    7
 16    0   19    3   16    3   13    9   15    7   24    6   16    9
 19   12   15    4   14    5   15    3   15    8   10   14   16    2
  7    9   13    5   16   14   20    4   16   15   15   16   21    7
 18    3   11    0   14   -5   20   -1   20   -8    9    1   15    3
 11    1   16   -4   21  -14   17   -1   13    5   19    5   16   -3
 19   -2   30    0   23   -8   15   -6   20   -2   21   -2   25  -10
 15    3    9    1   11    3   10    5   12    9   12    0   16    1
  9    1   14   -1    9   -3    3    1    7    9   17    7    8    6
 10   -2   10    7   14    1   13   -3   14   -6   11    8   10    3
 14    1   10    3   13   10   14   11   10    8   11    6   12   -1
 13    3    9   -3    7   -1    4   -1   12   -9    6   -1   13   -8
  6    4   13   -6    6    2    8    1    2    1    9   -5    7   -1
  5    4    4    5    8   -2   10   -4   13   -7    9   -5   10    4
  8    4    5    6   11   -5   10    3    7    1    9    0   12   -3
  6    4    8    1    8    3    7    4    8    2    8   -1    8    0
 10   -5    6    1    8    1    7    5    4    4    7   -3    4    0
  5    3    6   -1   11   -3   10   -2    2    4    5    0    8   -1
 13   -1    8   -7    5    0    8    0    4    4    6    2    4    6
  9   -1    8    3    7    0   10    0   12   -3   13    1    9   -1
 10    1    9    6    5    3   14   -1    9    1   18   -2   18   -1
 12   -3   12   -3    8    7   12    7   12   -1   12    6    7    7
 10    5    7    9    8    2    7    0    7    2   15   -3   11   -1
  9    2    9   -2    9   -2   11   -3   11    5    6   12    7   10
 13   -2    9    2   14   -9    8   -3   11    6    7    2   10    2
 10   -2    6   -1    5    2    9   -5   12    5    8    0    7    4
  6    1    7   -2   12    3   11    8    9    5    9    1    7   -1
  8   -1    4    1    6    2    5    4   10    1   12   -1   11   -1
 10    4   16    4   11   -4    5    0    6    5    6    1   11   -1
 11    7    7    2   12   -5    9   -2    9    2   10   -3   11   11
 13   -1   17    5   14   -4    4    5    8    0   11   -3    4    1
  4    4   26    5    8   -5    5    5    6    3    7    3    9    4
  5    0    8    3   11    5    7   -2   21    3   10    0   14    1
  7    2    5    3   11   -2    9    3   12    1   12   -4    5    3
 13   -4   14    3   19   -1    6   -1    5   -1   12    1    7    1
  6    2   31    4   33    4   20    5   30    2   32    1   29    2
 29    6   13    7   31   -2   22    5   31    6   37    1   32    1
 28    7   37    0   29    5   32    2   31    0   28   -2   29    3
 22   11   35   -2   29    4   33   -1   31    3   31   -6   28    4
 24    2   30    2   36   -2   32    0   31    6   16    5   13    5
 11   -2   14   -1   10    1   13    7    8    9   15    9    5   14
 18    3    8    6    6    0    7   15   17    1   20    6   10    6
  9    6   11    1   20   -3    7   -1   13    8   11    1   12    5
 16    3   12   12
;

data sims; merge sims class;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 8.5                                       ---*/
proc mixed data=sims covtest cl;
   class class;
   model gain = pretot / s ddfm=kr;
   random int pretot / sub=class type=un s; 
   ods output solutionf=est solutionr=rand;
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.6                                       ---*/
proc mixed data=sims info;
   model gain = pretot / s ddfm=satterth;
   random int pretot / sub=class type=un;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 8.4, Pig Growth                         ---*/
data pigsx;
   input trt pig day0 day6 day12 day18 day24 day30;
   datalines;
1   1  14.0  22.1  27.7  31.8  35.3  32.6
1   2  15.2  23.8  32.6  40.0  42.4  44.6
1   3  13.9  22.1  28.1  29.8  33.6  32.9
1   4  16.7  27.1  32.7  38.0  39.9  43.8
1   5  17.0  26.9  36.0  41.9  47.7  50.8
1   6  16.2  25.4  28.7  39.8  43.4  40.2
1   7  11.5  24.8  29.9  37.1  42.4  43.5
1   8  14.9  25.0  28.1  35.9  36.2  35.6
1   9  16.9  21.0  29.8  31.6  34.6  33.7
1  10  13.5  22.7  28.1  37.2  39.2  37.8
1  11  15.3  23.5  30.0  34.3  35.1  36.1
1  12  14.5  25.5  31.8  37.1  43.7  44.7
1  13  15.7  26.0  30.4  39.0  41.3  43.4
1  14  13.2  22.9  31.7  34.4  36.4  34.0
1  15  18.0  27.0  34.4  41.6  45.4  48.0
1  16  17.1  28.2  36.7  44.6  47.9  53.3
1  17  14.8  23.0  31.1  35.9  37.1  40.4
1  18  13.9  23.4  28.5  34.2  36.0  34.6
1  19  15.7  22.8  31.7  38.1  40.2  40.2
1  20  10.9  23.4  30.0  35.6  37.4  38.7
2   1  15.1  27.7  35.1  37.2  45.0  41.2
2   2  14.6  26.2  31.4  36.7  34.2  31.6
2   3  15.3  22.4  29.0  34.8  34.9  32.3
2   4  14.6  26.3  33.2  39.8  41.2  40.1
2   5  18.7  28.2  39.0  43.8  51.2  50.8
2   6  13.4  24.0  32.8  39.7  38.1  40.0
2   7  17.7  25.2  36.0  44.2  47.0  47.5
2   8  14.3  28.9  32.3  40.3  45.0  39.6
2   9  11.5  25.4  29.9  33.1  36.5  30.7
2  10  15.6  23.7  30.3  35.0  34.1  34.6
2  11  16.2  24.5  32.5  40.8  44.0  44.8
2  12  16.6  26.9  33.8  42.3  46.3  46.9
2  13  15.1  27.6  36.7  40.4  41.7  42.3
2  14  14.9  22.0  33.6  34.7  38.2  33.7
2  15  16.6  26.7  35.0  40.9  46.5  42.9
2  16  11.8  25.1  29.9  33.6  34.0  32.0
2  17  15.1  25.1  33.4  33.1  37.3  34.5
2  18  12.9  23.8  30.3  33.4  35.6  31.7
2  19  17.1  27.3  34.2  40.1  47.5  42.2
2  20  15.4  22.1  31.2  35.5  35.4  32.7
3   1  16.6  25.3  27.2  30.9  35.7  33.3
3   2  13.0  20.0  26.9  30.4  30.4  32.5
3   3  14.0  17.6  22.0  25.6  29.4  24.3
3   4   9.2  18.7  27.0  26.5  30.3  28.2
3   5  17.3  23.4  29.5  30.9  33.7  33.9
3   6  16.5  25.8  30.3  37.5  43.2  44.6
3   7  13.5  24.6  28.0  35.1  34.8  33.2
3   8  15.1  19.7  25.0  31.1  32.2  28.0
3   9  17.8  22.5  28.6  33.0  33.6  35.5
3  10  15.0  23.2  27.7  35.3  35.4  36.7
3  11  11.3  20.1  25.4  29.7  27.9  30.4
3  12  17.6  21.8  26.9  32.8  35.8  40.4
3  13  14.3  22.8  28.6  28.1  34.5  36.3
3  14  14.7  24.2  30.5  37.4  39.8  41.3
3  15  13.0  21.6  30.0  35.7  39.9  39.3
3  16  10.0  19.7  26.0  30.2  32.7  31.9
3  17  13.5  22.4  25.5  28.6  30.8  27.1
3  18  13.7  20.5  28.0  30.1  33.1  35.1
3  19  16.0  25.2  31.3  37.7  39.6  43.2
3  20  15.8  20.6  29.7  31.2  32.2  33.2
;

data pigs;
  set pigsx;
  array days{6} day:;
  do i=1 to 6;
     day = (i-1)*6;
     weight = days{i};
     output;
  end;
  keep trt pig weight day;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.7                                       ---*/
proc mixed data=pigs;
   class trt day pig;
   model weight=trt day day*trt / ddfm=kr;
   random pig / subject=trt;
   repeated day / subject=pig(trt) type=ar(1);
   lsmeans day*trt;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.8                                       ---*/
 /*---Output 8.9                                       ---*/
proc mixed data=pigs;
   class trt pig;
   model weight=trt day day*trt day*day day*day*trt/ddfm=kr;
   random int day day*day / subject=pig(trt) type=un; 

   lsmeans trt / at day=0 diff;
   lsmeans trt / at day=6 diff;
   lsmeans trt / at day=12 diff;
   lsmeans trt / at day=18 diff;
   lsmeans trt / at day=24 diff;
   lsmeans trt / at day=30 diff;
   ods output lsmeans=lsm diffs=diffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 8.10                                      ---*/
data pigs; set pigs;
  xday=day;
run;
proc mixed data=pigs;
  class trt pig xday;
  model weight=trt day day*trt day*day day*day*trt xday*trt/
                   ddfm=kr htype=1;
  random int day day*day/subject=pig(trt) type=un;
  ods select CovParms Tests1;
run;
 /*-------------------------------------------------------*/

/*-------------------------------------------------------*/
 /*---CHAPTER 9: Heterogeneous Variance Models         ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 9.2, TV                                 ---*/
data tv;
   input child age sex $ time age_sex $;
   datalines;
 1  2  F  12  2F
 2  3  M  17  3M
 3  2  M  10  2M
 4  4  M  24  4M
 5  2  M  13  2M
 6  3  F  19  3F
 7  4  F  22  4F
 8  3  F  20  3F
 9  4  M  31  4M
10  4  F  32  4F
11  3  M  23  3M
12  3  F  16  3F
13  2  F   8  2F
14  2  M  14  2M
15  2  F   9  2F
16  4  F  39  4F
17  4  M  37  4M
18  3  F  11  3F
19  3  F  14  3F
20  3  M  22  3M
21  2  M  11  2M
22  2  F   7  2F
23  2  M  11  2M
24  3  M  16  3M
25  4  F  12  4F
26  4  M  49  4M
27  2  M  15  2M
;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 9.1                                       ---*/
proc glm data=tv;
   class age sex;
   model time=age*sex;
   means age*sex / hovtest=levene(type=abs) welch;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.2                                       ---*/
proc mixed data=tv covtest cl ic;
   class age sex;
   model time = sex|age / outp=R;
   lsmeans age sex / diff adjust=Tukey;
   ods select CovParms InfoCrit Lsmeans Diffs Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 9.1                                       ---*/
ods html;
ods graphics on;

proc mixed data=tv boxplot;
   class age_sex;
   model time = age_sex;
run;

ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.3                                       ---*/
data R1; set R;**Compute the absolute value of residuals;
   ABSR = ABS(RESID);
run;
proc glm data=R1;
   class age sex;
   model ABSR = age*sex;
run;

 /*-------------------------------------------------------*/
 /*---Output 9.4                                       ---*/
proc glm data=R1;
   class age sex;
   model ABSR = age sex age*sex;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.5                                       ---*/
proc mixed data=TV ic;
   class age sex;
   model time = sex|age / ddfm=KR outp=R;
   repeated / group=sex*age;
   lsmeans age sex / diff adjust=Tukey;
   ods select CovParms InfoCrit Lsmeans Diffs Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.6                                       ---*/
proc mixed data=TV ic;
   class age sex;
   model time=sex|age / DDFM=KR OUTP=R;
   repeated / group=age;
   lsmeans age sex / diff adjust=Tukey;
   ods select CovParms InfoCrit Lsmeans Diffs Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 9.3, LR                                 ---*/
data lr;
  input x y;
  datalines;
0.1  4
0.4  9
0.7  6
0.8  10
1.0  15
1.2  7
1.3  25
1.4  15
1.9  32

2.0  21
2.1  10
2.4  28
2.6  36
2.7  12
2.8  9
3.0  22
3.2  34
3.3  42
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.7                                       ---*/
proc mixed data=LR;
   model y = x / outp=preml outpm=pm_reml solution;
   repeated / local=exp(x);
   parms (1.0) (4.3);
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.8                                       ---*/
proc mixed data=LR method=ml;
   model y = x / outp=pml outpm=pm_ml solution;
   repeated / local=exp(x);
   parms (1.0) (4.3);
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.9                                       ---*/
proc nlmixed data=LR;

   parms a=4.5 b=7.5 c=.01 sig2=5;
   mean = a+b*x;
   model y ~ normal(mean,sig2*exp(c*x));
   predict mean out=mean df=16;
   ods select ParameterEstimates;
run;
 /*-------------------------------------------------------*/
 
 /*-------------------------------------------------------*/
 /*---Output 9.10                                      ---*/
proc mixed data=LR;
   model y = x / solution;
   ods output solutionf=est;
   ods select CovParms SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.11                                      ---*/
proc mixed data=LR;
   model y = x / solution;
   ods output solutionf=est;
   ods select CovParms SolutionF;
run;
data cov;
   input estimate;
   datalines;
 2
.2
;
proc mixed data=LR;
   model y=x/outp=pml outpm=pm_ml solution;
   repeated  / local=pom(est);
   parms /pdata=cov;
   ods select CovParms SolutionF;
   ods output covparms=cov1 solutionf=est1;
run;
proc compare data=est compare=est1;
   var estimate;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.12                                      ---*/
proc mixed data=LR;
   model y = x / solution;
   ods output solutionf=est;
   ods select CovParms SolutionF;
run;
data cov;
   input estimate;
   datalines;
 2
.2
;
%macro iterate;
  %let iter = 1;
  %let maxiter = 20;
  %let converged = 0;
  %do %while ((&iter < &maxiter) & (&converged = 0));
     proc mixed data=LR;
        model y=x / solution;
        repeated  / local=pom(est);
        parms /pdata=cov;
        ods select CovParms SolutionF;
        ods output covparms=cov1 solutionf=est1;
     run;
     data crit;
        merge est(rename=(estimate=est_old)) est1;
        diff = abs(est_old - estimate);
     run;
     proc means data=crit noprint;
        var diff;
        output out=max max=crit;
     run;
     data _null_; set max;
        converged = (crit < 1e-6);
        call symput('converged',left(put(converged,1.)));
     run;
     data est; set est1;
     data cov; set cov1;
     run;
     %let iter = %eval(&iter+1);
     %put iter = &iter;
     %put converged = &converged;
  %end;
  %if (&converged = 1) %then %do;
     /*---final run---*/
     proc mixed data=LR;
        model y=x / solution;
        repeated  / local=pom(est);
        parms / pdata=cov;
     run;
  %end;
%mend iterate;
%iterate;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.13                                      ---*/
proc mixed data=LR;
   model y=x/ solution;
   ods select covparms solutionf tests3;
   ods output solutionf=est;
run;
data cov;
   input estimate;
   datalines;
.1
3
;
%macro iterate;
  %let iter = 1;
  %let maxiter = 20;
  %let converged = 0;
  %do %while ((&iter < &maxiter) & (&converged = 0));
     proc mixed data=LR method=ml;
        model y=x / solution;
        repeated  / local=pom(est);
        parms /pdata=cov;
        ods select CovParms SolutionF;
        ods output covparms=cov1 solutionf=est1;
     run;
     data crit;
        merge est(rename=(estimate=est_old)) est1;
        diff = abs(est_old - estimate);
     run;
     proc means data=crit noprint;
        var diff;
        output out=max max=crit;
     run;
     data _null_; set max;
        converged = (crit < 1e-6);
        call symput('converged',left(put(converged,1.)));
     run;
     data est; set est1;
     data cov; set cov1;
     run;
     %let iter = %eval(&iter+1);
     %put iter = &iter;
     %put converged = &converged;
  %end;
  %if (&converged = 1) %then %do;
     /*---final run---*/
     proc mixed data=LR method=ml;
        model y=x / solution;
        repeated  / local=pom(est);
        parms / pdata=cov;
     run;
  %end;
%mend iterate;
%iterate;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.14                                      ---*/
proc nlmixed data=LR;
   parms a=4.5 b=7.5 T=1 sig2=5;
   mean = a+b*x;
   model y ~ normal(mean,sig2*abs(mean)**T);
   predict mean out=mean df=16;
   ods select ParameterEstimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*--Data Set 9.4, Sales                              ----*/
data sales;
   input region $ dist s1-s8;
   datalines;
NC  1  42.9  47.4  41.0  46.6  42.9  39.8  43.4    .
NC  2  38.7  47.7  42.3  42.8  42.0  41.4  42.7  41.5
NC  3  37.6  43.5  37.8  39.0  39.5  42.2  39.0  45.7
NE  1  42.4  44.6  36.9  43.8  37.4  43.4  44.4  37.7
NE  2  41.5  41.2  41.4  41.7  41.3  41.8  .       .
NE  3  42.0  48.9  40.6  45.8  45.8  45.5  .       .
NE  4  42.2  44.8  36.9  37.1  41.3  39.9  38.4  41.9
NE  5  43.6  40.7  39.7  44.4  47.9  49.1  49.0  44.8
NE  6  47.6  49.1  45.8  45.2    .     .     .     .
NE  7  42.5  41.1  38.4  40.4  37.0  35.3  41.9  43.0
NE  8  29.9  36.0  30.4  33.7  38.5  41.0  33.0  35.9
NW  1  33.1  40.7  37.5  34.8  36.2  38.7    .     .
NW  2  28.7  36.3  36.0  28.8    .     .     .     .
NW  3  35.5  32.8  33.3  32.5  35.6  34.9  28.4  32.7
SC  1  33.6  32.0  35.5  35.4  33.4  32.9  35.4  34.6
SC  2  35.6  31.0  42.1  34.8  34.7    .     .     .
SC  3  37.6  35.4  33.4  35.5  31.6  32.0  38.5    .
SC  4  32.6  31.0  32.1  31.3  25.7    .     .     .
SC  5  29.9  27.0  33.0  30.0  31.2  32.5    .     .
SC  6  28.3  30.0  35.7  33.4  24.7  26.9  31.4  32.3
SE  1  38.9  40.3  42.1  41.6  44.7  37.8  39.3  40.0
SE  2  47.6  38.8  41.1  43.2  47.0    .     .     .
SE  3  35.8  40.5  39.1  37.7  43.7  40.3  42.1    .
SE  4  27.7  33.6  31.1  31.5  31.6    .     .     .
SE  5  34.0  29.8  27.4  33.0  29.4  32.6  28.2    .
SE  6  22.0  28.2  29.3  25.5  19.6  26.5  27.3  21.8
SW  1  41.3  39.2  38.0  38.0  33.9    .     .     .
SW  2  49.2  47.4  45.8  52.1  48.5    .     .     .
SW  3  36.9  31.3  32.2  36.5  39.8  30.3  36.6  34.0
;
data sales_univ; 
   set sales;
   array sale{8} s1-s8;
   do i=1 to 8;
      sales = sale{i};
	  output; 
   end;
   drop s1-s8;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 9.15                                      ---*/
proc mixed data=sales_univ ic;
   title2 'Fit Equal variance model';
   class region dist;
   model sales = region / ddfm=kr outp=r;
   random dist(region) /solution;
   lsmeans region /diff adjust=tukey;
   ods output solutionr=random;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 9.7                                       ---*/
ods html;
ods graphics on;

proc mixed data=random boxplot;
   class region;
   model estimate = region;
run;

ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.16                                      ---*/
data random1; set random;
   absdist=abs(estimate);
run;
proc mixed data=random1 ic;
   class region;
   model absdist=region;
   lsmeans region/diff;
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/
 

 /*-------------------------------------------------------*/
 /*---Output 9.17                                      ---*/
data r1; set r;
   absr=abs(resid);
run;
title2 'Test equality of residual means for regions and district within regions';
proc mixed data=r1;
   class region dist;
   model absr=region dist(region);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.18                                      ---*/
title2 'Fit model to Sales data with unequal district within region variances';
proc mixed data=sales_univ ic;
   class region dist;
   model sales = region / ddfm=kr;
   random dist / group=region;
   lsmeans region / diff adjust=tukey;
run;
title;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 9.5, Dial                               ---*/
data dial;
   input sub qb tmp ufr index type;
   datalines;
 1  200  0.240   0.645  1  1
 1  200  0.505  20.115  2  1
 1  200  0.995  38.460  3  1
 1  200  1.485  44.985  4  1
 1  200  2.020  51.765  5  1
 1  200  2.495  46.575  6  1
 1  200  2.970  40.815  7  1
 2  200  0.240   3.720  1  1
 2  200  0.540  18.885  2  1
 2  200  0.995  34.695  3  1
 2  200  1.475  40.305  4  1
 2  200  2.000  44.475  5  1
 2  200  2.500  42.435  6  1
 2  200  3.010  44.655  7  1
 3  200  0.245   2.985  1  1
 3  200  0.480  17.700  2  1
 3  200  1.010  35.295  3  1
 3  200  1.505  41.955  4  1
 3  200  2.000  47.610  5  1
 3  200  2.515  44.730  6  1
 3  200  2.970  46.035  7  1
 4  200  0.255   3.930  1  1
 4  200  0.495  19.830  2  1
 4  200  0.995  40.425  3  1
 4  200  1.480  52.260  4  1
 4  200  1.995  49.395  5  1
 4  200  2.490  45.975  6  1
 4  200  3.030  41.910  7  1
 5  200  0.255   3.210  1  1
 5  200  0.515  17.700  2  1
 5  200  1.000  32.490  3  1
 5  200  1.505  42.330  4  1
 5  200  2.020  45.735  5  1
 5  200  2.490  47.850  6  1
 5  200  3.010  48.045  7  1
 6  200  0.260   3.660  1  1
 6  200  0.500  16.950  2  1
 6  200  1.020  36.090  3  1
 6  200  1.490  42.630  4  1
 6  200  1.990  46.470  5  1
 6  200  2.480  46.275  6  1
 6  200  2.995  43.980  7  1
 7  200  0.305   9.825  1  1
 7  200  0.505  21.630  2  1
 7  200  0.980  42.270  3  1
 7  200  1.505  50.280  4  1
 7  200  2.005  45.510  5  1
 7  200  2.505  44.250  6  1
 7  200  2.990  42.300  7  1
 8  200  0.305   9.480  1  1
 8  200  0.505  21.750  2  1
 8  200  0.995  37.230  3  1
 8  200  1.500  44.430  4  1
 8  200  1.990  42.165  5  1
 8  200  2.480  43.065  6  1
 8  200  3.000  36.615  7  1
 9  200  0.250   1.560  1  1
 9  200  0.495  16.650  2  1
 9  200  1.000  34.530  3  1
 9  200  1.500  43.815  4  1
 9  200  1.965  48.495  5  1
 9  200  2.485  47.520  6  1
 9  200  2.980  41.640  7  1
10  200  0.235   1.230  1  1
10  200  0.505  15.375  2  1
10  200  1.020  32.835  3  1
10  200  1.475  37.830  4  1
10  200  1.970  40.590  5  1
10  200  2.480  32.550  6  1
10  200  3.000  34.305  7  1
11  300  0.255   3.885  1  2
11  300  0.500  19.155  2  2
11  300  0.980  37.650  3  2
11  300  1.490  47.895  4  2
11  300  2.015  54.495  5  2
11  300  2.510  53.175  6  2
11  300  2.980  59.355  7  2
12  300  0.280   5.715  1  2
12  300  0.505  20.505  2  2
12  300  1.000  39.405  3  2
12  300  1.490  50.100  4  2
12  300  2.000  55.155  5  2
12  300  2.505  61.185  6  2
12  300  3.020  50.715  7  2
13  300  0.355  10.410  1  2
13  300  0.480  19.320  2  2
13  300  1.025  43.770  3  2
13  300  1.500  51.225  4  2
13  300  1.990  58.095  5  2
13  300  2.500  54.090  6  2
13  300  3.005  62.010  7  2
14  300  0.235   3.600  1  2
14  300  0.480  20.490  2  2
14  300  1.010  41.880  3  2
14  300  1.490  49.995  4  2
14  300  1.990  57.675  5  2
14  300  2.480  62.475  6  2
14  300  3.005  62.145  7  2
15  300  0.260   1.890  1  2
15  300  0.515  18.510  2  2
15  300  0.970  37.215  3  2
15  300  1.505  52.350  4  2
15  300  1.990  60.915  5  2
15  300  2.500  62.985  6  2
15  300  2.995  64.770  7  2
16  300  0.235   1.170  1  2
16  300  0.485  17.685  2  2
16  300  1.025  39.705  3  2
16  300  1.515  52.680  4  2
16  300  1.990  61.800  5  2
16  300  2.510  61.485  6  2
16  300  3.020  61.425  7  2
17  300  0.285   1.500  1  2
17  300  0.520  15.405  2  2
17  300  1.005  32.520  3  2
17  300  1.500  42.435  4  2
17  300  1.985  48.570  5  2
17  300  2.490  53.685  6  2
17  300  2.995  53.655  7  2
18  300  0.295   6.420  1  2
18  300  0.515  20.250  2  2
18  300  1.010  43.050  3  2
18  300  1.480  58.110  4  2
18  300  2.000  61.995  5  2
18  300  2.480  60.915  6  2
18  300  3.005  63.600  7  2
19  300  0.290   4.050  1  2
19  300  0.495  16.590  2  2
19  300  1.015  40.515  3  2
19  300  1.520  52.845  4  2
19  300  2.020  60.435  5  2
19  300  2.500  64.830  6  2
19  300  2.975  63.825  7  2
20  300  0.400  10.935  1  2
20  300  0.470  13.470  2  2
20  300  1.010  35.355  3  2
20  300  1.515  45.345  4  2
20  300  1.980  49.440  5  2
20  300  2.510  53.625  6  2
20  300  3.000  56.430  7  2
21  200  0.250    .     1  1
21  200  0.500    .     2  1
21  200  1.000    .     3  1
21  200  1.500    .     4  1
21  200  2.000    .     5  1
21  200  2.500    .     6  1
21  200  3.000    .     7  1
22  300  0.250    .     1  2
22  300  0.500    .     2  2
22  300  1.000    .     3  2
22  300  1.500    .     4  2
22  300  2.000    .     5  2
22  300  2.500    .     6  2
22  300  3.000    .     7  2
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 9.8                                       ---*/
axis2 value=( font=swiss height=.2 in)
      width=3
      value=(f=swissb h=.15 in ) ORDER = 0 TO 70 BY 10
      label=(f=swissb H=.16 in a=90 'UFR');
axis1 value=( font=swiss height=.2 in)
      width=3
      label=(f=swissb H=.16 in 'TMP')
      value=(f=swissb h=.15 in )  order=0 TO 3 By 1 ;
symbol1 v=none i=join r=11 l=1 c=black;
symbol2 v=none i=join r=11 l=3 c=black;
footnote f=swissb h=.15 in 
         "Solid lines are QB=200 and dashed lines are QB=300";
proc gplot data=dial;
   plot ufr*tmp=sub/nolegend vaxis=axis2 haxis=axis1;
run;
footnote;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.19                                      ---*/
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=un subject=sub r rcorr;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.20                                      ---*/
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=un subject=sub;
   ods output InfoCrit=icun;
   ods select InfoCrit;
run;

proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=ar(1) subject=sub;
   ods output InfoCrit=icar;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=arh(1) subject=sub;
   ods output InfoCrit=icarh;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   random int tmp / subject=sub type=un;
   ods output InfoCrit=icrc;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=cs subject=sub;
   ods output InfoCrit=iccs;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=csh subject=sub;
   ods output InfoCrit=iccsh;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=fa(1) subject=sub;
   ods output InfoCrit=icfa;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=fa1(1) subject=sub;
   ods output InfoCrit=icfa1;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=hf subject=sub;
   ods output InfoCrit=ichf;
   ods select InfoCrit;
run;
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   random int tmp tmp*tmp / subject=sub type=un;
   ods output InfoCrit=icrcq;
   ods select InfoCrit;
run;
data ii;
   input parm row col1-col7;
   datalines;
1 1 1 1 1 1 1 1 1
1 2 1 1 1 1 1 1 1
1 3 1 1 1 1 1 1 1
1 4 1 1 1 1 1 1 1
1 5 1 1 1 1 1 1 1
1 6 1 1 1 1 1 1 1
1 7 1 1 1 1 1 1 1
2 2 0 1 1 1 1 1 1
2 3 0 1 1 1 1 1 1
2 4 0 1 1 1 1 1 1
2 5 0 1 1 1 1 1 1
2 6 0 1 1 1 1 1 1
2 7 0 1 1 1 1 1 1
3 3 0 0 1 1 1 1 1
3 4 0 0 1 1 1 1 1
3 5 0 0 1 1 1 1 1
3 6 0 0 1 1 1 1 1
3 7 0 0 1 1 1 1 1
4 4 0 0 0 1 1 1 1
4 5 0 0 0 1 1 1 1
4 6 0 0 0 1 1 1 1
4 7 0 0 0 1 1 1 1
5 5 0 0 0 0 1 1 1
5 6 0 0 0 0 1 1 1
5 7 0 0 0 0 1 1 1
6 6 0 0 0 0 0 1 1
6 7 0 0 0 0 0 1 1
7 7 0 0 0 0 0 0 1
;
 
proc mixed data=dial ic;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp;
   repeated / type=lin(7) ldata=ii sub=sub r rcorr;
   ods output InfoCrit=iclin;
   ods select InfoCrit;
run;

data icun;  set icun ; length type $6; type="UN    ";
data icar;  set icar ; length type $6; type="AR(1) ";
data icarh; set icarh; length type $6; type="ARH(1)";
data iccs;  set iccs ; length type $6; type="CS    ";
data iccsh; set iccsh; length type $6; type="CSH   ";
data ichf;  set ichf ; length type $6; type="HF    ";
data icfa;  set icfa ; length type $6; type="FA(1) ";
data icfa1; set icfa1; length type $6; type="FA1(1)";
data icrc ; set icrc ; length type $6; type="RC    "; 
data icrcq; set icrcq; length type $6; type="RCQ   "; 
data iclin; set iclin; length type $6; type="I_I   "; 
run;

data models;
   set icun icar icarh iccs iccsh ichf icfa icfa1 icrc icrcq iclin;
   model = _n_;
proc print data=models;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 9.9                                       ---*/
 /*---Figure 9.10                                      ---*/
 /*---Figure 9.11                                      ---*/
 /*---Figure 9.12                                      ---*/
 /*---Figure 9.13                                      ---*/
 /*---Figure 9.14                                      ---*/
 /*---Figure 9.15                                      ---*/
 /*---Figure 9.16                                      ---*/
 /*---Figure 9.17                                      ---*/
symbol1  color=black font=swiss value='UN    ' repeat=1;
symbol2  color=black font=swiss value='AR(1) ' repeat=1;
symbol3  color=black font=swiss value='ARH(1)' repeat=1;
symbol4  color=black font=swiss value='CS    ' repeat=1;
symbol5  color=black font=swiss value='CSH   ' repeat=1;
symbol6  color=black font=swiss value='HF    ' repeat=1;
symbol7  color=black font=swiss value='FA(1) ' repeat=1;
symbol8  color=black font=swiss value='FA1(1)' repeat=1;
symbol9  color=black font=swiss value='RC    ' repeat=1;
symbol10 color=black font=swiss value='RCQ   ' repeat=1;
symbol11 color=black font=swiss value='I-I   ' repeat=1;

proc gplot data=models;
   plot aic *parms = model / nolegend;
   plot bic *parms = model / nolegend;
   plot aicc*parms = model / nolegend;
   plot hqic*parms = model / nolegend;
   plot caic*parms = model / nolegend;
   plot aic*bic    = model / nolegend;
   plot aic*aicc   = model / nolegend;
   plot aic*hqic   = model / nolegend;
   plot aic*caic   = model / nolegend;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.21                                      ---*/
proc mixed data=dial;
   class qb sub;
   model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp / s;
   random int tmp tmp*tmp / type=un sub=sub;
   ods output solutionf=sf;
run;

data cp;
   input est;
   datalines;
  2.24606822 
 -3.73117853 
 24.08025511 
  0.68705846 
 -6.82952740 
  2.17225966
  1 
  0.0663507
;

%macro iterate;
  %let iter      = 1;
  %let maxiter   = 20;
  %let converged = 0;
  %do %while ((&iter < &maxiter) & (&converged = 0));
     proc mixed data=dial;
        class qb sub;
        model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp / s;
        random int tmp tmp*tmp / type=un sub=sub;
        repeated / local=pom(sf);
        parms / pdata=cp;
        ods output solutionf=sf1 covparms=cp1;
        ods select CovParms SolutionF;
     run;
     data crit;
        merge sf(rename=(estimate=est_old)) sf1;
        diff = abs(est_old - estimate);
     run;
     proc means data=crit noprint;
        var diff;
        output out=max max=crit;
     run;
     data _null_; set max;
        converged = (crit < 1e-6);
        call symput('converged',left(put(converged,1.)));
     run;
     data sf; set sf1;  
     data cp; set cp1; 
     run;
     %let iter = %eval(&iter+1);
     %put iter = &iter;
     %put converged = &converged;
  %end;
  %if (&converged = 1) %then %do;
     /*---final run---*/
     proc mixed data=dial;
        class qb sub;
        model ufr = tmp|tmp|tmp|tmp qb|tmp|tmp|tmp|tmp / s;
        random int tmp tmp*tmp / type=un sub=sub;
        repeated / local=pom(sf);
        parms / pdata=cp;
     run;
  %end;
%mend iterate;
%iterate;
run;
 /*-------------------------------------------------------*/
 
 /*-------------------------------------------------------*/
 /*---Output 9.22                                      ---*/
proc mixed data=dial ic;
    class qb sub;
     model ufr = tmp tmp*tmp tmp*tmp*tmp 
                 tmp*tmp*tmp*tmp qb qb*tmp /outp=pred;
     random sub;
     repeated / type=arh(1) subject=sub;
     lsmeans qb / diff at tmp=.5;
     lsmeans qb / diff at tmp=.6;
     lsmeans qb / diff at tmp=.65;
     lsmeans qb / diff at tmp=.7;
     lsmeans qb / diff at tmp=.75;
     lsmeans qb / diff at tmp=1;
     lsmeans qb / diff at tmp=2;
     lsmeans qb / diff at tmp=3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 9.6, Grip                               ---*/
data grip; 
   input subject x trt Gender $ time t y;
   datalines;
26  175  1  M  1  1  161
26  175  1  M  2  2  210
26  175  1  M  3  3  230
27  165  1  M  1  1  215
27  165  1  M  2  2  245
27  165  1  M  3  3  265
29  175  1  M  1  1  134
29  175  1  M  2  2  215
29  175  1  M  3  3  139
34  178  1  M  1  1  165
34  178  1  M  2  2  140
34  178  1  M  3  3  175
35  220  1  M  1  1  220
35  220  1  M  2  2  189
35  220  1  M  3  3  158
38   90  1  M  1  1  146
38   90  1  M  2  2  140
38   90  1  M  3  3  130
42  300  1  M  1  1  300
42  300  1  M  2  2  300
42  300  1  M  3  3  300
44  238  1  M  1  1  278
44  238  1  M  2  2  170
44  238  1  M  3  3  158
54  200  1  M  1  1  230
54  200  1  M  2  2  220
54  200  1  M  3  3  240
57  130  1  M  1  1  155
57  130  1  M  2  2  170
57  130  1  M  3  3  125
74  215  1  M  1  1  230
74  215  1  M  2  2  243
74  215  1  M  3  3  245
76  207  1  M  1  1  220
76  207  1  M  2  2  .
76  207  1  M  3  3  .
79  225  1  M  1  1  220
79  225  1  M  2  2  250
79  225  1  M  3  3  235
 1  120  2  M  1  1  130
 1  120  2  M  2  2  150
 1  120  2  M  3  3  120
25  300  2  M  1  1  300
25  300  2  M  2  2  300
25  300  2  M  3  3  300
28  179  2  M  1  1  232
28  179  2  M  2  2  285
28  179  2  M  3  3  .
31  209  2  M  1  1  260
31  209  2  M  2  2  200
31  209  2  M  3  3  125
36  200  2  M  1  1  200
36  200  2  M  2  2  200
36  200  2  M  3  3  232
39  300  2  M  1  1  300
39  300  2  M  2  2  300
39  300  2  M  3  3  300
41  200  2  M  1  1  245
41  200  2  M  2  2  290
41  200  2  M  3  3  280
43  172  2  M  1  1  170
43  172  2  M  2  2  170
43  172  2  M  3  3  146
45  158  2  M  1  1  140
45  158  2  M  2  2  152
45  158  2  M  3  3  150
47  150  2  M  1  1  220
47  150  2  M  2  2  168
47  150  2  M  3  3  139
53  135  2  M  1  1  155
53  135  2  M  2  2  215
53  135  2  M  3  3  170
56   75  2  M  1  1  170
56   75  2  M  2  2  220
56   75  2  M  3  3  240
58  150  2  M  1  1  200
58  150  2  M  2  2  185
58  150  2  M  3  3  163
61  155  2  M  1  1  101
61  155  2  M  2  2   93
61  155  2  M  3  3  120
73  190  2  M  1  1  240
73  190  2  M  2  2  210
73  190  2  M  3  3  173
75  265  2  M  1  1  275
75  265  2  M  2  2  255
75  265  2  M  3  3  270
 2   80  1  F  1  1   80
 2   80  1  F  2  2   86
 2   80  1  F  3  3   80
 4   64  1  F  1  1   80
 4   64  1  F  2  2   80
 4   64  1  F  3  3   70
 5   40  1  F  1  1   60
 5   40  1  F  2  2  .
 5   40  1  F  3  3  .
 8   40  1  F  1  1   50
 8   40  1  F  2  2   30
 8   40  1  F  3  3   40
 9   70  1  F  1  1   90
 9   70  1  F  2  2  110
 9   70  1  F  3  3   90
15   70  1  F  1  1   80
15   70  1  F  2  2   95
15   70  1  F  3  3  110
18   70  1  F  1  1   80
18   70  1  F  2  2   86
18   70  1  F  3  3  .
19   70  1  F  1  1   60
19   70  1  F  2  2   70
19   70  1  F  3  3   80
21   50  1  F  1  1   80
21   50  1  F  2  2   90
21   50  1  F  3  3   90
24   40  1  F  1  1   60
24   40  1  F  2  2   60
24   40  1  F  3  3   65
40  140  1  F  1  1  156
40  140  1  F  2  2  140
40  140  1  F  3  3  150
46  110  1  F  1  1   82
46  110  1  F  2  2   98
46  110  1  F  3  3  110
48  180  1  F  1  1  165
48  180  1  F  2  2  150
48  180  1  F  3  3  160
50  155  1  F  1  1  150
50  155  1  F  2  2  170
50  155  1  F  3  3  185
52   55  1  F  1  1  105
52   55  1  F  2  2   70
52   55  1  F  3  3   88
59   95  1  F  1  1   90
59   95  1  F  2  2   90
59   95  1  F  3  3  116
63   90  1  F  1  1  135
63   90  1  F  2  2   95
63   90  1  F  3  3  .
64  145  1  F  1  1  140
64  145  1  F  2  2  164
64  145  1  F  3  3  .
70   34  1  F  1  1   51
70   34  1  F  2  2   87
70   34  1  F  3  3  .
 3   60  2  F  1  1   80
 3   60  2  F  2  2   60
 3   60  2  F  3  3   60
 6   50  2  F  1  1   70
 6   50  2  F  2  2   70
 6   50  2  F  3  3   70
 7   80  2  F  1  1   75
 7   80  2  F  2  2   90
 7   80  2  F  3  3   90
10   80  2  F  1  1  100
10   80  2  F  2  2   80
10   80  2  F  3  3   90
13   80  2  F  1  1   60
13   80  2  F  2  2   65
13   80  2  F  3  3   70
17   58  2  F  1  1   50
17   58  2  F  2  2   80
17   58  2  F  3  3   80
20   60  2  F  1  1   60
20   60  2  F  2  2   80
20   60  2  F  3  3   60
22   80  2  F  1  1   90
22   80  2  F  2  2  120
22   80  2  F  3  3  130
23   60  2  F  1  1   90
23   60  2  F  2  2   94
23   60  2  F  3  3  100
30   75  2  F  1  1  131
30   75  2  F  2  2   95
30   75  2  F  3  3  105
37  150  2  F  1  1  108
37  150  2  F  2  2  160
37  150  2  F  3  3  160
49   55  2  F  1  1   60
49   55  2  F  2  2   65
49   55  2  F  3  3   55
51  130  2  F  1  1  130
51  130  2  F  2  2  160
51  130  2  F  3  3  125
55  115  2  F  1  1   95
55  115  2  F  2  2  105
55  115  2  F  3  3  110
62  135  2  F  1  1  120
62  135  2  F  2  2  144
62  135  2  F  3  3  135
65   60  2  F  1  1   85
65   60  2  F  2  2   85
65   60  2  F  3  3  .
67   40  2  F  1  1   45
67   40  2  F  2  2   76
67   40  2  F  3  3   75
71  104  2  F  1  1  107
71  104  2  F  2  2  .
71  104  2  F  3  3  .
72   60  2  F  1  1   60
72   60  2  F  2  2   55
72   60  2  F  3  3   58
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.23                                      ---*/
proc mixed data=grip;
   class subject trt Gender time;
   model y = trt|Gender|time x time*x Gender*x trt*x;
   repeated / type=un subject=subject r rcorr;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.24                                      ---*/
proc mixed data=grip;
   class subject trt gender time;
   model y = trt|gender|time x time*x gender*x trt*x;
   repeated / type=un sub=subject group=gender
              r=1,2 rcorr=1,2;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 9.21                                      ---*/
 /*---Figure 9.22                                      ---*/
proc mixed data=grip;
   class subject trt gender time;

   model y = trt|gender|time x time*x gender*x trt*x / outp=p;
   id time subject gender;
run; 

symbol i=join c=black r=38;
proc gplot data=p;
   where gender = 'F';
   plot resid*time=subject / nolegend hminor=0;
run;

symbol i=join c=black r=29;
proc gplot data=p;
   where gender = 'M';
   plot resid*time=subject / nolegend hminor=0;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.25                                      ---*/
proc mixed data=grip;
   class subject trt gender time;
   model y = trt|gender|time x time*x gender*x trt*x;
   random int t / type=un sub=subject group=gender;
   ods select CovParms FitStatistics Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.26                                      ---*/
proc mixed data=grip;
   class subject trt gender time;
   model y = trt|gender|time x time*x gender*x trt*x;
   random int t / type=un sub=subject group=gender;
   repeated / sub=subject group=gender;
   ods select CovParms FitStatistics Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 9.7, Preetch                           ---*/
data preetch;
   input expt wafer mask viscos spin baketemp baketime 
          aperture expos develop etch y1-y5;
    y = y1; loc = 'top'; output;
    y = y2; loc = 'cen'; output;
    y = y3; loc = 'bot'; output;
    y = y4; loc = 'lef'; output;
    y = y5; loc = 'rig'; output;
    drop y1-y5;
    datalines;
 1  1  -1  -1  -1  -1  -1  -1  -1  -1  -1  2.43  2.52  2.63  2.52  2.50
 1  2  -1  -1  -1  -1  -1  -1  -1  -1  -1  2.36  2.50  2.62  2.43  2.49
 2  1  -1  -1   0  -1   0   0   0   0   0  2.76  2.66  2.74  2.60  2.53
 2  2  -1  -1   0  -1   0   0   0   0   0  2.66  2.73  2.95  2.57  2.64
 3  1  -1  -1   1  -1   1   1   1   1   1  2.82  2.71  2.78  2.55  2.36
 3  2  -1  -1   1  -1   1   1   1   1   1  2.76  2.67  2.90  2.62  2.43
 4  1  -1   1  -1  -1  -1   0   0   1   1  2.02  2.06  2.21  1.98  2.13
 4  2  -1   1  -1  -1  -1   0   0   1   1  1.85  1.66  2.07  1.81  1.83

 5  1  -1   1   0  -1   0   1   1  -1  -1  1.87  1.78  2.07  1.80  1.83
 6  1  -1   1   1  -1   1  -1  -1   0   0  2.51  2.56  2.55  2.45  2.53
 6  2  -1   1   1  -1   1  -1  -1   0   0  2.68  2.60  2.85  2.55  2.56
 7  1  -1  -1  -1   1   0  -1   1   0   1  1.99  1.99  2.11  1.99  2.00
 7  2  -1  -1  -1   1   0  -1   1   0   1  1.96  2.20  2.04  2.01  2.03
 8  1  -1  -1   0   1   1   0  -1   1  -1  3.15  3.44  3.67  3.09  3.06
 8  2  -1  -1   0   1   1   0  -1   1  -1  3.27  3.29  3.49  3.02  3.19
 9  1  -1  -1   1   1  -1   1   0  -1   0  3.00  2.91  3.07  2.66  2.74
 9  2  -1  -1   1   1  -1   1   0  -1   0  2.73  2.79  3.00  2.69  2.70
10  1   1  -1  -1  -1   1   1   0   0  -1  2.69  2.50  2.51  2.46  2.40
10  2   1  -1  -1  -1   1   1   0   0  -1  2.75  2.73  2.75  2.78  3.03
11  1   1  -1   0  -1  -1  -1   1   1   0  3.20  3.19  3.32  3.20  3.15
11  2   1  -1   0  -1  -1  -1   1   1   0  3.07  3.14  3.14  3.13  3.12
12  1   1  -1   1  -1   0   0  -1  -1   1  3.21  3.32  3.33  3.23  3.10
12  2   1  -1   1  -1   0   0  -1  -1   1  3.48  3.44  3.49  3.25  3.38
13  1   1   1  -1  -1   0   1  -1   1   0  2.60  2.56  2.62  2.55  2.56
13  2   1   1  -1  -1   0   1  -1   1   0  2.53  2.49  2.79  2.50  2.56
14  1   1   1   0  -1   1  -1   0  -1   1  2.18  2.20  2.45  2.22  2.32
14  2   1   1   0  -1   1  -1   0  -1   1  2.33  2.20  2.41  2.37  2.38
15  1   1   1   1  -1  -1   0   1   0  -1  2.45  2.50  2.51  2.43  2.43
16  1   1  -1  -1   1   1   0   1  -1   0  2.67  2.53  2.72  2.70  2.60
16  2   1  -1  -1   1   1   0   1  -1   0  2.76  2.67  2.73  2.69  2.60
17  1   1  -1   0   1  -1   1  -1   0   1  3.31  3.30  3.44  3.12  3.14
17  2   1  -1   0   1  -1   1  -1   0   1  3.12  2.97  3.18  3.03  2.95
18  1   1  -1   1   1   0  -1   0   1  -1  3.46  3.49  3.50  3.45  3.57
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.27                                     ---*/
title "Initial Model with Equal Variances";
proc mixed data=preetch ic;
   class expt wafer mask viscos spin baketemp 
         baketime aperture expos develop loc;
   model y = mask viscos spin baketemp 
             baketime aperture expos develop 
             loc loc*mask loc*viscos loc*spin loc*baketemp 
             loc*baketime loc*aperture 
             loc*expos loc*develop / outp=pred ddfm=kr;
   random int / sub=wafer(expt);
   ods select CovParms InfoCrit Tests3;
   ods output InfoCrit=ic_init
              Tests3  =t3_init;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.28                                      ---*/
proc mixed data=preetch covtest ic;
   title "Model with Local=exp(all terms)";
   class expt wafer mask viscos spin baketemp 
         baketime aperture expos develop loc;
   model y = mask viscos spin baketemp 
             baketime aperture expos develop loc loc*mask
             loc*viscos loc*spin loc*baketemp loc*baketime
             loc*aperture loc*expos loc*develop / 
                          outp=pred ddfm=kr;
   random int / sub=wafer(expt);
   repeated  / subject=wafer(expt)  
               local=exp(mask viscos spin baketemp baketime 
                         aperture expos develop); 
   ods select CovParms InfoCrit Tests3;
   ods output InfoCrit=ic_full
              Tests3  =t3_full;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.29                                      ---*/
proc mixed data=preetch ic;
   title "Model with Local=exp(reduced terms)";
   class expt wafer mask viscos spin baketemp 
         baketime aperture expos develop loc;
    model y = mask viscos spin baketemp 
          baketime aperture expos develop loc loc*mask
          loc*viscos loc*spin loc*baketemp loc*baketime
          loc*aperture loc*expos loc*develop/outp=pred ddfm=kr;
   random int / sub=wafer(expt);
   repeated/subject=wafer(expt) local=exp( develop expos);
   ods select CovParms InfoCrit Tests3;
   ods output InfoCrit=ic_red
              Tests3  =t3_red;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.30                                      ---*/
proc mixed data=preetch ic;
   title "UN cov matrix for locs";
   class expt wafer mask viscos spin baketemp 
         baketime aperture expos develop loc;
   model y = mask viscos spin baketemp baketime aperture
             expos develop loc loc loc*mask loc*viscos 
             loc*spin loc*baketemp loc*baketime 
             loc*aperture loc*expos loc*develop/ ddfm=bw;
   repeated loc/sub=wafer(expt) type=un;
   ods select CovParms InfoCrit Tests3;
   ods output InfoCrit=ic_un
              Tests3  =t3_un;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.31                                      ---*/
data ic_un;   set ic_un;   length model $7; model='Un     ';
data ic_red;  set ic_red;  length model $7; model='Reduced';
data ic_full; set ic_full; length model $7; model='Full   ';
data ic_init; set ic_init; length model $7; model='Initial';
run;
data models; set ic_init ic_full ic_red ic_un;
proc print data=models;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 9.32                                      ---*/
data tests;
   merge t3_init(rename=(ProbF=Initial))
         t3_full(rename=(ProbF=Full   ))
         t3_red (rename=(ProbF=Reduced))
         t3_un  (rename=(ProbF=UN     ));
   keep Effect NumDf Initial Full Reduced Un;
proc print data=tests;
run;
 /*-------------------------------------------------------*/




 /*-------------------------------------------------------*/
 /*---CHAPTER 10: Mixed Model Diagnostics              ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 10.2 Cultivar-Inoculation Trial         ---*/
data cultspd;
   input block cult$ inoc$ drywt;
   datalines;
1 a con 27.4
1 a dea 29.7
1 a liv 34.5
1 b con 29.4
1 b dea 32.5
1 b liv 34.4
2 a con 28.9
2 a dea 28.7
2 a liv 33.4
2 b con 28.7
2 b dea 32.4
2 b liv 36.4
3 a con 28.6
3 a dea 29.7
3 a liv 32.9
3 b con 27.2
3 b dea 29.1
3 b liv 32.6
4 a con 26.7
4 a dea 28.9
4 a liv 31.8
4 b con 26.8
4 b dea 28.6
4 b liv 30.7
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/

 /*---Output 10.1                                      ---*/
 /*---Figure 10.1                                      ---*/
 /*---Figure 10.2                                      ---*/
ods html;
ods graphics on;
proc glimmix data=cultspd
      plots=(studentpanel(type=noblup)
             studentpanel(type=blup));
   class block cult inoc;
   model drywt = cult inoc cult*inoc / ddfm=satterth;
   random block block*cult;
   ods select FitStatistics CovParms Tests3 StudentPanel;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 10.2                                      ---*/
proc glimmix data=cultspd;
   class block cult inoc;
   model drywt = cult inoc cult*inoc / ddfm=satterth;
   random block block*cult;
   output out=gmxout student(blup)  = resid_cond
                     student(noblup)= resid_marg;
run;
proc means data=gmxout min max mean;
   var resid_cond resid_marg;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 10.3                                      ---*/
ods html;
ods graphics on;
proc glimmix data=cultspd plots=studentpanel(type=noblup);
   class block cult inoc;
   model drywt = block cult block*cult 
                 inoc cult*inoc / ddfm=satterth;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 5.4, Heart Rates                        ---*/
 /*---These data are revisited in Section 10.4         ---*/
data hr;
   input patient drug$ basehr hr1 hr5 hr15 hr30 hr1h;
   array hra{5} hr1 hr5 hr15 hr30 hr1h;
   do i = 1 to 5;
      if (i = 1) then hours = 1/60;
      else if (i = 2) then hours = 5/60;
      else if (i = 3) then hours = 15/60;
      else if (i = 4) then hours = 30/60;
      else hours = 1;
      hours1 = hours;
      hr = hra{i};
      output;
   end;
   drop i hr1 hr5 hr15 hr30 hr1h;
   datalines;
201  p    92   76   84   88   96   84 
202  b    54   58   60   60   60   64 
203  p    84   86   82   84   86   82 
204  a    72   72   68   68   78   72 
205  b    80   84   84   96   92   72 
206  p    68   72   68   68   64   62 
207  a   100  104  100   92   92   68 
208  a    60   60   58   56   50   56 
209  a    88  104   88   88   78   84 
210  b    92   82   82   76   82   80 
211  b    88   80   84   80   80   78 
212  p   102   86   86   96   86   88 
214  a    84   92  100   88   88   80 
215  b   104  100   96   88   92   84 
216  a    92   80   72   64   68   64 
217  p    92   88   84   76   88   84 
218  a    72   84   78   80   80   76 
219  b    72  100   92   84   88   80 
220  p    80   80   80   78   80   78 
221  p    72   68   76   72   72   68 
222  b    88   88   98   98   96   88 
223  b    88   88   96   88   88   80 
224  p    88   78   84   64   68   64 
232  a    78   72   72   78   80   68 
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 10.3                                      ---*/
 /*---Figure 10.4                                      ---*/
 /*---Figure 10.5                                      ---*/
 /*---Figure 10.6                                      ---*/
 /*---Figure 10.7                                      ---*/
 /*---Figure 10.8                                      ---*/
ods html;
ods graphics on;
proc mixed data=hr order=data;
   class drug hours patient;
   model hr = drug basehr / noint s residual
              influence(iter=5 effect=patient est);
   repeated hours / type=sp(exp)(hours1) sub=patient;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 10.9                                      ---*/
 /*---Figure 10.10                                     ---*/
 /*---Figure 10.11                                     ---*/
ods html file="test.html";
ods graphics on;
proc mixed data=hr order=data;
   class drug hours patient;
   model hr = drug hours drug*hours basehr / s
              residual
              influence(iter=5 effect=patient);
   repeated hours / type=sp(exp)(hours) sub=patient;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---CHAPTER 11: Spatial Variability                  ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 11.5, Uniformity Trial                  ---*/
data spatvar;
   input rep bloc row col yield;
   datalines;
1    4   1   1     10.5411
1    4   1   2      8.5806
1    2   1   3     11.2790
1    2   1   4     12.4344
1    4   2   1     10.3416
1    4   2   2     11.3103
1    2   2   3      9.0282
1    2   2   4      9.7985
1    3   3   1     10.4939
1    3   3   2     11.2576
1    1   3   3      7.3720
1    1   3   4      6.0833
1    3   4   1      9.8869
1    3   4   2      8.2849
1    1   4   3      7.2836
1    1   4   4      8.0018
2    7   5   1     10.3349
2    7   5   2      9.9135
2    6   5   3      8.1662
2    6   5   4     10.7679
2    7   6   1     12.1580
2    7   6   2     11.0230
2    6   6   3      9.2912
2    6   6   4      9.1392
2    5   7   1     13.1097
2    5   7   2     10.0121
2    8   7   3      8.2482
2    8   7   4      7.3975
2    5   8   1     11.0226
2    5   8   2     10.7690
2    8   8   3      6.2206
2    8   8   4      6.5696
3   12   1   5     11.1944
3   12   1   6      7.9737
3   11   1   7      5.8400
3   11   1   8      6.9580
3   12   2   5     10.2561
3   12   2   6      9.8180
3   11   2   7     10.3009
3   11   2   8      7.4719
3    9   3   5     10.1148
3    9   3   6      9.6252
3   10   3   7      8.7800
3   10   3   8     11.2786
3    9   4   5      7.9548
3    9   4   6      6.1100
3   10   4   7      8.6507
3   10   4   8      9.2237
4   16   5   5     10.3129
4   16   5   6      7.3161
4   13   5   7      8.6394
4   13   5   8      7.8669
4   16   6   5      9.0250
4   16   6   6      7.2483
4   13   6   7     10.0104
4   13   6   8     10.0473
4   14   7   5      7.0507
4   14   7   6     11.1225
4   15   7   7     12.0253
4   15   7   8     10.4298
4   14   8   5      7.3220
4   14   8   6     10.5104
4   15   8   7     12.6808
4   15   8   8     10.4482
;
 /*-------------------------------------------------------*/
 
 /*-------------------------------------------------------*/
 /*---Output 11.1                                      ---*/
title 'no nugget - spherical covariance model';
proc mixed data=spatvar;
   model yield = ;
   repeated / subject = intercept 
              type    = sp(sph)(row col);
   parms (0 to 10 by 2.5) 
         (1 to 10 by 3  );
   ods select ParmSearch CovParms IterHistory 
              ConvergenceStatus FitStatistics LRT;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 11.2                                      ---*/
title 'no nugget - exponential covariance model';
proc mixed data=spatvar;
   model yield = ;
   repeated / subject = intercept 
              type    = sp(exp)(row col);
   parms (0 to 10 by 2.5) 
         (1 to 10 by 3  );
   ods select CovParms FitStatistics;
run;
proc mixed data=spatvar;
   model yield = ;
   repeated / subject = intercept 
              type    = sp(gau)(row col);
   parms (0 to 10 by 2.5) 
         (1 to 10 by 3  );
   ods select CovParms FitStatistics;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 11.3                                      ---*/
title 'rcb error model';
proc mixed data=spatvar;
   class rep;
   model yield = ;
   random rep;
   ods select CovParms FitStatistics;
run;
    
title 'incomplete block error model';
proc mixed data=spatvar;
   class bloc;
   model yield = ;
   random bloc;
   ods select CovParms FitStatistics;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Outpuyt 11.4 a                                   ---*/
title 'nugget effect - exponential covariance model';
proc mixed data=spatvar; 
   model yield = ;
   repeated / subject = intercept 
              type    = sp(exp)(row col)
              local;
   parms (0    to 10    by 2.5 ) 
         (1    to 10    by 3   ) 
         (0.05 to  1.05 by 0.25);
   ods select IterHistory ConvergenceStatus CovParms;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Outpuyt 11.4 b                                   ---*/
title 'nugget effect - exponential covariance model';
proc mixed data=spatvar convg=1e-7; 
   model yield = ;
   repeated / subject = intercept 
              type    = sp(exp)(row col)
              local;
   parms (0    to 10    by 2.5 ) 
         (1    to 10    by 3   ) 
         (0.05 to  1.05 by 0.25);
   ods select IterHistory ConvergenceStatus CovParms;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 11.5                                      ---*/
data spatvar; set spatvar;
  obs = _n_;
run;
proc mixed data=spatvar convg=1e-7;
   class obs;
   model yield = ;
   random obs / type=sp(exp)(row col);
   parms (0    to 10   by 2.5 ) 
         (1    to 10   by 3   ) 
         (0.05 to 1.05 by 0.25);
   ods select Dimensions IterHistory ConvergenceStatus 
              FitStatistics CovParms;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 11.6, Hazardous Waste                   ---*/
data a;
   input easting northing logt salt xxx $;
   if logt=1e31 or logt<-10 then delete;
   if salt=1e31 then delete;
   datalines;
16.442  18.128 -6.02895   28.6   H-1
15.670  18.095 -6.20046   26.9   H-2b1
16.748  17.339 -5.60886   -0.6   H-3b1
15.399  14.927 -5.99598    0     H-4b
19.891  21.245 -7.01145   1E31   H-5b
13.613  21.452 -4.44995   -0.6   H-6b
11.143  11.092 -2.81246  -37.1   H-7b
11.702       0 -5.05465  -19.9   H-8b
17.008   4.705 -3.90188      0   H-9b
25.994   8.917 -7.12337      0   H-10b
18.365  15.574 -4.50570   1E31   H-11b1
20.042  11.896 -6.71319  100.3   H-12
15.36   16.798 -6.48422   1E31   H-14
18.334  18.303 -6.88042   1E31   H-15
16.388  18.656 -6.11491   32.8   H-16
18.737  13.957 -6.63614   64.6   H-17
15.283  19.61  -5.77751   27.4   H-18
18.222  16.777 -4.92707   1E31   DOE-1
16.702  21.738 -4.01908   1E31   DOE-2
15.357  16.785   1E+31    24.3   P-1
18.335  18.292   1E+31    31.1   P-2
15.818  18.342   1E+31    29.9   P-3
17.954  16.763   1E+31    31.7   P-4
16.703  19.984   1E+31    29.6   P-5
13.628  17.528   1E+31    -0.5   P-6
15.327  14.922   1E+31    20.7   P-7
16.849  14.911   1E+31    33.2   P-8
18.375  15.569   1E+31    31.4   P-9
20.106  17.647   1E+31     114   P-10
20.035  19.901   1E+31    30.5   P-11
13.475  19.896   1E+31    -0.9   P-12
13.55   21.473   1E+31    -1.2   P-13
12.10   18.42  -3.55706   -2.4   P-14
13.643  15.191 -7.03535     25   P-15
15.714  13.765   1E+31    28.6   P-16
16.945  13.91  -5.96847   34.4   P-17
21.386  16.794 -10.1233  132.2   P-18
20.7    18.862   1E+31    69.36  P-19
21.551  20.212   1E+31    30.8   P-20
19.917  21.293   1E+31    30.2   P-21
16.81   22.919   1E+31       0   WIPP-11
16.729  19.968 -6.96847   29.9   WIPP-12
15.663  20.691 -4.12962      0   WIPP-13
16.754  19.623 -6.49134   30.3   WIPP-18
16.758  19.226 -6.19031      0   WIPP-19
16.762  18.763 -6.57053   29.9   WIPP-21
16.758  19.097 -6.40026   29.8   WIPP-22
 9.404  20.472 -3.54116  -10.7   WIPP-25
 7.033  17.606 -2.91359   -3.3   WIPP-26
 7.445  29.523 -3.36921    -28   WIPP-27
14.285  31.124 -4.6839   -17.7   WIPP-28
 0      15.138 -2.96847  -32.9   WIPP-29
16.74   26.145 -6.60227      0   WIPP-30
12.649  20.463   1E+31    1E31   WIPP-33
17.353  21.586   1E+31    1E31   WIPP-34
21.239  25.452   1E+31    -0.1   ERDA-6
16.715  18.402 -6.29637   26.7   ERDA-9
 9.704   6.959   1E+31   -15.2   ERDA-10
16.21   14.493 -6.52131   1E31   C-B1
17.972   3.898 -4.33500   1E31   ENGLE
 9.481   5.903 -3.25842   1E31   USGS-1
 8.86    6.331   1E+31    1E31   USGS-4
 8.898   6.332   1E+31    1E31   USGS-8
11.721  15.321 -5.68971   1E31   D-268
24.145  25.825 -6.55349   18.7   AEC-7
20.544  22.886   1E+31       0   AEC-8
14.714  17.053   1E+31    -0.3   B-25
16.736  18.524   1E+31    1E31   EX. SHAFT
10.48   26.499   1E+31    1E31   FFG-107
 2.258   8.668   1E+31    1E31   FFG-153
 4.878    9.65   1E+31    1E31   FFG-165
 7.234   5.137   1E+31    1E31   FFG-181
 6.9    -0.971   1E+31    1E31   FFG-188*
32.296  33.411   1E+31    1E31   FFG-225*
23.873   33.47   1E+31    1E31   FFG-236
30.198  25.776   1E+31    1E31   FFG-244*
-4.458   28.01   1E+31    1E31   FFG-426*
-1.181  21.666   1E+31    1E31   1 DANF
 4.331   25.36   1E+31    1E31   1 DUNC
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 11.6                                      ---*/
proc mixed data=a; 
   model logt = salt / solution;
   repeated / subject = intercept 
              type    = sp(exp)(easting northing)
              local;
   parms (1   to  7   by 3  )
         (2   to 17   by 5  ) 
         (0.1 to  0.5 by 0.2);
   ods select CovParms FitStatistics SolutionF Tests3;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 11.7, Wheat Yield                       ---*/
data alliance;
   input Entry $ 1-22 variety_id 23-24 plot 26-29 RawYield 36-42 Rep 45-46
         LOC $ 47-49 NLOC  50-51 Yield 53-59 LAT 67-68 LNG 75-77;
   Latitude  = 4.3*LAT;
   Longitude = 1.2*LNG;
   if variety_id=. then delete;
   datalines;
    LANCER             1 1101       585.00   1    4  29.250        1       16
    BRULE              2 1102       631.00   1    4  31.550        1       17
    REDLAND            3 1103       701.00   1    4  35.050        1       18
    CODY               4 1104       602.00   1    4  30.100        1       19
    ARAPAHOE           5 1105       661.00   1    4  33.050        1       20
    NE83404            6 1106       605.00   1    4  30.250        1       21
    NE83406            7 1107    1  704.00   1    4  35.200        1       22
    NE83407            8 1108       388.00   1    4  19.400        2        1
    CENTURA            9 1109       487.00   1    4  24.350        2        2
    SCOUT 66          10 1110       511.00   1    4  25.550        2        3
    COLT              11 1111       502.00   1    4  25.100        2        4
    NE83498           12 1112       492.00   1    4  24.600        2        5
    NE84557           13 1113       509.00   1    4  25.450        2        6
    NE83432           14 1114       268.00   1    4  13.400        2        7
    NE85556           15 1115       633.00   1    4  31.650        2        8
    NE85623           16 1116       513.00   1    4  25.650        2        9
    CENTURK 78        17 1117       632.00   1    4  31.600        2       10
    NORKAN            18 1118       446.00   1    4  22.300        2       11
    KS831374          19 1119       684.00   1    4  34.200        2       12
    TAM 200           20 1120       422.00   1    4  21.100        2       13
    NE86482           21 1121       560.00   1    4  28.000        2       14
    HOMESTEAD         22 1122       566.00   1    4  28.300        2       15
    LANCOTA           23 1123       514.00   1    4  25.700        2       16
    NE86501           24 1124       635.00   1    4  31.750        2       17
    NE86503           25 1125       840.00   1    4  42.000        2       18
    NE86507           26 1126       618.00   1    4  30.900        2       19
    NE86509           27 1127       658.00   1    4  32.900        2       20
    TAM 107           28 1128       481.00   1    4  24.050        2       21
    CHEYENNE          29 1129    1  564.00   1    4  28.200        2       22
    BUCKSKIN          30 1130       597.00   1    4  29.850        3        1
    NE86527           31 1131       580.00   1    4  29.000        3        2
    NE86582           32 1132       418.00   1    4  20.900        3        3
    NE86606           33 1133       526.00   1    4  26.300        3        4
    NE86607           34 1134       517.00   1    4  25.850        3        5
    ROUGHRIDER        35 1135       479.00   1    4  23.950        3        6
    VONA              36 1136       506.00   1    4  25.300        3        7
    SIOUXLAND         37 1137       542.00   1    4  27.100        3        8
    GAGE              38 1138       513.00   1    4  25.650        3        9
    NE83T12           39 1139       504.00   1    4  25.200        3       10
    NE86T666          40 1140       368.00   1    4  18.400        3       11
    NE87403           41 1141       437.00   1    4  21.850        3       12
    NE87408           42 1142       540.00   1    4  27.000        3       13
    NE87409           43 1143       631.00   1    4  31.550        3       14
    NE87446           44 1144       610.00   1    4  30.500        3       15
    NE87451           45 1145       639.00   1    4  31.950        3       16
    NE87457           46 1146       611.00   1    4  30.550        3       17
    NE87463           47 1147       545.00   1    4  27.250        3       18
    NE87499           48 1148       598.00   1    4  29.900        3       19
    NE87512           49 1149       656.00   1    4  32.800        3       20
    NE87513           50 1150       557.00   1    4  27.850        3       21
    NE87522           51 1151    1  486.00   1    4  24.300        3       22
    NE87612           52 1152       563.00   1    4  28.150        4        1
    NE87613           53 1153       539.00   1    4  26.950        4        2
    NE87615           54 1154       502.00   1    4  25.100        4        3
    NE87619           55 1155       605.00   1    4  30.250        4        4
    NE87627           56 1156    1  403.00   1    4  20.150        4        5
    RC                                                 .           4        6
    CENTURA            9 2101       556.00   2    4  27.800        4        7
    NE85623           16 2102       569.00   2    4  28.450        4        8
    CODY               4 2103       455.00   2    4  22.750        4        9
    NE86582           32 2104       534.00   2    4  26.700        4       10
    NE87408           42 2105       513.00   2    4  25.650        4       11
    NE87451           45 2106       549.00   2    4  27.450        4       12
    NE83432           14 2107       620.00   2    4  31.000        4       13
    CENTURK 78        17 2108       498.00   2    4  24.900        4       14
    NE83T12           39 2109       513.00   2    4  25.650        4       15
    NE87409           43 2110       648.00   2    4  32.400        4       16
    NE87513           50 2111       624.00   2    4  31.200        4       17
    NE87627           56 2112       552.00   2    4  27.600        4       18
    ARAPAHOE           5 2113       693.00   2    4  34.650        4       19
    LANCER             1 2114       570.00   2    4  28.500        4       20
    TAM 107           28 2115       589.00   2    4  29.450        4       21
    REDLAND            3 2116    1  611.00   2    4  30.550        4       22
    VONA              36 2117       536.00   2    4  26.800        5        1
    NE87463           47 2118       477.00   2    4  23.850        5        2
    NE86507           26 2119       548.00   2    4  27.400        5        3
    BUCKSKIN          30 2120       602.00   2    4  30.100        5        4
    ROUGHRIDER        35 2121       495.00   2    4  24.750        5        5
    NE86527           31 2122       507.00   2    4  25.350        5        6
    SCOUT 66          10 2123       520.00   2    4  26.000        5        7
    NE86509           27 2124       500.00   2    4  25.000        5        8
    NE86606           33 2125       587.00   2    4  29.350        5        9
    NE84557           13 2126       572.00   2    4  28.600        5       10
    KS831374          19 2127       534.00   2    4  26.700        5       11
    GAGE              38 2128       505.00   2    4  25.250        5       12
    NE87619           55 2129       675.00   2    4  33.750        5       13
    NE87499           48 2130       446.00   2    4  22.300        5       14
    CHEYENNE          29 2131       561.00   2    4  28.050        5       15
    NE86607           34 2132       691.00   2    4  34.550        5       16
    NE83498           12 2133       748.00   2    4  37.400        5       17
    NE83404            6 2134       580.00   2    4  29.000        5       18
    NE87446           44 2135       624.00   2    4  31.200        5       19
    SIOUXLAND         37 2136       742.00   2    4  37.100        5       20
    HOMESTEAD         22 2137       590.00   2    4  29.500        5       21
    NE86501           24 2138    1  627.00   2    4  31.350        5       22
    NE87512           49 2139       404.00   2    4  20.200        6        1
    NE83407            8 2140       528.00   2    4  26.400        6        2
    NE87403           41 2141       513.00   2    4  25.650        6        3
    NE87457           46 2142       638.00   2    4  31.900        6        4
    NE83406            7 2143       621.00   2    4  31.050        6        5
    COLT              11 2144       615.00   2    4  30.750        6        6
    NE87522           51 2145       543.00   2    4  27.150        6        7
    NORKAN            18 2146       606.00   2    4  30.300        6        8
    NE87615           54 2147       634.00   2    4  31.700        6        9
    NE85556           15 2148       610.00   2    4  30.500        6       10
    TAM 200           20 2149       487.00   2    4  24.350        6       11
    LANCOTA           23 2150       522.00   2    4  26.100        6       12
    NE86503           25 2151       599.00   2    4  29.950        6       13
    NE86482           21 2152       656.00   2    4  32.800        6       14
    BRULE              2 2153       563.00   2    4  28.150        6       15
    NE87612           52 2154       654.00   2    4  32.700        6       16
    NE87613           53 2155       738.00   2    4  36.900        6       17
    NE86T666          40 2156    1  368.00   2    4  18.400        6       18
    RC                                                 .           6       19
    NE86607           34 3101       623.00   3    4  31.150        6       20
    LANCOTA           23 3102       539.00   3    4  26.950        6       21
    NE87513           50 3103    1  616.00   3    4  30.800        6       22
    NE87408           42 3104       438.00   3    4  21.900        7        1
    NE83407            8 3105       592.00   3    4  29.600        7        2
    NORKAN            18 3106       485.00   3    4  24.250        7        3
    REDLAND            3 3107       542.00   3    4  27.100        7        4
    KS831374          19 3108       421.00   3    4  21.050        7        5
    COLT              11 3109       479.00   3    4  23.950        7        6
    NE86527           31 3110       546.00   3    4  27.300        7        7
    VONA              36 3111       600.00   3    4  30.000        7        8
    TAM 107           28 3112       690.00   3    4  34.500        7        9
    CENTURK 78        17 3113       662.00   3    4  33.100        7       10
    NE87627           56 3114       564.00   3    4  28.200        7       11
    NE86T666          40 3115       516.00   3    4  25.800        7       12
    NE87615           54 3116       679.00   3    4  33.950        7       13
    NE86501           24 3117       607.00   3    4  30.350        7       14
    NE87522           51 3118       378.00   3    4  18.900        7       15
    CHEYENNE          29 3119       678.00   3    4  33.900        7       16
    SIOUXLAND         37 3120       675.00   3    4  33.750        7       17
    NE87451           45 3121       679.00   3    4  33.950        7       18
    GAGE              38 3122       500.00   3    4  25.000        7       19
    LANCER             1 3123       562.00   3    4  28.100        7       20
    NE87446           44 3124       500.00   3    4  25.000        7       21
    NE86482           21 3125    1  606.00   3    4  30.300        7       22
    CODY               4 3126       337.00   3    4  16.850        8        1
    NE87612           52 3127       342.00   3    4  17.100        8        2
    NE87457           46 3128       191.00   3    4   9.550        8        3
    NE84557           13 3129        30.00   3    4   1.500        8        4
    NE83T12           39 3130       255.00   3    4  12.750        8        5
    NE86507           26 3131       443.00   3    4  22.150        8        6
    TAM 200           20 3132       384.00   3    4  19.200        8        7
    NE87613           53 3133       471.00   3    4  23.550        8        8
    ARAPAHOE           5 3134       501.00   3    4  25.050        8        9
    SCOUT 66          10 3135       665.00   3    4  33.250        8       10
    NE87403           41 3136       480.00   3    4  24.000        8       11
    NE85623           16 3137       635.00   3    4  31.750        8       12
    NE86509           27 3138       481.00   3    4  24.050        8       13
    NE85556           15 3139       769.00   3    4  38.450        8       14
    HOMESTEAD         22 3140       517.00   3    4  25.850        8       15
    NE83404            6 3141       656.00   3    4  32.800        8       16
    NE86503           25 3142       702.00   3    4  35.100        8       17
    NE86582           32 3143       621.00   3    4  31.050        8       18
    NE87619           55 3144       663.00   3    4  33.150        8       19
    NE87463           47 3145       580.00   3    4  29.000        8       20
    NE86606           33 3146       643.00   3    4  32.150        8       21
    BRULE              2 3147    1  818.00   3    4  40.900        8       22

    BUCKSKIN          30 3148       360.00   3    4  18.000        9        1
    NE83406            7 3149        43.00   3    4   2.150        9        2
    NE87409           43 3150        75.00   3    4   3.750        9        3
    NE87499           48 3151        59.00   3    4   2.950        9        4
    CENTURA            9 3152       174.00   3    4   8.700        9        5
    NE83432           14 3153       221.00   3    4  11.050        9        6
    NE87512           49 3154       247.00   3    4  12.350        9        7
    ROUGHRIDER        35 3155       449.00   3    4  22.450        9        8
    NE83498           12 3156    1  538.00   3    4  26.900        9        9
    RC                                                 .           9       10
    NE86T666          40 4101       471.00   4    4  23.550        9       11
    NE87403           41 4102       580.00   4    4  29.000        9       12
    NE87512           49 4103       553.00   4    4  27.650        9       13
    NE87446           44 4104       480.00   4    4  24.000        9       14
    CENTURA            9 4105       515.00   4    4  25.750        9       15
    NE86503           25 4106       471.00   4    4  23.550        9       16
    NE87408           42 4107       613.00   4    4  30.650        9       17
    COLT              11 4108       564.00   4    4  28.200        9       18
    LANCER             1 4109       568.00   4    4  28.400        9       19
    NE83406            7 4110       574.00   4    4  28.700        9       20
    NE86607           34 4111       515.00   4    4  25.750        9       21
    SIOUXLAND         37 4112    1  450.00   4    4  22.500        9       22
    NE87612           52 4113       185.00   4    4   9.250       10        1
    BUCKSKIN          30 4114       486.00   4    4  24.300       10        2
    NE85556           15 4115        99.00   4    4   4.950       10        3
    BRULE              2 4116        74.00   4    4   3.700       10        4
    NE86507           26 4117       294.00   4    4  14.700       10        5
    ROUGHRIDER        35 4118       272.00   4    4  13.600       10        6
    VONA              36 4119       246.00   4    4  12.300       10        7
    NE83404            6 4120       350.00   4    4  17.500       10        8
    CODY               4 4121       303.00   4    4  15.150       10        9
    NE87463           47 4122       471.00   4    4  23.550       10       10
    NE86582           32 4123       390.00   4    4  19.500       10       11
    NE87499           48 4124       530.00   4    4  26.500       10       12
    NORKAN            18 4125       416.00   4    4  20.800       10       13
    SCOUT 66          10 4126       506.00   4    4  25.300       10       14
    NE87513           50 4127       348.00   4    4  17.400       10       15
    NE83T12           39 4128       453.00   4    4  22.650       10       16
    CENTURK 78        17 4129       632.00   4    4  31.600       10       17
    NE87627           56 4130       339.00   4    4  16.950       10       18
    NE86606           33 4131       625.00   4    4  31.250       10       19
    NE87457           46 4132       473.00   4    4  23.650       10       20
    NE86509           27 4133       509.00   4    4  25.450       10       21
    LANCOTA           23 4134    1  549.00   4    4  27.450       10       22
    KS831374          19 4135       291.00   4    4  14.550       11        1
    NE86482           21 4136       121.00   4    4   6.050       11        2
    NE85623           16 4137        21.00   4    4   1.050       11        3
    NE86527           31 4138       128.00   4    4   6.400       11        4
    NE87451           45 4139       102.00   4    4   5.100       11        5
    NE87409           43 4140       356.00   4    4  17.800       11        6
    GAGE              38 4141       443.00   4    4  22.150       11        7
    NE83407            8 4142       307.00   4    4  15.350       11        8
    NE87615           54 4143       240.00   4    4  12.000       11        9
    ARAPAHOE           5 4144       500.00   4    4  25.000       11       10
    CHEYENNE          29 4145       442.00   4    4  22.100       11       11
    REDLAND            3 4146       586.00   4    4  29.300       11       12
    NE83432           14 4147       469.00   4    4  23.450       11       13
    NE87619           55 4148       558.00   4    4  27.900       11       14
    NE83498           12 4149       632.00   4    4  31.600       11       15
    NE87613           53 4150       604.00   4    4  30.200       11       16
    NE86501           24 4151       606.00   4    4  30.300       11       17
    TAM 200           20 4152       406.00   4    4  20.300       11       18
    NE87522           51 4153       593.00   4    4  29.650       11       19
    NE84557           13 4154       531.00   4    4  26.550       11       20
    TAM 107           28 4155       512.00   4    4  25.600       11       21
    HOMESTEAD         22 4156    1  538.00   4    4  26.900       11       22
;
 /*-------------------------------------------------------*/
 

 /*-------------------------------------------------------*/
 /*---Figure 11.2                                      ---*/
proc mixed data=alliance;
   class Rep Entry;
   model Yield = Entry / outp=residuals;
   random Rep;
run;
proc variogram data=residuals outvar=plot_variogram;
   coordinates xc=lng yc=lat;
   compute lagd=1.2 maxlags=50;
   var resid;
run;
 /*---This code produces Figure 11.2 with SAS 9.1      ---*/
 /*---This template code is specific for SAS 9.1       ---*/
 /*---ODS graphics are experimental in SAS 9.1 and the ---*/
 /*---template syntax is different in subsequent releases-*/ 
proc template;
   define statgraph svartemplate;
      layout overlay / yaxisopts=(ticks=(0 50 100 150));
           scatterplot  y=variog x=distance /
                markersymbol = GraphDataDefault:markersymbol
                markercolor  = GraphDataDefault:contrastcolor
                markersize   = GraphDataDefault:markersize;
      endlayout;
   end;
run;
ods html; 
ods graphics on;
title;
data _null_;
    set plot_variogram;
    label variog='Semivariogram';
    file print ods=(template='svartemplate');
    put _ods_;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 11.7a                                     ---*/
proc mixed data=alliance;
   class Entry Rep;
   model Yield = entry / ddfm=kr;
   random Rep;
   repeated / subject=intercept 
              type=sp(sph)(latitude longitude) local;
   ods select CovParms;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 11.7b                                     ---*/
proc mixed data=alliance;
   class Entry Rep;
   model Yield = Entry /ddfm=kr;
   random Rep;
   repeated / subject=intercept 
              type=sp(sph)(latitude longitude);
   parms (9.88 18 45);
   ods select CovParms FitStatistics Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 11.7c                                     ---*/
proc mixed data=alliance;
   class Entry Rep;
   model Yield = entry / ddfm=kr;
   random Rep;
   repeated / subject=intercept 
              type=sp(sph)(latitude longitude) local;
   parms (1 18 18 25); 
   estimate 'arap v brul' entry 1 -1  0;
   estimate 'arap v buck' entry 1  0 -1 0;
   estimate 'arap v ks83' entry 1  0  0 0 0 0 0 0 0 0 -1 0;
   estimate 'brul v ks83' entry 0  1  0 0 0 0 0 0 0 0 -1 0; 
   ods select CovParms FitStatistics Tests3 Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 11.8                                      ---*/
data variogram1;
  set plot_variogram;
  if distance <= 35;
  if lag=-1 then distance=0;
run;
proc nlin data=variogram1;
    parms r=18 nugget=17 sill=25;
    model variog = nugget + 
           sill*(1.5*distance/r-0.5*(distance/r)**3)*(distance<r) +
           sill*(distance>=r); 
    /*   
        model covar=nugget*(distance=0) + sill*(1-1.5*distance/r + 
        0.5*(distance/r)**3)*(distance<r);
    */
run;
 /*-------------------------------------------------------*/
 
 /*-------------------------------------------------------*/
 /*---Output 11.9                                      ---*/
proc mixed data=alliance noprofile;
   class Entry rep;
   model Yield = entry / ddfm=kr;
   repeated / subject=intercept 

              type=sp(sph)(latitude longitude) local;
   parms (25.453 24.277 17.069) / noiter;
  /* parms (20.057  13.974 16.684)/noiter;  */
  ods select CovParms FitStatistics Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 11.10                                     ---*/
ods exclude all;
proc mixed data=alliance;
   class rep Entry;
   model Yield = Entry;
   random rep;
   lsmeans Entry;
   ods output lsmeans=rcb;
run;
proc mixed data=alliance;
   class entry rep;
   model Yield = entry / ddfm=kr;
   random rep;
   repeated / subject=intercept
              type=sp(sph)(latitude longitude) local;
   parms (0.1 15 18 18);
   lsmeans Entry;
   ods output lsmeans=sph;
run;
proc mixed data=alliance noprofile;
   class Entry Rep;
   model Yield = entry / ddfm=kr;
   repeated / subject=intercept
              type=sp(sph)(latitude longitude) local;
   parms (25.453 24.277 17.069)/noiter;
   lsmeans Entry;
   ods output lsmeans=sph2;
run;
ods exclude none;

data rcb1;
   set rcb(keep=entry estimate stderr rename=(estimate=rcb stderr=se_rcb));
   label rcb='LS-Mean RCB';
run;

proc rank data=rcb1 descending out=rcb_rank;

   var rcb;
   ranks rcb_rank;
run;

data sph1;
   set sph(keep=entry estimate stderr rename=(estimate=sph stderr=se_sph));
   label sph='LS-Mean SPH';
run;

proc rank data=sph1 descending out=sph_rank;
   var sph;
   ranks sph_rank;
run;

data sph2;
   set sph2(keep=entry estimate stderr rename=(estimate=sph2 stderr=se_sph2));
   label sph2='LS-Mean SPH2';
run;

proc rank data=sph2 descending out=sph2_rank;
   var sph2;
   ranks sph2_rank;
run;

proc sort data=rcb_rank;  by entry;

proc sort data=sph_rank;  by entry;
proc sort data=sph2_rank; by entry;
run;

data ranks; 
   merge rcb_rank sph_rank sph2_rank;
   by entry;
   label rcb_rank ='Rank of LS-Mean in RCB Model'
         sph_rank ='Rank of LS-Mean in Spherical Model'
         sph2_rank='Rank of LS-Mean in Spherical Model (noiter)';
run;

proc sort data=ranks;
   by rcb_rank;
run;

proc print data=ranks(obs=37) noobs label;
  var Entry rcb_rank rcb sph_rank sph sph2_rank sph2;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Figure 11.3                                      ---*/
 /*---This template code is specific for SAS 9.1       ---*/
 /*---ODS graphics are experimental in SAS 9.1 and the ---*/
 /*---template syntax is different in subsequent releases-*/ 
proc template;
   define statgraph temp;
      layout lattice / rows=2 columns=1 rowgutter=15;
          layout lattice / rows=1 columns=2 columngutter=25;
              scatterplot  x=rcb    y=sph;    
              scatterplot  x=sph2   y=sph;
          endlayout;
          layout overlay;
              scatterplot  x=se_sph2 y=se_sph;
              lineparm slope=0 yintercept=3.85569 /
                       linecolor     = black
                       linethickness = 2
                       linepattern   = solid
                       extreme       = true;
          endlayout;
      endlayout;
   end;
run;
title;
ods html; 
ods graphics on;
data _null_;
    set ranks;
    label rcb     = 'LS-Mean RCB'
          sph2    = 'LS-Mean SPH'
          sph     = 'LS-Mean SPH REML'
          se_rcb  = 'StdErr  RCB'
          se_sph  = 'StdErr SPH REML'
          se_sph2 = 'StdErr SPH';
    file print ods=(template='temp');
    put _ods_;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 11.8, C-N Ratios                        ---*/
data CNRatio;
  input x y TN TC CN;
  datalines;
  0     35.0    0.0810    0.9225    11.4201
  0     40.0    0.0790    0.8310    10.5300
  0     80.0    0.0800    0.8460    10.5750
  0    100.0    0.0705    0.7705    10.9451
  0    140.0    0.0915    0.9985    10.9132
  0    170.0    0.0855    0.9015    10.5427
  0    185.0    0.0745    0.8445    11.3654
  0    235.0    0.0670    0.6925    10.3396
  0    245.0    0.0600    0.5980     9.9667
  0    295.0    0.0610    0.6410    10.5113
  0    300.0    0.0580    0.5925    10.2155
  5     35.0    0.0880    0.9460    10.7640
  5     40.0    0.0785    0.8790    11.1974
  5    295.0    0.0650    0.6505    10.0077
  5    300.0    0.0570    0.5800    10.1813
 30     15.0    0.0770    0.8340    10.8312
 30     40.0    0.0690    0.7080    10.2660
 30     80.0    0.0860    0.9310    10.8263
 30    100.0    0.0765    0.8260    10.7962
 30    145.0    0.0990    1.0460    10.5665
 30    170.0    0.0875    0.9200    10.5133
 30    190.0    0.0740    0.7750    10.4748
 30    230.0    0.0740    0.7990    10.7973
 30    245.0    0.0675    0.7595    11.2648
 30    300.0    0.0585    0.6180    10.5812
 40    147.5    0.0985    1.0280    10.5327
 40    300.0    0.0550    0.5945    10.8091
 45     15.0    0.0900    0.9640    10.7223
 45     40.0    0.0760    0.8120    10.6836
 45    147.5    0.0815    0.8625    10.5883
 45    300.0    0.0390    0.3990    10.2308
 55     35.0    0.0920    0.9785    10.6254
 55     40.0    0.0805    0.9030    11.2184
 55    300.0    0.0600    0.6540    10.8960
 60     35.0    0.0820    0.8415    10.2739
 60     40.0    0.0805    0.8735    10.8447
 65    147.5    0.0925    1.0695    11.5640
 75     35.0    0.0730    0.8255    11.3061
 75     40.0    0.0800    0.8560    10.7237
 85     15.0    0.0775    0.8745    11.2875
 85     40.0    0.0720    0.8480    11.7778
 90     15.0    0.0750    0.8130    10.8542
 90     40.0    0.0750    0.8670    11.5600
100     27.5    0.0785    0.8245    10.5030
100     35.0    0.0740    0.8090    10.9642
100     75.0    0.0790    0.8525    10.7929
100     95.0    0.0610    0.6190    10.1475
100    145.0    0.0890    0.9310    10.4621
100    170.0    0.0795    0.8830    11.1179
100    175.0    0.0890    0.9055    10.1756
100    230.0    0.0765    0.7875    10.2912
100    240.0    0.0795    0.8560    10.7661
100    300.0    0.0670    0.7225    10.7872
115     15.0    0.0735    0.7770    10.5718
115     20.0    0.0780    0.8485    10.8829
115     75.0    0.0770    0.8420    10.9386
115    102.5    0.0870    0.9260    10.6437
115    135.0    0.0830    0.9025    10.8999
115    180.0    0.0845    0.9080    10.7515
115    190.0    0.0745    0.7675    10.3198
115    230.0    0.0780    0.7885    10.1086
115    245.0    0.0630    0.6635    10.5472
115    287.5    0.0635    0.7060    11.1217
170     35.0    0.0750    0.8395    11.3085
170     40.0    0.0905    0.9870    10.9053
170     85.0    0.0820    0.8690    10.5976
170    100.0    0.0820    0.8430    10.2827
170    145.0    0.1055    1.1750    11.1537
170    235.0    0.0625    0.6480    10.3910
170    240.0    0.0675    0.7040    10.4424
170    290.0    0.0725    0.7140     9.8487
180    300.0    0.0775    0.7790    10.0524
185    300.0    0.0765    0.8275    10.8195
190    170.0    0.0770    0.8670    11.2746
190    295.0    0.0725    0.7250    10.0421
200     30.0    0.0920    0.9895    10.7597
200     40.0    0.0955    1.0350    10.8457
200     80.0    0.0825    0.8240     9.9880
200     90.0    0.0700    0.7000    10.0094
200    140.0    0.0845    0.9080    10.7592
200    175.0    0.0750    0.8025    10.7092
200    190.0    0.0645    0.6545    10.1653
200    240.0    0.0675    0.6650     9.8513
200    250.0    0.0620    0.6020     9.7135
200    295.0    0.0810    0.8155    10.0684
205    175.0    0.0645    0.7090    11.0082
205    190.0    0.0665    0.7490    11.2618
205    295.0    0.0760    0.8180    10.7632
210     80.0    0.0760    0.7625    10.0504
215    190.0    0.0715    0.7870    11.0346
215    295.0    0.0885    0.9195    10.4139
230     80.0    0.0930    0.9540    10.2581
230    155.0    0.0660    0.6920    10.4848
230    190.0    0.0705    0.8020    11.3737
230    295.0    0.0915    0.9450    10.3286

235     80.0    0.0875    0.8855    10.1301
235    180.0    0.0720    0.8170    11.3472
235    295.0    0.0865    0.9055    10.4767
245    145.0    0.0690    0.7515    10.9183
250     35.0    0.0900    0.9590    10.6771
250     40.0    0.0940    0.9955    10.5981
250     85.0    0.0850    0.9300    10.9565
250    100.0    0.0855    0.8975    10.4994
250    140.0    0.0815    0.8500    10.4325
250    170.0    0.0655    0.6790    10.3736
250    175.0    0.0765    0.7795    10.1982
250    180.0    0.0670    0.6820    10.1935
250    190.0    0.0530    0.4975     9.3920
250    235.0    0.0730    0.7535    10.3511
250    245.0    0.0715    0.7195    10.0840
250    300.0    0.0750    0.8115    10.8296
255    145.0    0.0650    0.7580    11.6615
260    145.0    0.0695    0.7720    11.1081
265     80.0    0.0950    0.9900    10.4311
275    145.0    0.0830    1.0080    12.1446
280     80.0    0.0945    0.9890    10.4682
290     80.0    0.0930    0.9660    10.3871
300     30.0    0.0710    0.7870    11.0845
300     40.0    0.0770    0.8930    11.6073
300     90.0    0.0775    0.8700    11.2799
300     95.0    0.0760    0.8270    10.9265
300    145.0    0.0945    1.0035    10.6244
300    175.0    0.0846    0.8876    10.4890
300    180.0    0.0720    0.7495    10.4136
300    295.0    0.0745    0.7695    10.3343
305     35.0    0.0770    0.9020    11.7174
305     40.0    0.0730    0.8480    11.6214
305     80.0    0.0875    0.9940    11.4114
305     87.5    0.0845    0.9755    11.5312
305    140.0    0.0855    0.9650    11.2849
305    170.0    0.0810    0.9430    11.6485
305    190.0    0.0757    0.8445    11.1628
315    145.0    0.0715    0.7970    11.2645
320    145.0    0.0710    0.8155    11.5447
325    235.0    0.0800    0.8505    10.6308
325    245.0    0.0790    0.9040    11.4347
335    145.0    0.0690    0.8250    11.9699
340     30.0    0.0785    0.8565    10.9172
340     40.0    0.0870    1.0020    11.5172
340     80.0    0.0960    1.0885    11.3384
340     87.5    0.0780    0.9030    11.5769
340    145.0    0.0740    0.8295    11.2134
340    180.0    0.0705    0.7980    11.3178
340    190.0    0.0695    0.7845    11.2886
340    230.0    0.0760    0.8270    10.8816
340    235.0    0.0815    0.8670    10.6424
340    245.0    0.0775    0.8910    11.4973
350    235.0    0.0775    0.8395    10.8347
350    240.0    0.0755    0.8230    10.9038
365    235.0    0.0850    0.9060    10.6588
365    245.0    0.0850    0.9285    10.9268
370    235.0    0.0810    0.8610    10.6364
370    245.0    0.0845    0.8585    10.1599
385    235.0    0.0875    0.8870    10.1403
385    245.0    0.0520    0.4875     9.3879
400     20.0    0.0635    0.7420    11.7024
400     40.0    0.0525    0.5905    11.2603
400     80.0    0.0750    0.8465    11.2867
400     90.0    0.0655    0.7128    10.9226
400    140.0    0.0870    1.0155    11.6749
400    175.0    0.0725    0.8045    11.1201
400    190.0    0.0690    0.7190    10.4203
400    230.0    0.0745    0.7980    10.7073
400    235.0    0.0830    0.9040    10.8924
400    290.0    0.0735    0.8055    10.9637
415     80.0    0.0630    0.6900    10.9833
415     90.0    0.0545    0.5810    10.6864
415    300.0    0.0795    0.7785     9.7940
420    300.0    0.0760    0.7580    10.0185
425     80.0    0.0535    0.5405    10.1075
425    100.0    0.0480    0.5538    11.5496
430     80.0    0.0645    0.6575    10.1908
430     95.0    0.0635    0.6560    10.3396
430    300.0    0.0725    0.7380    10.1811
440     80.0    0.0595    0.6415    10.8016
440    100.0    0.0570    0.5590     9.8070
450    300.0    0.0695    0.7080    10.1856
475     80.0    0.0675    0.7780    11.5232
475     90.0    0.0780    0.8710    11.1667
485    300.0    0.0700    0.7650    10.9286
495     35.0    0.0705    0.7655    10.8600
495     40.0    0.0795    0.9095    11.4328
495    295.0    0.0670    0.7230    10.8141
495    300.0    0.0636    0.7136    11.2067
500     35.0    0.0660    0.8120    12.3030
500     40.0    0.0701    0.8349    11.9036
500     80.0    0.0550    0.6300    11.4730
500     90.0    0.0680    0.7875    11.6313
500    147.5    0.0840    1.0310    12.2738
500    172.5    0.0675    0.7845    11.6202
500    192.5    0.0685    0.7415    10.8862
500    232.5    0.0690    0.7460    10.8615
500    247.5    0.0595    0.6925    11.6414
500    295.0    0.0695    0.7425    10.6915
500    300.0    0.0765    0.8735    11.4545
  0      5.0    0.1290    .    .
  0     10.0    0.1120    .    .
  0     50.0    0.0755    .    .
  0     65.0    0.0820    .    .
  0    115.0    0.0790    .    .
  0    130.0    0.0770    .    .
  0    155.0    0.0960    .    .
  0    205.0    0.0705    .    .
  0    215.0    0.0685    .    .
  0    260.0    0.0610    .    .
  0    265.0    0.0600    .    .
  5      5.0    0.1075    .    .
  5     10.0    0.1205    .    .
  5    260.0    0.0600    .    .
  5    265.0    0.0640    .    .
 30     10.0    0.0865    .    .
 30     50.0    0.0860    .    .
 30     65.0    0.0885    .    .
 30    105.0    0.0730    .    .
 30    130.0    0.0905    .    .
 30    155.0    0.0955    .    .
 30    210.0    0.0735    .    .
 30    215.0    0.0760    .    .
 30    260.0    0.0595    .    .
 30    265.0    0.0545    .    .
 40    155.0    0.0790    .    .
 40    265.0    0.0545    .    .
 45      5.0    0.1170    .    .
 45    155.0    0.0865    .    .
 45    265.0    0.0550    .    .
 55     10.0    0.0960    .    .
 55    265.0    0.0655    .    .
 60      5.0    0.0990    .    .
 65    155.0    0.0835    .    .
 75      0.0    0.0985    .    .
 85      0.0    0.0825    .    .
 90      5.0    0.0830    .    .
100     10.0    0.0690    .    .
100     47.5    0.0840    .    .
100     65.0    0.0795    .    .
100    105.0    0.0775    .    .
100    130.0    0.0950    .    .
100    155.0    0.0910    .    .
100    210.0    0.0755    .    .
100    215.0    0.0705    .    .
100    255.0    0.0690    .    .
100    285.0    0.0635    .    .
115     10.0    0.0725    .    .
115     50.0    0.0830    .    .
115     55.0    0.0770    .    .
115    107.5    0.0850    .    .
115    132.5    0.0825    .    .
115    162.5    0.0885    .    .
115    200.0    0.0810    .    .
115    210.0    0.0750    .    .
115    265.0    0.0608    .    .
170     10.0    0.0785    .    .
170     55.0    0.0810    .    .
170     60.0    0.0960    .    .
170    115.0    0.0870    .    .
170    130.0    0.0975    .    .
170    155.0    0.0910    .    .
170    215.0    0.0560    .    .
170    220.0    0.0620    .    .
170    270.0    0.0650    .    .
170    275.0    0.0670    .    .
180    260.0    0.0665    .    .
180    285.0    0.0680    .    .
185    260.0    0.0775    .    .
185    285.0    0.0640    .    .
190    155.0    0.0765    .    .
190    260.0    0.0765    .    .
190    270.0    0.0775    .    .
200     50.0    0.1050    .    .
200     55.0    0.0995    .    .
200    110.0    0.0880    .    .
200    120.0    0.0945    .    .
200    162.5    0.0770    .    .
200    200.0    0.0640    .    .
200    215.0    0.0615    .    .
200    260.0    0.0765    .    .
200    280.0    0.0790    .    .
205    155.0    0.0700    .    .
205    260.0    0.0775    .    .
205    270.0    0.0700    .    .
210     65.0    0.0900    .    .

215    155.0    0.0745    .    .
215    260.0    0.0740    .    .
215    270.0    0.0740    .    .
230     65.0    0.0940    .    .
230    155.0    0.0770    .    .
230    260.0    0.0740    .    .
230    280.0    0.0805    .    .
235     65.0    0.0990    .    .
235    155.0    0.0625    .    .
235    260.0    0.0755    .    .
235    280.0    0.0810    .    .
245    110.0    0.0775    .    .
245    125.0    0.0745    .    .
250     55.0    0.1040    .    .
250     65.0    0.0970    .    .
250    115.0    0.0510    .    .
250    120.0    0.0722    .    .
250    155.0    0.0420    .    .
250    205.0    0.0625    .    .
250    215.0    0.0700    .    .
250    265.0    0.0705    .    .
250    280.0    0.0640    .    .
255    115.0    0.0670    .    .
255    125.0    0.0730    .    .
260    110.0    0.0700    .    .
260    125.0    0.0708    .    .
265     65.0    0.1030    .    .
275    120.0    0.0660    .    .
275    125.0    0.0755    .    .
280     65.0    0.1075    .    .
285    115.0    0.0760    .    .
285    125.0    0.0675    .    .
290     65.0    0.1155    .    .
290    110.0    0.0650    .    .
290    125.0    0.0735    .    .
300     50.0    0.0840    .    .
300     65.0    0.1035    .    .
300    155.0    0.0930    .    .
300    265.0    0.0710    .    .
300    280.0    0.0755    .    .
305     10.0    0.0645    .    .
305     50.0    0.0835    .    .
305     60.0    0.0920    .    .
305    110.0    0.0795    .    .
305    130.0    0.0850    .    .
305    160.0    0.0860    .    .
305    260.0    0.0760    .    .
315    110.0    0.0710    .    .
315    125.0    0.0740    .    .
320    110.0    0.0710    .    .
320    125.0    0.0820    .    .
325    205.0    0.0705    .    .
325    210.0    0.0860    .    .
335    110.0    0.0795    .    .
335    125.0    0.0705    .    .
340     10.0    0.0855    .    .
340     50.0    0.0830    .    .
340     70.0    0.0950    .    .
340    110.0    0.0820    .    .
340    130.0    0.0770    .    .
340    155.0    0.0645    .    .
340    200.0    0.0715    .    .
340    205.0    0.0660    .    .
340    210.0    0.0765    .    .
340    265.0    0.0720    .    .
340    275.0    0.0685    .    .
350    205.0    0.0760    .    .
350    210.0    0.0815    .    .
365    205.0    0.0785    .    .
365    210.0    0.0725    .    .
370    205.0    0.0870    .    .
370    210.0    0.0800    .    .
385    205.0    0.0795    .    .
385    215.0    0.0905    .    .
400     10.0    0.0560    .    .
400     50.0    0.0630    .    .
400     60.0    0.0710    .    .
400    110.0    0.0696    .    .
400    115.0    0.0825    .    .
400    155.0    0.0740    .    .
400    200.0    0.0690    .    .
400    205.0    0.0760    .    .
400    260.0    0.0745    .    .
400    275.0    0.0825    .    .
415     50.0    0.0520    .    .
415     60.0    0.0650    .    .
415    275.0    0.0860    .    .
420    275.0    0.0835    .    .
425     50.0    0.0595    .    .
425     70.0    0.0601    .    .
430     50.0    0.0580    .    .
430     65.0    0.0690    .    .
430    275.0    0.0744    .    .
440     50.0    0.0525    .    .
440     65.0    0.0600    .    .
450    275.0    0.0685    .    .
475     50.0    0.0795    .    .
475     60.0    0.0710    .    .
485    275.0    0.0700    .    .
495      5.0    0.0685    .    .
495     10.0    0.0715    .    .
495    277.5    0.0635    .    .
495    282.5    0.0700    .    .
500      5.0    0.0885    .    .
500     10.0    0.0765    .    .
500     50.0    0.0790    .    .
500     60.0    0.0780    .    .
500    110.0    0.0730    .    .
500    132.5    0.0920    .    .
500    157.5    0.0790    .    .
500    202.5    0.0710    .    .
500    215.0    0.0655    .    .
500    277.5    0.0640    .    .
500    282.5    0.0630    .    .
;
  /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 11.11                                     ---*/
data predlocs;
  do x=0 to 500 by 12.5;
     do y=0 to 300 by 7.5;
	    output;
     end;
  end;
run;
data fitthis; 
    set cnratio(where=(tc ne .)) predlocs;
run;
proc mixed data=fitthis;
   model cn = / outp=OKpredictions;
   repeated / subject=intercept type=sp(exp)(x y);
   ods select Dimensions NObs FitStatistics 
              ConvergenceStatus CovParms;
run;
 /*-------------------------------------------------------*/
 

 /*-------------------------------------------------------*/
 /*---Output 11.12a                                    ---*/
proc print data=OKpredictions(where=((x=100) and (y=300))); 
run;
 /*-------------------------------------------------------*/ 

 /*-------------------------------------------------------*/
 /*---Output 11.12b                                    ---*/
proc print data=OKpredictions(where=(x=100)); 
run;
 /*-------------------------------------------------------*/ 

 /*-------------------------------------------------------*/
 /*---Output 11.13                                     ---*/
proc mixed data=cnratio;
   model tc = tn / solution outp=UKpredictions;
   repeated / subject = intercept 
              type    = sp(expa)(x y);
   ods select Dimensions NObs CovParms SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 11.14                                     ---*/
proc print data=UKPredictions(where=(x=5));
   var x y TC TN Pred StdErrPred;
run;
 /*-------------------------------------------------------*/



 /*-------------------------------------------------------*/
 /*---CHAPTER 12: Power Calculations for Mixed Models  ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 4.7 Mouse Condition--Diet Experiment    ---*/
data mice;
  input cage condition diet $ gain;
  datalines;
1   1   normal    58
1   1   restrict    58
1   1   suppleme    58
1   2   normal      54
1   2   restrict    46
1   2   suppleme    57
2   1   normal      49
2   1   restrict    50
2   1   suppleme    57
2   3   normal      57
2   3   restrict    53
2   3   suppleme    62
3   1   normal      59
3   1   restrict    58
3   1   suppleme    57

3   4   normal      63
3   4   restrict    61
3   4   suppleme    65
4   2   normal      57
4   2   restrict    64
4   2   suppleme    52
4   3   normal      63
4   3   restrict    67
4   3   suppleme    51
5   2   normal      53
5   2   restrict    46
5   2   suppleme    51
5   4   normal      58
5   4   restrict    52
5   4   suppleme    61
6   3   normal      65
6   3   restrict    64
6   3   suppleme    54
6   4   normal      59
6   4   restrict    47
6   4   suppleme    73
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 12.1                                      ---*/
proc mixed data=mice nobound cl;
   class cage condition diet;
   model gain= condition|diet / solution ddfm=satterth;
   random cage cage*condition;
   ods output tests3=t3;
run;

data f_power; 
   set t3; 
   Noncen = NumDF*FValue; 
   Alpha  = 0.05; 
   FCrit  = finv(1-Alpha,NumDF,DenDF,0); 
   Power  = 1 - probf(FCrit,NumDF,DenDF,Noncen); 
run; 

proc print data=f_power; 
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 12.2                                      ---*/
data mice1;
   set mice;
   cage = cage + 6;
data mice2;
   set mice mice1;
run;

proc mixed data=mice2 nobound cl;
   class cage condition diet;
   model gain=condition|diet / ddfm=satterth;
   random cage cage*condition;
   ods select Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 12.3                                      ---*/
proc mixed data=mice nobound cl;
   class cage condition diet;
   model gain = condition|diet / ddf=11.9,40,40;
   random cage cage*condition;
   ods output tests3=t3;
run;

data f_power2; 
   set t3; 
   Alpha  = 0.05; 
   Noncen = NumDF*FValue; 
   FCrit  = finv(1-Alpha,NumDF,DenDF,0); 
   Power  = 1 - probf(FCrit,NumDF,DenDF,Noncen); 
run; 

proc print data=f_power2; 
run;  
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 12.1                                      ---*/
%macro MixedTPower;

  * run proc mixed;
  proc mixed data=&InData &ProcMixedOptions;
    &ProcMixedStatements
    ods output estimates=ests;
  run;

  libname OutLib "&OutPath";

  * compute power curves for each difference
    using a noncentral t-distribution;
  data OutLib.MixedPower;
    set ests;
    do alpha = &AlphaValues;
       do effectsize = &EffectSizes;
          tcrit  = tinv(1-alpha/2,df);
          noncen = effectsize/stderr;
          power  = sum(1, -cdf("t", tcrit,df,noncen),
		                       cdf("t",-tcrit,df,noncen));
          output;
		    end;	
      end;
  run;

  * create JMP scripting code;
  filename jslfile "&OutPath.mixedtpower.jsl";

  data _null_;
     file jslfile;
     put "%str(data=open(%".\MixedPower.sas7bdat%");)";
     put " ";
     put "Overlay Plot(X( :effectsize), Y( :power), 
          Grouping(  :Label,  :alpha),";
     put "Connect Thru Missing(1));";
   run;

%mend MixedTPower;

%let InData = mice; 
%let ProcMixedStatements= 
%str(
   class cage condition diet;
   model gain = condition|diet / ddfm=satterth;
   random cage cage*condition;
   estimate "est1: condition 2-1" condition -1 1 0 0;
   estimate "est2: diet restrict-normal" diet -1 1 0;
   estimate "est3: condition*diet 1 restr-nor"
                   diet -1 1 0  
                   condition*diet -1 1 0 0 0 0 0 0 0 0 0 0; 
); 
%let ProcMixedOptions = nobound; 
%let AlphaValues = 0.05; 
%let EffectSizes = 0 to 10 by 0.5;
%let OutPath = C:\temp\; 

%MixedTPower;

data power; set outlib.mixedpower;
  symbol = substr(label,4,1)+0;
run;
goptions reset=all hsize=9in vsize=8in;
symbol1 color=black value=none i=join l=1  r=1 w=2;
symbol2 color=black value=none i=join l=2  r=1 w=2;
symbol3 color=black value=none i=join l=21 r=1 w=2;
axis1 minor =none
      order =(0 to 1 by 0.1)
      label =(font='Arial Black' Height=1.5 angle=90 'Power')
      offset=(0.3in,0.3in)
      value =(font='Arial Black' Height=1.3);
axis2 minor =none
      order =(-2 to 12 by 2)
      label =(font='Arial Black' Height=1.5 'Effect Size')    
      offset=(0.3in,0.3in)
      value =(font='Arial Black' Height=1.3);
legend1 across  =1
        cborder =black
        mode    =protect
        position=(top left inside)
        label   = none
        value   =(font='Arial Black' Height=2
                       'Condition 2-1'
                       'Diet restrict-normal'
                       'Condition*diet 1 restr-nor');

proc gplot data=power;
   plot power*effectsize=symbol / 
               noframe 
               vaxis=axis1 haxis=axis2
               legend=legend1;
run;
quit;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 12.4                                      ---*/
 /*---Output 12.5                                      ---*/
data layout;
  do row=1 to 8;
      do col=1 to 8;
         output;
      end;
  end;
run;

/*---design option 1, 16 trts, 4 blocks, no randomization---*/
data td;
   input trt @@;
   datalines;
 1  2  3  4  5  6  7  8
 9 10 11 12 13 14 15 16
 1  2  3  4  5  6  7  8
 9 10 11 12 13 14 15 16
 1  2  3  4  5  6  7  8
 9 10 11 12 13 14 15 16
 1  2  3  4  5  6  7  8
 9 10 11 12 13 14 15 16
;

/*---specify treatment effects as the data---*/
data design1;
   merge layout td;
   mu=-6*(trt=1)-2*(trt>1 and trt<5)+3*(trt>12);
run;

proc mixed noprofile;
   class trt;
   model mu=trt/ddf=48;

   parms (16) (3) /noiter;
   repeated / subject=intercept type=sp(sph)(row col);
   lsmeans trt/diff;
   contrast '1 vs 2' trt 1 -1 0;
   contrast '1 vs 4' trt 1 0 0 -1 0;
   contrast '1 vs 5' trt 1 0 0 0 -1 0;
   contrast '1 vs 10' trt 1 0 0 0 0 0 0 0 0 -1 0;
   contrast '1 vs 13' trt 1 0 0 0 0 0 0 0 0 0 0 0 -1 0;
   contrast '1 vs 16' trt 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 -1;
   ods output diffs=trtdiff contrasts=b;
run;

proc means data=trtdiff;
   var estimate;
run;

data power1;
   set b;
   alpha=0.05;
   ncparm=fvalue;
   fcrit=finv(1-alpha,numdf,dendf,0);
   power=1-probf(fcrit,numdf,dendf,ncparm);
run;

 /*---Output 12.4---*/
proc print;
   var label numdf dendf alpha ncparm fcrit power;
run;


/*---design option 2; layout from Cochran & Cox, Experimental Designs, plan 10.2
 4x4 lattice incomplete block design---*/

data td;
  input trt @@;
  datalines;
 1  2  3  4  1  5  9 13
 5  6  7  8  2  6 10 14
 9 10 11 12  3  7 11 15
13 14 15 16  4  8 12 16
 1  6 11 16  1  8 11 14
 2  7 12 13  2  5 12 15
 3  8  9 14  3  6  9 16
 4  5 10 15  4  7 10 13
;

data design2;
   merge layout td;
   mu=-6*(trt=1)-2*(trt>1 and trt<5)+3*(trt>12);
run;

proc mixed noprofile;
   class trt;
   model mu=trt/ddf=48;
   parms (16) (3) /noiter;
   repeated / subject=intercept type=sp(sph)(row col);
   lsmeans trt/diff;
   contrast '1 vs 2' trt 1 -1 0;
   contrast '1 vs 4' trt 1 0 0 -1 0;
   contrast '1 vs 5' trt 1 0 0 0 -1 0;
   contrast '1 vs 10' trt 1 0 0 0 0 0 0 0 0 -1 0;
   contrast '1 vs 13' trt 1 0 0 0 0 0 0 0 0 0 0 0 -1 0;
   contrast '1 vs 16' trt 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 -1;
   ods output diffs=trtdiff contrasts=b;
run;
 
proc means data=trtdiff;
   var estimate;
run;

data power2;
   set b;
   alpha=0.05;
   ncparm=fvalue;
   fcrit=finv(1-alpha,numdf,dendf,0);
   power=1-probf(fcrit,numdf,dendf,ncparm);
run;
 /*---Output 12.5---*/
proc print;
   var label numdf dendf alpha ncparm fcrit power;
run;
 /*-------------------------------------------------------*/ 


 /*-------------------------------------------------------*/
 /*---Output 12.6                                      ---*/
/*---simulate noise structure from the mice data, IML is used 
     in order to accommodate the negative variance component---*/

%let seed      = 71853048;
%let var_cage  = 5.03;
%let var_cc    = -6.24;
%let var_resid = 31.56; 
%let nsim      = 1000;

proc iml;
   cov = &var_cc * j(3,3) + &var_resid * i(3);
   covh = half(cov)`;
   print cov covh;

run;
				
data noise;
   retain i j;
   do sim = 1 to &nsim;
      i = 1;
      j = 2;
      do cage = 1 to 6;
         u_cage = sqrt(&var_cage) * rannor(&seed);
         do condition = i,j;
            e1 = rannor(&seed);
            e2 = rannor(&seed);
            e3 = rannor(&seed);
            diet = "normal  ";
            noise = u_cage + 5.0318983*e1;
            output;
            diet = "restrict";
            noise = u_cage - 1.240089*e1 + 4.8766977*e2;
            output;
            diet = "suppleme";
            noise = u_cage - 1.240089*e1 - 1.594895*e2 + 4.6085237*e3;
            output;	
         end;
         j = j + 1;
         if (j = 5) then do;
            i = i + 1;
            j = i + 1;
         end;
      end;
   end;
run;

ods exclude all;
ods noresults;

proc mixed data=noise nobound;
   by sim;
   class cage condition diet;
   model noise=condition|diet;
   random cage cage*condition;
   parms &var_cage &var_cc &var_resid;
   ods output covparms=cpsim tests3=t3sim;
run;

ods exclude none;
ods results;

proc sort data=cpsim;
   by covparm;
run;

proc means data=cpsim;
   by covparm;
   var estimate;
run;

data t3sim;
   set t3sim;
   if probf < 0.05 then sig = 1;
   else sig = 0;
proc sort data=t3sim;
   by effect;
proc means data=t3sim mean;
   by effect;
   var sig;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 12.7                                      ---*/
 /*---simulate power under alternative as estimated 
     from the pilot data---*/
proc mixed data=mice nobound;
   class cage condition diet;
   model gain=condition|diet / outpm=opm;
   random cage cage*condition;
run;

data opm1;
   set opm;
   drop gain stderrpred df alpha lower upper resid;
run;

proc sort data=noise;
   by cage condition diet;
run;

data mice_sim;
   merge noise opm1;
   by cage condition diet;
   y = pred + noise;
run;

proc sort data=mice_sim;
   by sim;
run;

ods exclude all;
ods noresults;

proc mixed data=mice_sim nobound;
   by sim;
   class cage condition diet;
   model y = condition|diet / ddf=11.9,40,40;
   random cage cage*condition;
   parms &var_cage &var_cc &var_resid;
   ods output covparms=cpsim tests3=t3sim;
run;

ods exclude none;
ods results;

proc sort data=cpsim;
   by covparm;
run;

proc means data=cpsim;
   by covparm;
   var estimate;
run;

data t3sim;
   set t3sim;
   if probf < 0.05 then sig = 1;
   else sig = 0;
proc sort data=t3sim;
   by effect;
proc means data=t3sim mean;
   by effect;
   var sig;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---CHAPTER 13: Some Bayesian Approaches to Mixed    ---*/
 /*---            Models                               ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 13.1                                      ---*/
 /*---Figure 13.1                                      ---*/
data p;
   do p=0.2,0.1,0.05,0.01,0.005,1e-3,1e-4,1e-5,1e-6;
      log10_p = log10(p);
      bayes_factor = -exp(1)*p*log(p);
      do prior_prob_h0 = 0.9,0.5,0.1;
         prior_odds_h0 = prior_prob_h0 /(1-prior_prob_h0);
         post_odds_h0  = prior_odds_h0 * bayes_factor;
         post_prob_h0  = post_odds_h0  /(1+post_odds_h0);
         log10_pph     = log10(post_prob_h0);
         output;
      end;
   end;
run;

proc print data=p;
run;

goptions reset=all
   hsize   = 5.25 in
   vsize   = 5.25 in
   htext   = 3.0 pct
   htitle  = 3.5 pct
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss 

   lfactor = 1;

axis1 order=(-6 to 0) 
      value=(font=swissl height=1)  
      label=(font=swissl h=1) 
      major=(h=0.5) 
      minor=none;

axis2 order=(-6 to 0) 
      value=(font=swissl height=1)
      label=(font=swissl h=1) 
      major=(h=1) 
      minor=none;
symbol1 i=join r=1 color=black line=1;
symbol2 i=join r=1 color=black line=2;
symbol3 i=join r=1 color=black line=25;
proc gplot;
  plot log10_pph * log10_p = prior_prob_h0 /
                   haxis=axis1 vaxis=axis2;

run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 7.7, Teaching Methods I                 ---*/
 /*---Revisited in Chapter 13                          ---*/

data Ex_7_7sp;
    input met teacher gen $ student score y_ex @@;
    datalines;
1  1  f  1  15  11 1  1  f  2  17  11 1  1  f  3  16  11
1  1  f  4  16  11 1  1  m  1  17  11 1  1  m  2  16  11
1  1  m  3  17  11 1  1  m  4  17  11 1  2  f  1  18   8
1  2  f  2  17   8 1  2  f  3  17   8 1  2  f  4  16   8
1  2  m  1  16   8 1  2  m  2  17   8 1  2  m  3  18   8
1  2  m  4  17   8 1  3  f  1  15   9 1  3  f  2  15   9
1  3  f  3  15   9 1  3  f  4  16   9 1  3  m  1  15   9
1  3  m  2  15   9 1  3  m  3  15   9 1  3  m  4  16   9
1  4  f  1  16  17 1  4  f  2  17  17 1  4  f  3  16  17
1  4  f  4  15  17 1  4  m  1  14  17 1  4  m  2  17  17
1  4  m  3  17  17 1  4  m  4  16  17 2  1  f  1  21   6
2  1  f  2  22   6 2  1  f  3  22   6 2  1  f  4  21   6
2  1  m  1  20   6 2  1  m  2  20   6 2  1  m  3  21   6
2  1  m  4  22   6 2  2  f  1  21  11 2  2  f  2  20  11
2  2  f  3  20  11 2  2  f  4  21  11 2  2  m  1  18  11
2  2  m  2  19  11 2  2  m  3  20  11 2  2  m  4  19  11
2  3  f  1  23  13 2  3  f  2  23  13 2  3  f  3  24  13
2  3  f  4  23  13 2  3  m  1  21  13 2  3  m  2  20  13
2  3  m  3  21  13 2  3  m  4  22  13 2  4  f  1  23  18
2  4  f  2  22  18 2  4  f  3  22  18 2  4  f  4  22  18
2  4  m  1  19  18 2  4  m  2  19  18 2  4  m  3  19  18
2  4  m  4  20  18 3  1  f  1  33   8 3  1  f  2  31   8
3  1  f  3  31   8 3  1  f  4  32   8 3  1  m  1  27   8
3  1  m  2  28   8 3  1  m  3  27   8 3  1  m  4  27   8
3  2  f  1  28  18 3  2  f  2  27  18 3  2  f  3  27  18
3  2  f  4  29  18 3  2  m  1  23  18 3  2  m  2  23  18
3  2  m  3  24  18 3  2  m  4  23  18 3  3  f  1  30  12
3  3  f  2  29  12 3  3  f  3  29  12 3  3  f  4  30  12
3  3  m  1  25  12 3  3  m  2  25  12 3  3  m  3  26  12
3  3  m  4  24  12 3  4  f  1  28   6 3  4  f  2  27   6
3  4  f  3  28   6 3  4  f  4  30   6 3  4  m  1  25   6
3  4  m  2  25   6 3  4  m  3  22   6 3  4  m  4  25   6
;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 13.2                                      ---*/
proc mixed data=Ex_7_7sp covtest cl; 
   class teacher met gen;
   model score = met gen gen*met y_ex y_ex*gen / ddfm=kr;
   random teacher(met);
   ods output tests3=t3;
run;

data t3_bayes;
  set t3;
  if (probf < 1/exp(1)) then bf_sbb=-exp(1)*probf*log(probf);
  else bf_sbb = 1;
  if fvalue > 1 then bf_j = ((dendf/numdf + 1)/
                 (dendf/numdf +	fvalue))**((numdf+dendf)/2) * 
                 fvalue**(numdf/2);
  else bf_j = 1;
  do prior_prob_h0 = 0.9,0.5,0.1;
    prior_odds_h0    = prior_prob_h0/(1-prior_prob_h0);
    post_odds_h0_sbb = prior_odds_h0 * bf_sbb;
    post_odds_h0_j   = prior_odds_h0 * bf_j;
    post_prob_h0_sbb = post_odds_h0_sbb/(1+post_odds_h0_sbb);
    post_prob_h0_j   = post_odds_h0_j/(1+post_odds_h0_j);
    output;
  end;
run;

proc print data=t3_bayes;
   id effect;
   format _numeric_ best6.;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data 13.6, Beetle Fecundity                      ---*/
data beetle;
   input sire dam progeny value trait$ @@;
   datalines;
 1 1 1  58.0  fec  1 1 1   4.6  mass  1 1 2  64.0  fec  1 1 2   4.0  mass
 1 1 3  50.0  fec  1 1 3   4.1  mass  1 1 4  53.0  fec  1 1 4   4.2  mass
 1 1 5  50.0  fec  1 1 5   4.0  mass  1 2 1  54.0  fec  1 2 1   4.7  mass
 1 2 2  85.0  fec  1 2 2   5.7  mass  1 2 3  48.0  fec  1 2 3   3.6  mass
 1 2 4  55.0  fec  1 2 4   4.9  mass  1 2 5  48.0  fec  1 2 5   3.3  mass
 1 3 1  51.0  fec  1 3 1   5.1  mass  1 3 2  76.0  fec  1 3 2   5.2  mass
 1 3 3  58.0  fec  1 3 3   5.6  mass  1 3 4  48.0  fec  1 3 4   3.6  mass
 1 3 5  55.0  fec  1 3 5   3.5  mass  1 4 1  28.0  fec  1 4 1   5.1  mass
 1 4 2  44.0  fec  1 4 2   5.6  mass  1 4 3  21.0  fec  1 4 3   4.3  mass
 1 4 4  31.0  fec  1 4 4   4.4  mass  1 4 5  17.0  fec  1 4 5   4.2  mass
 1 5 1  44.0  fec  1 5 1   4.1  mass  1 5 2  51.0  fec  1 5 2   4.4  mass
 1 5 3  27.0  fec  1 5 3   4.1  mass  1 5 4  42.0  fec  1 5 4   3.5  mass
 1 5 5  40.0  fec  1 5 5   3.7  mass  2 1 1  62.0  fec  2 1 1   4.7  mass
 2 1 2  52.0  fec  2 1 2   4.3  mass  2 1 3  66.0  fec  2 1 3   5.2  mass
 2 1 4  56.0  fec  2 1 4   4.6  mass  2 1 5  37.0  fec  2 1 5   3.0  mass
 2 2 1  59.0  fec  2 2 1   4.5  mass  2 2 2  52.0  fec  2 2 2   4.7  mass
 2 2 3  62.0  fec  2 2 3   4.9  mass  2 2 4  56.0  fec  2 2 4   4.2  mass
 2 2 5  58.0  fec  2 2 5   5.5  mass  2 3 1  48.0  fec  2 3 1   5.3  mass
 2 3 2  63.0  fec  2 3 2   5.7  mass  2 3 3  21.0  fec  2 3 3   4.2  mass
 2 3 4  60.0  fec  2 3 4   4.4  mass  2 3 5  50.0  fec  2 3 5   3.9  mass
 2 4 1  38.0  fec  2 4 1   4.4  mass  2 4 2  56.0  fec  2 4 2   4.3  mass
 2 4 3  33.0  fec  2 4 3   4.8  mass  2 4 4  22.0  fec  2 4 4   4.5  mass
 2 4 5  68.0  fec  2 4 5   4.9  mass  3 1 1  70.0  fec  3 1 1   5.5  mass
 3 1 2  36.0  fec  3 1 2   4.1  mass  3 1 3  64.0  fec  3 1 3   4.9  mass
 3 1 4  46.0  fec  3 1 4   4.8  mass  3 1 5  31.0  fec  3 1 5   4.2  mass
 3 2 1  43.0  fec  3 2 1   5.7  mass  3 2 2  17.0  fec  3 2 2   5.2  mass
 3 2 3  23.0  fec  3 2 3   4.9  mass  3 2 4  76.0  fec  3 2 4   5.6  mass
 3 2 5  12.0  fec  3 2 5   4.7  mass  3 3 1  18.0  fec  3 3 1   4.1  mass
 3 3 2   9.0  fec  3 3 2   4.9  mass  3 3 3  18.0  fec  3 3 3   3.8  mass
 3 3 4  53.0  fec  3 3 4   4.2  mass  3 3 5  43.0  fec  3 3 5   4.5  mass
 3 4 1  53.0  fec  3 4 1   4.0  mass  3 4 2  57.0  fec  3 4 2   5.1  mass
 3 4 3  60.0  fec  3 4 3   4.2  mass  3 4 4  50.0  fec  3 4 4   5.1  mass
 3 4 5  62.0  fec  3 4 5   5.0  mass  3 5 1  83.0  fec  3 5 1   6.4  mass
 3 5 2  22.0  fec  3 5 2   4.8  mass  3 5 3  22.0  fec  3 5 3   5.3  mass
 3 5 4  71.0  fec  3 5 4   4.6  mass  3 5 5  71.0  fec  3 5 5   5.3  mass
 4 1 1  70.0  fec  4 1 1   4.8  mass  4 1 2  66.0  fec  4 1 2   5.5  mass
 4 1 3  64.0  fec  4 1 3   5.1  mass  4 1 4  43.0  fec  4 1 4   3.9  mass
 4 1 5  46.0  fec  4 1 5   3.5  mass  4 2 1  34.0  fec  4 2 1   4.3  mass
 4 2 2  16.0  fec  4 2 2   4.6  mass  4 2 3  14.0  fec  4 2 3   4.3  mass
 4 2 4  19.0  fec  4 2 4   4.1  mass  4 2 5  17.0  fec  4 2 5   4.5  mass
 4 3 1  46.0  fec  4 3 1   5.3  mass  4 3 2  62.0  fec  4 3 2   5.4  mass
 4 3 3  72.0  fec  4 3 3   5.4  mass  4 3 4  54.0  fec  4 3 4   5.1  mass
 4 3 5  55.0  fec  4 3 5   4.9  mass  4 4 1  52.0  fec  4 4 1   4.3  mass
 4 4 2  61.0  fec  4 4 2   4.6  mass  4 4 3  57.0  fec  4 4 3   4.2  mass
 4 4 4  71.0  fec  4 4 4   4.9  mass  4 4 5  52.0  fec  4 4 5   4.6  mass
 4 5 1  51.0  fec  4 5 1   4.0  mass  4 5 2  45.0  fec  4 5 2   4.1  mass
 4 5 3  51.0  fec  4 5 3   4.5  mass  4 5 4  44.0  fec  4 5 4   4.6  mass
 4 5 5  44.0  fec  4 5 5   4.0  mass  5 1 1  75.0  fec  5 1 1   5.1  mass
 5 1 2  62.0  fec  5 1 2   5.4  mass  5 1 3  60.0  fec  5 1 3   5.2  mass
 5 1 4  64.0  fec  5 1 4   4.8  mass  5 1 5  64.0  fec  5 1 5   5.1  mass
 5 2 1  92.0  fec  5 2 1   5.6  mass  5 2 2  88.0  fec  5 2 2   5.5  mass
 5 2 3  67.0  fec  5 2 3   5.5  mass  5 2 4  72.0  fec  5 2 4   5.5  mass
 5 2 5  77.0  fec  5 2 5   5.4  mass  5 3 1  85.0  fec  5 3 1   5.7  mass
 5 3 2  64.0  fec  5 3 2   4.9  mass  5 3 3  48.0  fec  5 3 3   4.5  mass
 5 3 4  50.0  fec  5 3 4   4.1  mass  5 3 5  59.0  fec  5 3 5   5.1  mass
 5 4 1  93.0  fec  5 4 1   5.1  mass  5 4 2  47.0  fec  5 4 2   4.7  mass
 5 4 3  58.0  fec  5 4 3   4.0  mass  5 4 4  48.0  fec  5 4 4   3.8  mass
 5 4 5  39.0  fec  5 4 5   3.6  mass  6 1 1  73.0  fec  6 1 1   4.1  mass
 6 1 2  33.0  fec  6 1 2   3.3  mass  6 1 3  25.0  fec  6 1 3   4.0  mass
 6 1 4  53.0  fec  6 1 4   4.0  mass  6 1 5  29.0  fec  6 1 5   3.9  mass
 6 2 1  72.0  fec  6 2 1   5.0  mass  6 2 2  75.0  fec  6 2 2   5.0  mass
 6 2 3  75.0  fec  6 2 3   4.6  mass  6 2 4  77.0  fec  6 2 4   5.5  mass
 6 2 5  63.0  fec  6 2 5   4.8  mass  6 3 1  54.0  fec  6 3 1   3.9  mass
 6 3 2  40.0  fec  6 3 2   3.1  mass  6 3 3  58.0  fec  6 3 3   4.2  mass
 6 3 4  52.0  fec  6 3 4   4.4  mass  6 3 5  53.0  fec  6 3 5   4.1  mass
 6 4 1  63.0  fec  6 4 1   5.0  mass  6 4 2  57.0  fec  6 4 2   3.8  mass
 6 4 3  36.0  fec  6 4 3   3.2  mass  6 4 4  20.0  fec  6 4 4   4.3  mass
 6 4 5  49.0  fec  6 4 5   4.9  mass  6 5 1  67.0  fec  6 5 1   4.4  mass
 6 5 2  85.0  fec  6 5 2   5.8  mass  6 5 3  46.0  fec  6 5 3   4.7  mass
 6 5 4  68.0  fec  6 5 4   4.8  mass  6 5 5  44.0  fec  6 5 5   5.0  mass
 7 1 1  32.0  fec  7 1 1   5.3  mass  7 1 2  64.0  fec  7 1 2   4.7  mass
 7 1 3  72.0  fec  7 1 3   5.7  mass  7 1 4  40.0  fec  7 1 4   3.9  mass
 7 1 5  40.0  fec  7 1 5   5.4  mass  7 2 1  70.0  fec  7 2 1   5.0  mass
 7 2 2  19.0  fec  7 2 2   4.9  mass  7 2 3  31.0  fec  7 2 3   4.1  mass
 7 2 4  66.0  fec  7 2 4   5.0  mass  7 2 5  53.0  fec  7 2 5   5.3  mass
 7 3 1  63.0  fec  7 3 1   4.7  mass  7 3 2  50.0  fec  7 3 2   4.8  mass
 7 3 3  78.0  fec  7 3 3   5.2  mass  7 3 4  77.0  fec  7 3 4   6.3  mass
 7 3 5  48.0  fec  7 3 5   4.3  mass  7 4 1  73.0  fec  7 4 1   5.4  mass
 7 4 2  67.0  fec  7 4 2   4.9  mass  7 4 3  57.0  fec  7 4 3   4.2  mass
 7 4 4  33.0  fec  7 4 4   5.1  mass  7 4 5  53.0  fec  7 4 5   4.0  mass
 7 5 1  79.0  fec  7 5 1   5.3  mass  7 5 2  68.0  fec  7 5 2   4.8  mass
 7 5 3  39.0  fec  7 5 3   4.6  mass  7 5 4  48.0  fec  7 5 4   4.8  mass
 7 5 5  58.0  fec  7 5 5   5.1  mass  8 1 1  56.0  fec  8 1 1   4.6  mass
 8 1 2  36.0  fec  8 1 2   3.3  mass  8 1 3  40.0  fec  8 1 3   4.1  mass
 8 1 4  60.0  fec  8 1 4   4.6  mass  8 1 5  51.0  fec  8 1 5   3.8  mass
 8 2 1  63.0  fec  8 2 1   4.3  mass  8 2 2  73.0  fec  8 2 2   4.7  mass
 8 2 3  51.0  fec  8 2 3   3.8  mass  8 2 4  74.0  fec  8 2 4   4.8  mass
 8 2 5  64.0  fec  8 2 5   4.5  mass  8 3 1  48.0  fec  8 3 1   4.2  mass
 8 3 2  28.0  fec  8 3 2   4.0  mass  8 3 3  32.0  fec  8 3 3   3.6  mass
 8 3 4  50.0  fec  8 3 4   4.1  mass  8 3 5  44.0  fec  8 3 5   3.4  mass
 8 4 1  79.0  fec  8 4 1   4.6  mass  8 4 2  27.0  fec  8 4 2   2.4  mass
 8 4 3  17.0  fec  8 4 3   4.4  mass  8 4 4  41.0  fec  8 4 4   4.0  mass
 8 4 5  30.0  fec  8 4 5   5.7  mass  9 1 1  51.0  fec  9 1 1   3.3  mass
 9 1 2  48.0  fec  9 1 2   4.0  mass  9 1 3  78.0  fec  9 1 3   5.2  mass
 9 1 4  31.0  fec  9 1 4   3.9  mass  9 1 5  53.0  fec  9 1 5   3.7  mass
 9 2 1  65.0  fec  9 2 1   3.8  mass  9 2 2  40.0  fec  9 2 2   3.5  mass
 9 2 3  46.0  fec  9 2 3   4.1  mass  9 2 4  39.0  fec  9 2 4   4.7  mass
 9 2 5  58.0  fec  9 2 5   3.9  mass  9 3 1  72.0  fec  9 3 1   4.4  mass
 9 3 2  52.0  fec  9 3 2   3.7  mass  9 3 3  56.0  fec  9 3 3   3.7  mass
 9 3 4  61.0  fec  9 3 4   3.9  mass  9 3 5  46.0  fec  9 3 5   3.3  mass
 9 4 1  28.0  fec  9 4 1   4.3  mass  9 4 2  25.0  fec  9 4 2   4.4  mass
 9 4 3  63.0  fec  9 4 3   4.2  mass  9 4 4  20.0  fec  9 4 4   4.9  mass
 9 4 5  26.0  fec  9 4 5   4.2  mass 10 1 1  35.0  fec 10 1 1   4.1  mass
10 1 2  60.0  fec 10 1 2   4.6  mass 10 1 3  17.0  fec 10 1 3   4.4  mass
10 1 4  65.0  fec 10 1 4   4.5  mass 10 1 5  31.0  fec 10 1 5   4.6  mass
10 2 1  78.0  fec 10 2 1   4.7  mass 10 2 2  74.0  fec 10 2 2   4.9  mass
10 2 3  72.0  fec 10 2 3   5.3  mass 10 2 4  72.0  fec 10 2 4   5.1  mass
10 2 5  71.0  fec 10 2 5   6.4  mass 10 3 1  69.0  fec 10 3 1   4.5  mass
10 3 2  76.0  fec 10 3 2   5.0  mass 10 3 3  54.0  fec 10 3 3   4.5  mass
10 3 4  69.0  fec 10 3 4   5.2  mass 10 3 5  51.0  fec 10 3 5   4.8  mass

10 4 1  79.0  fec 10 4 1   5.5  mass 10 4 2  84.0  fec 10 4 2   5.3  mass
10 4 3  85.0  fec 10 4 3   5.2  mass 10 4 4  51.0  fec 10 4 4   6.2  mass
10 4 5  73.0  fec 10 4 5   6.8  mass 11 1 1  76.0  fec 11 1 1   4.3  mass
11 1 2  56.0  fec 11 1 2   4.4  mass 11 1 3  80.0  fec 11 1 3   4.6  mass
11 1 4  74.0  fec 11 1 4   5.2  mass 11 1 5  54.0  fec 11 1 5   4.0  mass
11 2 1  69.0  fec 11 2 1   4.0  mass 11 2 2  72.0  fec 11 2 2   4.6  mass
11 2 3  68.0  fec 11 2 3   4.4  mass 11 2 4  81.0  fec 11 2 4   4.7  mass
11 2 5  45.0  fec 11 2 5   3.6  mass 11 3 1  43.0  fec 11 3 1   3.8  mass
11 3 2  40.0  fec 11 3 2   3.6  mass 11 3 3  48.0  fec 11 3 3   4.4  mass
11 3 4  45.0  fec 11 3 4   3.4  mass 11 3 5  74.0  fec 11 3 5   5.3  mass
11 4 1  58.0  fec 11 4 1   4.1  mass 11 4 2  47.0  fec 11 4 2   3.8  mass
11 4 3  63.0  fec 11 4 3   4.0  mass 11 4 4  45.0  fec 11 4 4   3.2  mass
11 4 5  45.0  fec 11 4 5   5.0  mass 11 5 1  62.0  fec 11 5 1   4.8  mass
11 5 2  72.0  fec 11 5 2   4.1  mass 11 5 3  63.0  fec 11 5 3   5.1  mass
11 5 4  47.0  fec 11 5 4   3.8  mass 11 5 5  64.0  fec 11 5 5   6.1  mass
12 1 1  72.0  fec 12 1 1   6.3  mass 12 1 2  47.0  fec 12 1 2   4.0  mass
12 1 3  56.0  fec 12 1 3   4.9  mass 12 1 4  37.0  fec 12 1 4   4.5  mass
12 1 5  65.0  fec 12 1 5   4.8  mass 12 2 1  47.0  fec 12 2 1   5.0  mass
12 2 2  52.0  fec 12 2 2   4.9  mass 12 2 3  59.0  fec 12 2 3   5.4  mass
12 2 4  51.0  fec 12 2 4   4.6  mass 12 2 5  25.0  fec 12 2 5   3.8  mass
12 3 1  49.0  fec 12 3 1   5.2  mass 12 3 2  48.0  fec 12 3 2   4.7  mass
12 3 3  70.0  fec 12 3 3   4.8  mass 12 3 4  52.0  fec 12 3 4   4.4  mass
12 3 5  67.0  fec 12 3 5   5.4  mass 12 4 1  54.0  fec 12 4 1   5.6  mass
12 4 2  58.0  fec 12 4 2   4.6  mass 12 4 3  54.0  fec 12 4 3   4.7  mass
12 4 4  64.0  fec 12 4 4   5.3  mass 12 4 5  56.0  fec 12 4 5   5.0  mass
12 5 1  44.0  fec 12 5 1   4.9  mass 12 5 2  70.0  fec 12 5 2   5.6  mass
12 5 3  47.0  fec 12 5 3   4.4  mass 12 5 4  41.0  fec 12 5 4   3.9  mass
12 5 5  45.0  fec 12 5 5   5.3  mass 13 1 1  48.0  fec 13 1 1   3.7  mass
13 1 2  55.0  fec 13 1 2   3.5  mass 13 1 3  22.0  fec 13 1 3   4.0  mass
13 1 4  61.0  fec 13 1 4   3.8  mass 13 1 5  57.0  fec 13 1 5   4.1  mass
13 2 1  43.0  fec 13 2 1   4.7  mass 13 2 2  44.0  fec 13 2 2   3.7  mass
13 2 3  30.0  fec 13 2 3   3.9  mass 13 2 4  42.0  fec 13 2 4   2.8  mass
13 2 5  25.0  fec 13 2 5   4.1  mass 13 3 1  58.0  fec 13 3 1   4.1  mass
13 3 2  55.0  fec 13 3 2   4.3  mass 13 3 3  55.0  fec 13 3 3   4.6  mass
13 3 4  46.0  fec 13 3 4   4.6  mass 13 3 5  50.0  fec 13 3 5   4.6  mass
13 4 1  82.0  fec 13 4 1   5.3  mass 13 4 2  94.0  fec 13 4 2   4.8  mass
13 4 3  43.0  fec 13 4 3   5.0  mass 13 4 4  38.0  fec 13 4 4   5.0  mass
13 4 5  19.0  fec 13 4 5   4.2  mass 13 5 1  81.0  fec 13 5 1   4.4  mass
13 5 2  84.0  fec 13 5 2   4.7  mass 13 5 3  46.0  fec 13 5 3   3.7  mass
13 5 4  81.0  fec 13 5 4   4.5  mass 13 5 5  48.0  fec 13 5 5   4.2  mass
14 1 1  28.0  fec 14 1 1   5.7  mass 14 1 2  55.0  fec 14 1 2   5.8  mass
14 1 3  27.0  fec 14 1 3   5.3  mass 14 1 4  48.0  fec 14 1 4   4.3  mass
14 1 5  52.0  fec 14 1 5   5.2  mass 14 2 1  39.0  fec 14 2 1   3.9  mass
14 2 2  48.0  fec 14 2 2   4.7  mass 14 2 3  30.0  fec 14 2 3   5.5  mass
14 2 4  51.0  fec 14 2 4   4.8  mass 14 2 5  43.0  fec 14 2 5   4.0  mass
14 3 1  24.0  fec 14 3 1   4.4  mass 14 3 2  20.0  fec 14 3 2   4.8  mass
14 3 3  14.0  fec 14 3 3   4.0  mass 14 3 4  18.0  fec 14 3 4   3.8  mass
14 3 5  48.0  fec 14 3 5   3.9  mass 14 4 1  60.0  fec 14 4 1   4.5  mass
14 4 2  45.0  fec 14 4 2   4.0  mass 14 4 3  57.0  fec 14 4 3   5.5  mass
14 4 4  38.0  fec 14 4 4   4.9  mass 14 4 5  62.0  fec 14 4 5   5.1  mass
14 5 1  52.0  fec 14 5 1   4.5  mass 14 5 2  58.0  fec 14 5 2   4.5  mass
14 5 3  54.0  fec 14 5 3   5.6  mass 14 5 4  64.0  fec 14 5 4   5.1  mass
14 5 5  49.0  fec 14 5 5   4.5  mass 15 1 1  88.0  fec 15 1 1   5.2  mass
15 1 2  48.0  fec 15 1 2   4.4  mass 15 1 3  48.0  fec 15 1 3   3.6  mass
15 1 4  61.0  fec 15 1 4   4.7  mass 15 1 5  41.0  fec 15 1 5   3.9  mass
15 2 1  64.0  fec 15 2 1   4.3  mass 15 2 2  78.0  fec 15 2 2   5.5  mass
15 2 3  67.0  fec 15 2 3   4.5  mass 15 2 4  71.0  fec 15 2 4   5.1  mass
15 2 5  59.0  fec 15 2 5   4.5  mass 15 3 1  64.0  fec 15 3 1   5.0  mass
15 3 2  59.0  fec 15 3 2   4.9  mass 15 3 3  51.0  fec 15 3 3   5.3  mass
15 3 4  67.0  fec 15 3 4   4.8  mass 15 3 5  72.0  fec 15 3 5   6.0  mass
15 4 1  86.0  fec 15 4 1   4.9  mass 15 4 2  81.0  fec 15 4 2   5.9  mass
15 4 3  71.0  fec 15 4 3   6.1  mass 15 4 4  86.0  fec 15 4 4   5.6  mass
15 4 5  73.0  fec 15 4 5   4.8  mass 15 5 1  75.0  fec 15 5 1   6.3  mass
15 5 2  61.0  fec 15 5 2   5.6  mass 15 5 3  42.0  fec 15 5 3   5.1  mass
15 5 4  65.0  fec 15 5 4   5.3  mass 15 5 5  58.0  fec 15 5 5   4.9  mass
16 1 1  50.0  fec 16 1 1   4.0  mass 16 1 2  23.0  fec 16 1 2   4.5  mass
16 1 3  74.0  fec 16 1 3   5.0  mass 16 1 4  64.0  fec 16 1 4   4.3  mass
16 1 5  51.0  fec 16 1 5   4.3  mass 16 2 1  74.0  fec 16 2 1   5.3  mass
16 2 2  68.0  fec 16 2 2   4.7  mass 16 2 3  61.0  fec 16 2 3   3.8  mass
16 2 4  60.0  fec 16 2 4   4.0  mass 16 2 5  60.0  fec 16 2 5   4.3  mass
16 3 1  72.0  fec 16 3 1   4.8  mass 16 3 2  62.0  fec 16 3 2   4.5  mass
16 3 3  68.0  fec 16 3 3   4.4  mass 16 3 4  78.0  fec 16 3 4   5.2  mass
16 3 5  63.0  fec 16 3 5   4.7  mass 16 4 1  68.0  fec 16 4 1   3.9  mass
16 4 2  72.0  fec 16 4 2   4.0  mass 16 4 3  61.0  fec 16 4 3   3.5  mass
16 4 4  56.0  fec 16 4 4   4.1  mass 16 4 5  73.0  fec 16 4 5   4.8  mass
17 1 1  14.0  fec 17 1 1   3.7  mass 17 1 2  26.0  fec 17 1 2   4.9  mass
17 1 3  44.0  fec 17 1 3   3.4  mass 17 1 4  34.0  fec 17 1 4   3.9  mass
17 1 5  51.0  fec 17 1 5   4.4  mass 17 2 1  57.0  fec 17 2 1   4.3  mass
17 2 2  75.0  fec 17 2 2   6.6  mass 17 2 3  45.0  fec 17 2 3   3.3  mass
17 2 4  68.0  fec 17 2 4   5.6  mass 17 2 5  77.0  fec 17 2 5   5.2  mass
17 3 1  51.0  fec 17 3 1   5.1  mass 17 3 2  35.0  fec 17 3 2   5.4  mass
17 3 3  61.0  fec 17 3 3   5.3  mass 17 3 4  34.0  fec 17 3 4   5.4  mass
17 3 5  57.0  fec 17 3 5   4.7  mass 17 4 1  62.0  fec 17 4 1   5.2  mass
17 4 2  49.0  fec 17 4 2   3.8  mass 17 4 3  40.0  fec 17 4 3   4.9  mass
17 4 4  45.0  fec 17 4 4   4.9  mass 17 4 5  55.0  fec 17 4 5   4.6  mass
17 5 1  65.0  fec 17 5 1   4.7  mass 17 5 2  24.0  fec 17 5 2   3.4  mass
17 5 3  19.0  fec 17 5 3   4.8  mass 17 5 4  28.0  fec 17 5 4   3.6  mass
17 5 5  68.0  fec 17 5 5   4.7  mass 18 1 1  28.0  fec 18 1 1   3.8  mass
18 1 2  42.0  fec 18 1 2   3.3  mass 18 1 3  19.0  fec 18 1 3   3.4  mass
18 1 4  24.0  fec 18 1 4   5.0  mass 18 1 5  15.0  fec 18 1 5   2.7  mass
18 2 1  80.0  fec 18 2 1   5.7  mass 18 2 2  57.0  fec 18 2 2   3.8  mass
18 2 3  76.0  fec 18 2 3   4.7  mass 18 2 4  30.0  fec 18 2 4   4.7  mass
18 2 5  72.0  fec 18 2 5   5.6  mass 18 3 1  61.0  fec 18 3 1   4.1  mass
18 3 2  46.0  fec 18 3 2   3.6  mass 18 3 3  50.0  fec 18 3 3   4.1  mass
18 3 4  64.0  fec 18 3 4   3.8  mass 18 3 5  41.0  fec 18 3 5   4.0  mass
18 4 1  71.0  fec 18 4 1   4.3  mass 18 4 2  59.0  fec 18 4 2   4.8  mass
18 4 3  58.0  fec 18 4 3   4.1  mass 18 4 4  61.0  fec 18 4 4   4.0  mass
18 4 5  70.0  fec 18 4 5   4.6  mass 19 1 1  73.0  fec 19 1 1   5.0  mass
19 1 2  63.0  fec 19 1 2   4.2  mass 19 1 3  58.0  fec 19 1 3   4.1  mass
19 1 4  64.0  fec 19 1 4   4.0  mass 19 1 5  72.0  fec 19 1 5   5.2  mass
19 2 1  66.0  fec 19 2 1   4.4  mass 19 2 2  61.0  fec 19 2 2   3.5  mass
19 2 3  85.0  fec 19 2 3   4.2  mass 19 2 4  32.0  fec 19 2 4   4.6  mass
19 2 5  48.0  fec 19 2 5   4.0  mass 19 3 1  68.0  fec 19 3 1   4.7  mass
19 3 2  62.0  fec 19 3 2   4.4  mass 19 3 3  60.0  fec 19 3 3   3.8  mass
19 3 4  62.0  fec 19 3 4   5.0  mass 19 3 5  52.0  fec 19 3 5   4.4  mass
19 4 1  70.0  fec 19 4 1   4.0  mass 19 4 2  71.0  fec 19 4 2   4.9  mass
19 4 3  44.0  fec 19 4 3   3.6  mass 19 4 4  63.0  fec 19 4 4   4.4  mass
19 5 1  64.0  fec 19 5 1   4.6  mass 19 5 2  62.0  fec 19 5 2   4.4  mass
19 5 3  53.0  fec 19 5 3   4.9  mass 19 5 4  62.0  fec 19 5 4   4.4  mass
19 5 5  55.0  fec 19 5 5   4.5  mass 20 1 1  55.0  fec 20 1 1   4.0  mass
20 1 2  86.0  fec 20 1 2   7.0  mass 20 1 3  71.0  fec 20 1 3   4.5  mass
20 1 4  62.0  fec 20 1 4   5.0  mass 20 1 5  48.0  fec 20 1 5   4.8  mass
20 2 1  57.0  fec 20 2 1   4.6  mass 20 2 2  51.0  fec 20 2 2   4.4  mass
20 2 3  66.0  fec 20 2 3   4.8  mass 20 2 4  38.0  fec 20 2 4   4.0  mass
20 2 5  68.0  fec 20 2 5   5.5  mass 20 3 1  22.0  fec 20 3 1   4.6  mass
20 3 2  18.0  fec 20 3 2   5.9  mass 20 3 3   6.0  fec 20 3 3   5.5  mass
20 3 4  20.0  fec 20 3 4   4.2  mass 20 3 5   4.0  fec 20 3 5   4.5  mass
20 4 1  56.0  fec 20 4 1   3.9  mass 20 4 2  57.0  fec 20 4 2   4.9  mass
20 4 3  64.0  fec 20 4 3   5.0  mass 20 4 4  54.0  fec 20 4 4   4.0  mass
20 4 5  58.0  fec 20 4 5   4.8  mass 21 1 1  58.0  fec 21 1 1   4.1  mass
21 1 2  81.0  fec 21 1 2   5.7  mass 21 1 3  74.0  fec 21 1 3   5.3  mass
21 1 4  62.0  fec 21 1 4   4.1  mass 21 1 5  58.0  fec 21 1 5   4.7  mass
21 2 1  69.0  fec 21 2 1   4.9  mass 21 2 2  74.0  fec 21 2 2   6.2  mass
21 2 3  58.0  fec 21 2 3   5.0  mass 21 2 4  64.0  fec 21 2 4   4.5  mass
21 2 5  59.0  fec 21 2 5   5.5  mass 21 3 1  47.0  fec 21 3 1   4.9  mass
21 3 2  65.0  fec 21 3 2   5.2  mass 21 3 3  28.0  fec 21 3 3   5.1  mass
21 3 4  58.0  fec 21 3 4   4.0  mass 21 3 5  64.0  fec 21 3 5   4.5  mass
21 4 1  80.0  fec 21 4 1   4.7  mass 21 4 2  83.0  fec 21 4 2   4.0  mass
21 4 3  69.0  fec 21 4 3   4.8  mass 21 4 4  62.0  fec 21 4 4   5.0  mass
21 4 5  59.0  fec 21 4 5   5.3  mass 22 1 1  68.0  fec 22 1 1   4.5  mass
22 1 2  39.0  fec 22 1 2   5.2  mass 22 1 3  40.0  fec 22 1 3   4.8  mass
22 1 4  60.0  fec 22 1 4   4.7  mass 22 1 5  45.0  fec 22 1 5   3.7  mass
22 2 1  80.0  fec 22 2 1   5.0  mass 22 2 2  70.0  fec 22 2 2   5.0  mass
22 2 3  81.0  fec 22 2 3   5.2  mass 22 2 4  61.0  fec 22 2 4   5.2  mass
22 2 5  67.0  fec 22 2 5   4.9  mass 22 3 1  60.0  fec 22 3 1   5.8  mass
22 3 2  64.0  fec 22 3 2   5.3  mass 22 3 3  46.0  fec 22 3 3   4.4  mass
22 3 4  60.0  fec 22 3 4   5.7  mass 22 3 5  59.0  fec 22 3 5   4.8  mass
22 4 1  71.0  fec 22 4 1   5.0  mass 22 4 2  68.0  fec 22 4 2   5.2  mass
22 4 3  78.0  fec 22 4 3   5.4  mass 22 4 4  60.0  fec 22 4 4   4.4  mass
22 4 5  58.0  fec 22 4 5   5.6  mass 22 5 1  66.0  fec 22 5 1   5.1  mass
22 5 2  53.0  fec 22 5 2   4.1  mass 22 5 3  65.0  fec 22 5 3   5.0  mass
22 5 4  25.0  fec 22 5 4   4.5  mass 22 5 5  58.0  fec 22 5 5   4.8  mass
23 1 1  73.0  fec 23 1 1   5.1  mass 23 1 2  64.0  fec 23 1 2   5.7  mass
23 1 3  64.0  fec 23 1 3   6.1  mass 23 1 4  64.0  fec 23 1 4   6.0  mass
23 1 5  87.0  fec 23 1 5   7.2  mass 23 2 1  36.0  fec 23 2 1   4.9  mass
23 2 2  73.0  fec 23 2 2   6.1  mass 23 2 3  42.0  fec 23 2 3   3.6  mass
23 2 4  68.0  fec 23 2 4   5.3  mass 23 2 5  52.0  fec 23 2 5   5.2  mass
23 3 1  65.0  fec 23 3 1   4.9  mass 23 3 2  76.0  fec 23 3 2   4.6  mass
23 3 3  59.0  fec 23 3 3   5.1  mass 23 3 4  45.0  fec 23 3 4   4.6  mass
23 3 5  67.0  fec 23 3 5   5.3  mass 23 4 1  54.0  fec 23 4 1   5.6  mass
23 4 2  50.0  fec 23 4 2   3.6  mass 23 4 3  50.0  fec 23 4 3   4.8  mass
23 4 4  60.0  fec 23 4 4   3.9  mass 23 4 5  59.0  fec 23 4 5   5.2  mass
23 5 1  101.0 fec 23 5 1   6.3  mass 23 5 2  96.0  fec 23 5 2   5.2  mass
23 5 3  104.0 fec 23 5 3   5.1  mass 23 5 4  97.0  fec 23 5 4   5.7  mass
23 5 5  79.0  fec 23 5 5   5.5  mass 24 1 1  74.0  fec 24 1 1   4.3  mass
24 1 2  93.0  fec 24 1 2   5.2  mass 24 1 3  93.0  fec 24 1 3   5.5  mass
24 1 4  101.0 fec 24 1 4   5.9  mass 24 1 5  86.0  fec 24 1 5   5.1  mass
24 2 1  77.0  fec 24 2 1   5.3  mass 24 2 2  59.0  fec 24 2 2   3.4  mass
24 2 3  82.0  fec 24 2 3   5.4  mass 24 2 4  82.0  fec 24 2 4   5.1  mass
24 2 5  68.0  fec 24 2 5   5.1  mass 24 3 1  31.0  fec 24 3 1   4.7  mass
24 3 2  57.0  fec 24 3 2   5.6  mass 24 3 3  52.0  fec 24 3 3   6.5  mass
24 3 4  39.0  fec 24 3 4   4.6  mass 24 3 5  39.0  fec 24 3 5   5.4  mass
24 4 1  81.0  fec 24 4 1   4.9  mass 24 4 2  86.0  fec 24 4 2   4.8  mass
24 4 3  77.0  fec 24 4 3   4.3  mass 24 4 4  65.0  fec 24 4 4   3.9  mass
24 4 5  80.0  fec 24 4 5   4.6  mass
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---output 13.3                                      ---*/
proc mixed data=beetle covtest cl asycov;
   where trait = 'fec';
   class sire dam;
   model value = / solution;
   random sire dam(sire);
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 13.4                                      ---*/
proc mixed data=beetle covtest cl asycov;
	 where trait = 'fec';
	 class sire dam;
	 model value = / solution;
	 random sire dam(sire);
	 prior / nsample=1e4 seed=3102834 out=post 
           psearch ptrans;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 13.5                                      ---*/
data post;
  set post;
  Var_Additive      = 4*covp1;
  Var_Maternal      = covp2 - covp1;
  Var_Environmental = covp3 - 2*covp1;
  if Var_Maternal < 0 or Var_Environmental < 0 then delete;
  Var_Total         = Var_Additive + Var_Maternal + 
                      Var_Environmental;
  Percent_Var_Additive = 100*Var_Additive/Var_Total;
  Percent_Var_Maternal = 100*Var_Maternal/Var_Total;
  Percent_Var_Environmental = 100*Var_Environmental/Var_Total;
  rename covp1 = Var_Sire 
         covp2 = Var_Dam_Sire 
         covp3 = Var_Residual
         beta1 = Intercept;
run;

proc univariate data=post noprint;
  var Var_Sire Var_Dam_Sire Var_Residual Intercept;
  output out=confInt pctlpts=2.5,50,97.5
                pctlpre = Sire_ DamSire_ Residual_ Intercept_ 
                pctlname= lower Median upper
                mean    = Sire_mean DamSire_mean 
                          Residual_Mean Intercept_Mean
                std     = Sire_Std DamSire_Std Residual_Std  
                          Intercept_Std;
run;
proc print data=confInt label noobs; var sire:     ;
proc print data=confInt label noobs; var damsire:  ;
proc print data=confInt label noobs; var residual: ;
proc print data=confInt label noobs; var intercept:;
run;
 /*-------------------------------------------------------*/ 

 /*-------------------------------------------------------*/
 /*---Output 13.6                                       ---*/
proc univariate data=post noprint;
  var Var_Additive Var_Maternal Var_Environmental;
  output out=confInt pctlpts=2.5,50,97.5
                pctlpre=Additive_ Maternal_ Environ_
                pctlname=lower Median upper
                mean=Additive_mean Maternal_mean Environ_Mean
                std=Additive_Std   Maternal_Std  Environ_Std;
run;
proc print data=confInt label noobs; var Additive:;
proc print data=confInt label noobs; var Maternal:;
proc print data=confInt label noobs; var Environ:;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 13.7                                      ---*/
 /*---Figure 13.2                                      ---*/
ods html;
ods graphics on;
proc corr data=post plots=matrix;
  var Var_Additive Var_Maternal Var_Environmental;
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 13.8                                      ---*/
proc univariate data=post noprint;
  var Percent_Var_Additive 
      Percent_Var_Maternal 
      Percent_Var_Environmental;
  output out=confInt pctlpts=2.5,50,97.5
                     pctlpre=Additive_ Maternal_ Environ_
                     pctlname=lower Median upper
                     mean   =Additive_mean Maternal_mean Environ_Mean
                     std    =Additive_Std  Maternal_Std  Environ_Std;

run;
proc print data=confInt label noobs; var Additive:;
proc print data=confInt label noobs; var Maternal:;
proc print data=confInt label noobs; var Environ:;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 13.9                                      ---*/
data pv;
   input type $ Parm1 Parm2;
   datalines;
ig 11.265 16709
ig 42.967 32216  
ig 219.55 38966
run; 

proc mixed data=beetle covtest cl asycov;
   where trait = 'fec';
   class sire dam;
   model value = / solution;
   random sire dam(sire);
   prior data=pv / nsample=1e4 seed=3102834 out=post1 
                   psearch ptrans;
run;

data post1;
   set post1;
   Var_Additive      = 4*covp1;
   Var_Maternal      = covp2 - covp1;
   Var_Environmental = covp3 - 2*covp1;
   if Var_Maternal < 0 or Var_Environmental < 0 then delete;
   Var_Total = Var_Additive + Var_Maternal + Var_Environmental;
   Percent_Var_Additive      = 100*Var_Additive/Var_Total;
   Percent_Var_Maternal      = 100*Var_Maternal/Var_Total;
   Percent_Var_Environmental = 100*Var_Environmental/Var_Total;
   rename covp1 = Var_Sire 
          covp2 = Var_Dam_Sire 
          covp3 = Var_Residual
          beta1 = Intercept;
run;

proc means data= post1 mean std;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---CHAPTER 14: Generalized Linear Mixed Models      ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 14.5, Clinics                           ---*/
data clinics;
   input clinic trt$ fav unfav;
   nij = fav+unfav;
   if fav=0 then fav = 0.1/nij;
   datalines;
1 drug 11 25
1 cntl 10 27
2 drug 16 4
2 cntl 22 10
3 drug 14 5
3 cntl 7 12
4 drug 2 14
4 cntl 1 16
5 drug 6 11
5 cntl 0 12
6 drug 1 10
6 cntl 0 10
7 drug 1 4
7 cntl 1 8
8 drug 4 2
8 cntl 6 1
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.1                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth;
   random clinic trt*clinic;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.2                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth oddsratio;
   random clinic trt*clinic;
   lsmeans trt                     / ilink;
   estimate 'trt diff' trt 1 -1    / exp cl;
   estimate 'trt 1 clinic 1 BLUP' intercept 1 trt 1 0 
            | clinic 1 0           / ilink;
   estimate 'trt 1 clinic 6 BLUP' intercept 1 trt 1 0
            | clinic 0 0 0 0 0 1 0 / ilink;
   ods select OddsRatios LSMeans Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.3                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth;
   random clinic trt*clinic / s;
   ods select ParameterEstimates SolutionR;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.4                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth;
   random clinic trt*clinic;
   output out=gmxout pred(ilink   noblup) = mupa
                     pred(ilink     blup) = mu
                     pred(noilink noblup) = linppa
                     pred(noilink blup  ) = linp;
run;
proc print data=gmxout; 
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.5                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth
                         link=probit;
   random clinic trt*clinic / solution;
   lsmeans trt / ilink;
   estimate 'trt diff' trt 1 -1 / cl;
   estimate 'trt 1 clinic 1 BLUP' intercept 1 trt 1 0 
            | clinic 1 0 / ilink;
   estimate 'trt 1 clinic 6 BLUP' intercept 1 trt 1 0
            | clinic 0 0 0 0 0 1 0 / ilink;
   ods select FitStatistics CovParms Tests3 Estimates LSMeans;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.6                                      ---*/
proc glimmix data=clinics;
   class clinic trt;
   model fav/nij = trt / solution ddfm=satterth
                         link=probit;
   random clinic trt*clinic / solution;
   ods select ParameterEstimates SolutionR;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 14.6, Seed Mix                          ---*/
data mix;
   input trt blk mix count @@;
   y = count + 1;
   datalines;
1 1 1  24 1 1 2  12 1 1 3   8 1 1 4  13 1 2 1   9 1 2 2   9
1 2 3   9 1 2 4  18 1 3 1  12 1 3 2   8 1 3 3  44 1 3 4   0
1 4 1   8 1 4 2  12 1 4 3  25 1 4 4   0 2 1 1  11 2 1 2  32
2 1 3  12 2 1 4  22 2 2 1  41 2 2 2  15 2 2 3  39 2 2 4  38
2 3 1  30 2 3 2  11 2 3 3   5 2 3 4  50 2 4 1  11 2 4 2   0
2 4 3   7 2 4 4  10 3 1 1   0 3 1 2   0 3 1 3  19 3 1 4  25
3 2 1  33 3 2 2  14 3 2 3  20 3 2 4  30 3 3 1  46 3 3 2  31
3 3 3   5 3 3 4   7 3 4 1   8 3 4 2  25 3 4 3  19 3 4 4   3
4 1 1  19 4 1 2  50 4 1 3  20 4 1 4   7 4 2 1  13 4 2 2  42
4 2 3  37 4 2 4   6 4 3 1  10 4 3 2   9 4 3 3  10 4 3 4  24
4 4 1  24 4 4 2  34 4 4 3  35 4 4 4  45 5 1 1  19 5 1 2  48
5 1 3  50 5 1 4  34 5 2 1   0 5 2 2  36 5 2 3  24 5 2 4  24
5 3 1  40 5 3 2  40 5 3 3  14 5 3 4  18 5 4 1  99 5 4 2  39
5 4 3  21 5 4 4  25 6 1 1 115 6 1 2  38 6 1 3  16 6 1 4  34
6 2 1  52 6 2 2  55 6 2 3  17 6 2 4  18 6 3 1  37 6 3 2  19
6 3 3  44 6 3 4  10 6 4 1  10 6 4 2  11 6 4 3  14 6 4 4  13
7 1 1  46 7 1 2  45 7 1 3  37 7 1 4  13 7 2 1  30 7 2 2  96
7 2 3  41 7 2 4  37 7 3 1  59 7 3 2  34 7 3 3  28 7 3 4  20
7 4 1  84 7 4 2  56 7 4 3  26 7 4 4  27
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.7                                      ---*/
proc glimmix data=mix;
   class trt blk mix;
   model y = trt mix trt*mix / dist=poisson;
   random blk blk*trt;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.8                                      ---*/
proc glimmix data=mix;
   class trt blk mix;
   model y = trt mix trt*mix / dist=poisson s;
   random blk*trt;
   output out=gmxout pearson(blup)=res;
run;
proc means data=gmxout mean std; var res;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 14.9                                      ---*/
 /*---Figure 14.1                                      ---*/
 /*---Figure 14.2                                      ---*/
ods html;
ods graphics on;
proc glimmix data=mix;
   class trt blk mix;
   model y = trt mix trt*mix / dist=poisson;
   random blk blk*trt;
   random _residual_;
   lsmeans trt / plots=diffplot adjust=tukey;
   lsmeans trt / plots=anomplot adjust=nelson; 
run;
ods graphics off;
ods html close;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 14.10                                     ---*/
proc glimmix data=mix;
   class trt blk mix;
   model y = trt mix trt*mix / dist=poisson;
   lsmeans trt;
   random _residual_;
run;
 /*-------------------------------------------------------*/


 
/*-------------------------------------------------------*/
 /*---CHAPTER 15: Nonlinear Mixed Models               ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Orange tree data (Data Set 15.3, Appendix 2      ---*/
 /*---Draper and Smith (1981, p. 524) and              ---*/
 /*---Lindstrom and Bates (1990, Biometrics, p. 673-687)--*/
data tree; 
  input tree day circum @@; 
  datalines; 
   1  118   30    1  484   58    1  664   87    1 1004  115 
   1 1231  120    1 1372  142    1 1582  145 
   2  118   33    2  484   69    2  664  111    2 1004  156 
   2 1231  172    2 1372  203    2 1582  203 
   3  118   30    3  484   51    3  664   75    3 1004  108 
   3 1231  115    3 1372  139    3 1582  140 
   4  118   32    4  484   62    4  664  112    4 1004  167 
   4 1231  179    4 1372  209    4 1582  214 
   5  118   30    5  484   49    5  664   81    5 1004  125 
   5 1231  142    5 1372  174    5 1582  177 
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*--- Figure 15.1                                     ---*/
goptions reset=all

   hsize   = 9 in
   vsize   = 8 in
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss
   lfactor = 1;

axis1 order = (0 to 1600 by 400)
      value = (font=swissl height=2)  
      label = (font=swissl h=2)
      major = (h=0.5)
      minor = none;

axis2 order = (0 to 250 by 50)
      value = (font=swissl height=2)
      label = (font=swissl h=2)
      major = (h=1)
      minor = none;

symbol1 color=black value=none i=join l=1 r=5 w=1;

proc gplot data=tree;
   plot circum*day=tree / nolegend haxis=axis1 vaxis=axis2;
run;
quit;
goptions reset=all;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*--- Output 15.1                                     ---*/
proc nlmixed data=tree method=firo; 
   parms b1=190 b2=10 b3=100 s2u1=500 c12=0 s2u2=10 s2e=50;
   bounds s2u1 >= 0, s2u2 >= 0, s2e > 0; 
   num = b1+u1; 
   ex  = exp(-day/b3); 
   den = 1 + (b2+u2)*ex; 
   model circum ~ normal(num/den,s2e); 
   random u1 u2 ~ normal([0,0],[s2u1,c12,s2u2]) subject=tree; 
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Load the NLINMIX macro. You can download the file---*/
 /*---nlmm800.sas from the SAS technical support web site-*/ 
%include 'nlmm800.sas' / nosource;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Logistic model, NLINMIX Method 1                 ---*/
 /*---Output 15.2 and 15.3                             ---*/
%nlinmix(data=tree,
   procopt=method=ml,
   model=%str(
      num   = b1+u1;
      e     = exp(-day/b3);
      den   = 1 + (b2+u2)*e;
      predv = num/den; 
   ),
   parms=%str(b1=190 b2=10 b3=100),
   stmts=%str(
      class tree;
      model pseudo_circum = d_b1 d_b2 d_b3 / noint notest solution cl;
      random d_u1 d_u2 / subject=tree type=un solution cl;
   ),
   expand=zero
)
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Logistic model, NLINMIX Method 2                 ---*/
 /*---Output not shown                                 ---*/
%nlinmix(data=tree,
   procopt=method=ml,
   model=%str(
      num   = b1+u1;
      e     = exp(-day/b3);
      den   = 1 + (b2+u2)*e;
      predv = num/den; 
   ),
   parms=%str(b1=190 b2=10 b3=100),
   stmts=%str(
      class tree;
      model pseudo_circum = d_b1 d_b2 d_b3 / noint notest solution cl;
      random d_u1 d_u2 / subject=tree type=un solution cl;
   ),
   expand=eblup
)
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Logistic model, NLINMIX Method 3                 ---*/
 /*---Without variance weighing                        ---*/
 /*---Output not shown                                 ---*/
%nlinmix(data=tree,
   procopt=method=ml,
   model=%str(
      num   = b1;
      e     = exp(-day/b3);
      den   = 1 + b2*e;
      predv = num/den; 
   ),
   parms=%str(b1=190 b2=10 b3=100),
   stmts=%str(
      class tree;
      model pseudo_circum = d_b1 d_b2 d_b3 / noint notest solution cl;
      repeated / subject=tree type=cs;
   )
)
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Logistic model, NLINMIX Method 3                 ---*/
 /*---Without variance weighing for constant CV        ---*/
 /*---Output 15.4, Output 15.5                         ---*/
%nlinmix(data=tree,
   procopt=method=ml,
   model=%str(
      num   = b1;
      e     = exp(-day/b3);
      den   = 1 + b2*e;
      predv = num/den; 
   ),
   weight = %str(
      wghtv = 1/predv**2;
   ),
   parms=%str(b1=190 b2=10 b3=100),
   stmts=%str(
      class tree;
      model pseudo_circum = d_b1 d_b2 d_b3 / noint notest solution cl;
      repeated / subject=tree type=cs;
      weight wghtv;
   )
)
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Compare power models, each m2ll value below is the--*/
 /*---result of running the previous model using a     ---*/
 /*---different power to weight the variance           ---*/
data pom;
   input power m2ll;
   datalines;
-4     275.4207
-3.5   269.8219
-3     266.9001
-2.75  266.4461
-2.5   266.6548
-2.25  267.5017
-2     268.9451
-1     279.5383
 0     295.2636
;

proc glm data=pom;
   model m2ll = power power*power / solution;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 15.6                                      ---*/
 /*---Simulate from a model with three random components--*/
 /*---B is nested within A, plus a residual variance   ---*/
%let na = 100;
%let nb = 5;
%let nr = 2;
data nested;
  do A = 1 to &na;
     err1 = 3*rannor(339205);
     do B = 1 to &nb;
        err2 = 2*rannor(0);
        do rep = 1 to &nr;
          err3  = 1*rannor(0);
          resp = 10 + err1 + err2 + err3;
          output;
        end;
     end;
  end;
run;

 /*---PROC NLMIXED requires that the data are grouped---*/
 /*---by subject. These data are already properly    ---*/
 /*---grouped. The PROC SORT step is simply added here -*/
 /*---for completeness.                              ---*/
proc sort data=nested; by A; run;


proc nlmixed data=nested method=firo;
   array aeffect { 1  };
   array beffect {&nb };
   vara     = exp(2*logsiga);
   varb_a   = exp(2*logsigb_a);
   mean     = intercept + aeffect{1} + beffect{B};
   model resp ~ normal (mean,s2);
   random aeffect1 beffect1 beffect2 beffect3 beffect4 beffect5 ~
             normal( [0,0,0,0,0,0],
                     [vara,
                     0, varb_a,
                     0, 0, varb_a,
                     0, 0, 0, varb_a,
                     0, 0, 0, 0, varb_a,
                     0, 0, 0, 0, 0, varb_a] ) subject=A;
   estimate 'Var[A]    ' vara;
   estimate 'Var[B(A)] ' varb_a;
run;

 /*---equivalent proc mixed code---*/
proc mixed data=nested method=ml;
   class a b;
   model resp = / s;
   random a b(a);
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Section 15.5 Zero-inflated Poisson (ZIP)  Model  ---*/
 /*---Siumulated data for ZIP model                    ---*/
 /*
   Z ~ Poisson(lambda)                   
   Pr(Count=0) = pi + (1-pi)*Pr(Z=0)     
   Pr(Count=j) = (1-pi)*Pr(Z=j), j > 0   
   lambda is a function of covariates and a random effect
 */

%let pi = 0.27;
data zip;
  do s = 1 to 100;
    u = rannor(556712);
    do i = 1 to 20; 
       x = int(ranuni(0)*100);
       y = int(rannor(0)*100);
       if (ranuni(0) < &pi) then do;
          count = 0;
          lambda = .;
       end; else do;
          lambda = exp(-2 + 0.01*x + 0.01*y + u);
          count = ranpoi(0,lambda);
       end;
       output;
    end;
  end;
  drop i u lambda;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*--- Figure 15.2                                     ---*/
proc gchart data=zip; 
   vbar3d count / discrete;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Poisson model with a random effect               ---*/
 /*---Output 15.7                                      ---*/
proc nlmixed data=zip;
   parameters b0=0 b1=0 b2=0;
   lambda = exp(b0 + b1*x + b2*y + u);
   model count ~ poisson(lambda);
   random u ~ normal(0,s2u) subject=s;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/ 
 /*---Negative binomial model with a random effect     ---*/
 /*---Output 15.8                                      ---*/
proc nlmixed data=zip;
   parameters b0=0 b1=0 b2=0;
   eta = b0 + b1*x + b2*y + u;
   p = exp(eta)/(1+exp(eta));
   model count ~ negbin(22,p);
   random u ~ normal(0,s2u) subject=s;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---ZIP model with a random effect                   ---*/
 /*---Output 15.9                                      ---*/
proc nlmixed data=zip;
   parameters b0=0 b1=0 b2=0
              a0=0 s2u=1;
   /* linear predictor for the inflation probability      */
   linpinfl = a0;
   /* infprob = inflation probability for zeros           */
   /*         = logistic transform of the linear predictor*/
   infprob  = 1/(1+exp(-linpinfl));
   /* Poisson mean */
   lambda   = exp(b0 + b1*x + b2*y + u);
   /* Build the ZIP log likelihood */
   if count=0 then 
        ll = log(infprob + (1-infprob)*exp(-lambda));
   else ll = log((1-infprob)) + count*log(lambda) - lgamma(count+1) - lambda;
   model count ~ general(ll);
   random u ~ normal(0,s2u) subject=s;
   estimate "inflation probability" infprob;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Section 15.5 Poisson Hurdle Model                ---*/
 /*---Simulated data for hurdle model                  ---*/
 /*
   Z0 ~ Poisson(lambda0)              
   Z1 ~ Poisson(lambda1)              
                                      
   Pr(Count=0) = Pr(Z0=0)             
                                      
                 Pr(Z0>0)*Pr(Z1=j)    
   Pr(Count=j) = -----------------      for j > 0
                   1 - Pr(Z1=0)       
   */
data hurdle;
  do s = 1 to 100;
    u = rannor(9213740);
    do i = 1 to 20; 
       x = int(ranuni(0)*100);
       y = int(rannor(0)*100);
       count = ranpoi(0,exp(-2 + 0.01*x + 0.01*y + u) );
       if (count > 0) then do;
         count1 = 0;
         do while (count1 = 0);
             count1 = ranpoi(0,exp(-1 + 0.01*x + 0.01*y + u) );
         end;
         count = count1;
       end;
       output;
    end;
  end;
  drop i u;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 15.10                                     ---*/
proc nlmixed data=hurdle;
   parameters a0=-1 a1=0 a2=0 
              b0=-1 b1=0 b2=0
              s2u=1; 
   linpzero   = a0 + a1*x + a2*y + u;
   linpnozero = b0 + b1*x + b2*y + u;
   muzero     = exp(linpzero);
   munozero   = exp(linpnozero);
   f10        = exp(-muzero);
   f20        = exp(-munozero);
   logpnozero = log(1-f10) - log(1-f20) - munozero -
                lgamma(count+1) + count*log(munozero); 
   if count = 0 then ll = -muzero; 
   else ll = logpnozero; 
   model count ~ general(ll);
   random u ~ normal(0,s2u) subject=s;
run;
 /*-------------------------------------------------------*/



 /*-------------------------------------------------------*/
 /*---Survival and longitudinal CD4 data               ---*/
 /*---Data set for Section 15.6                        ---*/
 /* Source:         
     Carlin, B.P. and Louis, T.A. (1996) "Bayes and        
        Empirical Bayes Methods for Data Analysis",        
        Boca Raton: Chapman & Hall/CRC Press, Ch. 8.1      
     See also                                              
       1. http://www.biostat.umn.edu/~brad/data.html       
          for data sets                                    
       2. Guo, X. and Carlin, B.P. (2003) "Separate and    
          Joint Modeling of Longitudinal and Event Time    
          Data Using Standard Computer Packages", The
          American Statistician, 58, 16--24.
 */
data alldata;
  input t2death death randgrp1 gender1 prevoi1 stratum1 y1-y5;
  array yy{5} y1-y5;
  array t{5} (0,2,6,12,18);
  patient = _n_;
  do i = 1 to 5;
     obstime = t{i};
     if (yy{i} ne .) then do;
         cd4 = sqrt(yy{i});
         output;
     end;
  end;
  drop i y1-y5 t1-t5; 
  datalines;
16.97 0 0  1  1 -1 114    .    71    89     . 
19.00 0 1  1 -1 -1  40    .    66    21    25 
18.53 1 1 -1  1 -1  12   13    38     .     . 
12.70 0 0  1  1  1  15   21     7     3     . 
15.13 0 1  1  1  1  53   74    74    45     . 
 1.90 1 0 -1  1  1  21    .     .     .     . 
14.33 0 0  1  1 -1  46   29    20    10     . 
 9.57 1 1 -1 -1 -1  12    1     0     .     . 
11.57 1 0  1  1  1   0   33     .     .     . 
16.43 0 1  1  1 -1 147  180   111    56     . 
 2.40 1 0  1  1 -1  47    .     .     .     . 
18.10 0 1  1 -1 -1 185  262   177    91   138 
12.23 1 0  1 -1 -1   6   16     6     .     . 
 2.60 1 1  1 -1 -1   4    8     .     .     . 
12.23 0 1  1  1  1 138   97    83    79     . 
 7.10 1 0  1  1 -1   3    1    26     .     . 
16.67 0 0  1 -1 -1  43   24    25    25     . 
13.70 0 0  1  1 -1  32   29     9     7     . 
 2.73 1 1 -1  1 -1   9    .     .     .     . 
14.40 0 0  1  1  1 363  364   270   279     . 
 8.07 1 1  1  1 -1  52   29    11     .     . 
17.40 0 1  1 -1 -1   3    3     2     4     . 
12.53 1 1 -1 -1 -1  15    .     .     .     . 
20.27 0 0  1 -1 -1 197  255     .   235   206 
 4.57 1 0 -1  1  1   5    .     .     .     . 
20.27 0 1  1 -1 -1 295  394   411   291   185 
18.13 0 0  1 -1 -1  17    .     5     2     3 
19.57 0 1  1  1  1 285    .     .     .     . 
 6.13 1 1  1  1  1  21    .     .     .     . 
18.87 0 0 -1 -1 -1  33    .    19     .     . 
16.27 1 0 -1  1 -1  83  112    31     .     . 
 7.17 1 1  1  1 -1   3    .     1     .     . 
18.57 0 1  1  1  1  60   43     .     .    12 
18.50 0 0  1  1 -1   1    .     2     .     7 
18.40 0 1  1 -1 -1 157  101    51    47    40 
 7.67 1 0  1  1 -1   0    .     1     .     . 
14.87 1 0  1  1 -1  15    9     5     .     . 
17.87 0 1 -1 -1 -1 280  233     .     .     . 
17.70 0 0  1 -1 -1 100    .    61    20     . 
17.40 0 1  1 -1 -1 263  204     .     .     . 
17.37 0 0  1  1 -1  22   11     .     2     . 
17.37 0 0 -1 -1 -1  69    .     .     .     . 
17.23 0 0  1 -1 -1 272    .     .     .     . 
 8.47 1 1  1 -1 -1  21   29    12     .     . 
 8.43 1 0  1  1  1   3    .     .     .     . 
11.07 1 1  1 -1 -1  39   24     7     .     . 
11.07 1 0 -1  1  1  16   13     .     .     . 
 5.90 1 0  1  1  1   1    2     .     .     . 
 2.00 1 1  1 -1 -1   1    .     .     .     . 
14.40 0 1 -1 -1 -1 190  207   147    16     . 
 7.57 1 1  1  1 -1   9   20     .     .     . 
 5.57 1 0  1  1 -1   2    0     .     .     . 
 4.93 1 0  1  1  1  13    .     .     .     . 
16.03 0 0  1  1  1 111  187   130    81     . 
12.27 0 0  1  1 -1   6   10    23     4     . 
15.03 0 0  1  1  1  48   53    13    20     . 
12.20 1 1  1  1 -1  11   32    10     .     . 
12.27 0 1  1 -1 -1   6    3     3     .     . 
10.57 1 0  1  1 -1 130   27    33     .     . 
15.70 1 0  1  1  1   8    .     5     1     . 
12.30 0 0  1  1 -1 154  177     .     .     . 
14.17 0 0  1 -1 -1 271  250   125   169     . 
12.70 0 0  1  1  1 194  307   142    99     . 
 7.17 1 1  1  1 -1  32   31     6     .     . 
 2.60 1 1  1  1  1  15    .     .     .     . 
15.57 1 1  1  1  1  50    .    21     .     . 
11.13 1 1  1  1  1  17    .     6     .     . 
14.17 0 1  1  1  1 192   78    33    11     . 
 0.77 1 0  1  1  1   5    .     .     .     . 
14.07 0 1  1  1 -1  46   61    79     .     . 
 6.00 1 0  1  1 -1   4    5     .     .     . 
13.93 0 0  1 -1 -1 226  187   190   187     . 
 1.30 1 1  1  1 -1   1    .     .     .     . 
13.93 0 1  1  1 -1  21   37     4     8     . 
12.67 1 1  1  1  1 110   66    58     .     . 
13.23 0 0  1 -1 -1  19   19    16    10     . 
10.33 1 0  1  1  1  14    1     2     .     . 
12.47 0 1  1 -1 -1  52  137   104   130     . 
12.47 0 0  1 -1 -1  21   31    32     8     . 
17.93 0 0  1 -1 -1 120  300   220   272     . 
 3.13 1 1  1  1 -1   5    5     .     .     . 
18.03 0 1  1  1  1  42   34    15     .     7 
 4.60 1 1  1  1  1  50   50     .     .     . 
15.97 0 0  1  1 -1  64   15     .     .     . 
14.90 0 1 -1  1 -1  15   54    45    25     . 
15.60 0 1  1  1 -1 242  390   264   332     . 
10.40 1 0  1  1  1  39    2    24     .     . 
 9.77 1 0  1  1  1   8   30     3     .     . 
18.13 0 0  1 -1  1   4   11     2    21    19 
17.93 0 1  1 -1 -1 199  203   286   255   183 
18.13 0 0  1 -1 -1  65   51    46     5    37 
18.03 0 1  1  1  1  45   48    60    61    42 
17.87 0 0  1 -1 -1 291  314   453   382   273 
15.57 0 1  1  1 -1  39   30    21    16     . 
17.43 0 0  1 -1 -1 115   90   139   141     . 
17.67 0 0  1 -1 -1 224    .   363   262     . 
15.10 0 1  1  1  1  40   16     .     .     . 
16.30 0 0  1  1  1  40   26    36     .     . 
13.03 0 0  1 -1 -1  24    .     3     .     . 
10.30 1 0  1  1  1  21   35    28     .     . 
15.03 0 1  1  1  1 176  198    98    22     . 
 5.10 1 1  1  1  1   6    2     .     .     . 
12.90 0 0  1 -1 -1  13  162     .    42     . 
11.03 1 0  1  1  1  15   20    20     .     . 
11.17 1 0  1  1 -1  11    5     .     .     . 
14.07 0 1  1 -1 -1 275  415   284   308     . 
18.40 0 1  1  1  1  50   72    36     .     . 
 1.07 1 0  1  1  1   2    .     .     .     . 
 4.67 1 0  1  1  1  61    .     .     .     . 
12.20 0 1  1  1  1 274  265     .     .     . 
17.83 0 1  1  1  1  28   42    16     .     . 
16.23 0 0  1 -1 -1  41   30     .     .     . 
12.50 0 1  1  1  1  54    .     .     .     . 
10.23 1 1  1  1 -1   4    4     2     .     . 
15.10 1 0  1  1  1  54   21     .     .     . 
12.50 0 0  1  1  1  29   21     .     .     . 
12.93 0 1  1  1  1 100    .    14    29     . 
 7.97 1 0  1  1  1  10    .     .     .     . 
14.33 0 1  1 -1 -1 156    .    39     .     . 
 3.83 1 1 -1  1 -1   0    .     .     .     . 
12.50 0 1  1 -1 -1  59   43    61    25     . 
12.20 0 0  1  1 -1   6    4     .     .     . 
12.27 0 0  1  1 -1  71    .     .     6     . 
12.77 0 1  1  1 -1  27    8    13    18     . 
16.47 0 0  1  1 -1  15    3     3     4     . 
20.23 0 0  1 -1 -1  63   30    22     4     . 
15.47 1 1  1  1 -1  25  163   113    59     . 
 3.20 1 1  1  1  1  14    .     .     .     . 
13.50 0 0  1  1 -1  21   15     5     .     . 
19.20 0 0  1 -1 -1 197  154   135   110    31 
12.23 0 1 -1 -1 -1 130  582     .     .     . 
17.80 0 0  1 -1 -1  16   37    10     8     . 
16.70 0 0  1  1  1  37   26     0     8     . 
13.87 1 1  1  1 -1  10   12     9     .     . 
16.30 0 0  1 -1 -1  50   40    20    10     . 
16.23 0 0  1 -1 -1 109   42    18     .     . 
20.40 0 1  1 -1 -1  89   19    43     9     6 
11.30 1 1  1 -1 -1  52   15    26     .     . 
18.60 0 0  1 -1 -1  42   23    30    11    15 
13.20 1 1  1  1  1   7    .     1     .     . 
10.93 1 1  1  1 -1  10    0     5     .     . 
17.17 0 1  1 -1 -1 232  221   166   141     . 
16.40 1 0  1  1  1 117   17     .    55     . 
16.23 0 1  1 -1 -1 288  268   150   298     . 
16.03 0 0  1 -1 -1 168  226   129   144     . 
16.03 0 0  1  1  1 169  149    93    45     . 
14.63 1 0  1  1 -1  12   16     0     .     . 
15.27 0 1  1 -1 -1 126  246   153   140     . 
14.83 0 1  1 -1 -1 136  112     .    86     . 
14.60 0 0  1 -1 -1   1    3     0     0     . 
10.23 1 1  1 -1 -1  91   37     .     .     . 
13.83 0 0  1 -1 -1 280    .   319     .     . 
14.13 0 0  1 -1 -1 160  115    57    69     . 
13.13 0 1  1 -1 -1  46   31     8    10     . 
13.03 0 1  1  1 -1   5    3     3     7     .  
 6.63 1 1  1  1  1   0    .     .     .     . 
18.37 0 1  1 -1 -1 246  333     .   232   177 
16.20 0 1  1 -1 -1 224    .   204   141     . 
13.47 0 1  1 -1 -1 240  360     .   310     . 
13.20 0 0 -1  1 -1 198  172     .   286     . 
18.17 0 0  1  1  1  66   89    81    18     . 
15.57 0 1  1  1  1  40   15    34     5     . 
 5.43 1 1  1  1  1  10   30     .     .     . 
10.30 1 1  1  1  1  30    .     .     .     . 
18.37 0 0  1 -1 -1 120  160   120   130    80 
17.80 1 0  1  1  1  50    .    20    10     . 
17.80 0 1  1 -1 -1  47  110    63    20     . 
16.63 1 0  1  1  1  20   10    20     .     . 
17.37 0 0  1  1 -1  30   40    95    50     . 
15.90 0 0  1 -1 -1  80   50    60    10     . 
17.33 0 0  1  1  1  30    4    40    10     . 
 9.37 1 1  1  1  1  76  110     .     .     . 
16.97 0 0  1 -1 -1 250    .   210   220     . 
17.10 0 0  1 -1 -1  30   40    40   320     . 
 9.37 1 0  1  1  1 100   40     .     .     . 
15.80 0 0  1  1  1 140  105     .    89     . 
15.50 0 0  1  1  1  20   20    10    20     . 
15.10 0 0  1 -1 -1 270  290   220   240     . 
11.93 1 1  1  1 -1  40   20    30     .     . 
14.63 0 0  1 -1 -1 190   90   130    80     . 
 3.13 1 1  1  1  1  40    .     .     .     . 
14.57 0 1  1 -1 -1  40   80    20    20     . 
14.33 0 0  1  1 -1  70   40    30     0     . 
13.93 0 1  1 -1 -1 180  260   160   180     . 
13.37 0 1  1  1  1   0    .    60    70     . 
13.23 0 0  1 -1 -1 190  280   130   200     . 
12.97 0 0  1 -1 -1 270  370   360   350     . 
14.87 0 1  1  1 -1   7    4     6   287     . 
 1.83 0 1  1  1 -1 370    .     .     .     . 
13.73 0 0  1  1 -1  24    3    11     7     . 
16.93 0 1 -1  1 -1 144  237   242   119     . 
16.17 0 1  1  1  1  13   27     .    19     . 
12.27 0 1  1 -1 -1 104  174   194     .     . 
12.53 0 0  1  1  1  25    0     9    23     . 
12.77 0 1  1 -1 -1 110  250   170    80     . 
 1.70 1 1  1  1 -1  20    .     .     .     . 
 2.17 0 0  1 -1 -1 130    .     .     .     . 
12.30 0 1  1 -1 -1 160  230   300   200     . 
12.23 0 1  1 -1 -1 190  300   150   240     . 
12.23 0 0  1  1 -1  20   10     0     4     . 
 7.03 1 1  1  1  1   5    0     .     .     . 
 3.30 1 0 -1  1  1  59    .     .     .     . 
11.60 1 1 -1  1  1   5   14     5     .     . 
12.20 0 1 -1  1 -1  28    .    46     .     . 
 4.33 1 1  1  1  1   6    5     .     .     . 
17.57 0 0  1 -1 -1 107  126    72    14     . 
 4.53 1 1  1  1  1  23    .     .     .     . 
13.73 0 0  1  1  1   4    5     4     9     . 
18.80 0 1  1  1  1  32   39    46    30    34 
18.57 0 1  1 -1 -1 143  154   264   176     . 
 2.47 1 0  1  1  1  14    8     .     .     . 
12.43 0 0  1 -1 -1 273  383   263   369     . 
12.30 1 1  1  1  1  72   20     9     .     . 
11.90 1 0  1  1 -1  77   19     .     .     . 
13.37 0 1  1 -1 -1  95  234   216    98     . 
17.67 0 0  1  1  1  94   53    29     5     . 
 9.93 1 1  1  1 -1 165    .    35     .     . 
12.27 1 1  1  1 -1   6   18     .     .     . 
18.33 0 0  1  1 -1 281  207   160    71    62
17.67 0 0  1  1 -1  17   10     .     .     . 
11.20 1 1  1  1 -1   7   15    11     .     . 
18.13 0 1  1 -1 -1 109   92    85     .    68 
18.57 0 0  1 -1 -1 222  136     .   179     . 
17.93 0 1  1 -1 -1   6   10     8     5    11 
16.23 0 0  1 -1 -1  10    8     3     .     . 
17.20 0 1 -1  1 -1  21   17     8     .     . 
11.47 1 1  1  1 -1  10    .     .     .     . 
10.70 1 0  1  1  1   0   21     .     .     . 
 2.17 1 0  1  1 -1  13    .     .     .     . 
 2.70 1 0  1  1 -1  14    .     .     .     . 
12.67 0 1  1  1 -1   9    .    10    30     . 
12.70 0 1  1  1 -1  11    7    14    16     . 
17.03 1 0  1  1  1  53   27     .     .     . 
14.70 1 0  1 -1 -1 131  129   122    66     . 
13.30 1 1  1  1  1   3    7     .     .     . 
13.87 0 1  1 -1 -1 216  249    14   139     . 
10.87 1 1  1  1  1   8    7     .     .     . 
16.73 0 1  1  1 -1  37   30    21    16     . 
13.20 0 0  1 -1 -1 200    .   203   209     . 
13.90 0 0  1 -1 -1  32   57    13     7     . 
15.37 0 0  1 -1 -1  67   40    32    54     . 
15.97 0 0  1 -1 -1 235    .   134    53     . 
 7.93 1 0  1  1 -1  43   55     .     .     . 
16.00 0 1  1  1 -1  35   19    11     .     . 
15.60 0 1  1 -1 -1 228  235    29   294     . 
14.63 0 1  1 -1 -1 109  124    88     .     . 
14.43 1 1  1  1  1  11    .     .     .     . 
14.10 0 0  1 -1 -1  82    .     .     .     . 
14.07 0 0  1  1  1 112    9     5     .     . 
12.47 0 1 -1 -1 -1 181  110     .     .     . 
12.67 0 0  1  1  1  76   18    11     7     . 
12.33 0 0  1  1  1 152  168   144    68     . 
12.20 0 0  1  1  1   7    8     5     2     . 
16.17 0 0  1 -1 -1 230  253    17   170     . 
15.53 0 0 -1  1  1   2    3     2     4     . 
14.40 0 0  1  1  1   1    2     1     1     . 
12.70 0 0  1  1 -1   9   22     8    11     . 
19.27 0 0 -1 -1 -1 281  300   368   202   130 
 4.53 1 1 -1  1 -1   5    .     .     .     . 
20.67 0 0  1  1 -1  12   35    34    14    14 
 3.37 1 0  1  1 -1 277   84     .     .     . 
12.23 0 1  1  1  1   4    3     1     1     . 
19.27 0 0 -1  1  1   2    2     2     2     . 
14.20 0 1  1 -1 -1 254  284   291   204     . 
12.23 0 0  1  1 -1  51   75    78     .     . 
 9.80 1 1  1  1  1   6    2     1     .     . 
14.20 0 1  1  1 -1  19   27    34    12     . 
12.73 0 0 -1  1 -1  16   10     3     4     . 
12.73 0 1  1 -1 -1   2    6     1     1     . 
12.63 1 1  1  1 -1   8   12     4     .     . 
10.03 1 0  1  1  1  17    4     7     .     . 
13.27 0 1  1 -1 -1  11    8     .     5     . 
19.77 0 1  1 -1 -1  41   52    30     1     . 
19.53 0 1  1  1  1  54   39    23    14    19 
18.37 0 1  1  1  1  16    .    10     2     4 
15.93 0 1  1 -1 -1  70   35    49    26     . 
 5.03 1 1  1  1  1  10    .     .     .     . 
20.27 0 0  1 -1 -1  10   10     4     .     . 
12.93 0 1  1  1  1   8    9     6     9     . 
11.00 1 0  1  1 -1  12    .     6     .     . 
19.57 0 0  1  1  1  10    8     3     7     . 
 8.13 1 1  1  1 -1  17    3     1     .     . 
21.40 0 1  1  1  1  15    5     1     1     . 
21.13 0 1  1  1  1  31   26    27    12     . 
21.13 0 1  1  1 -1  40    9     .     .     . 
 5.53 1 1  1  1 -1  44   30     .     .     . 
 3.57 1 0  1  1  1  40    6     .     .     . 
 2.57 1 1  1  1  1  12    .     .     .     . 
12.27 0 1  1  1  1  80   35    47     3     . 
19.57 0 1  1 -1 -1  99  200   152   191     . 
13.90 0 0  1  1  1   8    .     .     5     . 
 1.43 1 0 -1  1 -1   3    .     .     .     . 
12.20 0 0  1  1 -1  34   34    36    13     . 
15.97 0 1  1 -1 -1  60   33    37    14     . 
17.83 0 0  1  1 -1  38   17    12    55     . 
12.37 1 0  1  1  1  31   22    10     .     . 
 8.80 1 0  1  1  1  34   13     9     .     . 
16.20 0 1  1  1  1  11   11     3     .     . 
 9.57 1 1  1  1  1  77   51    37     .     . 
10.63 1 1  1  1 -1   9   21     .     .     . 
13.87 0 1  1 -1 -1 122  112    77    72     . 
13.43 0 0  1 -1 -1 273  129   163   154     . 
13.03 0 0  1  1  1  81   52    26     .     . 
12.33 0 1  1  1  1  10    7    14    10     . 
12.30 0 0 -1  1  1   4    .     6     .     . 
12.07 1 0  1  1  1  35    .    11     4     . 
12.33 0 0  1 -1 -1  65   58    22    15     . 
 9.60 1 0  1  1  1   7    4     6     .     . 
15.97 0 0  1 -1 -1 180  238   171    65     . 
11.30 1 0  1  1  1   4    8     3     .     . 
20.87 0 0  1 -1 -1  93  142     .    15     . 
13.90 1 0 -1 -1 -1 297  122    89    40     . 
18.97 0 0  1 -1 -1 300  330   290   270   340 
 4.97 1 0  1  1 -1  13   10     .     .     . 
18.17 0 1  1  1  1   8   15    17    12     8 
18.07 1 0  1  1  1   3    3     8     6     3 
15.93 0 1  1  1  1   7    9     2     .     . 
18.37 0 1  1  1  1 273  152    65    38    21 
15.97 0 1  1  1 -1 137  121   146   138     . 
17.70 0 0  1 -1 -1  42    .     .     .     . 
 3.63 1 1  1  1  1   8    .     .     .     . 
 3.97 1 0  1 -1 -1  62    .     .     .     . 
17.37 0 1  1  1 -1   3    4     3     4     . 
10.07 1 0  1  1  1  13    7     3     .     . 
17.00 0 0  1  1  1  37   17    20     1     . 
11.67 1 0  1  1  1   6    3     1     .     . 
17.20 0 1  1 -1 -1 128    .    24    15     . 
 6.13 1 1  1 -1 -1  64   28     .     .     . 
 2.03 1 1  1  1  1   2    .     .     .     . 
16.47 0 1  1 -1 -1 125  147   203   113     . 
16.23 0 0  1  1  1  18   30    22     .     . 
16.03 0 0  1 -1 -1  21    .     8     7     . 
15.77 0 0  1  1 -1  47   56     .     .     . 
 7.40 1 1  1  1 -1   5    5     4     .     . 
10.80 1 0  1  1  1  11   12     8     .     . 
12.57 0 0 -1 -1 -1 184  138    37     .     . 
 1.13 1 1 -1  1  1  12    .     .     .     . 
13.20 0 0  1  1  1   7   10     9     4     . 
13.47 0 1 -1 -1 -1  40   29    28    20     . 
13.90 0 0 -1  1 -1 100  145    88    45     . 
13.93 0 1 -1 -1 -1 113  116   173   126     . 
14.60 0 1  1  1 -1  74   56    29    27     . 
14.43 0 0 -1 -1 -1 161  176     .    30     . 
 1.07 1 0  1  1 -1   5    .     .     .     . 
 7.17 1 0  1  1 -1  31   24    31     .     . 
15.33 0 1  1  1  1 233  269   182    71     . 
15.57 0 1  1  1 -1  63   71    16    16     . 
12.23 0 1  1  1  1 247  289   219     .     . 
11.50 1 1  1  1  1  10   20     .     .     . 
12.23 0 0  1 -1 -1 291  367   323   267     . 
12.27 0 0 -1 -1 -1  30   41    22    16     . 
12.23 0 0  1  1 -1   5    .     .     .     . 
12.53 0 1  1  1 -1 108  475   284   151     . 
 6.30 1 1  1 -1 -1  13   15     .     .     . 
 0.47 1 1 -1 -1 -1 341    .     .     .     .  
 4.10 1 1  1  1  1   6    6     .     .     . 
12.23 0 0  1  1  1   7   12     9     0     . 
 8.17 1 1  1  1 -1  23   54     .     .     . 
20.50 0 1  1  1  1  27   33    18     5    12 
19.80 0 1  1  1 -1  52   48    84    63    20 
 6.90 1 1  1  1  1   0    .    15     .     . 
 3.43 1 0  1  1  1   0    .     .     .     . 
 7.97 1 0  1  1 -1   4   10     0     .     . 
15.33 1 1  1  1 -1  14    .     .     0     . 
 5.37 1 0  1 -1 -1  48  143     .     .     . 
13.90 0 0  1 -1 -1  49   77     .    90     . 
 3.20 1 0  1  1 -1   5    2     .     .     . 
17.83 0 1  1 -1 -1  63  110    55    26     . 
19.93 0 0  1  1  1   6    0     .     5     . 
18.63 1 0  1  1  1   8    0     .     .     . 
 8.47 1 0  1  1  1  10    .     7     .     . 
16.87 0 0  1 -1 -1 237  306   286   276     . 
11.93 1 1  1 -1 -1  66   70     .     .     . 
18.77 0 0  1  1  1 155  104     .   184     . 
 7.83 1 1  1 -1 -1 281    .     .     .     . 
 1.63 1 1  1  1  1   0    .     .     .     . 
13.50 0 0 -1 -1 -1 201  238   240   418     . 
 6.07 1 1  1  1  1   6    0     .     .     . 
 8.30 1 1  1  1 -1  20   12    12     .     . 
19.80 0 0  1  1 -1  27   20    11     .     . 
13.60 1 0  1  1 -1 110   57    41     .     . 
17.23 0 0  1  1  1  37   40     .     .     . 
16.50 0 0  1 -1 -1   3    5     1     .     . 
13.40 0 1 -1 -1 -1 176  207   383   161     . 
17.63 0 0  1  1  1 217   90    97     9     . 
 8.33 1 0  1  1  1  84   39     .     .     . 
10.70 1 0  1  1 -1  22   14     6     .     . 
12.53 0 0  1  1  1   8   29    16     7     . 
 9.67 1 1  1 -1 -1  80   51     .     .     . 
12.20 0 0  1  1  1 224  194   125     .     . 
18.17 0 1  1  1 -1  13   19     .     3     2 
 7.70 1 0  1 -1 -1  96   53     .     .     . 
 8.73 1 0  1  1  1  10   17     9     .     . 
 2.13 1 1  1  1 -1  30    .     .     .     . 
13.00 0 0  1  1 -1  57   55     .    11     . 
11.63 1 1  1  1  1   2    3    11     .     . 
 3.00 1 0  1  1 -1  19    .     .     .     . 
12.70 0 1  1  1 -1  39   14    16     .     . 
16.93 0 1  1 -1 -1 288  323   357   369     . 
 9.63 1 0  1  1  1  15   11     3     .     . 
15.07 1 1  1  1 -1  43   13     .     .     . 
 9.93 1 1  1  1  1  14   14    10     .     . 
16.50 0 1  1 -1 -1 125    .     .     .     . 
16.97 0 1  1  1  1   7    7     3    11     . 
14.40 0 1  1  1 -1  14    9    10     7     . 
 6.60 1 1  1  1  1   2    8     .     .     . 
12.53 0 0  1  1 -1  11    7     8     0     . 
 5.23 1 0  1  1 -1   5    7     .     .     . 
13.00 0 1  1  1  1  46   47    35    25     . 
 3.40 1 0 -1  1 -1   3    2     .     .     . 
16.03 0 0  1 -1 -1 132   90    60    23     . 
12.20 1 1  1  1  1  84   57    54     .     . 
 6.87 1 1  1  1  1  26    .     .     .     . 
15.03 0 1  1 -1 -1 239  200    89    51     . 
 1.03 1 0  1  1 -1   4    .     .     .     . 
14.10 0 0  1  1 -1  29   23    35     .     . 
10.60 1 1  1 -1 -1  21  113     5     .     . 
 4.20 1 1  1 -1 -1 166    .     .     .     . 
13.60 0 1  1 -1 -1 273   87   359   285     . 
13.00 0 0  1  1 -1 181    .     .     .     . 
13.50 0 1  1  1 -1   2    4     2     0     . 
13.20 0 0  1  1  1  28   43    28    28     . 
13.20 0 0  1  1 -1  70   60    66    49     . 
 9.73 1 1  1 -1 -1  76  105    40     .     . 
13.60 0 0  1 -1 -1  78    .     .     .     . 
20.63 0 1  1 -1 -1  75  132     .     .     . 
 1.43 1 0  1  1  1  36    .     .     .     . 
12.43 0 0  1  1 -1  12    6    16    13     . 
 8.00 1 0 -1  1  1  40    .    28     .     . 
12.47 0 0  1  1 -1  16   50    17     5     . 
 2.47 1 0  1  1  1   5    .     .     .     . 
 9.07 1 1  1  1  1   3   12     .     .     . 
14.13 1 1  1  1  1  56   45     9     8     . 
15.17 1 0  1  1 -1  66   78    50    32     . 
17.70 0 0  1 -1 -1  65   96    60    91     . 
16.63 1 1  1 -1 -1 272  240   234    98     . 
14.30 0 0  1  1  1  60   24    90    76     . 
12.43 0 1 -1 -1 -1 105  272   375   150     . 
 7.30 1 1  1  1 -1  36   32    42     .     . 
 5.57 1 0  1  1  1  24    4     .     .     . 
17.20 0 0  1  1  1 300  270   143   160     . 
 7.73 1 0  1 -1 -1  20   18    10     .     . 
19.80 0 0  1 -1 -1  13   14     6     7     7 
16.47 0 1  1  1 -1  42   20    30    18     . 
13.50 0 0  1  1 -1  27   42     6     6     . 
11.50 1 1  1  1  1   7    9    21     .     . 
12.47 1 1  1 -1 -1  70   63    30     .     . 
 5.07 1 1  1  1 -1 159   73     .     .     . 
12.70 1 1  1  1  1  14   16     5     .     . 
19.03 0 1  1  1  1 138  140   154   120   126 
 7.93 0 1  1  1 -1 169  144    84     .     . 
19.07 1 0  1  1  1  40   36     .    10     . 
 0.90 1 1 -1  1  1  40    .     .     .     . 
19.70 0 1  1 -1 -1  24   15     5     5     3 
13.10 1 0  1 -1 -1  21   12    24   102     . 
20.87 0 0  1 -1 -1   6   24     .     .     . 
17.27 1 0  1  1  1  10   20    14     3     . 
13.37 0 1  1  1 -1 190  136     .     .     . 
 9.33 1 1  1 -1 -1 220  400   240     .     . 
12.30 0 1  1  1  1 247  300   220   242     . 
10.23 1 1  1  1  1   9   30    10     .     . 
 3.30 1 1  1  1  1   3   21     .     .     . 
14.33 0 1  1 -1 -1   7   10     6     7     . 
 2.00 1 0  1  1 -1  24    .     .     .     . 
13.30 1 1  1  1  1  10    6    12     .     . 
15.07 0 0 -1  1 -1   9   10     .     .     . 
 3.90 1 0  1  1  1  30    5     .     .     . 
; 

proc sort data=alldata; 
   by patient obstime;
data alldata; 
   set alldata; 
   by patient;
   last = last.patient;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 15.11                                     ---*/ 
title1 'The first 20 observations of the joint data';
proc print data=alldata(obs=20);
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Fit the longitudinal part with PROC MIXED        ---*/
 /*---The FA0(2) structure will yield parameter estimates-*/
 /*---identical to the Cholesky root of an unstructured --*/
 /*---variance-covariance matrix. This is the parameteri- */
 /*---zation chosen below in NLMIXED.                  ---*/

 /*-For comparison with NLMIXED below we choose ML esti- -*/
 /*-mation. The MIXED default would be REML.           ---*/
 /*---Output 15.12                                     ---*/
title1 'Longitudinal Model - MIXED';
proc mixed data=alldata noclprint covtest method=ml;
   class patient;
   model cd4 = obstime obstime*randgrp1 gender1 prevoi1 stratum1 / s;
   random intercept obstime / subject=patient type=fa0(2);
   ods output covparms=cp;
   ods output solutionf=solf;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Fit the survival part of the model               ---*/
 /*---Output 15.13                                     ---*/
title1 'Survival Model - LIFEREG';
proc lifereg data=alldata(where=(last=1));
   model t2death*death(0)=randgrp1 gender1 prevoi1 stratum1
          / dist=exponential;

   ods output ParameterEstimates=survpe(rename=(Parameter=SurvEffect));
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Combine the estimates from the separate models   ---*/
 /*---You can use this data set for comparison with the---*/
 /*---estimates in the joint model and to provide      ---*/
 /*---starting values in the joint model               ---*/
data SeparateEstimates; set solf cp survpe;
  length Parameter $5;
  select ; 
    when ( Effect    = 'Intercept'        ) Parameter = 'bl0'  ; 
    when ( Effect    = 'obstime'          ) Parameter = 'bl1'  ; 
    when ( Effect    = 'obstime*randgrp1' ) Parameter = 'bl2'  ; 
    when ( Effect    = 'gender1'          ) Parameter = 'bl3'  ; 
    when ( Effect    = 'prevoi1'          ) Parameter = 'bl4'  ;
    when ( Effect    = 'stratum1'         ) Parameter = 'bl5'  ;
    when ( CovParm   = 'FA(1,1)'          ) Parameter = 'a11'  ;
    when ( CovParm   = 'FA(2,1)'          ) Parameter = 'a12'  ;
    when ( CovParm   = 'FA(2,2)'          ) Parameter = 'a22'  ;
    when ( CovParm   = 'Residual'         ) Parameter = 's2'   ;
    when ( SurvEffect= 'Intercept'        ) Parameter = 'bs0'  ;
    when ( SurvEffect= 'randgrp1'         ) Parameter = 'bs1'  ;
    when ( SurvEffect= 'gender1'          ) Parameter = 'bs2'  ;
    when ( SurvEffect= 'prevoi1'          ) Parameter = 'bs3'  ;
    when ( SurvEffect= 'stratum1'         ) Parameter = 'bs4'  ;
    otherwise Parameter = '';
  end;
  if Parameter ne '';
  keep Parameter Estimate StdErr;
  rename Estimate=SeparateEstimate StdErr=SeparateStdErr;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Model XI in Guo and Carlin (2003)                ---*/
 /*---Fit by maximum likelihood with NLMIXED.          ---*/
 /*---Marginal log likelihood is computed by Gaussian  ---*/
 /*---quadrature.                                      ---*/
 /*---Output 15.14                                     ---*/
 /*-------------------------------------------------------*/
title1 'Joint Model - NLMIXED';
proc nlmixed data=alldata;

    /*---All parameters not assigned starting values   ---*/
    /*---explicitly are assigned the default value (1) ---*/
    parameters r1=0.13;

    /*---Compute log likelihood contribution of the    ---*/
    /*---survival data part when the last observaion   ---*/
    /*---of a subject is reached                       ---*/

    /*---NOTE: This parameterization yields estimates  ---*/
    /*---      equivalent to those in LIFEREG          ---*/
    if (last) then do;
      linpsurv  = bs0 + bs1*randgrp1 +
                        bs2*gender1  +
                        bs3*prevoi1  +
                        bs4*stratum1 + r1*u0 + r2*u1;
      alpha  = exp(-linpsurv);
      G_t    = exp(-alpha*t2death);
      g      = alpha*G_t;
      llsurv = (death=1)*log(g) + (death=0)*log(G_t);
    end; else llsurv=0;

    /*---Cholesky parameterization of the random effects ---*/
    /*---variance matrix.                                ---*/
    /*---This ensures that the variance-covariance matrix---*/
    /*---of the random effects is non-negative definite  ---*/
    v11 = a11*a11;
    v12 = a11*a12;
    v22 = a12*a12 + a22*a22;

    /*---Compute the contribution of the longitudinal    ---*/
    /*---part. Every observation in the data set         ---*/
    /*---makes a contribution. Notice that conditional   ---*/
    /*---on the random effects we have independent       ---*/
    /*---Gaussian contributions                          ---*/
    linplong = (bl0 + u0)            +
               (bl1 + u1)*obstime    +
                bl2*obstime*randgrp1 +
                bl3*gender1          +
                bl4*prevoi1          +
                bl5*stratum1;
    
    resid = (cd4-linplong);
    if (abs(resid) > 1.3E100) or (s2 < 1e-12) then do;
       lllong = -1e20;
    end; else do;
       lllong = -0.5*(1.837876 + resid**2 / s2  + log(s2));
    end;

    /*---Any numeric variable in the data set can be used---*/
    /*---as the response in the MODEL statement. It has  ---*/
    /*---no bearing on the results                       ---*/
    model last ~ general(lllong + llsurv);
    random u0 u1 ~ normal([0, 0],[v11,v12,v22]) subject=patient;

    /*---Compute median of the patient-specific          ---*/
    /*---survival distributions                          ---*/
    predict (1/alpha)* log(2) out=median;

    /*---Compute the variances and covariance of the random-*/
    /*---effects and obtain their std. errors by the delta--*/
    /*---method                                          ---*/
    estimate 'Var[U0]'    v11;
    estimate 'Cov[U0,U1]' v12;
    estimate 'Var[U1]'    v22;

    ods output ParameterEstimates=JointEstimates;
run;


 /*---Compare estimates in joint and separate models   ---*/
proc sort data=SeparateEstimates; by Parameter;
proc sort data=JointEstimates;    by Parameter;
data Estimates; merge SeparateEstimates JointEstimates; by Parameter;
run;

title1 'Estimates and Standard Errors from Separate and Joint Analysis';
proc print data=Estimates label;
    label SeparateEstimate = 'MLE in separate models'
          SeparateStdErr   = 'Asymptotic Std. Error of MLE in separate models'
          Estimate         = 'MLE in joint model'
          StandardError    = 'Asymptotic Std. Error of MLE in joint model';
    var SeparateEstimate SeparateStdErr
        Estimate         StandardError;
    id  Parameter;
run;


 /*---Extract predicted patient-specific median        ---*/
title1 'Patient Specific Modes and Medians for Patients 450 and 454';
title2 'With Standard Errors and Confidence Intervals';
proc print data=median(where=( ((patient=450) or (patient=454)) and (last=1)));
   var patient pred stderrpred lower upper;
run;
title1;
 /*-------------------------------------------------------*/



 /*-------------------------------------------------------*/
 /*---Phenobarbital data from Grasela and Donn (1985)  ---*/
 /*---Data set 15.7 in Appendix 2                     ---*/
data pheno;
   input indiv time dose weight apgar conc;
   retain cursub .;
   if cursub ne indiv then do;
      newsub = 1;
      cursub = indiv;
   end;
   else newsub = 0;
   if (apgar < 5) then apgarlow = 1;
   else apgarlow = 0;
   tlag = lag(time);
   if (newsub=1) then tlag = 0;
   drop apgar cursub; 
   datalines;   
 1    0.    25.0    1.4      7     . 
 1    2.0    0.0    1.4      7   17.3
 1   12.5    3.5    1.4      7     . 
 1   24.5    3.5    1.4      7     . 
 1   37.0    3.5    1.4      7     . 
 1   48.0    3.5    1.4      7     . 
 1   60.5    3.5    1.4      7     . 
 1   72.5    3.5    1.4      7     . 
 1   85.3    3.5    1.4      7     . 
 1   96.5    3.5    1.4      7     . 
 1  108.5    3.5    1.4      7     . 
 1  112.5    0.0    1.4      7   31.0
 2    0.    15.0    1.5      9     . 
 2    2.0    0.0    1.5      9    9.7
 2    4.0    3.8    1.5      9     . 
 2   16.0    3.8    1.5      9     . 
 2   27.8    3.8    1.5      9     . 
 2   40.0    3.8    1.5      9     . 
 2   52.0    3.8    1.5      9     . 
 2   63.5    0.0    1.5      9   24.6
 2   64.0    3.8    1.5      9     . 
 2   76.0    3.8    1.5      9     . 
 2   88.0    3.8    1.5      9     . 
 2  100.0    3.8    1.5      9     . 
 2  112.0    3.8    1.5      9     . 
 2  124.0    3.8    1.5      9     . 
 2  135.5    0.0    1.5      9   33.0
 3    0.    30.0    1.5      6     . 
 3    1.5    0.0    1.5      6   18.0
 3   11.5    3.7    1.5      6     . 
 3   23.5    3.7    1.5      6     . 
 3   35.5    3.7    1.5      6     . 
 3   47.5    3.7    1.5      6     . 
 3   59.3    3.7    1.5      6     . 
 3   73.0    3.7    1.5      6     . 
 3   83.5    0.0    1.5      6   23.8
 3   84.0    3.7    1.5      6     . 
 3   96.5    3.7    1.5      6     . 
 3  108.5    3.7    1.5      6     . 
 3  120.0    3.7    1.5      6     . 
 3  132.0    3.7    1.5      6     . 
 3  134.3    0.0    1.5      6   24.3
 4    0.    18.6    0.9      6     . 
 4    1.8    0.0    0.9      6   20.8
 4   12.0    2.3    0.9      6     . 
 4   24.3    2.3    0.9      6     . 
 4   35.8    2.3    0.9      6     . 
 4   48.1    2.3    0.9      6     . 
 4   59.3    0.0    0.9      6   23.9
 4   59.8    2.3    0.9      6     . 
 4   71.8    2.3    0.9      6     . 
 4   83.8    2.3    0.9      6     . 
 4   95.8    2.3    0.9      6     . 
 4  107.8    2.3    0.9      6     . 
 4  119.8    2.3    0.9      6     . 
 4  130.8    0.0    0.9      6   31.7
 5    0.    27.0    1.4      7     . 
 5    2.0    0.0    1.4      7   14.2
 5   12.0    3.4    1.4      7     . 
 5   24.0    3.4    1.4      7     . 
 5   36.0    3.4    1.4      7     . 
 5   48.0    3.4    1.4      7     . 
 5   59.5    0.0    1.4      7   18.2
 5   60.0    3.4    1.4      7     . 
 5   72.0    3.4    1.4      7     . 
 5   84.0    3.4    1.4      7     . 
 5   96.0    3.4    1.4      7     . 
 5  108.0    3.4    1.4      7     . 
 5  120.0    3.4    1.4      7     . 
 5  132.0    0.0    1.4      7   20.3
 6    0.    24.0    1.2      5     . 
 6    1.8    0.0    1.2      5   19.0
 6   11.8    3.0    1.2      5     . 
 6   23.8    3.0    1.2      5     . 
 6   35.8    3.0    1.2      5     . 
 6   47.8    3.0    1.2      5     . 
 6   59.3    0.0    1.2      5   17.3
 6   59.8    3.0    1.2      5     . 
 6   71.8    3.0    1.2      5     . 
 6   83.8    3.0    1.2      5     . 
 6   95.8    3.0    1.2      5     . 
 6  107.8    3.0    1.2      5     . 
 6  120.1    3.0    1.2      5     . 
 6  131.8    3.0    1.2      5     . 
 6  142.8    0.0    1.2      5   32.5
 7    0.    19.0    1.0      5     . 
 7    2.0    0.0    1.0      5   17.9
 7   11.3    2.4    1.0      5     . 
 7   23.3    2.4    1.0      5     . 
 7   36.5    2.4    1.0      5     . 
 7   48.2    2.4    1.0      5     . 
 7   60.3    2.4    1.0      5     . 
 7   73.8    0.0    1.0      5   23.4
 7   75.8    2.4    1.0      5     . 
 7   84.3    2.4    1.0      5     . 
 7   96.3    2.4    1.0      5     . 
 7  108.3    2.4    1.0      5     . 
 7  120.3    2.4    1.0      5     . 
 7  132.3    2.4    1.0      5     . 
 7  144.5    2.4    1.0      5     . 
 7  165.3    0.0    1.0      5   25.8
 8    0.    24.0    1.2      7     . 
 8    1.7    0.0    1.2      7   25.8
 8   11.8    3.0    1.2      7     . 
 8   23.7    3.0    1.2      7     . 

 8   35.7    3.0    1.2      7     . 
 8   47.7    3.0    1.2      7     . 
 8   59.7    3.0    1.2      7     . 
 8   71.7    3.0    1.2      7     . 
 8   73.7    0.0    1.2      7   34.2
 8   83.7    3.0    1.2      7     . 
 8   95.7    3.0    1.2      7     . 
 8  107.7    3.0    1.2      7     . 
 8  119.7    3.0    1.2      7     . 
 8  131.7    3.0    1.2      7     . 
 8  143.7    3.0    1.2      7     . 
 8  146.7    0.0    1.2      7   36.1
 9    0.    27.0    1.4      8     . 
 9    1.1    0.0    1.4      8   22.1
 9   11.1    3.2    1.4      8     . 
 9   22.3    3.2    1.4      8     . 
 9   34.6    3.2    1.4      8     . 
 9   46.6    3.2    1.4      8     . 
 9   58.7    3.2    1.4      8     . 
 9   70.9    3.2    1.4      8     . 
 9   82.7    0.0    1.4      8   29.2
 9   83.2    3.2    1.4      8     . 
 9   94.6    3.2    1.4      8     . 
 9  106.6    3.2    1.4      8     . 
 9  118.6    3.2    1.4      8     . 
 9  130.6    3.2    1.4      8     . 
 9  142.1    0.0    1.4      8   34.2
 9  142.6    3.2    1.4      8     . 
 9  312.6    0.0    1.4      8   19.6
10    0.    27.0    1.4      7     . 
10    1.2    0.0    1.4      7   19.9
10   11.2    3.5    1.4      7     . 
10   23.2    3.5    1.4      7     . 
10   35.3    3.5    1.4      7     . 
10   47.2    3.5    1.4      7     . 
10   59.2    3.5    1.4      7     . 
10   70.7    0.0    1.4      7   23.4
10   71.2    3.5    1.4      7     . 
10   83.2    3.5    1.4      7     . 
10   95.2    3.5    1.4      7     . 
10  107.2    3.5    1.4      7     . 
10  119.2    3.5    1.4      7     . 
10  131.2    3.5    1.4      7     . 
10  142.2    0.0    1.4      7   30.9
11    0.    24.0    1.2      7     . 
11   11.5   24.0    1.2      7     . 
11   23.5    3.0    1.2      7     . 
11   35.5    3.0    1.2      7     . 
11   47.5    3.0    1.2      7     . 
11   57.5    0.0    1.2      7   24.3
12    0.    26.0    1.3      6     . 
12    2.0    0.0    1.3      6   17.0
12   12.0    3.3    1.3      6     . 
12   13.0    5.0    1.3      6     . 
12   24.5    3.3    1.3      6     . 
12   36.0    3.3    1.3      6     . 
12   48.5    3.3    1.3      6     . 
12   60.0    3.3    1.3      6     . 
12   72.0    3.3    1.3      6     . 
12   84.0    3.3    1.3      6     . 
12   96.0    3.3    1.3      6     . 
12  108.0    3.3    1.3      6     . 
12  120.0    3.3    1.3      6     . 
12  132.2    0.0    1.3      6   34.1
12  132.5    3.3    1.3      6     . 
12  302.5    0.0    1.3      6   16.0
13    0.    11.0    1.1      6     . 
13   12.0   11.0    1.1      6     . 
13   25.0    2.8    1.1      6     . 
13   36.5    0.0    1.1      6   24.1
13   37.0    2.8    1.1      6     . 
13   49.0    2.8    1.1      6     . 
13   61.0    2.8    1.1      6     . 
13   74.0    2.8    1.1      6     . 
13   85.0    2.8    1.1      6     . 
13   98.0    2.8    1.1      6     . 
13  110.0    2.8    1.1      6     . 
13  121.3    2.8    1.1      6     . 
13  134.0    2.8    1.1      6     . 
13  145.0    2.8    1.1      6     . 
13  157.0    2.8    1.1      6     . 
13  169.0    0.0    1.1      6   38.2
14    0.    22.0    1.1      7     . 
14    2.3    0.0    1.1      7   25.6
14   11.8    2.8    1.1      7     . 
14   23.8    2.8    1.1      7     . 
14   35.8    2.8    1.1      7     . 
14   47.8    2.8    1.1      7     . 
14   59.3    0.0    1.1      7   25.6
14   59.8    2.8    1.1      7     . 
14   71.8    2.8    1.1      7     . 
14   83.8    2.8    1.1      7     . 
14   95.8    2.8    1.1      7     . 
14  107.3    2.8    1.1      7     . 
14  119.8    2.8    1.1      7     . 
14  131.5    0.0    1.1      7   25.7
14  131.8    2.8    1.1      7     . 
14  143.8    2.8    1.1      7     . 
14  303.3    0.0    1.1      7   14.3
15    0.    26.0    1.3      7     . 
15   12.2    3.3    1.3      7     . 
15   22.2    0.0    1.3      7   19.3
15   24.2    3.3    1.3      7     . 
15   36.2    3.3    1.3      7     . 
15   47.8    3.3    1.3      7     . 
15   70.2    3.3    1.3      7     . 
15   85.6    3.3    1.3      7     . 
15   96.2    3.3    1.3      7     . 
15  108.2    3.3    1.3      7     . 
15  120.2    3.3    1.3      7     . 
15  132.2    3.3    1.3      7     . 
15  143.7    3.3    1.3      7     . 
15  145.7    0.0    1.3      7   29.7
16    0.    12.0    1.2      9     . 
16    9.0   12.0    1.2      9     . 
16   12.0    0.0    1.2      9   17.3
16   15.4    4.0    1.2      9     . 
16   21.3    3.0    1.2      9     . 
16   33.0    3.0    1.2      9     . 
16   45.0    3.0    1.2      9     . 
16   56.0    0.0    1.2      9   26.8
16   57.0    3.0    1.2      9     . 
16   69.0    3.0    1.2      9     . 
16   81.0    3.0    1.2      9     . 
16   93.0    3.0    1.2      9     . 
16  105.0    3.0    1.2      9     . 
16  117.0    3.0    1.2      9     . 
16  129.5    3.0    1.2      9     . 
16  141.5    3.0    1.2      9     . 
16  152.8    3.0    1.2      9     . 
16  153.5    0.0    1.2      9   38.4
17    0.    22.0    1.1      5     . 
17   12.0    2.8    1.1      5     . 
17   24.0    2.8    1.1      5     . 
17   32.0    0.0    1.1      5   21.3
17   35.5    2.8    1.1      5     . 
17   48.0    2.8    1.1      5     . 
17   60.0    2.8    1.1      5     . 
17   72.0    0.0    1.1      5   28.8
17   72.3    2.8    1.1      5     . 
17   84.3    2.8    1.1      5     . 
17   95.8    2.8    1.1      5     . 
17  108.0    2.8    1.1      5     . 
17  120.0    2.8    1.1      5     . 
17  132.0    2.8    1.1      5     . 
17  144.0    2.8    1.1      5     . 
17  155.0    0.0    1.1      5   34.9
18    0.    20.0    1.0      5     . 
18    2.8    0.0    1.0      5   21.9
18   11.8   20.0    1.0      5     . 
18   23.8    2.5    1.0      5     . 
18   35.8    2.5    1.0      5     . 
18   48.1    2.5    1.0      5     . 
18   59.3    2.5    1.0      5     . 
18   71.3    0.0    1.0      5   25.9
18   71.8    2.5    1.0      5     . 
18   82.8    2.5    1.0      5     . 
18   95.8    2.5    1.0      5     . 
18  107.8    2.5    1.0      5     . 
18  119.8    2.5    1.0      5     . 
18  131.8    2.5    1.0      5     . 
18  143.8    0.0    1.0      5   28.9
18  389.8    0.0    1.0      5    6.7
19    0.    10.0    1.0      1     . 
19    4.0   10.0    1.0      1     . 
19    9.5    0.0    1.0      1   18.9
19   13.0    2.5    1.0      1     . 
19   24.0    2.5    1.0      1     . 
19   35.9    3.0    1.0      1     . 
19   48.0    3.0    1.0      1     . 
19   59.9    3.0    1.0      1     . 
19   72.0    3.0    1.0      1     . 
19   83.5    0.0    1.0      1   23.2
19   84.3    3.0    1.0      1     . 
19   96.0    3.0    1.0      1     . 
19  108.3    3.0    1.0      1     . 
19  120.0    3.0    1.0      1     . 
19  132.0    3.0    1.0      1     . 
19  144.0    3.0    1.0      1     . 
19  158.0    0.0    1.0      1   32.9
20    0.    24.0    1.2      6     . 
20    2.0    0.0    1.2      6   23.1
20   12.0    3.0    1.2      6     . 
20   24.0    3.0    1.2      6     . 
20   36.0    3.0    1.2      6     . 
20   48.0    3.0    1.2      6     . 
20   60.5    3.0    1.2      6     . 
20   62.5    0.0    1.2      6   27.8
20   72.0    3.0    1.2      6     . 
20   84.0    3.0    1.2      6     . 
20   95.5    3.0    1.2      6     . 
20  108.0    3.0    1.2      6     . 
20  120.0    3.0    1.2      6     . 
20  132.0    3.0    1.2      6     . 
20  134.0    0.0    1.2      6   34.0
21    0.    17.5    1.8      7     . 
21    4.2   17.5    1.8      7     . 
21    8.3    0.0    1.8      7   21.1
21   15.8    4.5    1.8      7     . 
21   28.0    4.5    1.8      7     . 
21   39.8    4.5    1.8      7     . 
21   51.8    4.5    1.8      7     . 
21   63.8    4.5    1.8      7     . 
21   76.8    4.5    1.8      7     . 
21   88.3    4.5    1.8      7     . 
21  100.8    4.5    1.8      7     . 
21  112.3    0.0    1.8      7   29.1
21  112.8    4.5    1.8      7     . 
21  124.3    4.5    1.8      7     . 
21  136.3    4.5    1.8      7     . 
21  148.8    4.5    1.8      7     . 
21  260.6    0.0    1.8      7   21.1
22    0.    15.0    1.5      8     . 
22    4.0   15.0    1.5      8     . 
22    6.0    0.0    1.5      8   21.8
22   16.0    4.0    1.5      8     . 
22   28.0    4.0    1.5      8     . 
22   40.0    4.0    1.5      8     . 
22   51.0    0.0    1.5      8   25.0
23    0.    60.0    3.1      3     . 
23   11.0    0.0    3.1      3   22.3
23   11.5    7.5    3.1      3     . 
23   24.0    7.5    3.1      3     . 
23   35.5    7.5    3.1      3     . 
23   47.0    7.5    3.1      3     . 
23   59.5    7.5    3.1      3     . 
23   70.5    0.0    3.1      3   26.6
23   71.5    7.5    3.1      3     . 
23   84.0    7.5    3.1      3     . 
23   95.8    7.5    3.1      3     . 
23  107.5    7.5    3.1      3     . 
23  120.0    7.5    3.1      3     . 
23  132.5    7.5    3.1      3     . 
23  140.0    0.0    3.1      3   27.7
24    0.    63.0    3.2      2     . 
24    0.7   63.0    3.2      2     . 
24    2.0    0.0    3.2      2   37.3
24    6.5   32.0    3.2      2     . 
24   16.0   10.0    3.2      2     . 
24   28.0   10.0    3.2      2     . 
24   40.0   10.0    3.2      2     . 
24   52.7   10.0    3.2      2     . 
24   64.0   10.0    3.2      2     . 
24   76.0   10.0    3.2      2     . 
24   79.0    0.0    3.2      2   41.7
24   88.0   10.0    3.2      2     . 
24  100.0   10.0    3.2      2     . 
24  112.0   10.0    3.2      2     . 
24  124.0   10.0    3.2      2     . 
24  136.0   10.0    3.2      2     . 
24  147.5   10.0    3.2      2     . 
24  176.0    0.0    3.2      2   38.1
25    0.    15.0    0.7      1     . 
25    2.0    0.0    0.7      1   13.7
25   12.0    1.9    0.7      1     . 
25   18.5    7.5    0.7      1     . 

25   21.0    0.0    0.7      1   21.8
25   23.7    1.5    0.7      1     . 
25   35.8    1.5    0.7      1     . 
25   48.3    1.5    0.7      1     . 
25   60.5    1.5    0.7      1     . 
25   61.5    0.0    0.7      1   16.7
25   70.7    5.0    0.7      1     . 
25   72.0    2.0    0.7      1     . 
25   84.0    2.0    0.7      1     . 
25   90.5    0.0    0.7      1   29.8
25   95.8    2.0    0.7      1     . 
25  108.0    2.0    0.7      1     . 
25  120.0    2.0    0.7      1     . 
25  121.5    0.0    0.7      1   38.0
25  132.0    2.0    0.7      1     . 
25  138.0    0.0    0.7      1   31.3
26    0.    70.0    3.5      9     . 
26   11.5    9.0    3.5      9     . 
26   23.5    9.0    3.5      9     . 
26   35.5    9.0    3.5      9     . 
26   37.5    0.0    3.5      9   28.6
26   47.5    9.0    3.5      9     . 
26   59.5    9.0    3.5      9     . 
26   71.5    9.0    3.5      9     . 
26   83.5    9.0    3.5      9     . 
26   95.5    9.0    3.5      9     . 
26  107.5    9.0    3.5      9     . 
26  110.5    0.0    3.5      9   34.9
27    0.    35.0    1.9      5     . 
27    1.7    0.0    1.9      5   26.4
27   12.4    5.0    1.9      5     . 
27   23.7    5.0    1.9      5     . 
27   35.2    5.0    1.9      5     . 
27   48.0    5.0    1.9      5     . 
27   59.7    5.0    1.9      5     . 
27   71.7    5.0    1.9      5     . 
27   83.2    0.0    1.9      5   33.3
28    0.    60.0    3.2      9     . 
28    2.0    0.0    3.2      9   16.9
29    0.    20.0    1.0      7     . 
29   12.0    2.5    1.0      7     . 
29   23.5    2.5    1.0      7     . 
29   36.5    2.5    1.0      7     . 
29   47.5    0.0    1.0      7   22.9
30    0.    18.0    1.8      8     . 
30    2.2   18.0    1.8      8     . 
30    6.3    0.0    1.8      8   17.9
30   15.3    3.5    1.8      8     . 
30   26.3    3.5    1.8      8     . 
30   38.8    3.5    1.8      8     . 
30   50.8    3.5    1.8      8     . 
30   62.8    3.5    1.8      8     . 
30   75.3    3.5    1.8      8     . 
30   87.3    3.5    1.8      8     . 
30   98.8    3.5    1.8      8     . 
30  110.8    3.5    1.8      8     . 
30  123.3    3.5    1.8      8     . 
30  134.8    3.5    1.8      8     . 
30  226.3    0.0    1.8      8   16.5
31    0.    30.0    1.4      8     . 
31    1.0    0.0    1.4      8   25.3
32    0.    70.0    3.6      9     . 
32    6.5    0.0    3.6      9   12.7
32   12.0    7.5    3.6      9     . 
32   21.6   35.0    3.6      9     . 
32   24.0    0.0    3.6      9   22.1
32   24.3    7.5    3.6      9     . 
32   35.6    7.5    3.6      9     . 
32   48.0    7.5    3.6      9     . 
32   61.0    7.5    3.6      9     . 
32   72.0    7.5    3.6      9     . 
32   83.5    0.0    3.6      9   21.2
33    0.    17.0    1.7      8     . 
33    4.0   17.0    1.7      8     . 
33    5.5    0.0    1.7      8   21.2
33   16.0    4.3    1.7      8     . 
33   28.0    4.3    1.7      8     . 
33   40.3    4.3    1.7      8     . 
33   52.0    4.3    1.7      8     . 
33   65.0    0.0    1.7      8   27.4
34    0.    34.0    1.7      4     . 
34    1.8    0.0    1.7      4   22.1
34   11.8    4.3    1.7      4     . 
34   23.8    4.3    1.7      4     . 
34   47.8    4.3    1.7      4     . 
34   59.8    4.0    1.7      4     . 
34   71.8    4.0    1.7      4     . 
34   83.8    4.0    1.7      4     . 
34   86.8    0.0    1.7      4   28.7
35    0.    25.0    2.5      5     . 
35    3.5   25.0    2.5      5     . 
35   15.0    6.0    2.5      5     . 
35   19.0    0.0    2.5      5   25.2
35   27.0    6.0    2.5      5     . 
35   39.0    6.0    2.5      5     . 
35   51.0    6.0    2.5      5     . 
35   63.0    6.0    2.5      5     . 
35   75.0    6.0    2.5      5     . 
35   87.0    6.0    2.5      5     . 
35   99.0    0.0    2.5      5   38.0
36    0.    30.0    1.5      5     . 
36    2.0    0.0    1.5      5   23.2
36   12.0    4.0    1.5      5     . 
36   23.5    4.0    1.5      5     . 
36   36.0    4.0    1.5      5     . 
36   48.0    4.0    1.5      5     . 
36   60.0    4.0    1.5      5     . 
36   72.0    4.0    1.5      5     . 
36   85.0    4.0    1.5      5     . 
36   96.0    4.0    1.5      5     . 
36  108.0    4.0    1.5      5     . 
36  120.0    4.0    1.5      5     . 
36  132.0    4.0    1.5      5     . 
36  134.0    0.0    1.5      5   28.9
36  304.0    0.0    1.5      5   12.7
37    0.    24.0    1.2      9     . 
37    2.3    0.0    1.2      9   19.5
37   11.8    3.0    1.2      9     . 
37   24.3    3.0    1.2      9     . 
37   36.3    3.0    1.2      9     . 
37   48.3    3.0    1.2      9     . 
37   60.3    3.0    1.2      9     . 
37   72.8    3.0    1.2      9     . 
37   84.3    3.0    1.2      9     . 
37   96.3    3.0    1.2      9     . 
37  108.3    3.0    1.2      9     . 
37  119.8    3.0    1.2      9     . 
37  132.3    3.0    1.2      9     . 
37  144.3    3.0    1.2      9     . 
37  156.3    3.0    1.2      9     . 
37  159.8    0.0    1.2      9   33.4
38    0.    26.0    1.3      8     . 
38    1.8    0.0    1.3      8   17.9
38   11.6    3.0    1.3      8     . 
38   23.3    3.0    1.3      8     . 
38   35.3    3.0    1.3      8     . 
38   47.3    3.0    1.3      8     . 
38   59.3    3.0    1.3      8     . 
38   71.3    3.0    1.3      8     . 
38   83.3    3.0    1.3      8     . 
38   95.3    3.0    1.3      8     . 
38  107.3    3.0    1.3      8     . 
38  118.8    0.0    1.3      8   21.6
38  119.3    3.0    1.3      8     . 
38  131.3    3.0    1.3      8     . 
38  143.3    3.0    1.3      8     . 
38  155.3    3.0    1.3      8     . 
38  167.3    3.0    1.3      8     . 
38  183.3    0.0    1.3      8   30.5
38  310.3    0.0    1.3      8   13.0
39    0.    56.0    1.9     10     . 
39    1.4    0.0    1.9     10   30.0
39   12.7    5.0    1.9     10     . 
39   24.4    5.0    1.9     10     . 
39   36.4    5.0    1.9     10     . 
39   48.4    5.0    1.9     10     . 
39   60.4    5.0    1.9     10     . 
39   72.3    5.0    1.9     10     . 
39   84.8    5.0    1.9     10     . 
39   96.4    5.0    1.9     10     . 
39  108.4    5.0    1.9     10     . 
39  110.4    0.0    1.9     10   37.7
39  120.4    5.0    1.9     10     . 
39  132.4    5.0    1.9     10     . 
39  260.4    0.0    1.9     10   18.4
40    0.    19.0    1.1      3     . 
40    1.0    0.0    1.1      3   13.7
40    2.0    3.0    1.1      3     . 
40    3.8   12.0    1.1      3     . 
40    4.0    0.0    1.1      3   25.0
41    0.    34.0    1.7      7     . 
41    2.0    0.0    1.7      7   18.6
41    7.3    4.0    1.7      7     . 
41   12.0    4.0    1.7      7     . 
41   24.8    4.0    1.7      7     . 
41   33.9    4.0    1.7      7     . 
41   36.0    0.0    1.7      7   21.0
41   48.3    4.0    1.7      7     . 
41   58.7    4.0    1.7      7     . 
41   59.0    0.0    1.7      7   26.4
42    0.    28.0    2.8      9     . 
42   12.0   28.0    2.8      9     . 
42   14.0    0.0    2.8      9   13.3
42   23.7    7.0    2.8      9     . 
42   36.2    7.0    2.8      9     . 
42   47.8    7.0    2.8      9     . 
42   60.0    7.0    2.8      9     . 
42   72.0    7.0    2.8      9     . 
42   84.0    7.0    2.8      9     . 
42   95.5    0.0    2.8      9   13.9
43    0.    18.0    0.9      1     . 
43    2.0    0.0    0.9      1   22.3
44    0.    14.0    1.4      7     . 
44    5.0   14.0    1.4      7     . 
44   11.0    0.0    1.4      7   17.8
44   17.0    3.5    1.4      7     . 
44   29.0    3.5    1.4      7     . 
44   41.0    3.5    1.4      7     . 
44   54.5    3.5    1.4      7     . 
44   65.0    3.5    1.4      7     . 
44   77.5    3.5    1.4      7     . 
44   89.0    3.5    1.4      7     . 
44  101.0    3.5    1.4      7     . 
44  113.0    3.5    1.4      7     . 
44  125.0    0.0    1.4      7   27.6
44  125.5    3.5    1.4      7     . 
44  292.0    0.0    1.4      7   13.5
45    0.    16.0    0.8      2     . 
45    4.5    0.0    0.8      2   16.6
45   12.5    2.0    0.8      2     . 
45   24.5    2.0    0.8      2     . 
45   36.5    2.0    0.8      2     . 
45   48.3    0.0    0.8      2   20.2
45   48.5    2.0    0.8      2     . 
45   60.5    2.0    0.8      2     . 
45   72.5    2.0    0.8      2     . 
45   84.5    2.0    0.8      2     . 
45   96.5    2.0    0.8      2     . 
45  106.5    0.0    0.8      2   24.5
46    0.    11.0    1.1      8     . 
46    0.5   11.0    1.1      8     . 
46    2.0    0.0    1.1      8   20.1
47    0.    40.0    2.6      9     . 
47    9.3    6.7    2.6      9     . 
47   19.3    6.7    2.6      9     . 
47   33.3    6.7    2.6      9     . 
47   36.3    6.7    2.6      9     . 
47   38.3    0.0    2.6      9   25.1
48    0.    14.0    0.7      8     . 
48    2.8    0.0    0.7      8   12.9
48   11.3    1.7    0.7      8     . 
48   23.3    1.7    0.7      8     . 
48   28.8   10.0    0.7      8     . 
48   35.3    1.7    0.7      8     . 
48   47.5    1.7    0.7      8     . 
48   59.3    1.7    0.7      8     . 
48   65.8    0.0    0.7      8   41.1
48   71.8    1.7    0.7      8     . 
48   84.8    0.0    0.7      8   40.3
48  112.3    0.0    0.7      8   36.8
48  137.9    0.0    0.7      8   35.8
49    0.    26.0    1.3      8     . 
49    2.0    0.0    1.3      8   18.8
49   12.0    4.0    1.3      8     . 
49   24.0    4.0    1.3      8     . 
49   36.0    4.0    1.3      8     . 
49   48.0    4.0    1.3      8     . 
49   60.5    4.0    1.3      8     . 
49   72.0    4.0    1.3      8     . 
49   74.0    0.0    1.3      8   25.1
49   84.0    4.0    1.3      8     . 
49   96.0    4.0    1.3      8     . 
49  108.5    4.0    1.3      8     . 
49  120.0    4.0    1.3      8     . 
49  132.0    4.0    1.3      8     . 
49  144.0    4.0    1.3      8     . 

49  150.0    0.0    1.3      8   37.2
50    0.    20.0    1.1      6     . 
50    3.0    0.0    1.1      6   22.2
50   12.5    2.5    1.1      6     . 
50   24.5    2.5    1.1      6     . 
50   36.5    2.5    1.1      6     . 
50   48.0    2.5    1.1      6     . 
50   60.5    2.5    1.1      6     . 
50   72.5    2.5    1.1      6     . 
50   81.0    0.0    1.1      6   30.5
50   84.5    2.5    1.1      6     . 
50   88.0   30.0    1.1      6     . 
50   89.0    0.0    1.1      6   67.9
50   96.5    2.5    1.1      6     . 
50  108.5    2.5    1.1      6     . 
50  120.5    3.5    1.1      6     . 
50  132.5    3.5    1.1      6     . 
50  144.5    3.5    1.1      6     . 
50  157.0    3.5    1.1      6     . 
50  162.0    0.0    1.1      6   58.7
51    0.    18.0    0.9      9     . 
51    3.0    0.0    0.9      9   12.7
51   11.5    2.5    0.9      9     . 
51   12.5    9.0    0.9      9     . 
51   24.5    2.5    0.9      9     . 
51   36.5    2.5    0.9      9     . 
51   49.0    2.5    0.9      9     . 
51   60.0    0.0    0.9      9   31.3
51   60.5    2.5    0.9      9     . 
51   72.5    2.5    0.9      9     . 
51   84.5    2.5    0.9      9     . 
51   96.5    2.5    0.9      9     . 
51  108.5    2.5    0.9      9     . 
51  120.5    2.5    0.9      9     . 
51  132.0    0.0    0.9      9   31.1
52    0.     9.5    0.9      7     . 
52    2.0    0.0    0.9      7   14.3
52    4.0    9.5    0.9      7     . 
52   12.5    9.0    0.9      7     . 
52   35.5    2.5    0.9      7     . 
52   37.5    2.5    0.9      7     . 
52   59.5    2.5    0.9      7     . 
52   71.5    2.5    0.9      7     . 
52   83.0    0.0    0.9      7   38.1
52   83.5    2.5    0.9      7     . 
52   95.5    2.5    0.9      7     . 
52  107.5    2.5    0.9      7     . 
52  119.5    2.5    0.9      7     . 
52  131.5    2.5    0.9      7     . 
52  143.5    2.5    0.9      7     . 
52  155.0    0.0    0.9      7   31.2
53    0.    17.0    1.7      8     . 
53    4.0   17.0    1.7      8     . 
53    6.0    0.0    1.7      8   19.1
53   23.8    4.0    1.7      8     . 
53   27.0    7.5    1.7      8     . 
53   28.0    4.0    1.7      8     . 
53   39.5    4.0    1.7      8     . 
53   47.0    0.0    1.7      8   33.3
54    0.    18.0    1.8      8     . 
54    3.7   18.0    1.8      8     . 
54    9.7    0.0    1.8      8   25.5
54   15.7    4.4    1.8      8     . 
54   27.7    4.4    1.8      8     . 
54   29.7    0.0    1.8      8   29.4
54   39.7    4.4    1.8      8     . 
54   51.7    4.4    1.8      8     . 
54   63.2    0.0    1.8      8   29.5
54   63.7    4.4    1.8      8     . 
54   75.7    4.4    1.8      8     . 
54   87.7    4.4    1.8      8     . 
54   99.7    4.4    1.8      8     . 
54  111.3    0.0    1.8      8   37.9
55    0.    25.0    1.1      4     . 
55   12.0    3.0    1.1      4     . 
55   24.0    3.0    1.1      4     . 
55   36.0    3.0    1.1      4     . 
55   48.0    3.0    1.1      4     . 
55   60.0    3.0    1.1      4     . 
55   72.0    3.0    1.1      4     . 
55   74.0    0.0    1.1      4   20.8
56    0.    12.0    0.6      4     . 
56   12.7    1.5    0.6      4     . 
56   20.0    0.0    0.6      4   18.8
57    0.    20.0    2.1      6     . 
57    0.5   20.0    2.1      6     . 
57    1.7    0.0    2.1      6   20.2
57   12.2    5.0    2.1      6     . 
57   24.7    5.0    2.1      6     . 
57   37.2    5.0    2.1      6     . 
57   47.8    5.0    2.1      6     . 
57   60.2    5.0    2.1      6     . 
57   72.2    6.0    2.1      6     . 
57   84.2    6.0    2.1      6     . 
57   96.2    6.0    2.1      6     . 
57  109.0    0.0    2.1      6   27.8
58    0.    14.0    1.4      8     . 
58    0.5   14.0    1.4      8     . 
58    8.5    0.0    1.4      8   22.4
58   12.0    3.5    1.4      8     . 
58   24.3    3.5    1.4      8     . 
58   35.8    3.5    1.4      8     . 
58   47.5    0.0    1.4      8   27.9
58   48.0    3.5    1.4      8     . 
58   59.5    3.5    1.4      8     . 
58   72.0    3.5    1.4      8     . 
58   84.0    3.5    1.4      8     . 
58   96.3    3.5    1.4      8     . 
58  107.0    3.5    1.4      8     . 
58  120.3    3.5    1.4      8     . 
58  131.8    0.0    1.4      8   31.0
59    0.    22.8    1.1      6     . 
59    1.8    0.0    1.1      6   22.6
59   12.5    3.0    1.1      6     . 
59   24.3    3.0    1.1      6     . 
59   36.3    3.0    1.1      6     . 
59   48.8    3.0    1.1      6     . 
59   60.3    3.0    1.1      6     . 
59   72.3    3.0    1.1      6     . 
59   73.8    0.0    1.1      6   34.3
59   84.3    3.0    1.1      6     . 
59   96.0    3.0    1.1      6     . 
59  108.3    3.0    1.1      6     . 
59  120.5    3.0    1.1      6     . 
59  132.3    3.0    1.1      6     . 
59  144.8    3.0    1.1      6     . 
59  146.8    0.0    1.1      6   40.2
; 
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 15.3                                      ---*/
goptions reset=all
   hsize   = 6.25 in
   vsize   = 5.25 in
   htext   = 3.0 pct
   htitle  = 3.5 pct
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss
   lfactor = 1;

axis1 order = (0 to 400 by 50)
      value = (font=swissl height=1)  
      label = (font=swissl h=1)
      major = (h=0.5)
      minor = none;

axis2 order = (0 to 70 by 10)
      value = (font=swissl height=1)
      label = (font=swissl h=1)
      major = (h=1)
      minor = none;

symbol1 color=black value=none i=join l=1 r=100 w=1;

proc gplot data=pheno;
   plot conc*time=indiv / nolegend;
run;
quit;
goptions reset=all;
/*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---One-compartment model with intravenous bolus     ---*/
 /*---administration and first-order elimination,      ---*/
 /*---constant CV weighting                            ---*/
 /*---Output 15.15                                     ---*/	  
proc nlmixed data=pheno qpoints=1;
   * starting values;
   parms beta1=0.5 beta2=1 beta3=0.15 
         s2u1=0.05 s2u2=0.03 cu12=0.015 s2e=0.01;

   * bounds;
   bounds beta1>=0, beta2>=0, s2u1>=0, s2u2>=0, s2e>0;

   * compute key terms in the model;
   clear = beta1/100*weight*exp(u1);
   vol   = beta2*weight*(1+beta3*apgarlow)*exp(u2);
   eterm = exp(-(time-tlag)*clear/vol);

   * compute predicted value depending on whether this is a 
     new subject or not;
   if (newsub = 1) then pred = dose/vol;
   else pred = dose/vol + zlag(pred)*eterm;

    * variance goes up with the square of the predicted value, 
      a constant coefficient of variation model;
   var = s2e*(pred**2);

   * model specification;
   model conc ~ normal(pred,var);

   * random effects specification;
   random u1 u2 ~ normal([0,0],[s2u1,cu12,s2u2]) subject=indiv out=ebayes;

   * compute an additional estimate of the correlation;
   estimate 'corr(u1,u2)' cu12/sqrt(s2u1*s2u2);

   * output subject-specific predictions of clearance and volume;
   predict clear out=clear;
   predict vol out=vol;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Figure 15.4                                      ---*/
 /*---code to plot empirical Bayes estimates of random ---*/
 /*---effects                                          ---*/
proc transpose data=ebayes out=ebt;
   var estimate;
   by indiv;
   id effect;
run;

data ebt;
  set ebt;
  format u1 u2 4.1;
run;

goptions reset=all
   hsize   = 5 in
   vsize   = 5 in
   htext   = 3.0 pct
   htitle  = 3.5 pct
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss
   lfactor = 1;

axis1 order = (-0.3 to 0.5 by 0.1)
      value = (font=swissl height=1)  
      label = (font=swissl h=1)
      major = (h=0.5)
      minor = none;

symbol v=circle;

proc gplot data=ebt;
   plot u1*u2 / haxis=axis1 vaxis=axis1;
run;   
quit;
goptions reset=all;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Figure 15.5                                      ---*/
 /*---Code to plot subject-specific clearance versus   ---*/
 /*---volume                                           ---*/
data clear1;
   set clear;
   if time = 0;
   clearance = pred;
   format clearance 4.1;
   keep indiv clearance;
run;

data vol1;
   set vol;
   if time = 0;
   volume = pred;
   format volume 4.1;
   keep indiv volume;
run;

data cv;
   merge clear1 vol1;
   by indiv;
run;

goptions reset=all
   hsize   = 5 in
   vsize   = 5 in
   htext   = 3.0 pct
   htitle  = 3.5 pct
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss
   lfactor = 1;

axis1 order = (0 to 5 by 1)
      value = (font=swissl height=1)  
      label = (font=swissl h=1)
      major = (h=0.5)
      minor = none;

axis2 order = (0 to 0.025 by 0.005)
      value = (font=swissl height=1)  
      label = (font=swissl h=1)
      major = (h=0.5)
      minor = none;

symbol v=circle;

proc gplot data=cv;
   plot clearance*volume / haxis=axis1 vaxis=axis2;
run;
quit;
goptions reset=all;
 /*-------------------------------------------------------*/



 /*-------------------------------------------------------*/
 /*---Code to remove dependence of variance on random  ---*/
 /*---effects                                          ---*/
 /*---Output not shown                                 ---*/
proc nlmixed data=pheno qpoints=1;
   parms beta1=0.5 beta2=1 beta3=0.15 
      s2u1=0.05 s2u2=0.03 cu12=0.015 s2e=0.01;
   bounds beta1>=0, beta2>=0, s2u1>=0, s2u2>=0, s2e>0;
   /*---mean---*/
   clear = beta1/100*weight*exp(u1);
   vol   = beta2*weight*(1+beta3*apgarlow)*exp(u2);
   eterm = exp(-(time-tlag)*clear/vol);
   if (newsub = 1) then pred = dose/vol;
   else pred = dose/vol + zlag(pred)*eterm;
   /*---variance---*/
   clear0 = beta1/100*weight;
   vol0   = beta2*weight*(1+beta3*apgarlow);
   eterm0 = exp(-(time-tlag)*clear0/vol0);
   if (newsub = 1) then pred0 = dose/vol0;
   else pred0 = dose/vol0 + zlag(pred0)*eterm0;
   var = s2e*(pred0**2);
   /*---model---*/
   model conc ~ normal(pred,var);
   random u1 u2 ~ normal([0,0],[s2u1,cu12,s2u2]) subject=indiv;
   estimate 'corr(u1,u2)' cu12/sqrt(s2u1*s2u2);
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---One-compartment model with intravenous bolus     ---*/
 /*---administration and first-order elimination,      ---*/
 /*---NLINMIX Method 2                                 ---*/
 /*---Output 15.16, Output 15.17                       ---*/
%nlinmix(data=pheno,
   modinit=%str(
      array plag{11} _temporary_;
      if (newsub=1) then do call = 1 to 11;
         plag[call] = 0;
      end;
      call = 1;
   ),
   model=%str(
      clear = beta1/100*weight*exp(u1);
      vol   = beta2*weight*(1+beta3*apgarlow)*exp(u2);
      eterm = exp(-(time-tlag)*clear/vol);
      predv = dose/vol + plag[call]*eterm;
      plag[call] = predv;
      call = call + 1;
   ),
   weight=%str(
      wghtv = 1/predv**2;
   ),
   parms=%str(beta1=0.5 beta2=1 beta3=0.15),
   stmts=%str(
      class indiv;
      model pseudo_conc = d_beta1 d_beta2 d_beta3 / 
                          noint notest solution cl;
      random d_u1 d_u2 / subject=indiv type=un solution;
      weight wghtv;
   ),
   expand=eblup
)
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Figure 15.6                                      ---*/
 /*---code to plot EBLUPs                              ---*/
proc transpose data=_solnr out=eblups;
   var estimate;
   by indiv;
   id effect;
run;

data eblups;
  set eblups;
  format d_u1 d_u2 4.1;
run;

goptions reset=all
   hsize   = 8 in
   vsize   = 8 in
   vorigin = 0 in
   horigin = 0 in
   ftext   = swiss
   lfactor = 1;

axis1 order = (-0.3 to 0.5 by 0.1)
      value = (font=swissl height=2)  
      label = (font=swissl h=2)
      major = (h=0.5)
      minor = none;

symbol v=circle;

proc gplot data=eblups;
   plot d_u1*d_u2 / haxis=axis1 vaxis=axis1;
run; quit;
goptions reset=all;
run;
 /*-------------------------------------------------------*/


/*-------------------------------------------------------*/
 /*---CHAPTER 16: Case Studies                         ---*/
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data set 16.2, Milling Corn                      ---*/
data design;
   input batch a b c d y aa;
   aa=a;
   datalines;
 1     1     1     1     1    505     1
 1     1    -1    -1    -1    493     1
 1     1    -1     1    -1    491     1
 2     1     1    -1     0    498     1
 2     1     1    -1    -1    504     1
 2     1    -1     1     0    500     1
 3    -1     0    -1    -1    494    -1
 3    -1     0     1     0    498    -1
 3    -1    -1     0     1    498    -1
 4     0    -1    -1     0    496     0
 4     0     0     1     1    503     0
 4     0    -1     0    -1    496     0
 5    -1    -1     1     1    503    -1
 5    -1     1     1    -1    495    -1
 5    -1    -1     1    -1    494    -1
 6     0     0     0     0    486     0
 6     0     1     1    -1    501     0
 6     0     1    -1     1    490     0
 7    -1     1     0     0    494    -1
 7    -1     1     1     1    497    -1
 7    -1    -1     1    -1    492    -1
 8     1    -1     1     1    503     1
 8     1     0     0    -1    499     1
 8     1     0    -1     1    493     1
 9     1     1     1    -1    505     1
 9     1     1     0     1    500     1
 9     1    -1    -1     1    490     1
10    -1    -1    -1     1    494    -1
10    -1     1    -1    -1    497    -1
10    -1    -1    -1    -1    495    -1
;
 /*-------------------------------------------------------*/

 
 /*-------------------------------------------------------*/
 /*---Output 16.1                                      ---*/
proc mixed data=design;
   class batch aa;
   model y = a|b|c|d@2 a*a b*b c*c d*d / solution;
   random batch(aa);
   ods select ClassLevels CovParms SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.2                                      ---*/
proc mixed data=design;
   class batch aa;
   model y=a|b|c|d@2 a*a b*b c*c d*d /solution ddfm=satterth;
   random batch(aa);
   ods select SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 16.3, Mayonnaise                        ---*/
data mayo;

   input y a b c p $ d u h t;
   u  = t;
   ca = a;
   cb = b;
   cc = c;
   datalines;
 95     1     1     1    X6     0    -1         1    -1     
 67     1     1     1    X6     1    -1         1    -1     
100     1     1     1    X6     0    -0.5854    2    -0.5854
 70     1     1     1    X6     1    -0.5854    2    -0.5854
100     1     1     1    X6     0     1         3     1     
 77     1     1     1    X6     1     1         3     1     
 41     1    -1    -1    X7     0    -1         1    -1     
 32     1    -1    -1    X7     1    -1         1    -1     
 42     1    -1    -1    X7     0    -0.5854    2    -0.5854
 27     1    -1    -1    X7     1    -0.5854    2    -0.5854
 60     1    -1    -1    X7     0     1         3     1     
 27     1    -1    -1    X7     1     1         3     1     
 35     0     0     0    X8     0    -1         1    -1     
 26     0     0     0    X8     1    -1         1    -1     
 39     0     0     0    X8     0    -0.5854    2    -0.5854

 24     0     0     0    X8     1    -0.5854    2    -0.5854
 57     0     0     0    X8     0     1         3     1     
 25     0     0     0    X8     1     1         3     1     
 48     0     0     0    X9     0    -1         1    -1     
 35     0     0     0    X9     1    -1         1    -1     
 55     0     0     0    X9     0    -0.5854    2    -0.5854
 35     0     0     0    X9     1    -0.5854    2    -0.5854
 72     0     0     0    X9     0     1         3     1     
 36     0     0     0    X9     1     1         3     1     
 31    -1     1    -1    X10    0    -1         1    -1     
 26    -1     1    -1    X10    1    -1         1    -1     
 37    -1     1    -1    X10    0    -0.5854    2    -0.5854
 25    -1     1    -1    X10    1    -0.5854    2    -0.5854
 55    -1     1    -1    X10    0     1         3     1     
 25    -1     1    -1    X10    1     1         3     1     
 30    -1    -1     1    X11    0    -1         1    -1     
 25    -1    -1     1    X11    1    -1         1    -1     
 36    -1    -1     1    X11    0    -0.5854    2    -0.5854
 25    -1    -1     1    X11    1    -0.5854    2    -0.5854
 50    -1    -1     1    X11    0     1         3     1     
 25    -1    -1     1    X11    1     1         3     1     
 45     0     0     1    X12    0    -1         1    -1     
 34     0     0     1    X12    1    -1         1    -1     
 54     0     0     1    X12    0    -0.5854    2    -0.5854
 33     0     0     1    X12    1    -0.5854    2    -0.5854
 75     0     0     1    X12    0     1         3     1     
 34     0     0     1    X12    1     1         3     1     
 22     0    -1     0    X13    0    -1         1    -1     
 18     0    -1     0    X13    1    -1         1    -1     
 23     0    -1     0    X13    0    -0.5854    2    -0.5854
 16     0    -1     0    X13    1    -0.5854    2    -0.5854
 28     0    -1     0    X13    0     1         3     1     
 16     0    -1     0    X13    1     1         3     1     
 56     0     1     0    X14    0    -1         1    -1     
 40     0     1     0    X14    1    -1         1    -1     
 69     0     1     0    X14    0    -0.5854    2    -0.5854
 42     0     1     0    X14    1    -0.5854    2    -0.5854
 95     0     1     0    X14    0     1         3     1     
 45     0     1     0    X14    1     1         3     1     
 50     0     0    -1    X15    0    -1         1    -1     
 37     0     0    -1    X15    1    -1         1    -1     
 57     0     0    -1    X15    0    -0.5854    2    -0.5854
 35     0     0    -1    X15    1    -0.5854    2    -0.5854
 73     0     0    -1    X15    0     1         3     1     
 35     0     0    -1    X15    1     1         3     1     
 43     0     0     0    X16    0    -1         1    -1     
 31     0     0     0    X16    1    -1         1    -1     
 48     0     0     0    X16    0    -0.5854    2    -0.5854
 32     0     0     0    X16    1    -0.5854    2    -0.5854
 64     0     0     0    X16    0     1         3     1     
 31     0     0     0    X16    1     1         3     1     
 64     1     0     0    X17    0    -1         1    -1     
 46     1     0     0    X17    1    -1         1    -1     
 69     1     0     0    X17    0    -0.5854    2    -0.5854
 45     1     0     0    X17    1    -0.5854    2    -0.5854
 85     1     0     0    X17    0     1         3     1     
 45     1     0     0    X17    1     1         3     1     
 27    -1     0     0    X18    0    -1         1    -1     
 21    -1     0     0    X18    1    -1         1    -1     
 28    -1     0     0    X18    0    -0.5854    2    -0.5854
 21    -1     0     0    X18    1    -0.5854    2    -0.5854
 37    -1     0     0    X18    0     1         3     1     
 18    -1     0     0    X18    1     1         3     1     
 45     0     0     0    X19    0    -1         1    -1     
 35     0     0     0    X19    1    -1         1    -1     
 48     0     0     0    X19    0    -0.5854    2    -0.5854
 33     0     0     0    X19    1    -0.5854    2    -0.5854
 67     0     0     0    X19    0     1         3     1     
 33     0     0     0    X19    1     1         3     1     
 81     1     1    -1    X20    0    -1         1    -1     
 56     1     1    -1    X20    1    -1         1    -1     
 90     1     1    -1    X20    0    -0.5854    2    -0.5854
 55     1     1    -1    X20    1    -0.5854    2    -0.5854
100     1     1    -1    X20    0     1         3     1     
 58     1     1    -1    X20    1     1         3     1     
 40     1    -1     1    X21    0    -1         1    -1     
 29     1    -1     1    X21    1    -1         1    -1     
 40     1    -1     1    X21    0    -0.5854    2    -0.5854
 28     1    -1     1    X21    1    -0.5854    2    -0.5854
 52     1    -1     1    X21    0     1         3     1     
 26     1    -1     1    X21    1     1         3     1     
 49    -1     1     1    X22    0    -1         1    -1     
 35    -1     1     1    X22    1    -1         1    -1     
 55    -1     1     1    X22    0    -0.5854    2    -0.5854
 35    -1     1     1    X22    1    -0.5854    2    -0.5854
 73    -1     1     1    X22    0     1         3     1     
 35    -1     1     1    X22    1     1         3     1     
 15    -1    -1    -1    X23    0    -1         1    -1     
 13    -1    -1    -1    X23    1    -1         1    -1     
 14    -1    -1    -1    X23    0    -0.5854    2    -0.5854
 12    -1    -1    -1    X23    1    -0.5854    2    -0.5854
 18    -1    -1    -1    X23    0     1         3     1     
 11    -1    -1    -1    X23    1     1         3     1     
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.3                                      ---*/
proc mixed data=mayo;
   class ca cb cc p d u;
   model y = d a(d) b(d) c(d) a*a b*b c*c a*b a*c b*c  
           t(d) t*t t*a t*b t*c /noint solution htype=1 ddfm=kr;
   random p(ca cb cc);
   repeated / type=cs subject=d*p(ca cb cc);
   ods select CovParms FitStatistics SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.4                                      ---*/
proc mixed data=mayo;
   class ca cb cc p d u;
   model y = d a(d) b(d) c(d) a*a b*b c*c a*b a*c b*c  
           t(d) t*t t*a t*b t*c /noint solution htype=1 ddfm=kr;
   random p(ca cb cc);
   repeated / type=cs subject=d*p(ca cb cc);
   ods select Tests1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.5                                      ---*/
proc mixed data=mayo;
   class ca cb cc p d u;
   model y = d a(d) b(d) c(d) a*a b*b c*c a*b a*c b*c  
            t(d) t*t t*a t*b t*c /noint solution htype=1 ddfm=kr;
   random p(ca cb cc);
   repeated / type=sp(pow)(t) subject=d*p(ca cb cc);
   ods select CovParms FitStatistics;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.6                                      ---*/
proc mixed data=mayo;
   class ca cb cc p d u;
   model y = d a(d) b(d) c(d) a*a b*b c*c a*b a*c b*c  
            t(d) t*t t*a t*b t*c /noint solution htype=1 ddfm=kr;
   random p(ca cb cc);
   repeated / type=sp(pow)(t) subject=d*p(ca cb cc);
   ods select SolutionF Tests1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 16.4, Irrigation                        ---*/
data irrigation;
   input eu bloc trt level y @@;
   datalines;
 1  1  1  1  43   2  1  2  1  45
 3  1  1  2  41   4  1  2  2  45
 5  1  1  3  46   6  1  2  3  46
 7  1  1  4  46   8  1  2  4  46
 9  1  1  5  45  10  1  2  5  45
11  1  1  6  50  12  1  2  6  51
13  1  1  7  49  14  1  2  7  47
15  1  1  8  46  16  1  2  8  49
17  2  1  1  39  18  2  2  1  44
19  2  3  1  39  20  2  1  2  43
21  2  2  2  47  22  2  3  2  42
23  2  1  3  47  24  2  2  3  49
25  2  3  3  45  26  2  1  4  40
27  2  2  4  42  28  2  3  4  40
29  2  1  5  38  30  2  2  5  39
31  2  3  5  37  32  2  1  6  43
33  2  2  6  45  34  2  3  6  42
35  2  1  7  36  36  2  2  7  36
37  2  3  7  36  38  2  1  8  39
39  2  2  8  40  40  2  3  8  39
41  3  2  1  34  42  3  3  1  31
43  3  2  2  38  44  3  3  2  34
45  3  2  3  37  46  3  3  3  36
47  3  2  4  39  48  3  3  4  37
49  3  2  5  43  50  3  3  5  42
51  3  2  6  43  52  3  3  6  41
53  3  2  7  40  54  3  3  7  39
55  3  2  8  39  56  3  3  8  37
57  4  1  1  44  58  4  3  1  39
59  4  1  2  45  60  4  3  2  41
61  4  1  3  47  62  4  3  3  47
63  4  1  4  46  64  4  3  4  43
65  4  1  5  45  66  4  3  5  40
67  4  1  6  43  68  4  3  6  41
69  4  1  7  41  70  4  3  7  40
71  4  1  8  40  72  4  3  8  38
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.7                                      ---*/
proc glimmix data=irrigation;
   class bloc trt level;
   model y = level trt trt*level / ddfm=kr; 
   random intercept / subject=bloc;
   random level     / subject=bloc type=ar(1);
   lsmeans trt / diff;
   lsmeans level trt*level;
   estimate 'lev 1 vs lev 2' level 1 -1 0;
   estimate 'lev 1 vs lev 8' level 1  0 0  0  0  0  0  -1;
   lsmestimate trt*level 
        'trt 1 v 2 given lev 1'  1  0 0 0 0 0 0  0 -1 0,
        'lev 1 v 2 given trt 1'  1 -1 0                ,
        'lev 1 v 8 given trt 1'  1  0 0 0 0 0 0 -1  0  ;
   contrast 'linear'    level -7  -5  -3  -1   1  3   5  7;
   contrast 'quadratic' level  7   1  -3  -5  -5 -3   1  7;
   contrast 'other'     level -7   5   7   3  -3 -7  -5  7,
                        level  7 -13  -3   9   9 -3 -13  7,
                        level -7  23 -17 -15  15 17 -23  7,
                        level  1  -5   9  -5  -5  9  -5  1,
                        level -1  7  -21  35 -35 21  -7  1;
   ods select CovParms Tests3 LSMeans Diffs Estimates Contrasts
              LSMEstimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.8                                      ---*/
proc glimmix data=irrigation;
   class bloc trt level;
   model y=  level trt trt*level/ ddfm=kr;
   random bloc bloc*level;
   lsmeans trt/diff;
   lsmeans level trt*level;
   estimate 'lev 1 vs lev 2' level 1 -1 0;
   estimate 'lev 1 vs lev 8' level 1  0 0  0  0  0  0  -1;
   estimate 'trt 1 vs trt 2' trt   1 -1 0;
   lsmestimate trt*level 
            'trt 1 v 2 given lev 1' 1  0 0 0 0 0 0  0 -1 0,
            'lev 1 v 2 given trt 1' 1 -1 0,
            'lev 1 v 8 given trt 1' 1  0 0 0 0 0 0 -1 0;
   contrast 'linear'    level -7  -5  -3  -1   1  3   5  7;
   contrast 'quadratic' level  7   1  -3  -5  -5 -3   1  7;
   contrast 'other'     level -7   5   7   3  -3 -7  -5  7,
                        level  7 -13  -3   9   9 -3 -13  7,
                        level -7  23 -17 -15  15 17 -23  7,
                        level  1  -5  9   -5  -5  9  -5  1,
                        level -1   7 -21  35 -35 21  -7  1;
   ods select CovParms Tests3 Diffs Estimates Contrasts
              LSMEstimates;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 16.5, Nitrogen                          ---*/
data nitrogen;
  input row col N G y;
  nclass=N;
  datalines;
1 1 1 1 20.1
1 1 1 2 20.4
2 1 2 1 16.2
2 1 2 2 14
3 1 3 1 16.2
3 1 3 2 12.6
1 2 2 1 18.1
1 2 2 2 16.7
2 2 1 1 10.3
2 2 1 2 8.1
3 2 4 1 14.9
3 2 4 2 9.9
1 3 5 1 23.1
1 3 5 2 18.1
2 3 3 1 17.8
2 3 3 2 16.1
3 3 1 1 9.8
3 3 1 2 9
1 4 4 1 21.8
1 4 4 2 17.4
2 4 5 1 18.1
2 4 5 2 12.9
3 4 2 1 14
3 4 2 2 12.1
1 5 3 1 22.7
1 5 3 2 19.5
2 5 4 1 18.7
2 5 4 2 13.7
3 5 5 1 17
3 5 5 2 10.9
;

 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.9                                      ---*/
proc mixed data=nitrogen;
   class row col n g;
   model y = n g n*g / ddfm=satterth;
   random row col row*col*n;
   lsmeans n g n*g;
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.10                                     ---*/
proc mixed data=nitrogen;
   class row col NClass G;
   model y = N|N|N|N|G / htype=1 ddfm=satterth; 
   random row col row*col*NClass;
   ods select Tests1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.11                                     ---*/
proc mixed data=nitrogen;
   class row col NClass G;
   model y = N|N|G@2 NClass NClass*G / htype=1 ddfm=satterth;
   random row col row*col*NClass;
   ods select Tests1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 16.4                                      ---*/
ods html file="test.html";
ods graphics on;
ods select MeanPlot;
proc glimmix data=nitrogen;
   class row col G N;
   model y = G|N;
   random row col row*col*nclass;
   lsmeans G*N / plot=MeanPlot(sliceby=G join);
run;

ods graphics off;
ods html close;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 16.12                                     ---*/
proc mixed data=nitrogen;
   class row col g nclass;
   model y = g n(g) n*n/ noint solution ddfm=satterth;
   random row col row*col*nclass;
   ods select SolutionF;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Figure 16.5                                      ---*/
proc mixed data=nitrogen;
   class row col g nclass;
   model y = g n(g) n*n/ noint solution ddfm=satterth 
                         outpm=now_plot(rename=(pred=yhat));
   random row col row*col*nclass;
   ods select SolutionF;
run;
goptions reset=all;
proc sort data=now_plot; by g n; run;
axis1 value=(font=swiss h=2) 
      label=(angle=90 f=swiss h=2 'Predicted Y');
axis2 value=(font=swiss h=2 )
      label=(f=swiss h=2 'N Level');
legend1 value=(font=swiss h=2  ) 
        label=(f=swiss h=2 'By Genotype'); 
symbol1 color=black interpol=join line=1 value=circle; 
symbol2 color=black interpol=join line=20 value=triangle;
proc gplot data=now_plot;
   plot yhat*n=g / vaxis  = axis1 
                          haxis  = axis2
                          legend = legend1;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 16.6, Sandhills                         ---*/
data sandhills;
   input circle ec ir v y;
   datalines;
1 1 1 1 30.0
1 1 1 2 40.9
1 1 2 1 38.9
1 1 2 2 38.2
1 2 1 1 41.8
1 2 1 2 52.2
1 2 2 1 54.8
1 2 2 2 58.2
2 1 1 1 20.5
2 1 1 2 26.9
2 1 2 1 21.4
2 1 2 2 25.1
2 2 1 1 26.4
2 2 1 2 36.7
2 2 2 1 28.9
2 2 2 2 35.9
3 1 1 1 21.0
3 1 1 2 25.4
3 1 2 1 24.0
3 1 2 2 23.3
3 2 1 1 34.4
3 2 1 2 41.0
3 2 2 1 33.2
3 2 2 2 34.9
;
 /*-------------------------------------------------------*/



 /*-------------------------------------------------------*/
 /*---Output 16.13                                     ---*/
proc glimmix data=sandhills;
   class circle ec ir v;
   model y=ec ir ec*ir v v*ec v*ir v*ec*ir/ddfm=satterth;
   random circle circle*ec circle*ir circle*ec*ir;
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.14                                     ---*/
 /*---Output 16.15                                     ---*/
proc glimmix data=sandhills;
   class circle ec ir v;
   model y=ec ir ec*ir v v*ec v*ir v*ec*ir/ddfm=satterth;
   random circle circle*ec circle*ir circle*ec*ir;
   lsmeans ec      / diff             cl;
   lsmeans ir*v    / slicediff=(ir v) cl;
   lsmeans ec*ir*v / slicediff=ec*ir  cl;
   ods select LSMeans Diffs SliceDiffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 16.7, Breaking Strength                 ---*/
data breaking_strength;
   input soap_pH num_washes water_temp$ dry_cycle$ 
         Breaking_Strength Elongation Slope Energy;
   pH = soap_pH;
   w  = num_washes;
   datalines;
8   10  cold  air       0.11056     16.878      0.045682857 0.672025714
8   10  cold  delicate  0.1117      18.54695652 0.041152174 0.721471739
8   10  cold  normal    0.107987755 19.11102041 0.036804082 0.723695918
8   10  hot   air       0.100611538 19.53923077 0.03965     0.683511538
8   10  hot   delicate  0.102096226 20.14716981 0.038160377 0.703624528
8   10  hot   normal    0.101670833 19.74       0.036022917 0.720902083
8   20  cold  air       0.09264878  16.64       0.041070732 0.55695122
8   20  cold  delicate  0.09106     18.4896     0.04062     0.615916
8   20  cold  normal    0.088258696 16.12826087 0.032113043 0.489576087
8   20  hot   air       0.101257143 18.81632653 0.038085714 0.66635102
8   20  hot   delicate  0.099182979 19.41446809 0.037704255 0.63837234
8   20  hot   normal    0.094102083 17.71625    0.031552083 0.572995833
8   30  cold  air       0.087420513 14.7641     0.041738462 0.530387179
8   30  cold  delicate  0.092523404 16.85957447 0.033329787 0.563642553
8   30  cold  normal    0.097338776 16.86533333 0.030046667 0.526977778
8   30  hot   air       0.0965      18.42875    0.03406875  0.633804167
8   30  hot   delicate  0.092455556 17.28962963 0.032787037 0.543883333
8   30  hot   normal    0.094755556 17.896      0.032833333 0.639137778
8   40  cold  air       0.092959459 15.70378378 0.035575676 0.525878378
8   40  cold  delicate  0.086335556 17.21377778 0.030368889 0.526986667
8   40  cold  normal    0.08709375  17.6175     0.03115625  0.530825
8   40  hot   air       0.089866    17.756      0.032736    0.558094
8   40  hot   delicate  0.083214286 17.44204082 0.03034898  0.524738776
8   40  hot   normal    0.075329167 17.76208333 0.03019375  0.5520875
8   50  cold  air       0.08597     15.5376     0.035356    0.493366
8   50  cold  delicate  0.084926667 16.56089    0.030668889 0.472746667
8   50  cold  normal    0.077727907 14.7414     0.02962093  0.436155814
8   50  hot   air       0.08686383  16.10894    0.03116383  0.493459574
8   50  hot   delicate  0.079282222 15.81822    0.027962222 0.423888889
8   50  hot   normal    0.075106    15.2064     0.027636    0.391664
10  10  cold  air       0.094640385 15.383846   0.040991    0.5117736
10  10  cold  delicate  0.090370588 16.4941176  0.0344667   0.512739
10  10  cold  normal    0.093637736 17.3056604  0.0299075   0.550775
10  10  hot   air       0.101960784 18.487059   0.0346471   0.6320549
10  10  hot   delicate  0.096967308 18.030385   0.0326192   0.5952846
10  10  hot   normal    0.085365306 16.7257143  0.02970612  0.48526122
10  20  cold  air       0.096437705 15.2419672  0.039969    0.516157
10  20  cold  delicate  0.083050909 15.458182   0.033105    0.448816
10  20  cold  normal    0.085377966 16.09051    0.030073    0.475436
10  20  hot   air       0.090378182 17.23964    0.031922    0.537931
10  20  hot   delicate  0.079803704 15.91074    0.030565    0.454283
10  20  hot   normal    0.0739      14.88       0.027289    0.387181
10  30  cold  air       0.08783871  15.6171     0.038597    0.455755
10  30  cold  delicate  0.076156364 15.91455    0.032376    0.404242
10  30  cold  normal    0.071062264 14.84717    0.027789    0.35516
10  30  hot   air       0.07604     15.148      0.029545    0.404447
10  30  hot   delicate  0.057938596 12.54772    0.027037    0.244839
10  30  hot   normal    0.055872222 11.84222    0.025644    0.233622
10  40  cold  air       0.079812281 14.35544    0.034681    0.413628
10  40  cold  delicate  0.064691379 14.60483    0.027314    0.343205
10  40  cold  normal    0.068009091 14.87855    0.026175    0.351716
10  40  hot   air       0.060152632 13.28281    0.025086    0.279744
10  40  hot   delicate  0.048512727 12.18364    0.023535    0.213495
10  40  hot   normal    0.044706122 11.43592    0.020757    0.18009
10  50  cold  air       0.077755172 11.75052    0.036457    0.402684
10  50  cold  delicate  0.051081132 11.35898    0.025847    0.238051
10  50  cold  normal    0.057578431 11.35529    0.025898    0.26828
10  50  hot   air       0.050215217 11.36404    0.024804    0.233435
10  50  hot   delicate  0.040911429 11.16834    0.020217    0.173549
10  50  hot   normal    0.034036364 11.053      0.018532    0.141359
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.16                                     ---*/
proc mixed data=breaking_strength;
   class pH water_temp dry_cycle;
   model breaking_strength=pH water_temp dry_cycle 
                       w w*pH w*water_temp w*dry_cycle/solution;
   random pH*water_temp*dry_cycle;
   contrast 'air vs dryer effect on wear'  
               w*dry_cycle 2 -1 -1;
   contrast 'delicate v normal effect on wear' 
               w*dry_cycle 0 1 -1;
   ods select CovParms Tests3 Contrasts SolutionF;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.17                                     ---*/
proc mixed data=breaking_strength;
   class pH water_temp dry_cycle;
   model breaking_strength = w(pH) w(water_temp) 
                             w(dry_cycle) / solution;
   random pH*water_temp*dry_cycle;
   estimate 'slope: ph 8, cold, air' 
             w(ph) 1 0 w(water_temp) 1 0 w(dry_cycle) 1 0 0;
   estimate 'slope: ph 8, cold, delicate' 
             w(ph) 1 0 w(water_temp) 1 0 w(dry_cycle) 0 1 0;
   estimate 'slope: ph 8, cold, normal' 
             w(ph) 1 0 w(water_temp) 1 0 w(dry_cycle) 0 0 1;
   estimate 'slope: ph 8, hot, air' 
             w(ph) 1 0 w(water_temp) 0 1 w(dry_cycle) 1 0 0;
   estimate 'slope: ph 8, hot, delicate' 
             w(ph) 1 0 w(water_temp) 0 1 w(dry_cycle) 0 1 0;
   estimate 'slope: ph 8, hot, normal' 
             w(ph) 1 0 w(water_temp) 0 1 w(dry_cycle) 0 0 1;
   estimate 'slope: ph 10, cold, air' 
             w(ph) 0 1 w(water_temp) 1 0 w(dry_cycle) 1 0 0;
   estimate 'slope: ph 10, cold, delicate' 
             w(ph) 0 1 w(water_temp) 1 0 w(dry_cycle) 0 1 0;
   estimate 'slope: ph 10, cold, normal' 
             w(ph) 0 1 w(water_temp) 1 0 w(dry_cycle) 0 0 1;
   estimate 'slope: ph 10, hot, air' 
             w(ph) 0 1 w(water_temp) 0 1 w(dry_cycle) 1 0 0;
   estimate 'slope: ph 10, hot, delicate' 
             w(ph) 0 1 w(water_temp) 0 1 w(dry_cycle) 0 1 0;
   estimate 'slope: ph 10, hot, normal' 
             w(ph) 0 1 w(water_temp) 0 1 w(dry_cycle) 0 0 1;
   estimate 'avg slope: ph 8' 
             w(ph) 6 0 w(water_temp) 3 3 w(dry_cycle) 2 2 2
             / divisor=6;
   estimate 'avg slope: ph 10' 
             w(ph) 0 6 w(water_temp) 3 3 w(dry_cycle) 2 2 2
             / divisor=6;
   estimate 'avg slope: cold water' 
             w(ph) 3 3 w(water_temp) 6 0 w(dry_cycle) 2 2 2
             / divisor=6;
   estimate 'avg slope: hot water' 
             w(ph) 3 3 w(water_temp) 0 6 w(dry_cycle) 2 2 2
             / divisor=6;
   estimate 'avg slope: air dry' 
             w(ph) 1 1 w(water_temp) 1 1 w(dry_cycle) 2 0 0
             / divisor=2;
   estimate 'avg slope: delicate dry' 
             w(ph) 1 1 w(water_temp) 1 1 w(dry_cycle) 0 2 0
             / divisor=2;
   estimate 'avg slope: normal dry' 
             w(ph) 1 1 w(water_temp) 1 1 w(dry_cycle) 0 0 2
             / divisor=2;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Data Set 16.8, 2^3 Factorial                     ---*/
data fac_sp;
  input rep blk a b c y;
  abc = a*b*c;
  datalines;
 1  1  -1  -1  -1  117
 1  1  -1   1   1  130
 1  1   1  -1   1  122
 1  1   1   1  -1  113
 1  2  -1  -1   1  123
 1  2  -1   1  -1  121
 1  2   1  -1  -1  122
 1  2   1   1   1  125
 2  1  -1  -1  -1  127
 2  1  -1   1   1  137
 2  1   1  -1   1  131
 2  1   1   1  -1  122
 2  2  -1  -1   1  128
 2  2  -1   1  -1  124
 2  2   1  -1  -1  124
 2  2   1   1   1  130
 3  1  -1  -1  -1  114
 3  1  -1   1   1  132
 3  1   1  -1   1  121
 3  1   1   1  -1  116
 3  2  -1  -1   1  125
 3  2  -1   1  -1  124
 3  2   1  -1  -1  122
 3  2   1   1   1  129
 4  1  -1  -1  -1  118
 4  1  -1   1   1  132
 4  1   1  -1   1  120
 4  1   1   1  -1  117
 4  2  -1  -1   1  120
 4  2  -1   1  -1  118
 4  2   1  -1  -1  113
 4  2   1   1   1  122
 5  1  -1  -1  -1  120
 5  1  -1   1   1  132
 5  1   1  -1   1  118
 5  1   1   1  -1  120
 5  2  -1  -1   1  127
 5  2  -1   1  -1  127
 5  2   1  -1  -1  118
 5  2   1   1   1  130
 6  1  -1  -1  -1  122
 6  1  -1   1   1  134
 6  1   1  -1   1  124
 6  1   1   1  -1  115
 6  2  -1  -1   1  123
 6  2  -1   1  -1  122
 6  2   1  -1  -1  123
 6  2   1   1   1  124
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.18                                     ---*/
proc glimmix data=fac_sp; 
   class a b c rep blk;
   model y=a|b|c / ddfm=kr;
   random rep blk(rep);
   lsmeans a*b b*c / slicediff=b;
   lsmeans a*b*c;
   ods select CovParms LSMeans SliceDiffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.19                                     ---*/
proc mixed data=fac_sp;
   class rep blk;
   model y=a|b|c / solution ddfm=satterth;
   random rep blk(rep);
   ods select CovParms SolutionF Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.20                                     ---*/
proc glm data=fac_sp;
   class a b c rep blk;
   model y=rep blk(rep) a|b|c/solution;
   random rep blk(rep)/test;
   lsmeans a*b*c;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.21                                     ---*/
proc glm data=fac_sp;
   class a b c rep blk;
   model y = a|b|c rep blk(rep) / e1;
   random rep blk(rep)/test;
   lsmeans a*b*c;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.22                                     ---*/
proc glm data=fac_sp; 
   class abc a b c rep ;
   model y=rep abc rep*abc a|b|c@2;
   random rep rep*abc / test;
   lsmeans a*b b*c / pdiff;
   estimate '(0)' intercept 1 abc 1 0 a 1 0 b 1 0 c 1 0 
                  a*b 1 0 0 0 a*c 1 0 0 0 b*c 1 0 0 0;
   estimate 'a'   intercept 1 abc 0 1 a 0 1 b 1 0 c 1 0 
                  a*b 0 0 1 0 a*c 0 0 1 0 b*c 1 0 0 0;
   estimate 'b'   intercept 1 abc 0 1 a 1 0 b 0 1 c 1 0 
                  a*b 0 1 0 0 a*c 1 0 0 0 b*c 0 0 1 0;
   estimate 'c'   intercept 1 abc 0 1 a 1 0 b 1 0 c 0 1 
                  a*b 1 0 0 0 a*c 0 1 0 0 b*c 0 1 0 0;
   estimate 'ab'  intercept 1 abc 1 0 a 0 1 b 0 1 c 1 0 
                  a*b 0 0 0 1 a*c 0 0 1 0 b*c 0 0 1 0;
   estimate 'ac'  intercept 1 abc 1 0 a 0 1 b 1 0 c 0 1 
                  a*b 0 0 1 0 a*c 0 0 0 1 b*c 0 1 0 0;
   estimate 'bc'  intercept 1 abc 1 0 a 1 0 b 0 1 c 0 1 
                  a*b 0 1 0 0 a*c 0 1 0 0 b*c 0 0 0 1;
   estimate 'abc' intercept 1 abc 0 1 a 0 1 b 0 1 c 0 1 
                  a*b 0 0 0 1 a*c 0 0 0 1 b*c 0 0 0 1;
   ods select Estimates;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 16.9, Edge Slope                        ---*/
data resist; 
   input rep blk a b c edslp;
   datalines;
 1 1 -1 -1 -1 3.6
 1 1 -1  1  1 4.5
 1 1  1 -1  1 4.2
 1 1  1  1 -1 4.0
 1 2 -1 -1  1 5.1
 1 2 -1  1 -1 3.9
 1 2  1 -1 -1 4.5
 1 2  1  1  1 4.9
 2 1 -1 -1 -1 5.2
 2 1 -1  1  1 5.9
 2 1  1 -1  1 5.3
 2 1  1  1 -1 5.2

 2 2 -1 -1  1 5.2
 2 2 -1  1 -1 4.6
 2 2  1 -1 -1 4.7
 2 2  1  1  1 5.2
 3 1 -1  1 -1 4.3
 3 1 -1  1  1 5.1
 3 1  1 -1 -1 4.5
 3 1  1 -1  1 4.6
 3 2 -1 -1 -1 4.8
 3 2 -1 -1  1 5.2
 3 2  1  1 -1 5.2
 3 2  1  1  1 5.9
 4 1 -1 -1  1 5.9
 4 1 -1  1  1 6.4
 4 1  1 -1 -1 5.7
 4 1  1  1 -1 5.6
 4 2 -1 -1 -1 4.3
 4 2 -1  1 -1 4.4
 4 2  1 -1  1 5.3
 4 2  1  1  1 5.6
 5 1 -1 -1  1 4.3
 5 1 -1  1 -1 4.2
 5 1  1 -1  1 4.3
 5 1  1  1 -1 4.4
 5 2 -1 -1 -1 4.5
 5 2 -1  1  1 5.5
 5 2  1 -1 -1 4.6
 5 2  1  1  1 5.2
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.23                                     ---*/
proc glimmix data=resist; 
   class a b c rep blk;
   model edslp = a|b|c / ddfm=kr;
   random rep blk(rep);
   lsmeans a*b b*c / slicediff=(a b c);
   ods select CovParms Tests3 LSMeans SliceDiffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.24                                     ---*/
proc mixed data=resist; 
   class rep blk;
   model edslp = a|b|c / solution ddfm=satterth;
   random rep blk(rep);
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 16.10, Use Products                     ---*/
data prior;
   input blk seq t1 t2 t3 person 
         y11 y12 y13 y21 y22 y23 y31 y32 y33;
   array yy{3,3}  y11-y13 y21-y23 y31-y33;
   array tt{3}  t1-t3;
   array ll{4}  l1-l4;
   do period = 1 to 3;
      prod = tt{period} ;
      do i = 1 to 4;
         ll{i}  = 0;
      end;
      if (period = 1) then priorprd = 0;
      else do;
         priorprd = tt{period - 1} ;
         ll{priorprd}  = 1;
      end;
      do time = 1 to 3;
         y = yy{period,time} ;
         output;
      end;
   end;
   drop i t1-t3 y11-y13 y21-y23 y31-y33;
   datalines;
1    1    1   2   3    101    5    4    3    5    5    5    5    4    4
1    2    1   3   2    102    4    4    3    6    6    6    5    5    4
1    3    2   1   3    103    5    4    4    5    5    4    5    5    5
1    4    2   3   1    104    4    4    4    4    4    4    4    4    4
1    5    3   2   1    105    5    5    5    5    5    5    6    6    5
1    6    3   1   2    106    6    5    5    6    6    5    7    6    6
2    1    1   2   4    201    3    2    1    3    3    3    2    3    3
2    2    1   4   2    202    4    4    3    4    5    5    4    3    3
2    3    2   1   4    203    4    3    3    3    3    2    4    5    5
2    4    2   4   1    204    4    4    3    4    4    4    3    3    2
2    5    4   2   1    205    4    4    4    3    3    2    4    3    3
2    6    4   1   2    206    4    4    4    3    3    2    4    4    4
3    1    1   3   4    301    4    4    3    5    5    5    4    5    5
3    2    1   4   3    302    3    3    3    4    4    4    3    4    3
3    3    3   1   4    303    4    4    4    4    4    3    4    4    4
3    4    3   4   1    304    3    2    2    3    3    3    3    2    2
3    5    4   3   1    305    2    2    2    2    2    2    2    2    1
3    6    4   1   3    306    4    4    4    4    3    2    4    4    4
4    1    2   3   4    401    3    3    3    3    3    3    4    4    4
4    2    2   4   3    402    3    2    2    4    4    4    3    3    3
4    3    3   2   4    403    4    4    4    5    5    4    4    4    4
4    4    3   4   2    404    2    2    2    3    3    3    4    4    3
4    5    4   3   2    405    4    4    4    4    4    4    4    4    4
4    6    4   2   3    406    3    4    3    4    3    4    3    3    3
;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 16.25                                     ---*/
proc mixed data=prior; 
   class blk person seq prod period time priorprd;
   model y=prod period time time*prod priorprd/ddfm=satterth;
   random blk person(blk) period*person(blk);
   lsmeans prod time*prod; 
   estimate 'prod 1 v 2' prod 1 -1 0 0;
   ods select CovParms Tests3 Estimates;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.26                                     ---*/
proc glimmix data=prior; 
   class blk person seq prod period time PRIORPRD;
   model y=prod period time time*prod L1 L2 L3 L4/ ddfm=satterth;
   random blk person(blk) prod*person (blk);
   lsmeans time*prod/slicediff=(time prod);
   ods select CovParms Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.27                                     ---*/
proc glimmix data=prior; 
   class blk person seq prod period time PRIORPRD;
   model y=prod period time time*prod L1 L2 L3 L4/ ddfm=satterth;
   random blk person(blk) prod*person (blk);
   lsmeans time*prod/slicediff=(time prod);
   ods select LSMeans SliceDiffs;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.28                                     ---*/
proc mixed data=prior; 
   class blk person seq prod period time priorprd;
   model y=prod period time time*prod priorprd/ ddfm=satterth;
   random blk person(blk) period(person blk);
   repeated time/subject=period*person(blk) type=ar(1);
   ods select CovParms FitStatistics Tests3;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 16.29                                     ---*/
 /*---Output 16.30                                     ---*/
proc glimmix data=prior; 
   class blk person seq prod period time priorprd;
   model y=prod period time time*prod L1 L2 L3 L4/ ddfm=kr;
   random blk person(blk) period*person (blk);
   random _residual_ / subject=period*person(blk) type=ar(1); 
   lsmeans time*prod / slicediff=(time prod);
   ods select CovParms FitStatistics Tests3 LSMeans SliceDiffs;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Output 16.31                                     ---*/ 
proc mixed data=prior; 
   class blk person seq prod period time priorprd;
   model y=prod period time time*prod priorprd / ddfm=kr;
   random int person / sub=blk;
   random period / type=ar(1) subject=person(blk);
   repeated time / subject=period*person(blk) type=ar(1);
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.32                                     ---*/
 /*---Output 16.33                                     ---*/
proc glimmix data=prior; 
   class blk person seq prod period time priorprd;
   model y=prod period time time*prod L1 L2 L3 L4/ddfm=kr s;
   random int person / sub=blk;
   random period / type=ar(1) subject=person(blk);
   random time / subject=period*person*blk type=ar(1) residual;
   lsmeans time*prod/slicediff=(time prod);
   ods select Tests3 LSMeans SliceDiffs;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 16.4, CD4 Counts                        ---*/
data cd4;
   input randgrp stratum unit @@;
   seq = _n_;
   do visit = 0,2,6,12,18;
      input cd4 @@;
      sqrtcd4 = sqrt(cd4);
      if visit ne 0 then notbase = 1;
      else notbase = 0;
      if visit ne 0 then visitm2 = visit - 2;
      else visitm2 = 0;
      output;
   end;
   datalines;
2   2    2   114      .     71     89      .
1   2    2    40      .     66     21     25
1   2    3    12     13     38      .      .
2   1    3    15     21      7      3      .
1   1    3    53     74     74     45      .
2   1    3    21      .      .      .      .
2   2    3    46     29     20     10      .
1   2    5    12      1      0      .      .
2   1    5     0     33      .      .      .
1   2    5   147    180    111     56      .
2   2    5    47      .      .      .      .
1   2    5   185    262    177     91    138
2   2    5     6     16      6      .      .
1   2    5     4      8      .      .      .
1   1    5   138     97     83     79      .
2   2    5     3      1     26      .      .
2   2    5    43     24     25     25      .

2   2    5    32     29      9      7      .
1   2    5     9      .      .      .      .
2   1    6   363    364    270    279      .
1   2    6    52     29     11      .      .
1   2    6     3      3      2      4      .
1   2    6    15      .      .      .      .
2   2    6   197    255      .    235    206
2   1    6     5      .      .      .      .
1   2    6   295    394    411    291    185
2   2    6    17      .      5      2      3
1   1    6   285      .      .      .      .
1   1    6    21      .      .      .      .
2   2    6    33      .     19      .      .
2   2    6    83    112     31      .      .
1   2    6     3      .      1      .      .
1   1    6    60     43      .      .     12
2   2    6     1      .      2      .      7
1   2    6   157    101     51     47     40
2   2    6     0      .      1      .      .
2   2    6    15      9      5      .      .
1   2    6   280    233      .      .      .
2   2    6   100      .     61     20      .
1   2    6   263    204      .      .      .
2   2    6    22     11      .      2      .
2   2    6    69      .      .      .      .
2   2    6   272      .      .      .      .
1   2    6    21     29     12      .      .
2   1    6     3      .      .      .      .
1   2    6    39     24      7      .      .
2   1    6    16     13      .      .      .
2   1    6     1      2      .      .      .
1   2    6     1      .      .      .      .
1   2    6   190    207    147     16      .
1   2    6     9     20      .      .      .
2   2    6     2      0      .      .      .
2   1    6    13      .      .      .      .
2   1    7   111    187    130     81      .
2   2    7     6     10     23      4      .
2   1    7    48     53     13     20      .
1   2    7    11     32     10      .      .
1   2    7     6      3      3      .      .
2   2    7   130     27     33      .      .
2   1    7     8      .      5      1      .
2   2    7   154    177      .      .      .
2   2    7   271    250    125    169      .
2   1    7   194    307    142     99      .
1   2    7    32     31      6      .      .
1   1    7    15      .      .      .      .
1   1    7    50      .     21      .      .
1   1    7    17      .      6      .      .
1   1    7   192     78     33     11      .
2   1    7     5      .      .      .      .
1   2    7    46     61     79      .      .
2   2    7     4      5      .      .      .
2   2    7   226    187    190    187      .
1   2    7     1      .      .      .      .
1   2    7    21     37      4      8      .
1   1    7   110     66     58      .      .
2   2    7    19     19     16     10      .
2   1    7    14      1      2      .      .
1   2    7    52    137    104    130      .
2   2    7    21     31     32      8      .
2   2    8   120    300    220    272      .
1   2    8     5      5      .      .      .
1   1    8    42     34     15      .      7
1   1    8    50     50      .      .      .
2   2    8    64     15      .      .      .
1   2    8    15     54     45     25      .
1   2    8   242    390    264    332      .
2   1    8    39      2     24      .      .
2   1    8     8     30      3      .      .
2   1    8     4     11      2     21     19
1   2    8   199    203    286    255    183
2   2    8    65     51     46      5     37
1   1    8    45     48     60     61     42
2   2    8   291    314    453    382    273
1   2    8    39     30     21     16      .
2   2    8   115     90    139    141      .
2   2    8   224      .    363    262      .
1   1    8    40     16      .      .      .
2   1    8    40     26     36      .      .
2   2    8    24      .      3      .      .
2   1    8    21     35     28      .      .
1   1    8   176    198     98     22      .
1   1    8     6      2      .      .      .
2   2    8    13    162      .     42      .
2   1    8    15     20     20      .      .
2   2    8    11      5      .      .      .
1   2    8   275    415    284    308      .
1   1    8    50     72     36      .      .
2   1    8     2      .      .      .      .
2   1    8    61      .      .      .      .
1   1    8   274    265      .      .      .
1   1    8    28     42     16      .      .
2   2    8    41     30      .      .      .
1   1    8    54      .      .      .      .
1   2    8     4      4      2      .      .
2   1    8    54     21      .      .      .
2   1    8    29     21      .      .      .
1   1    8   100      .     14     29      .
2   1    8    10      .      .      .      .
1   2    8   156      .     39      .      .
1   2    8     0      .      .      .      .
1   2    8    59     43     61     25      .
2   2    8     6      4      .      .      .
2   2    8    71      .      .      6      .
1   2    8    27      8     13     18      .
2   2    9    15      3      3      4      .
2   2    9    63     30     22      4      .
1   2    9    25    163    113     59      .
1   1    9    14      .      .      .      .
2   2    9    21     15      5      .      .
2   2    9   197    154    135    110     31
1   2    9   130    582      .      .      .
2   2    9    16     37     10      8      .
2   1    9    37     26      0      8      .
1   2    9    10     12      9      .      .
2   2    9    50     40     20     10      .
2   2    9   109     42     18      .      .
1   2    9    89     19     43      9      6
1   2    9    52     15     26      .      .
2   2    9    42     23     30     11     15
1   1    9     7      .      1      .      .
1   2    9    10      0      5      .      .
1   2    9   232    221    166    141      .
2   1    9   117     17      .     55      .
1   2    9   288    268    150    298      .
2   2    9   168    226    129    144      .

2   1    9   169    149     93     45      .
2   2    9    12     16      0      .      .
1   2    9   126    246    153    140      .
1   2    9   136    112      .     86      .
2   2    9     1      3      0      0      .
1   2    9    91     37      .      .      .
2   2    9   280      .    319      .      .
2   2    9   160    115     57     69      .
1   2    9    46     31      8     10      .
1   2    9     5      3      3      7      .
1   1    9     0      .      .      .      .
1   2   10   246    333      .    232    177
1   2   10   224      .    204    141      .
1   2   10   240    360      .    310      .
2   2   10   198    172      .    286      .
2   1   10    66     89     81     18      .
1   1   10    40     15     34      5      .
1   1   10    10     30      .      .      .
1   1   10    30      .      .      .      .
2   2   10   120    160    120    130     80
2   1   10    50      .     20     10      .
1   2   10    47    110     63     20      .
2   1   10    20     10     20      .      .
2   2   10    30     40     95     50      .
2   2   10    80     50     60     10      .
2   1   10    30      4     40     10      .
1   1   10    76    110      .      .      .
2   2   10   250      .    210    220      .
2   2   10    30     40     40    320      .
2   1   10   100     40      .      .      .
2   1   10   140    105      .     89      .
2   1   10    20     20     10     20      .
2   2   10   270    290    220    240      .
1   2   10    40     20     30      .      .
2   2   10   190     90    130     80      .
1   1   10    40      .      .      .      .
1   2   10    40     80     20     20      .
2   2   10    70     40     30      0      .
1   2   10   180    260    160    180      .
1   1   10     0      .     60     70      .
2   2   10   190    280    130    200      .
2   2   10   270    370    360    350      .
1   2   10     7      4      6    287      .
1   2   10   370      .      .      .      .
2   2   10    24      3     11      7      .
1   2   10   144    237    242    119      .
1   1   10    13     27      .     19      .
1   2   10   104    174    194      .      .
2   1   10    25      0      9     23      .
1   2   10   110    250    170     80      .
1   2   10    20      .      .      .      .
2   2   10   130      .      .      .      .
1   2   10   160    230    300    200      .
1   2   10   190    300    150    240      .
2   2   10    20     10      0      4      .
1   1   10     5      0      .      .      .
2   1   11    59      .      .      .      .
1   1   11     5     14      5      .      .
1   2   11    28      .     46      .      .
1   1   12     6      5      .      .      .
2   2   12   107    126     72     14      .
1   1   12    23      .      .      .      .
2   1   12     4      5      4      9      .
1   1   12    32     39     46     30     34
1   2   12   143    154    264    176      .
2   1   12    14      8      .      .      .
2   2   12   273    383    263    369      .
1   1   12    72     20      9      .      .
2   2   12    77     19      .      .      .
1   2   12    95    234    216     98      .
2   1   12    94     53     29      5      .
1   2   12   165      .     35      .      .
1   2   12     6     18      .      .      .
2   2   12   281    207    160     71     62
2   2   12    17     10      .      .      .
1   2   12     7     15     11      .      .
1   2   12   109     92     85      .     68
2   2   12   222    136      .    179      .
1   2   12     6     10      8      5     11
2   2   12    10      8      3      .      .
1   2   12    21     17      8      .      .
1   2   12    10      .      .      .      .
2   1   12     0     21      .      .      .
2   2   12    13      .      .      .      .
2   2   12    14      .      .      .      .
1   2   12     9      .     10     30      .
1   2   12    11      7     14     16      .
2   1   12    53     27      .      .      .
2   2   12   131    129    122     66      .
1   1   12     3      7      .      .      .
1   2   12   216    249     14    139      .
1   1   12     8      7      .      .      .
1   2   12    37     30     21     16      .
2   2   12   200      .    203    209      .
2   2   12    32     57     13      7      .
2   2   12    67     40     32     54      .
2   2   12   235      .    134     53      .
2   2   12    43     55      .      .      .
1   2   12    35     19     11      .      .
1   2   12   228    235     29    294      .
1   2   12   109    124     88      .      .
1   1   12    11      .      .      .      .
2   2   12    82      .      .      .      .
2   1   12   112      9      5      .      .
1   2   12   181    110      .      .      .
2   1   12    76     18     11      7      .
2   1   12   152    168    144     68      .
2   1   12     7      8      5      2      .
2   2   12   230    253     17    170      .
2   1   13     2      3      2      4      .
2   1   13     1      2      1      1      .
2   2   13     9     22      8     11      .
2   2   13   281    300    368    202    130
1   2   13     5      .      .      .      .
2   2   13    12     35     34     14     14
2   2   13   277     84      .      .      .
1   1   13     4      3      1      1      .
2   1   13     2      2      2      2      .
1   2   13   254    284    291    204      .
2   2   13    51     75     78      .      .
1   1   13     6      2      1      .      .
1   2   13    19     27     34     12      .
2   2   13    16     10      3      4      .
1   2   13     2      6      1      1      .
1   2   13     8     12      4      .      .
2   1   14    17      4      7      .      .
1   2   14    11      8      .      5      .
1   2   14    41     52     30      1      .

1   1   14    54     39     23     14     19
1   1   14    16      .     10      2      4
1   2   14    70     35     49     26      .
1   1   14    10      .      .      .      .
2   2   14    10     10      4      .      .
1   1   14     8      9      6      9      .
2   2   14    12      .      6      .      .
2   1   14    10      8      3      7      .
1   2   14    17      3      1      .      .
1   1   14    15      5      1      1      .
1   1   14    31     26     27     12      .
1   2   14    40      9      .      .      .
1   2   14    44     30      .      .      .
2   1   14    40      6      .      .      .
1   1   14    12      .      .      .      .
1   1   14    80     35     47      3      .
1   2   14    99    200    152    191      .
2   1   14     8      .      .      5      .
2   2   14     3      .      .      .      .
2   2   14    34     34     36     13      .
1   2   14    60     33     37     14      .
2   2   14    38     17     12     55      .
2   1   14    31     22     10      .      .
2   1   14    34     13      9      .      .
1   1   14    11     11      3      .      .
1   1   14    77     51     37      .      .
1   2   14     9     21      .      .      .
1   2   14   122    112     77     72      .
2   2   14   273    129    163    154      .
2   1   14    81     52     26      .      .
1   1   14    10      7     14     10      .
2   1   14     4      .      6      .      .
2   1   14    35      .     11      4      .
2   2   14    65     58     22     15      .
2   1   14     7      4      6      .      .
2   2   14   180    238    171     65      .
2   1   14     4      8      3      .      .
2   2   14    93    142      .     15      .
2   2   14   297    122     89     40      .
2   2   14   300    330    290    270    340
2   2   15    13     10      .      .      .
1   1   15     8     15     17     12      8
2   1   15     3      3      8      6      3
1   1   15     7      9      2      .      .
1   1   15   273    152     65     38     21
1   2   15   137    121    146    138      .
2   2   15    42      .      .      .      .
1   1   15     8      .      .      .      .
2   2   15    62      .      .      .      .
1   2   15     3      4      3      4      .
2   1   15    13      7      3      .      .
2   1   15    37     17     20      1      .
2   1   15     6      3      1      .      .
1   2   15   128      .     24     15      .
1   2   15    64     28      .      .      .
1   1   15     2      .      .      .      .
1   2   15   125    147    203    113      .
2   1   15    18     30     22      .      .
2   2   15    21      .      8      7      .
2   2   15    47     56      .      .      .
1   2   15     5      5      4      .      .
2   1   15    11     12      8      .      .
2   2   15   184    138     37      .      .
1   1   15    12      .      .      .      .
2   1   15     7     10      9      4      .
1   2   15    40     29     28     20      .
2   2   15   100    145     88     45      .
1   2   15   113    116    173    126      .
1   2   15    74     56     29     27      .
2   2   15   161    176      .     30      .
2   2   15     5      .      .      .      .
2   2   15    31     24     31      .      .
1   1   15   233    269    182     71      .
1   2   15    63     71     16     16      .
1   1   15   247    289    219      .      .
1   1   15    10     20      .      .      .
2   2   15   291    367    323    267      .
2   2   15    30     41     22     16      .
2   2   15     5      .      .      .      .
1   2   15   108    475    284    151      .
1   2   15    13     15      .      .      .
1   2   15   341      .      .      .      .
1   1   15     6      6      .      .      .
2   1   15     7     12      9      0      .
1   2   16    23     54      .      .      .
1   1   16    27     33     18      5     12
1   2   16    52     48     84     63     20
1   1   16     0      .     15      .      .
2   1   16     0      .      .      .      .
2   2   16     4     10      0      .      .
1   2   16    14      .      .      0      .
2   2   16    48    143      .      .      .
2   2   16    49     77      .     90      .
2   2   16     5      2      .      .      .
1   2   16    63    110     55     26      .
2   1   16     6      0      .      5      .
2   1   16     8      0      .      .      .
2   1   16    10      .      7      .      .
2   2   16   237    306    286    276      .
1   2   16    66     70      .      .      .
2   1   16   155    104      .    184      .
1   2   16   281      .      .      .      .
1   1   16     0      .      .      .      .
2   2   16   201    238    240    418      .
1   1   16     6      0      .      .      .
1   2   17    20     12     12      .      .
2   2   17    27     20     11      .      .
2   2   17   110     57     41      .      .
2   1   17    37     40      .      .      .
2   2   17     3      5      1      .      .
1   2   17   176    207    383    161      .
2   1   17   217     90     97      9      .
2   1   17    84     39      .      .      .
2   2   17    22     14      6      .      .
2   1   17     8     29     16      7      .
1   2   17    80     51      .      .      .
2   1   17   224    194    125      .      .
1   2   17    13     19      .      3      2
2   2   17    96     53      .      .      .
2   1   17    10     17      9      .      .
1   2   17    30      .      .      .      .
2   2   17    57     55      .     11      .
1   1   17     2      3     11      .      .
2   2   17    19      .      .      .      .
1   2   17    39     14     16      .      .
1   2   17   288    323    357    369      .
2   1   17    15     11      3      .      .
1   2   17    43     13      .      .      .

1   1   17    14     14     10      .      .
1   2   17   125      .      .      .      .
1   1   17     7      7      3     11      .
1   2   17    14      9     10      7      .
1   1   17     2      8      .      .      .
2   2   17    11      7      8      0      .
2   2   17     5      7      .      .      .
1   1   17    46     47     35     25      .
2   2   17     3      2      .      .      .
2   2   17   132     90     60     23      .
1   1   17    84     57     54      .      .
1   1   17    26      .      .      .      .
1   2   17   239    200     89     51      .
2   2   17     4      .      .      .      .
2   2   17    29     23     35      .      .
1   2   17    21    113      5      .      .
1   2   17   166      .      .      .      .
1   2   17   273     87    359    285      .
2   2   17   181      .      .      .      .
1   2   17     2      4      2      0      .
2   1   17    28     43     28     28      .
2   2   17    70     60     66     49      .
1   2   17    76    105     40      .      .
2   2   17    78      .      .      .      .
1   2   18    75    132      .      .      .
2   1   18    36      .      .      .      .
2   2   18    12      6     16     13      .
2   1   18    40      .     28      .      .
2   2   18    16     50     17      5      .
2   1   18     5      .      .      .      .
1   1   18     3     12      .      .      .
1   1   18    56     45      9      8      .
2   2   18    66     78     50     32      .
2   2   18    65     96     60     91      .
1   2   18   272    240    234     98      .
2   1   18    60     24     90     76      .
1   2   18   105    272    375    150      .
1   2   18    36     32     42      .      .
2   1   18    24      4      .      .      .
2   1   18   300    270    143    160      .
2   2   18    20     18     10      .      .
2   2   18    13     14      6      7      7
1   2   18    42     20     30     18      .
2   2   18    27     42      6      6      .
1   1   18     7      9     21      .      .
1   2   18    70     63     30      .      .
1   2   18   159     73      .      .      .
1   1   18    14     16      5      .      .
1   1   18   138    140    154    120    126
1   2   18   169    144     84      .      .
2   1   18    40     36      .     10      .
1   1   18    40      .      .      .      .
1   2   18    24     15      5      5      3
2   2   18    21     12     24    102      .
2   2   18     6     24      .      .      .
2   1   18    10     20     14      3      .
1   2   18   190    136      .      .      .
1   2   18   220    400    240      .      .
1   1   18   247    300    220    242      .
1   1   18     9     30     10      .      .
1   1   18     3     21      .      .      .
1   2   18     7     10      6      7      .
2   2   18    24      .      .      .      .
1   1   18    10      6     12      .      .
2   2   18     9     10      .      .      .
2   1   18    30      5      .      .      .
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.34                                     ---*/
proc mixed data=cd4;
   class randgrp stratum unit seq;
   model sqrtcd4 = stratum unit notbase
                   notbase*randgrp notbase*stratum
                   visitm2 visitm2*randgrp visitm2*stratum 
                   / ddfm=kr;
   random int notbase visitm2 / type=un sub=seq g gcorr;
   ods select CovParms FitStatistics G Gcorr Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.35                                     ---*/
proc mixed data=cd4;
   class randgrp stratum unit seq visit;

   model sqrtcd4 = stratum unit notbase 
                   notbase*randgrp notbase*stratum
                   visitm2 visitm2*randgrp visitm2*stratum 
                  / ddfm=kr;
   random int notbase visitm2 / type=un sub=seq;
   repeated visit / sub=seq group=randgrp*stratum;
   ods select CovParms FitStatistics Tests3;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.36                                     ---*/
proc mixed data=cd4;
   class randgrp stratum visit seq;
   model sqrtcd4 = stratum notbase notbase*randgrp 
                   notbase*stratum visitm2 /solution ddfm=kr;
   random int notbase visitm2 / type=un sub=seq g gcorr;
   repeated visit / sub=seq group=randgrp*stratum;
   estimate 'ddI 2   base s 2' 
            notbase 1 notbase*randgrp 1 0 visitm2 0 / cl;
   estimate 'ddC 2   base s 2' 
            notbase 1 notbase*randgrp 0 1 visitm2 0;
   estimate 'ddI 6   base s 2' 

            notbase 1 notbase*randgrp 1 0 visitm2 4;
   estimate 'ddC 6   base s 2' 
            notbase 1 notbase*randgrp 0 1 visitm2 4;
   estimate 'ddI   ddC s 2' notbase*randgrp 1 -1;
   estimate 'ddI 24 s 1' int 1 stratum 1 0 notbase 1 
            notbase*randgrp 1 0 notbase*stratum 1 0 visitm2 22;
   estimate 'ddC 24 s 1' int 1 stratum 1 0 notbase 1 
            notbase*randgrp 0 1 notbase*stratum 1 0 visitm2 22;
   estimate 'ddI 24 s 2' int 1 notbase 1 notbase*randgrp 1 0 
            visitm2 22;
   estimate 'ddC 24 s 2' int 1 notbase 1 notbase*randgrp 0 1 
             visitm2 22;
run;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Figure 16.10                                     ---*/
data cd4x;
   input seq randgrp stratum sqrtcd4 visit notbase;
   if (visit ne 0) then visitm2 = visit - 2;
   else visitm2 = 0;
   datalines;
1000 1 1 .  0 0
1000 1 1 .  2 1
1000 1 1 .  6 1
1000 1 1 . 12 1
1000 1 1 . 18 1
1001 1 2 .  0 0
1001 1 2 .  2 1
1001 1 2 .  6 1
1001 1 2 . 12 1
1001 1 2 . 18 1
1002 2 1 .  0 0
1002 2 1 .  2 1
1002 2 1 .  6 1
1002 2 1 . 12 1
1002 2 1 . 18 1
1003 2 2 .  0 0
1003 2 2 .  2 1
1003 2 2 .  6 1
1003 2 2 . 12 1
1003 2 2 . 18 1
;
proc append base=cd4 data=cd4x;
run;
proc mixed data=cd4;
   class randgrp stratum visit seq;
   model sqrtcd4 = stratum  
         notbase notbase*randgrp notbase*stratum
         visitm2 / ddfm=res outp=p;
   random int notbase visitm2 / type=un sub=seq g gcorr;
   repeated visit / sub=seq group=randgrp*stratum;
   id visit seq;
run;
symbol1 i=join c=green w=1 r=467;
symbol2 i=join c=black w=4 r=4;
proc gplot data=p;
  plot pred*visit=seq / nolegend
                        vaxis=0 to 25 by 5 vminor=0
                        haxis=0 to 18 by 2 hminor=0;
run;
 /*-------------------------------------------------------*/


 /*-------------------------------------------------------*/
 /*---Data Set 16.12, Microarray                       ---*/
data microarray;
   input array dye$ trt row @@;
   input pin @@;
   do dip=1 to 2;
      input gene log_intensity @@;
         output;
   end;
   input pin @@;
   do dip=3 to 4;
     input gene log_intensity @@;
     output;
   end;
   datalines;
1 g 0 1 1 1  0.1907 2 -0.0829 3 1  0.3392 3  0.3193
1 g 0 2 2 3  0.2378 5  0.2329 4 2  0.7002 4  0.5768
1 g 0 3 1 2  0.1554 4 -0.0289 3 3  0.4332 5  0.3022
1 g 0 4 2 5  0.1443 7  0.0782 4 4  0.3772 6  0.2524
1 g 0 5 1 4  0.0174 6  0.0325 3 5  0.3553 7  0.2871
1 g 0 6 2 7 -0.2612 8  0.4427 4 6  0.6877 8  0.4636
1 g 0 7 1 6  0.0052 1 -0.2233 3 7  0.3867 1  0.1974
1 g 0 8 2 8 -0.307  3  0.1465 4 8  0.4864 2  0.308
1 r 1 1 1 1 -0.0668 2 -0.0327 3 1  0.2827 3  0.2519
1 r 1 2 2 3  0.1057 5  0.1137 4 2  0.6827 4  0.1942
1 r 1 3 1 2  0.125  4 -0.1126 3 3  0.1751 5  0.1315
1 r 1 4 2 5 -0.3206 7  0.1833 4 4  0.4353 6  0.4331
1 r 1 5 1 4 -0.1133 6 -0.1678 3 5  0.2912 7 -0.0462
1 r 1 6 2 7 -0.0602 8  0.2357 4 6  0.6294 8  0.2211
1 r 1 7 1 6 -0.1195 1 -0.352  3 7  0.3998 1  0.1125
1 r 1 8 2 8  0.1973 3 -0.002  4 8  0.2742 2  0.6028
2 g 1 1 1 1 -0.0688 2 -0.0833 3 1  0.1697 4 -0.1348
2 g 1 2 2 3 -0.4062 4 -0.4153 4 2 -0.1338 3  0.1829
2 g 1 3 1 2 -0.2492 5 -0.3246 3 4 -0.078  7 -0.0966
2 g 1 4 2 4 -0.4785 7 -0.3383 4 3 -0.2376 5  0.2191
2 g 1 5 1 5 -0.3406 6 -0.0904 3 7 -0.2738 8  0.3622
2 g 1 6 2 7 -0.2332 8 -0.4752 4 5 -0.0378 6  0.124
2 g 1 7 1 6 -0.467  1 -0.2558 3 8 -0.1252 1 -0.0634
2 g 1 8 2 8 -0.2724 3 -0.3642 4 6  0.2625 2 0.1457
2 r 2 1 1 1 -0.2336 2 -0.1691 3 1 -0.191  4 -0.1016
2 r 2 2 2 3 -0.4213 4 -0.1866 4 2  0.1008 3  0.0796
2 r 2 3 1 2 -0.2382 5 -0.3198 3 4 -0.0585 7 -0.0311
2 r 2 4 2 4 -0.4483 7 -0.5769 4 3 -0.1174 5 -0.3397
2 r 2 5 1 5 -0.2762 6 -0.2164 3 7 -0.359  8 -0.0886
2 r 2 6 2 7 -0.5948 8 -0.3436 4 5 -0.2083 6  0.1619
2 r 2 7 1 6 -0.1384 1 -0.2169 3 8 -0.0239 1  0.2815
2 r 2 8 2 8 -0.4022 3 -0.5579 4 6  0.1493 2 -0.0618
3 g 2 1 1 1  0.1867 2  0.4189 3 1  0.046  3 -0.0247
3 g 2 2 2 3  0.4205 4  0.7581 4 2  0.1829 5  0.2073
3 g 2 3 1 2  0.4308 5  0.3575 3 3  0.2484 4  0.1089
3 g 2 4 2 4  0.5159 6  0.7167 4 5  0.3128 7  0.1482
3 g 2 5 1 5  0.3008 7  0.3432 3 4  0.2077 6  0.1775
3 g 2 6 2 6  0.5234 8  0.1952 4 7  0.2487 8  0.295
3 g 2 7 1 7  0.2528 1  0.3054 3 6  0.2741 1 -0.1375
3 g 2 8 2 8  0.5686 3  0.5857 4 8  0.4427 2  0.1475
3 r 3 1 1 1  0.2709 2  0.3207 3 1 -0.0084 3 -0.1043
3 r 3 2 2 3  0.2363 4  0.5667 4 2  0.1772 5 -0.0501
3 r 3 3 1 2  0.6945 5  0.3878 3 3 -0.0911 4  0.0087
3 r 3 4 2 4  0.483  6  0.5148 4 5  0.2867 7 -0.1861
3 r 3 5 1 5  0.3144 7  0.0367 3 4  0.2272 6  0.105
3 r 3 6 2 6  0.8022 8  0.3158 4 7 -0.0186 8 -0.1071
3 r 3 7 1 7  0.0252 1  0.1669 3 6  0.0354 1 -0.0262
3 r 3 8 2 8  0.2114 3  0.0767 4 8  0.2971 2  0.3306
4 g 3 1 1 5 -0.0666 4  0.0908 3 8  0.2564 6  0.2192
4 g 3 2 2 8  0.388  7  0.3491 4 7  0.2873 5  0.482
4 g 3 3 1 4 -0.0118 2  0.2273 3 6  0.263  3  0.2995
4 g 3 4 2 7 -0.0124 6  0.5433 4 5  0.267  4  0.1209
4 g 3 5 1 2  0.1084 1  0.093  3 3 -0.0907 1 -0.0277
4 g 3 6 2 6  0.4487 3  0.316  4 4  0.4768 2  0.1686
4 g 3 7 1 1  0.1208 5  0.116  3 1 -0.0509 8 -0.0348
4 g 3 8 2 3  0.4648 8  0.2003 4 2  0.3766 7  0.1611
4 r 4 1 1 5 -0.1773 4  0.2046 3 8  0.2864 6  0.2656
4 r 4 2 2 8  0.335  7  0.2224 4 7 -0.1175 5  0.187
4 r 4 3 1 4 -0.2345 2  0.261  3 6  0.068  3 -0.1159
4 r 4 4 2 7 -0.0606 6  0.5218 4 5  0.061  4 -0.0182
4 r 4 5 1 2  0.3213 1 -0.2191 3 3  0.0857 1 -0.2704
4 r 4 6 2 6  0.4291 3  0.4206 4 4  0.1548 2  0.3084
4 r 4 7 1 1  0.1591 5 -0.1249 3 1  0.0118 8 -0.2502
4 r 4 8 2 3  0.3317 8  0.3393 4 2  0.3033 7  0.1212
5 g 4 1 1 5  0.5517 4 -0.0644 3 8  0.4244 7  0.4454
5 g 4 2 2 8 -0.3676 7 -0.3789 4 6  0.461  5  0.4221
5 g 4 3 1 4  0.1899 2  0.3064 3 7  0.1654 3  0.4978
5 g 4 4 2 7 -0.2358 6 -0.0055 4 5  0.2014 4  0.1544
5 g 4 5 1 2  0.6772 1  0.1971 3 3  0.183  1  0.3266
5 g 4 6 2 6 -0.0406 3 -0.4498 4 4  0.3124 2  0.5508
5 g 4 7 1 1  0.4595 5  0.2712 3 1  0.591  8  0.337
5 g 4 8 2 3 -0.0274 8 -0.4286 4 2  0.5265 6  0.6042
5 r 5 1 1 5  0.1724 4  0.2798 3 8  0.4042 7  0.5652
5 r 5 2 2 8 -0.4007 7 -0.2172 4 6  0.2638 5  0.472
5 r 5 3 1 4  0.121  2  0.3221 3 7  0.2502 3  0.4138
5 r 5 4 2 7 -0.2406 6 -0.1723 4 5  0.0341 4  0.3078
5 r 5 5 1 2  0.6888 1  0.2805 3 3  0.296  1  0.3515
5 r 5 6 2 6  0.2289 3 -0.5382 4 4 -0.1745 2  0.6739
5 r 5 7 1 1  0.1696 5  0.2032 3 1  0.0848 8  0.1495
5 r 5 8 2 3 -0.2606 8 -0.3536 4 2  0.1644 6  0.3109
6 g 5 1 1 7  0.2351 6  0.5415 3 2  0.3471 8  0.0274
6 g 5 2 2 5  0.0921 4 -0.1718 4 4 -0.2356 5  0.177
6 g 5 3 1 6  0.5824 8  0.1855 3 8 -0.1587 1 -0.3407
6 g 5 4 2 4 -0.1562 3  0.1223 4 5 -0.0096 6  0.4527
6 g 5 5 1 8  0.1985 1  0.0622 3 1 -0.1452 3 -0.0113
6 g 5 6 2 3  0.0961 2  0.2304 4 6  0.5136 7 -0.0875
6 g 5 7 1 1 -0.0128 7  0.1124 3 3 -0.1161 2 -0.0076
6 g 5 8 2 2  0.1381 5  0.0285 4 7  0.1501 4 -0.1956
6 r 0 1 1 7  0.0143 6 -0.0559 3 2 -0.0582 8 -0.2804
6 r 0 2 2 5 -0.1531 4 -0.3912 4 4 -0.2513 5  0.0966
6 r 0 3 1 6  0.2103 8 -0.1462 3 8 -0.0697 1 -0.2384
6 r 0 4 2 4 -0.2152 3  0.0462 4 5  0.0437 6  0.2255
6 r 0 5 1 8  0.0637 1 -0.1448 3 1 -0.294  3 -0.1107
6 r 0 6 2 3 -0.2533 2 -0.1884 4 6  0.0765 7 -0.0643
6 r 0 7 1 1  0.2061 7  0.1384 3 3 -0.1363 2 -0.5183
6 r 0 8 2 2 -0.2306 5  0.0531 4 7 -0.2809 4 -0.2613
;
 /*-------------------------------------------------------*/

 /*-------------------------------------------------------*/
 /*---Output 16.37                                     ---*/
proc glimmix data=microarray;
   class array dye trt gene pin dip;
   model log_intensity = dye trt gene dye*gene 
                         trt*gene pin / ddfm=kr;
   random array array*gene dip(array) pin*array;
   lsmeans trt*gene / slice=gene
                      slicediff=gene
                      slicedifftype=control('0' '2');
run;
 /*-------------------------------------------------------*/



